#line 1 "ad_aarch64.cpp"
//
// Copyright (c) 2003, 2022, Oracle and/or its affiliates. All rights reserved.
// Copyright (c) 2014, 2021, Red Hat, Inc. All rights reserved.
// DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
//
// This code is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License version 2 only, as
// published by the Free Software Foundation.
//
// This code is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// version 2 for more details (a copy is included in the LICENSE file that
// accompanied this code).
//
// You should have received a copy of the GNU General Public License version
// 2 along with this work; if not, write to the Free Software Foundation,
// Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
// or visit www.oracle.com if you need additional information or have any
// questions.
//
//

// Machine Generated File.  Do Not Edit!

#include "precompiled.hpp"
#include "adfiles/adGlobals_aarch64.hpp"
#include "adfiles/ad_aarch64.hpp"
#include "memory/allocation.inline.hpp"
#include "code/codeCache.hpp"
#include "code/compiledIC.hpp"
#include "code/nativeInst.hpp"
#include "code/vmreg.inline.hpp"
#include "gc/shared/collectedHeap.inline.hpp"
#include "oops/compiledICHolder.hpp"
#include "oops/compressedOops.hpp"
#include "oops/markWord.hpp"
#include "oops/method.hpp"
#include "oops/oop.inline.hpp"
#include "opto/c2_MacroAssembler.hpp"
#include "opto/cfgnode.hpp"
#include "opto/intrinsicnode.hpp"
#include "opto/locknode.hpp"
#include "opto/opcodes.hpp"
#include "opto/regalloc.hpp"
#include "opto/regmask.hpp"
#include "opto/runtime.hpp"
#include "runtime/safepointMechanism.hpp"
#include "runtime/sharedRuntime.hpp"
#include "runtime/stubRoutines.hpp"
#include "utilities/growableArray.hpp"
#include "utilities/powerOfTwo.hpp"

//SourceForm

#line 1318 "src/hotspot/cpu/aarch64/aarch64.ad"


  // Derived RegMask with conditionally allocatable registers

  void PhaseOutput::pd_perform_mach_node_analysis() {
  }

  int MachNode::pd_alignment_required() const {
    return 1;
  }

  int MachNode::compute_padding(int current_offset) const {
    return 0;
  }

  RegMask _ANY_REG32_mask;
  RegMask _ANY_REG_mask;
  RegMask _PTR_REG_mask;
  RegMask _NO_SPECIAL_REG32_mask;
  RegMask _NO_SPECIAL_REG_mask;
  RegMask _NO_SPECIAL_PTR_REG_mask;

  void reg_mask_init() {
    // We derive below RegMask(s) from the ones which are auto-generated from
    // adlc register classes to make AArch64 rheapbase (r27) and rfp (r29)
    // registers conditionally reserved.

    _ANY_REG32_mask = _ALL_REG32_mask;
    _ANY_REG32_mask.Remove(OptoReg::as_OptoReg(r31_sp->as_VMReg()));

    _ANY_REG_mask = _ALL_REG_mask;

    _PTR_REG_mask = _ALL_REG_mask;

    _NO_SPECIAL_REG32_mask = _ALL_REG32_mask;
    _NO_SPECIAL_REG32_mask.SUBTRACT(_NON_ALLOCATABLE_REG32_mask);

    _NO_SPECIAL_REG_mask = _ALL_REG_mask;
    _NO_SPECIAL_REG_mask.SUBTRACT(_NON_ALLOCATABLE_REG_mask);

    _NO_SPECIAL_PTR_REG_mask = _ALL_REG_mask;
    _NO_SPECIAL_PTR_REG_mask.SUBTRACT(_NON_ALLOCATABLE_REG_mask);

    // r27 is not allocatable when compressed oops is on and heapbase is not
    // zero, compressed klass pointers doesn't use r27 after JDK-8234794
    if (UseCompressedOops && (CompressedOops::ptrs_base() != NULL)) {
      _NO_SPECIAL_REG32_mask.Remove(OptoReg::as_OptoReg(r27->as_VMReg()));
      _NO_SPECIAL_REG_mask.SUBTRACT(_HEAPBASE_REG_mask);
      _NO_SPECIAL_PTR_REG_mask.SUBTRACT(_HEAPBASE_REG_mask);
    }

    // r29 is not allocatable when PreserveFramePointer is on
    if (PreserveFramePointer) {
      _NO_SPECIAL_REG32_mask.Remove(OptoReg::as_OptoReg(r29->as_VMReg()));
      _NO_SPECIAL_REG_mask.SUBTRACT(_FP_REG_mask);
      _NO_SPECIAL_PTR_REG_mask.SUBTRACT(_FP_REG_mask);
    }
  }

  // Optimizaton of volatile gets and puts
  // -------------------------------------
  //
  // AArch64 has ldar<x> and stlr<x> instructions which we can safely
  // use to implement volatile reads and writes. For a volatile read
  // we simply need
  //
  //   ldar<x>
  //
  // and for a volatile write we need
  //
  //   stlr<x>
  //
  // Alternatively, we can implement them by pairing a normal
  // load/store with a memory barrier. For a volatile read we need
  //
  //   ldr<x>
  //   dmb ishld
  //
  // for a volatile write
  //
  //   dmb ish
  //   str<x>
  //   dmb ish
  //
  // We can also use ldaxr and stlxr to implement compare and swap CAS
  // sequences. These are normally translated to an instruction
  // sequence like the following
  //
  //   dmb      ish
  // retry:
  //   ldxr<x>   rval raddr
  //   cmp       rval rold
  //   b.ne done
  //   stlxr<x>  rval, rnew, rold
  //   cbnz      rval retry
  // done:
  //   cset      r0, eq
  //   dmb ishld
  //
  // Note that the exclusive store is already using an stlxr
  // instruction. That is required to ensure visibility to other
  // threads of the exclusive write (assuming it succeeds) before that
  // of any subsequent writes.
  //
  // The following instruction sequence is an improvement on the above
  //
  // retry:
  //   ldaxr<x>  rval raddr
  //   cmp       rval rold
  //   b.ne done
  //   stlxr<x>  rval, rnew, rold
  //   cbnz      rval retry
  // done:
  //   cset      r0, eq
  //
  // We don't need the leading dmb ish since the stlxr guarantees
  // visibility of prior writes in the case that the swap is
  // successful. Crucially we don't have to worry about the case where
  // the swap is not successful since no valid program should be
  // relying on visibility of prior changes by the attempting thread
  // in the case where the CAS fails.
  //
  // Similarly, we don't need the trailing dmb ishld if we substitute
  // an ldaxr instruction since that will provide all the guarantees we
  // require regarding observation of changes made by other threads
  // before any change to the CAS address observed by the load.
  //
  // In order to generate the desired instruction sequence we need to
  // be able to identify specific 'signature' ideal graph node
  // sequences which i) occur as a translation of a volatile reads or
  // writes or CAS operations and ii) do not occur through any other
  // translation or graph transformation. We can then provide
  // alternative aldc matching rules which translate these node
  // sequences to the desired machine code sequences. Selection of the
  // alternative rules can be implemented by predicates which identify
  // the relevant node sequences.
  //
  // The ideal graph generator translates a volatile read to the node
  // sequence
  //
  //   LoadX[mo_acquire]
  //   MemBarAcquire
  //
  // As a special case when using the compressed oops optimization we
  // may also see this variant
  //
  //   LoadN[mo_acquire]
  //   DecodeN
  //   MemBarAcquire
  //
  // A volatile write is translated to the node sequence
  //
  //   MemBarRelease
  //   StoreX[mo_release] {CardMark}-optional
  //   MemBarVolatile
  //
  // n.b. the above node patterns are generated with a strict
  // 'signature' configuration of input and output dependencies (see
  // the predicates below for exact details). The card mark may be as
  // simple as a few extra nodes or, in a few GC configurations, may
  // include more complex control flow between the leading and
  // trailing memory barriers. However, whatever the card mark
  // configuration these signatures are unique to translated volatile
  // reads/stores -- they will not appear as a result of any other
  // bytecode translation or inlining nor as a consequence of
  // optimizing transforms.
  //
  // We also want to catch inlined unsafe volatile gets and puts and
  // be able to implement them using either ldar<x>/stlr<x> or some
  // combination of ldr<x>/stlr<x> and dmb instructions.
  //
  // Inlined unsafe volatiles puts manifest as a minor variant of the
  // normal volatile put node sequence containing an extra cpuorder
  // membar
  //
  //   MemBarRelease
  //   MemBarCPUOrder
  //   StoreX[mo_release] {CardMark}-optional
  //   MemBarCPUOrder
  //   MemBarVolatile
  //
  // n.b. as an aside, a cpuorder membar is not itself subject to
  // matching and translation by adlc rules.  However, the rule
  // predicates need to detect its presence in order to correctly
  // select the desired adlc rules.
  //
  // Inlined unsafe volatile gets manifest as a slightly different
  // node sequence to a normal volatile get because of the
  // introduction of some CPUOrder memory barriers to bracket the
  // Load. However, but the same basic skeleton of a LoadX feeding a
  // MemBarAcquire, possibly thorugh an optional DecodeN, is still
  // present
  //
  //   MemBarCPUOrder
  //        ||       \\
  //   MemBarCPUOrder LoadX[mo_acquire]
  //        ||            |
  //        ||       {DecodeN} optional
  //        ||       /
  //     MemBarAcquire
  //
  // In this case the acquire membar does not directly depend on the
  // load. However, we can be sure that the load is generated from an
  // inlined unsafe volatile get if we see it dependent on this unique
  // sequence of membar nodes. Similarly, given an acquire membar we
  // can know that it was added because of an inlined unsafe volatile
  // get if it is fed and feeds a cpuorder membar and if its feed
  // membar also feeds an acquiring load.
  //
  // Finally an inlined (Unsafe) CAS operation is translated to the
  // following ideal graph
  //
  //   MemBarRelease
  //   MemBarCPUOrder
  //   CompareAndSwapX {CardMark}-optional
  //   MemBarCPUOrder
  //   MemBarAcquire
  //
  // So, where we can identify these volatile read and write
  // signatures we can choose to plant either of the above two code
  // sequences. For a volatile read we can simply plant a normal
  // ldr<x> and translate the MemBarAcquire to a dmb. However, we can
  // also choose to inhibit translation of the MemBarAcquire and
  // inhibit planting of the ldr<x>, instead planting an ldar<x>.
  //
  // When we recognise a volatile store signature we can choose to
  // plant at a dmb ish as a translation for the MemBarRelease, a
  // normal str<x> and then a dmb ish for the MemBarVolatile.
  // Alternatively, we can inhibit translation of the MemBarRelease
  // and MemBarVolatile and instead plant a simple stlr<x>
  // instruction.
  //
  // when we recognise a CAS signature we can choose to plant a dmb
  // ish as a translation for the MemBarRelease, the conventional
  // macro-instruction sequence for the CompareAndSwap node (which
  // uses ldxr<x>) and then a dmb ishld for the MemBarAcquire.
  // Alternatively, we can elide generation of the dmb instructions
  // and plant the alternative CompareAndSwap macro-instruction
  // sequence (which uses ldaxr<x>).
  //
  // Of course, the above only applies when we see these signature
  // configurations. We still want to plant dmb instructions in any
  // other cases where we may see a MemBarAcquire, MemBarRelease or
  // MemBarVolatile. For example, at the end of a constructor which
  // writes final/volatile fields we will see a MemBarRelease
  // instruction and this needs a 'dmb ish' lest we risk the
  // constructed object being visible without making the
  // final/volatile field writes visible.
  //
  // n.b. the translation rules below which rely on detection of the
  // volatile signatures and insert ldar<x> or stlr<x> are failsafe.
  // If we see anything other than the signature configurations we
  // always just translate the loads and stores to ldr<x> and str<x>
  // and translate acquire, release and volatile membars to the
  // relevant dmb instructions.
  //

  // is_CAS(int opcode, bool maybe_volatile)
  //
  // return true if opcode is one of the possible CompareAndSwapX
  // values otherwise false.

  bool is_CAS(int opcode, bool maybe_volatile)
  {
    switch(opcode) {
      // We handle these
    case Op_CompareAndSwapI:
    case Op_CompareAndSwapL:
    case Op_CompareAndSwapP:
    case Op_CompareAndSwapN:
    case Op_ShenandoahCompareAndSwapP:
    case Op_ShenandoahCompareAndSwapN:
    case Op_CompareAndSwapB:
    case Op_CompareAndSwapS:
    case Op_GetAndSetI:
    case Op_GetAndSetL:
    case Op_GetAndSetP:
    case Op_GetAndSetN:
    case Op_GetAndAddI:
    case Op_GetAndAddL:
      return true;
    case Op_CompareAndExchangeI:
    case Op_CompareAndExchangeN:
    case Op_CompareAndExchangeB:
    case Op_CompareAndExchangeS:
    case Op_CompareAndExchangeL:
    case Op_CompareAndExchangeP:
    case Op_WeakCompareAndSwapB:
    case Op_WeakCompareAndSwapS:
    case Op_WeakCompareAndSwapI:
    case Op_WeakCompareAndSwapL:
    case Op_WeakCompareAndSwapP:
    case Op_WeakCompareAndSwapN:
    case Op_ShenandoahWeakCompareAndSwapP:
    case Op_ShenandoahWeakCompareAndSwapN:
    case Op_ShenandoahCompareAndExchangeP:
    case Op_ShenandoahCompareAndExchangeN:
      return maybe_volatile;
    default:
      return false;
    }
  }

  // helper to determine the maximum number of Phi nodes we may need to
  // traverse when searching from a card mark membar for the merge mem
  // feeding a trailing membar or vice versa

// predicates controlling emit of ldr<x>/ldar<x>

bool unnecessary_acquire(const Node *barrier)
{
  assert(barrier->is_MemBar(), "expecting a membar");

  MemBarNode* mb = barrier->as_MemBar();

  if (mb->trailing_load()) {
    return true;
  }

  if (mb->trailing_load_store()) {
    Node* load_store = mb->in(MemBarNode::Precedent);
    assert(load_store->is_LoadStore(), "unexpected graph shape");
    return is_CAS(load_store->Opcode(), true);
  }

  return false;
}

bool needs_acquiring_load(const Node *n)
{
  assert(n->is_Load(), "expecting a load");
  LoadNode *ld = n->as_Load();
  return ld->is_acquire();
}

bool unnecessary_release(const Node *n)
{
  assert((n->is_MemBar() &&
          n->Opcode() == Op_MemBarRelease),
         "expecting a release membar");

  MemBarNode *barrier = n->as_MemBar();
  if (!barrier->leading()) {
    return false;
  } else {
    Node* trailing = barrier->trailing_membar();
    MemBarNode* trailing_mb = trailing->as_MemBar();
    assert(trailing_mb->trailing(), "Not a trailing membar?");
    assert(trailing_mb->leading_membar() == n, "inconsistent leading/trailing membars");

    Node* mem = trailing_mb->in(MemBarNode::Precedent);
    if (mem->is_Store()) {
      assert(mem->as_Store()->is_release(), "");
      assert(trailing_mb->Opcode() == Op_MemBarVolatile, "");
      return true;
    } else {
      assert(mem->is_LoadStore(), "");
      assert(trailing_mb->Opcode() == Op_MemBarAcquire, "");
      return is_CAS(mem->Opcode(), true);
    }
  }
  return false;
}

bool unnecessary_volatile(const Node *n)
{
  // assert n->is_MemBar();
  MemBarNode *mbvol = n->as_MemBar();

  bool release = mbvol->trailing_store();
  assert(!release || (mbvol->in(MemBarNode::Precedent)->is_Store() && mbvol->in(MemBarNode::Precedent)->as_Store()->is_release()), "");
#ifdef ASSERT
  if (release) {
    Node* leading = mbvol->leading_membar();
    assert(leading->Opcode() == Op_MemBarRelease, "");
    assert(leading->as_MemBar()->leading_store(), "");
    assert(leading->as_MemBar()->trailing_membar() == mbvol, "");
  }
#endif

  return release;
}

// predicates controlling emit of str<x>/stlr<x>

bool needs_releasing_store(const Node *n)
{
  // assert n->is_Store();
  StoreNode *st = n->as_Store();
  return st->trailing_membar() != NULL;
}

// predicate controlling translation of CAS
//
// returns true if CAS needs to use an acquiring load otherwise false

bool needs_acquiring_load_exclusive(const Node *n)
{
  assert(is_CAS(n->Opcode(), true), "expecting a compare and swap");
  LoadStoreNode* ldst = n->as_LoadStore();
  if (is_CAS(n->Opcode(), false)) {
    assert(ldst->trailing_membar() != NULL, "expected trailing membar");
  } else {
    return ldst->trailing_membar() != NULL;
  }

  // so we can just return true here
  return true;
}

#define __ _masm.

// advance declarations for helper functions to convert register
// indices to register objects

// the ad file has to provide implementations of certain methods
// expected by the generic code
//
// REQUIRED FUNCTIONALITY

//=============================================================================

// !!!!! Special hack to get all types of calls to specify the byte offset
//       from the start of the call to the point where the return address
//       will point.

int MachCallStaticJavaNode::ret_addr_offset()
{
  // call should be a simple bl
  int off = 4;
  return off;
}

int MachCallDynamicJavaNode::ret_addr_offset()
{
  return 16; // movz, movk, movk, bl
}

int MachCallRuntimeNode::ret_addr_offset() {
  // for generated stubs the call will be
  //   bl(addr)
  // or with far branches
  //   bl(trampoline_stub)
  // for real runtime callouts it will be six instructions
  // see aarch64_enc_java_to_runtime
  //   adr(rscratch2, retaddr)
  //   lea(rscratch1, RuntimeAddress(addr)
  //   stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)))
  //   blr(rscratch1)
  CodeBlob *cb = CodeCache::find_blob(_entry_point);
  if (cb) {
    return 1 * NativeInstruction::instruction_size;
  } else {
    return 6 * NativeInstruction::instruction_size;
  }
}

int MachCallNativeNode::ret_addr_offset() {
  // This is implemented using aarch64_enc_java_to_runtime as above.
  CodeBlob *cb = CodeCache::find_blob(_entry_point);
  if (cb) {
    return 1 * NativeInstruction::instruction_size;
  } else {
    return 6 * NativeInstruction::instruction_size;
  }
}

//=============================================================================

#ifndef PRODUCT
void MachBreakpointNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  st->print("BREAKPOINT");
}
#endif

void MachBreakpointNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  C2_MacroAssembler _masm(&cbuf);
  __ brk(0);
}

uint MachBreakpointNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_);
}

//=============================================================================

#ifndef PRODUCT
  void MachNopNode::format(PhaseRegAlloc*, outputStream* st) const {
    st->print("nop \t# %d bytes pad for loops and calls", _count);
  }
#endif

  void MachNopNode::emit(CodeBuffer &cbuf, PhaseRegAlloc*) const {
    C2_MacroAssembler _masm(&cbuf);
    for (int i = 0; i < _count; i++) {
      __ nop();
    }
  }

  uint MachNopNode::size(PhaseRegAlloc*) const {
    return _count * NativeInstruction::instruction_size;
  }

//=============================================================================
const RegMask& MachConstantBaseNode::_out_RegMask = RegMask::Empty;

int ConstantTable::calculate_table_base_offset() const {
  return 0;  // absolute addressing, no offset
}

bool MachConstantBaseNode::requires_postalloc_expand() const { return false; }
void MachConstantBaseNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  ShouldNotReachHere();
}

void MachConstantBaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  // Empty encoding
}

uint MachConstantBaseNode::size(PhaseRegAlloc* ra_) const {
  return 0;
}

#ifndef PRODUCT
void MachConstantBaseNode::format(PhaseRegAlloc* ra_, outputStream* st) const {
  st->print("-- \t// MachConstantBaseNode (empty encoding)");
}
#endif

#ifndef PRODUCT
void MachPrologNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  Compile* C = ra_->C;

  int framesize = C->output()->frame_slots() << LogBytesPerInt;

  if (C->output()->need_stack_bang(framesize))
    st->print("# stack bang size=%d\n\t", framesize);

  if (framesize < ((1 << 9) + 2 * wordSize)) {
    st->print("sub  sp, sp, #%d\n\t", framesize);
    st->print("stp  rfp, lr, [sp, #%d]", framesize - 2 * wordSize);
    if (PreserveFramePointer) st->print("\n\tadd  rfp, sp, #%d", framesize - 2 * wordSize);
  } else {
    st->print("stp  lr, rfp, [sp, #%d]!\n\t", -(2 * wordSize));
    if (PreserveFramePointer) st->print("mov  rfp, sp\n\t");
    st->print("mov  rscratch1, #%d\n\t", framesize - 2 * wordSize);
    st->print("sub  sp, sp, rscratch1");
  }
  if (C->stub_function() == NULL && BarrierSet::barrier_set()->barrier_set_nmethod() != NULL) {
    st->print("\n\t");
    st->print("ldr  rscratch1, [guard]\n\t");
    st->print("dmb ishld\n\t");
    st->print("ldr  rscratch2, [rthread, #thread_disarmed_offset]\n\t");
    st->print("cmp  rscratch1, rscratch2\n\t");
    st->print("b.eq skip");
    st->print("\n\t");
    st->print("blr #nmethod_entry_barrier_stub\n\t");
    st->print("b skip\n\t");
    st->print("guard: int\n\t");
    st->print("\n\t");
    st->print("skip:\n\t");
  }
}
#endif

void MachPrologNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile* C = ra_->C;
  C2_MacroAssembler _masm(&cbuf);

  // n.b. frame size includes space for return pc and rfp
  const int framesize = C->output()->frame_size_in_bytes();

  // insert a nop at the start of the prolog so we can patch in a
  // branch if we need to invalidate the method later
  __ nop();

  if (C->clinit_barrier_on_entry()) {
    assert(!C->method()->holder()->is_not_initialized(), "initialization should have been started");

    Label L_skip_barrier;

    __ mov_metadata(rscratch2, C->method()->holder()->constant_encoding());
    __ clinit_barrier(rscratch2, rscratch1, &L_skip_barrier);
    __ far_jump(RuntimeAddress(SharedRuntime::get_handle_wrong_method_stub()));
    __ bind(L_skip_barrier);
  }

  if (C->max_vector_size() > 0) {
    __ reinitialize_ptrue();
  }

  int bangsize = C->output()->bang_size_in_bytes();
  if (C->output()->need_stack_bang(bangsize))
    __ generate_stack_overflow_check(bangsize);

  __ build_frame(framesize);

  if (C->stub_function() == NULL) {
    BarrierSetAssembler* bs = BarrierSet::barrier_set()->barrier_set_assembler();
    bs->nmethod_entry_barrier(&_masm);
  }

  if (VerifyStackAtCalls) {
    Unimplemented();
  }

  C->output()->set_frame_complete(cbuf.insts_size());

  if (C->has_mach_constant_base_node()) {
    // NOTE: We set the table base offset here because users might be
    // emitted before MachConstantBaseNode.
    ConstantTable& constant_table = C->output()->constant_table();
    constant_table.set_table_base_offset(constant_table.calculate_table_base_offset());
  }
}

uint MachPrologNode::size(PhaseRegAlloc* ra_) const
{
  return MachNode::size(ra_); // too many variables; just compute it
                              // the hard way
}

int MachPrologNode::reloc() const
{
  return 0;
}

//=============================================================================

#ifndef PRODUCT
void MachEpilogNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  Compile* C = ra_->C;
  int framesize = C->output()->frame_slots() << LogBytesPerInt;

  st->print("# pop frame %d\n\t",framesize);

  if (framesize == 0) {
    st->print("ldp  lr, rfp, [sp],#%d\n\t", (2 * wordSize));
  } else if (framesize < ((1 << 9) + 2 * wordSize)) {
    st->print("ldp  lr, rfp, [sp,#%d]\n\t", framesize - 2 * wordSize);
    st->print("add  sp, sp, #%d\n\t", framesize);
  } else {
    st->print("mov  rscratch1, #%d\n\t", framesize - 2 * wordSize);
    st->print("add  sp, sp, rscratch1\n\t");
    st->print("ldp  lr, rfp, [sp],#%d\n\t", (2 * wordSize));
  }

  if (do_polling() && C->is_method_compilation()) {
    st->print("# test polling word\n\t");
    st->print("ldr  rscratch1, [rthread],#%d\n\t", in_bytes(JavaThread::polling_word_offset()));
    st->print("cmp  sp, rscratch1\n\t");
    st->print("bhi #slow_path");
  }
}
#endif

void MachEpilogNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile* C = ra_->C;
  C2_MacroAssembler _masm(&cbuf);
  int framesize = C->output()->frame_slots() << LogBytesPerInt;

  __ remove_frame(framesize);

  if (StackReservedPages > 0 && C->has_reserved_stack_access()) {
    __ reserved_stack_check();
  }

  if (do_polling() && C->is_method_compilation()) {
    Label dummy_label;
    Label* code_stub = &dummy_label;
    if (!C->output()->in_scratch_emit_size()) {
      code_stub = &C->output()->safepoint_poll_table()->add_safepoint(__ offset());
    }
    __ relocate(relocInfo::poll_return_type);
    __ safepoint_poll(*code_stub, true /* at_return */, false /* acquire */, true /* in_nmethod */);
  }
}

uint MachEpilogNode::size(PhaseRegAlloc *ra_) const {
  // Variable size. Determine dynamically.
  return MachNode::size(ra_);
}

int MachEpilogNode::reloc() const {
  // Return number of relocatable values contained in this instruction.
  return 1; // 1 for polling page.
}

const Pipeline * MachEpilogNode::pipeline() const {
  return MachNode::pipeline_class();
}

//=============================================================================

// Figure out which register class each belongs in: rc_int, rc_float or
// rc_stack.
enum RC { rc_bad, rc_int, rc_float, rc_predicate, rc_stack };

static enum RC rc_class(OptoReg::Name reg) {

  if (reg == OptoReg::Bad) {
    return rc_bad;
  }

  // we have 32 int registers * 2 halves
  int slots_of_int_registers = RegisterImpl::max_slots_per_register * RegisterImpl::number_of_registers;

  if (reg < slots_of_int_registers) {
    return rc_int;
  }

  // we have 32 float register * 8 halves
  int slots_of_float_registers = FloatRegisterImpl::max_slots_per_register * FloatRegisterImpl::number_of_registers;
  if (reg < slots_of_int_registers + slots_of_float_registers) {
    return rc_float;
  }

  int slots_of_predicate_registers = PRegisterImpl::max_slots_per_register * PRegisterImpl::number_of_registers;
  if (reg < slots_of_int_registers + slots_of_float_registers + slots_of_predicate_registers) {
    return rc_predicate;
  }

  // Between predicate regs & stack is the flags.
  assert(OptoReg::is_stack(reg), "blow up if spilling flags");

  return rc_stack;
}

uint MachSpillCopyNode::implementation(CodeBuffer *cbuf, PhaseRegAlloc *ra_, bool do_size, outputStream *st) const {
  Compile* C = ra_->C;

  // Get registers to move.
  OptoReg::Name src_hi = ra_->get_reg_second(in(1));
  OptoReg::Name src_lo = ra_->get_reg_first(in(1));
  OptoReg::Name dst_hi = ra_->get_reg_second(this);
  OptoReg::Name dst_lo = ra_->get_reg_first(this);

  enum RC src_hi_rc = rc_class(src_hi);
  enum RC src_lo_rc = rc_class(src_lo);
  enum RC dst_hi_rc = rc_class(dst_hi);
  enum RC dst_lo_rc = rc_class(dst_lo);

  assert(src_lo != OptoReg::Bad && dst_lo != OptoReg::Bad, "must move at least 1 register");

  if (src_hi != OptoReg::Bad && !bottom_type()->isa_vectmask()) {
    assert((src_lo&1)==0 && src_lo+1==src_hi &&
           (dst_lo&1)==0 && dst_lo+1==dst_hi,
           "expected aligned-adjacent pairs");
  }

  if (src_lo == dst_lo && src_hi == dst_hi) {
    return 0;            // Self copy, no move.
  }

  bool is64 = (src_lo & 1) == 0 && src_lo + 1 == src_hi &&
              (dst_lo & 1) == 0 && dst_lo + 1 == dst_hi;
  int src_offset = ra_->reg2offset(src_lo);
  int dst_offset = ra_->reg2offset(dst_lo);

  if (bottom_type()->isa_vect() && !bottom_type()->isa_vectmask()) {
    uint ireg = ideal_reg();
    if (ireg == Op_VecA && cbuf) {
      C2_MacroAssembler _masm(cbuf);
      int sve_vector_reg_size_in_bytes = Matcher::scalable_vector_reg_size(T_BYTE);
      if (src_lo_rc == rc_stack && dst_lo_rc == rc_stack) {
        // stack->stack
        __ spill_copy_sve_vector_stack_to_stack(src_offset, dst_offset,
                                                sve_vector_reg_size_in_bytes);
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_stack) {
        __ spill_sve_vector(as_FloatRegister(Matcher::_regEncode[src_lo]), ra_->reg2offset(dst_lo),
                            sve_vector_reg_size_in_bytes);
      } else if (src_lo_rc == rc_stack && dst_lo_rc == rc_float) {
        __ unspill_sve_vector(as_FloatRegister(Matcher::_regEncode[dst_lo]), ra_->reg2offset(src_lo),
                              sve_vector_reg_size_in_bytes);
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_float) {
        __ sve_orr(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                   as_FloatRegister(Matcher::_regEncode[src_lo]),
                   as_FloatRegister(Matcher::_regEncode[src_lo]));
      } else {
        ShouldNotReachHere();
      }
    } else if (cbuf) {
      assert(ireg == Op_VecD || ireg == Op_VecX, "must be 64 bit or 128 bit vector");
      C2_MacroAssembler _masm(cbuf);
      assert((src_lo_rc != rc_int && dst_lo_rc != rc_int), "sanity");
      if (src_lo_rc == rc_stack && dst_lo_rc == rc_stack) {
        // stack->stack
        assert((src_offset & 7) == 0 && (dst_offset & 7) == 0, "unaligned stack offset");
        if (ireg == Op_VecD) {
          __ unspill(rscratch1, true, src_offset);
          __ spill(rscratch1, true, dst_offset);
        } else {
          __ spill_copy128(src_offset, dst_offset);
        }
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_float) {
        __ mov(as_FloatRegister(Matcher::_regEncode[dst_lo]),
               ireg == Op_VecD ? __ T8B : __ T16B,
               as_FloatRegister(Matcher::_regEncode[src_lo]));
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_stack) {
        __ spill(as_FloatRegister(Matcher::_regEncode[src_lo]),
                 ireg == Op_VecD ? __ D : __ Q,
                 ra_->reg2offset(dst_lo));
      } else if (src_lo_rc == rc_stack && dst_lo_rc == rc_float) {
        __ unspill(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                   ireg == Op_VecD ? __ D : __ Q,
                   ra_->reg2offset(src_lo));
      } else {
        ShouldNotReachHere();
      }
    }
  } else if (cbuf) {
    C2_MacroAssembler _masm(cbuf);
    switch (src_lo_rc) {
    case rc_int:
      if (dst_lo_rc == rc_int) {  // gpr --> gpr copy
        if (is64) {
            __ mov(as_Register(Matcher::_regEncode[dst_lo]),
                   as_Register(Matcher::_regEncode[src_lo]));
        } else {
            C2_MacroAssembler _masm(cbuf);
            __ movw(as_Register(Matcher::_regEncode[dst_lo]),
                    as_Register(Matcher::_regEncode[src_lo]));
        }
      } else if (dst_lo_rc == rc_float) { // gpr --> fpr copy
        if (is64) {
            __ fmovd(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_Register(Matcher::_regEncode[src_lo]));
        } else {
            __ fmovs(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_Register(Matcher::_regEncode[src_lo]));
        }
      } else {                    // gpr --> stack spill
        assert(dst_lo_rc == rc_stack, "spill to bad register class");
        __ spill(as_Register(Matcher::_regEncode[src_lo]), is64, dst_offset);
      }
      break;
    case rc_float:
      if (dst_lo_rc == rc_int) {  // fpr --> gpr copy
        if (is64) {
            __ fmovd(as_Register(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        } else {
            __ fmovs(as_Register(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        }
      } else if (dst_lo_rc == rc_float) { // fpr --> fpr copy
        if (is64) {
            __ fmovd(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        } else {
            __ fmovs(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        }
      } else {                    // fpr --> stack spill
        assert(dst_lo_rc == rc_stack, "spill to bad register class");
        __ spill(as_FloatRegister(Matcher::_regEncode[src_lo]),
                 is64 ? __ D : __ S, dst_offset);
      }
      break;
    case rc_stack:
      if (dst_lo_rc == rc_int) {  // stack --> gpr load
        __ unspill(as_Register(Matcher::_regEncode[dst_lo]), is64, src_offset);
      } else if (dst_lo_rc == rc_float) { // stack --> fpr load
        __ unspill(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                   is64 ? __ D : __ S, src_offset);
      } else if (dst_lo_rc == rc_predicate) {
        __ unspill_sve_predicate(as_PRegister(Matcher::_regEncode[dst_lo]), ra_->reg2offset(src_lo),
                                 Matcher::scalable_vector_reg_size(T_BYTE) >> 3);
      } else {                    // stack --> stack copy
        assert(dst_lo_rc == rc_stack, "spill to bad register class");
        if (ideal_reg() == Op_RegVectMask) {
          __ spill_copy_sve_predicate_stack_to_stack(src_offset, dst_offset,
                                                     Matcher::scalable_vector_reg_size(T_BYTE) >> 3);
        } else {
          __ unspill(rscratch1, is64, src_offset);
          __ spill(rscratch1, is64, dst_offset);
        }
      }
      break;
    case rc_predicate:
      if (dst_lo_rc == rc_predicate) {
        __ sve_mov(as_PRegister(Matcher::_regEncode[dst_lo]), as_PRegister(Matcher::_regEncode[src_lo]));
      } else if (dst_lo_rc == rc_stack) {
        __ spill_sve_predicate(as_PRegister(Matcher::_regEncode[src_lo]), ra_->reg2offset(dst_lo),
                               Matcher::scalable_vector_reg_size(T_BYTE) >> 3);
      } else {
        assert(false, "bad src and dst rc_class combination.");
        ShouldNotReachHere();
      }
      break;
    default:
      assert(false, "bad rc_class for spill");
      ShouldNotReachHere();
    }
  }

  if (st) {
    st->print("spill ");
    if (src_lo_rc == rc_stack) {
      st->print("[sp, #%d] -> ", ra_->reg2offset(src_lo));
    } else {
      st->print("%s -> ", Matcher::regName[src_lo]);
    }
    if (dst_lo_rc == rc_stack) {
      st->print("[sp, #%d]", ra_->reg2offset(dst_lo));
    } else {
      st->print("%s", Matcher::regName[dst_lo]);
    }
    if (bottom_type()->isa_vect() && !bottom_type()->isa_vectmask()) {
      int vsize = 0;
      switch (ideal_reg()) {
      case Op_VecD:
        vsize = 64;
        break;
      case Op_VecX:
        vsize = 128;
        break;
      case Op_VecA:
        vsize = Matcher::scalable_vector_reg_size(T_BYTE) * 8;
        break;
      default:
        assert(false, "bad register type for spill");
        ShouldNotReachHere();
      }
      st->print("\t# vector spill size = %d", vsize);
    } else if (ideal_reg() == Op_RegVectMask) {
      assert(Matcher::supports_scalable_vector(), "bad register type for spill");
      int vsize = Matcher::scalable_predicate_reg_slots() * 32;
      st->print("\t# predicate spill size = %d", vsize);
    } else {
      st->print("\t# spill size = %d", is64 ? 64 : 32);
    }
  }

  return 0;

}

#ifndef PRODUCT
void MachSpillCopyNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  if (!ra_)
    st->print("N%d = SpillCopy(N%d)", _idx, in(1)->_idx);
  else
    implementation(NULL, ra_, false, st);
}
#endif

void MachSpillCopyNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  implementation(&cbuf, ra_, false, NULL);
}

uint MachSpillCopyNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_);
}

//=============================================================================

#ifndef PRODUCT
void BoxLockNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg = ra_->get_reg_first(this);
  st->print("add %s, rsp, #%d]\t# box lock",
            Matcher::regName[reg], offset);
}
#endif

void BoxLockNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  C2_MacroAssembler _masm(&cbuf);

  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg    = ra_->get_encode(this);

  // This add will handle any 24-bit signed offset. 24 bits allows an
  // 8 megabyte stack frame.
  __ add(as_Register(reg), sp, offset);
}

uint BoxLockNode::size(PhaseRegAlloc *ra_) const {
  // BoxLockNode is not a MachNode, so we can't just call MachNode::size(ra_).
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());

  if (Assembler::operand_valid_for_add_sub_immediate(offset)) {
    return NativeInstruction::instruction_size;
  } else {
    return 2 * NativeInstruction::instruction_size;
  }
}

//=============================================================================

#ifndef PRODUCT
void MachUEPNode::format(PhaseRegAlloc* ra_, outputStream* st) const
{
  st->print_cr("# MachUEPNode");
  if (UseCompressedClassPointers) {
    st->print_cr("\tldrw rscratch1, j_rarg0 + oopDesc::klass_offset_in_bytes()]\t# compressed klass");
    if (CompressedKlassPointers::shift() != 0) {
      st->print_cr("\tdecode_klass_not_null rscratch1, rscratch1");
    }
  } else {
   st->print_cr("\tldr rscratch1, j_rarg0 + oopDesc::klass_offset_in_bytes()]\t# compressed klass");
  }
  st->print_cr("\tcmp r0, rscratch1\t # Inline cache check");
  st->print_cr("\tbne, SharedRuntime::_ic_miss_stub");
}
#endif

void MachUEPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const
{
  // This is the unverified entry point.
  C2_MacroAssembler _masm(&cbuf);

  __ cmp_klass(j_rarg0, rscratch2, rscratch1);
  Label skip;
  // TODO
  // can we avoid this skip and still use a reloc?
  __ br(Assembler::EQ, skip);
  __ far_jump(RuntimeAddress(SharedRuntime::get_ic_miss_stub()));
  __ bind(skip);
}

uint MachUEPNode::size(PhaseRegAlloc* ra_) const
{
  return MachNode::size(ra_);
}

// REQUIRED EMIT CODE

//=============================================================================

// Emit exception handler code.
int HandlerImpl::emit_exception_handler(CodeBuffer& cbuf)
{
  // mov rscratch1 #exception_blob_entry_point
  // br rscratch1
  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a handler.
  C2_MacroAssembler _masm(&cbuf);
  address base = __ start_a_stub(size_exception_handler());
  if (base == NULL) {
    ciEnv::current()->record_failure("CodeCache is full");
    return 0;  // CodeBuffer::expand failed
  }
  int offset = __ offset();
  __ far_jump(RuntimeAddress(OptoRuntime::exception_blob()->entry_point()));
  assert(__ offset() - offset <= (int) size_exception_handler(), "overflow");
  __ end_a_stub();
  return offset;
}

// Emit deopt handler code.
int HandlerImpl::emit_deopt_handler(CodeBuffer& cbuf)
{
  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a handler.
  C2_MacroAssembler _masm(&cbuf);
  address base = __ start_a_stub(size_deopt_handler());
  if (base == NULL) {
    ciEnv::current()->record_failure("CodeCache is full");
    return 0;  // CodeBuffer::expand failed
  }
  int offset = __ offset();

  __ adr(lr, __ pc());
  __ far_jump(RuntimeAddress(SharedRuntime::deopt_blob()->unpack()));

  assert(__ offset() - offset <= (int) size_deopt_handler(), "overflow");
  __ end_a_stub();
  return offset;
}

// REQUIRED MATCHER CODE

//=============================================================================

const bool Matcher::match_rule_supported(int opcode) {
  if (!has_match_rule(opcode))
    return false;

  bool ret_value = true;
  switch (opcode) {
    case Op_OnSpinWait:
      return VM_Version::supports_on_spin_wait();
    case Op_CacheWB:
    case Op_CacheWBPreSync:
    case Op_CacheWBPostSync:
      if (!VM_Version::supports_data_cache_line_flush()) {
        ret_value = false;
      }
      break;
    case Op_LoadVectorMasked:
    case Op_StoreVectorMasked:
    case Op_LoadVectorGatherMasked:
    case Op_StoreVectorScatterMasked:
    case Op_MaskAll:
    case Op_AndVMask:
    case Op_OrVMask:
    case Op_XorVMask:
      if (UseSVE == 0) {
        ret_value = false;
      }
      break;
  }

  return ret_value; // Per default match rules are supported.
}

// Identify extra cases that we might want to provide match rules for vector nodes and
// other intrinsics guarded with vector length (vlen) and element type (bt).
const bool Matcher::match_rule_supported_vector(int opcode, int vlen, BasicType bt) {
  if (!match_rule_supported(opcode)) {
    return false;
  }
  int bit_size = vlen * type2aelembytes(bt) * 8;
  if (UseSVE == 0 && bit_size > 128) {
    return false;
  }
  if (UseSVE > 0) {
    return op_sve_supported(opcode, vlen, bt);
  } else { // NEON
    // Special cases
    switch (opcode) {
    case Op_VectorMaskCmp:
      if (vlen < 2 || bit_size < 64) {
        return false;
      }
      break;
    case Op_MulAddVS2VI:
      if (bit_size < 128) {
        return false;
      }
      break;
    case Op_MulVL:
      return false;
    case Op_VectorLoadShuffle:
    case Op_VectorRearrange:
      if (vlen < 4) {
        return false;
      }
      break;
    case Op_LoadVectorGather:
    case Op_StoreVectorScatter:
      return false;
    default:
      break;
    }
  }
  return vector_size_supported(bt, vlen);
}

const bool Matcher::match_rule_supported_vector_masked(int opcode, int vlen, BasicType bt) {
  // Only SVE supports masked operations.
  if (UseSVE == 0) {
    return false;
  }
  return match_rule_supported(opcode) &&
         masked_op_sve_supported(opcode, vlen, bt);
}

const RegMask* Matcher::predicate_reg_mask(void) {
  return &_PR_REG_mask;
}

const TypeVectMask* Matcher::predicate_reg_type(const Type* elemTy, int length) {
  return new TypeVectMask(elemTy, length);
}

// Vector calling convention not yet implemented.
const bool Matcher::supports_vector_calling_convention(void) {
  return false;
}

OptoRegPair Matcher::vector_return_value(uint ideal_reg) {
  Unimplemented();
  return OptoRegPair(0, 0);
}

// Is this branch offset short enough that a short branch can be used?
//
// NOTE: If the platform does not provide any short branch variants, then
//       this method should return false for offset 0.
bool Matcher::is_short_branch_offset(int rule, int br_size, int offset) {
  // The passed offset is relative to address of the branch.

  return (-32768 <= offset && offset < 32768);
}

// Vector width in bytes.
const int Matcher::vector_width_in_bytes(BasicType bt) {
  // The MaxVectorSize should have been set by detecting SVE max vector register size.
  int size = MIN2((UseSVE > 0) ? 256 : 16, (int)MaxVectorSize);
  // Minimum 2 values in vector
  if (size < 2*type2aelembytes(bt)) size = 0;
  // But never < 4
  if (size < 4) size = 0;
  return size;
}

// Limits on vector size (number of elements) loaded into vector.
const int Matcher::max_vector_size(const BasicType bt) {
  return vector_width_in_bytes(bt)/type2aelembytes(bt);
}

const int Matcher::min_vector_size(const BasicType bt) {
  int max_size = max_vector_size(bt);
  // Limit the min vector size to 8 bytes.
  int size = 8 / type2aelembytes(bt);
  if (bt == T_BYTE) {
    // To support vector api shuffle/rearrange.
    size = 4;
  } else if (bt == T_BOOLEAN) {
    // To support vector api load/store mask.
    size = 2;
  }
  if (size < 2) size = 2;
  return MIN2(size, max_size);
}

// Actual max scalable vector register length.
const int Matcher::scalable_vector_reg_size(const BasicType bt) {
  return Matcher::max_vector_size(bt);
}

// Vector ideal reg.
const uint Matcher::vector_ideal_reg(int len) {
  if (UseSVE > 0 && 2 <= len && len <= 256) {
    return Op_VecA;
  }
  switch(len) {
    // For 16-bit/32-bit mask vector, reuse VecD.
    case  2:
    case  4:
    case  8: return Op_VecD;
    case 16: return Op_VecX;
  }
  ShouldNotReachHere();
  return 0;
}

MachOper* Matcher::pd_specialize_generic_vector_operand(MachOper* original_opnd, uint ideal_reg, bool is_temp) {
  ShouldNotReachHere(); // generic vector operands not supported
  return NULL;
}

bool Matcher::is_reg2reg_move(MachNode* m) {
  ShouldNotReachHere();  // generic vector operands not supported
  return false;
}

bool Matcher::is_generic_vector(MachOper* opnd)  {
  ShouldNotReachHere();  // generic vector operands not supported
  return false;
}

// Return whether or not this register is ever used as an argument.
// This function is used on startup to build the trampoline stubs in
// generateOptoStub.  Registers not mentioned will be killed by the VM
// call in the trampoline, and arguments in those registers not be
// available to the callee.
bool Matcher::can_be_java_arg(int reg)
{
  return
    reg ==  R0_num || reg == R0_H_num ||
    reg ==  R1_num || reg == R1_H_num ||
    reg ==  R2_num || reg == R2_H_num ||
    reg ==  R3_num || reg == R3_H_num ||
    reg ==  R4_num || reg == R4_H_num ||
    reg ==  R5_num || reg == R5_H_num ||
    reg ==  R6_num || reg == R6_H_num ||
    reg ==  R7_num || reg == R7_H_num ||
    reg ==  V0_num || reg == V0_H_num ||
    reg ==  V1_num || reg == V1_H_num ||
    reg ==  V2_num || reg == V2_H_num ||
    reg ==  V3_num || reg == V3_H_num ||
    reg ==  V4_num || reg == V4_H_num ||
    reg ==  V5_num || reg == V5_H_num ||
    reg ==  V6_num || reg == V6_H_num ||
    reg ==  V7_num || reg == V7_H_num;
}

bool Matcher::is_spillable_arg(int reg)
{
  return can_be_java_arg(reg);
}

uint Matcher::int_pressure_limit()
{
  // JDK-8183543: When taking the number of available registers as int
  // register pressure threshold, the jtreg test:
  // test/hotspot/jtreg/compiler/regalloc/TestC2IntPressure.java
  // failed due to C2 compilation failure with
  // "COMPILE SKIPPED: failed spill-split-recycle sanity check".
  //
  // A derived pointer is live at CallNode and then is flagged by RA
  // as a spilled LRG. Spilling heuristics(Spill-USE) explicitly skip
  // derived pointers and lastly fail to spill after reaching maximum
  // number of iterations. Lowering the default pressure threshold to
  // (_NO_SPECIAL_REG32_mask.Size() minus 1) forces CallNode to become
  // a high register pressure area of the code so that split_DEF can
  // generate DefinitionSpillCopy for the derived pointer.
  uint default_int_pressure_threshold = _NO_SPECIAL_REG32_mask.Size() - 1;
  if (!PreserveFramePointer) {
    // When PreserveFramePointer is off, frame pointer is allocatable,
    // but different from other SOC registers, it is excluded from
    // fatproj's mask because its save type is No-Save. Decrease 1 to
    // ensure high pressure at fatproj when PreserveFramePointer is off.
    // See check_pressure_at_fatproj().
    default_int_pressure_threshold--;
  }
  return (INTPRESSURE == -1) ? default_int_pressure_threshold : INTPRESSURE;
}

uint Matcher::float_pressure_limit()
{
  // _FLOAT_REG_mask is generated by adlc from the float_reg register class.
  return (FLOATPRESSURE == -1) ? _FLOAT_REG_mask.Size() : FLOATPRESSURE;
}

bool Matcher::use_asm_for_ldiv_by_con(jlong divisor) {
  return false;
}

RegMask Matcher::divI_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for MODI projection of divmodI.
RegMask Matcher::modI_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for DIVL projection of divmodL.
RegMask Matcher::divL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for MODL projection of divmodL.
RegMask Matcher::modL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

const RegMask Matcher::method_handle_invoke_SP_save_mask() {
  return FP_REG_mask();
}

bool size_fits_all_mem_uses(AddPNode* addp, int shift) {
  for (DUIterator_Fast imax, i = addp->fast_outs(imax); i < imax; i++) {
    Node* u = addp->fast_out(i);
    if (u->is_LoadStore()) {
      // On AArch64, LoadStoreNodes (i.e. compare and swap
      // instructions) only take register indirect as an operand, so
      // any attempt to use an AddPNode as an input to a LoadStoreNode
      // must fail.
      return false;
    }
    if (u->is_Mem()) {
      int opsize = u->as_Mem()->memory_size();
      assert(opsize > 0, "unexpected memory operand size");
      if (u->as_Mem()->memory_size() != (1<<shift)) {
        return false;
      }
    }
  }
  return true;
}

bool can_combine_with_imm(Node* binary_node, Node* replicate_node) {
  if (UseSVE == 0 || !VectorNode::is_invariant_vector(replicate_node)){
    return false;
  }
  Node* imm_node = replicate_node->in(1);
  if (!imm_node->is_Con()) {
    return false;
  }

  const Type* t = imm_node->bottom_type();
  if (!(t->isa_int() || t->isa_long())) {
    return false;
  }

  switch (binary_node->Opcode()) {
  case Op_AndV:
  case Op_OrV:
  case Op_XorV: {
    Assembler::SIMD_RegVariant T = Assembler::elemType_to_regVariant(Matcher::vector_element_basic_type(binary_node));
    uint64_t value = t->isa_long() ? (uint64_t)imm_node->get_long() : (uint64_t)imm_node->get_int();
    return Assembler::operand_valid_for_sve_logical_immediate(Assembler::regVariant_to_elemBits(T), value);
  }
  case Op_AddVB:
    return (imm_node->get_int() <= 255 && imm_node->get_int() >= -255);
  case Op_AddVS:
  case Op_AddVI:
    return Assembler::operand_valid_for_sve_add_sub_immediate((int64_t)imm_node->get_int());
  case Op_AddVL:
    return Assembler::operand_valid_for_sve_add_sub_immediate(imm_node->get_long());
  default:
    return false;
  }
}

bool is_vector_arith_imm_pattern(Node* n, Node* m) {
  if (n != NULL && m != NULL) {
    return can_combine_with_imm(n, m);
  }
  return false;
}

// Should the matcher clone input 'm' of node 'n'?
bool Matcher::pd_clone_node(Node* n, Node* m, Matcher::MStack& mstack) {
  // ShiftV src (ShiftCntV con)
  // Binary src (Replicate con)
  if (is_vshift_con_pattern(n, m) || is_vector_arith_imm_pattern(n, m)) {
    mstack.push(m, Visit);
    return true;
  }

  return false;
}

// Should the Matcher clone shifts on addressing modes, expecting them
// to be subsumed into complex addressing expressions or compute them
// into registers?
bool Matcher::pd_clone_address_expressions(AddPNode* m, Matcher::MStack& mstack, VectorSet& address_visited) {
  if (clone_base_plus_offset_address(m, mstack, address_visited)) {
    return true;
  }

  Node *off = m->in(AddPNode::Offset);
  if (off->Opcode() == Op_LShiftL && off->in(2)->is_Con() &&
      size_fits_all_mem_uses(m, off->in(2)->get_int()) &&
      // Are there other uses besides address expressions?
      !is_visited(off)) {
    address_visited.set(off->_idx); // Flag as address_visited
    mstack.push(off->in(2), Visit);
    Node *conv = off->in(1);
    if (conv->Opcode() == Op_ConvI2L &&
        // Are there other uses besides address expressions?
        !is_visited(conv)) {
      address_visited.set(conv->_idx); // Flag as address_visited
      mstack.push(conv->in(1), Pre_Visit);
    } else {
      mstack.push(conv, Pre_Visit);
    }
    address_visited.test_set(m->_idx); // Flag as address_visited
    mstack.push(m->in(AddPNode::Address), Pre_Visit);
    mstack.push(m->in(AddPNode::Base), Pre_Visit);
    return true;
  } else if (off->Opcode() == Op_ConvI2L &&
             // Are there other uses besides address expressions?
             !is_visited(off)) {
    address_visited.test_set(m->_idx); // Flag as address_visited
    address_visited.set(off->_idx); // Flag as address_visited
    mstack.push(off->in(1), Pre_Visit);
    mstack.push(m->in(AddPNode::Address), Pre_Visit);
    mstack.push(m->in(AddPNode::Base), Pre_Visit);
    return true;
  }
  return false;
}

#define MOV_VOLATILE(REG, BASE, INDEX, SCALE, DISP, SCRATCH, INSN)      \
  C2_MacroAssembler _masm(&cbuf);                                       \
  {                                                                     \
    guarantee(INDEX == -1, "mode not permitted for volatile");          \
    guarantee(DISP == 0, "mode not permitted for volatile");            \
    guarantee(SCALE == 0, "mode not permitted for volatile");           \
    __ INSN(REG, as_Register(BASE));                                    \
  }


static Address mem2address(int opcode, Register base, int index, int size, int disp)
  {
    Address::extend scale;

    // Hooboy, this is fugly.  We need a way to communicate to the
    // encoder that the index needs to be sign extended, so we have to
    // enumerate all the cases.
    switch (opcode) {
    case INDINDEXSCALEDI2L:
    case INDINDEXSCALEDI2LN:
    case INDINDEXI2L:
    case INDINDEXI2LN:
      scale = Address::sxtw(size);
      break;
    default:
      scale = Address::lsl(size);
    }

    if (index == -1) {
      return Address(base, disp);
    } else {
      assert(disp == 0, "unsupported address mode: disp = %d", disp);
      return Address(base, as_Register(index), scale);
    }
  }


typedef void (MacroAssembler::* mem_insn)(Register Rt, const Address &adr);
typedef void (MacroAssembler::* mem_insn2)(Register Rt, Register adr);
typedef void (MacroAssembler::* mem_float_insn)(FloatRegister Rt, const Address &adr);
typedef void (MacroAssembler::* mem_vector_insn)(FloatRegister Rt,
                                  MacroAssembler::SIMD_RegVariant T, const Address &adr);

  // Used for all non-volatile memory accesses.  The use of
  // $mem->opcode() to discover whether this pattern uses sign-extended
  // offsets is something of a kludge.
  static void loadStore(C2_MacroAssembler masm, mem_insn insn,
                        Register reg, int opcode,
                        Register base, int index, int scale, int disp,
                        int size_in_memory)
  {
    Address addr = mem2address(opcode, base, index, scale, disp);
    if (addr.getMode() == Address::base_plus_offset) {
      /* If we get an out-of-range offset it is a bug in the compiler,
         so we assert here. */
      assert(Address::offset_ok_for_immed(addr.offset(), exact_log2(size_in_memory)),
             "c2 compiler bug");
      /* Fix up any out-of-range offsets. */
      assert_different_registers(rscratch1, base);
      assert_different_registers(rscratch1, reg);
      addr = masm.legitimize_address(addr, size_in_memory, rscratch1);
    }
    (masm.*insn)(reg, addr);
  }

  static void loadStore(C2_MacroAssembler masm, mem_float_insn insn,
                        FloatRegister reg, int opcode,
                        Register base, int index, int size, int disp,
                        int size_in_memory)
  {
    Address::extend scale;

    switch (opcode) {
    case INDINDEXSCALEDI2L:
    case INDINDEXSCALEDI2LN:
      scale = Address::sxtw(size);
      break;
    default:
      scale = Address::lsl(size);
    }

    if (index == -1) {
      /* If we get an out-of-range offset it is a bug in the compiler,
         so we assert here. */
      assert(Address::offset_ok_for_immed(disp, exact_log2(size_in_memory)), "c2 compiler bug");
      /* Fix up any out-of-range offsets. */
      assert_different_registers(rscratch1, base);
      Address addr = Address(base, disp);
      addr = masm.legitimize_address(addr, size_in_memory, rscratch1);
      (masm.*insn)(reg, addr);
    } else {
      assert(disp == 0, "unsupported address mode: disp = %d", disp);
      (masm.*insn)(reg, Address(base, as_Register(index), scale));
    }
  }

  static void loadStore(C2_MacroAssembler masm, mem_vector_insn insn,
                        FloatRegister reg, MacroAssembler::SIMD_RegVariant T,
                        int opcode, Register base, int index, int size, int disp)
  {
    if (index == -1) {
      (masm.*insn)(reg, T, Address(base, disp));
    } else {
      assert(disp == 0, "unsupported address mode");
      (masm.*insn)(reg, T, Address(base, as_Register(index), Address::lsl(size)));
    }
  }


#line 1633 "ad_aarch64.cpp"


//SourceForm

#line 94 "src/hotspot/cpu/aarch64/aarch64_sve.ad"


  typedef void (C2_MacroAssembler::* sve_mem_insn_predicate)(FloatRegister Rt, Assembler::SIMD_RegVariant T,
                                                             PRegister Pg, const Address &adr);

  // Predicated load/store, with optional ptrue to all elements of given predicate register.
  static void loadStoreA_predicated(C2_MacroAssembler masm, bool is_store, FloatRegister reg,
                                    PRegister pg, BasicType mem_elem_bt, BasicType vector_elem_bt,
                                    int opcode, Register base, int index, int size, int disp) {
    sve_mem_insn_predicate insn;
    int mesize = type2aelembytes(mem_elem_bt);
    if (index == -1) {
      assert(size == 0, "unsupported address mode: scale size = %d", size);
      switch(mesize) {
      case 1:
        insn = is_store ? &C2_MacroAssembler::sve_st1b : &C2_MacroAssembler::sve_ld1b;
        break;
      case 2:
        insn = is_store ? &C2_MacroAssembler::sve_st1h : &C2_MacroAssembler::sve_ld1h;
        break;
      case 4:
        insn = is_store ? &C2_MacroAssembler::sve_st1w : &C2_MacroAssembler::sve_ld1w;
        break;
      case 8:
        insn = is_store ? &C2_MacroAssembler::sve_st1d : &C2_MacroAssembler::sve_ld1d;
        break;
      default:
        assert(false, "unsupported");
        ShouldNotReachHere();
      }
      int imm4 = disp / mesize / Matcher::scalable_vector_reg_size(vector_elem_bt);
      (masm.*insn)(reg, Assembler::elemType_to_regVariant(vector_elem_bt), pg, Address(base, imm4));
    } else {
      assert(false, "unimplemented");
      ShouldNotReachHere();
    }
  }

  bool op_sve_supported(int opcode, int vlen, BasicType bt) {
    int length_in_bytes = vlen * type2aelembytes(bt);
    switch (opcode) {
      case Op_MulAddVS2VI:
      // No multiply reduction instructions
      case Op_MulReductionVD:
      case Op_MulReductionVF:
      case Op_MulReductionVI:
      case Op_MulReductionVL:
      // Others
      case Op_ExtractC:
      case Op_ExtractUB:
        return false;
      // Vector API specific
      case Op_VectorLoadShuffle:
      case Op_VectorRearrange:
        return vlen >= 4 && length_in_bytes <= MaxVectorSize;
      case Op_LoadVector:
      case Op_StoreVector:
        return Matcher::vector_size_supported(bt, vlen);
      default:
        break;
    }
    // By default, we only support vector operations with no less than 8 bytes and 2 elements.
    return 8 <= length_in_bytes && length_in_bytes <= MaxVectorSize && vlen >= 2;
  }

  bool masked_op_sve_supported(int opcode, int vlen, BasicType bt) {
    if (opcode == Op_VectorRearrange) {
      return false;
    }
    return op_sve_supported(opcode, vlen, bt);
  }


#line 1712 "ad_aarch64.cpp"


//SourceForm

#line 32 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"


static void z_load_barrier(MacroAssembler& _masm, const MachNode* node, Address ref_addr, Register ref, Register tmp, uint8_t barrier_data) {
  if (barrier_data == ZLoadBarrierElided) {
    return;
  }
  ZLoadBarrierStubC2* const stub = ZLoadBarrierStubC2::create(node, ref_addr, ref, tmp, barrier_data);
  __ ldr(tmp, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
  __ andr(tmp, tmp, ref);
  __ cbnz(tmp, *stub->entry());
  __ bind(*stub->continuation());
}

static void z_load_barrier_slow_path(MacroAssembler& _masm, const MachNode* node, Address ref_addr, Register ref, Register tmp) {
  ZLoadBarrierStubC2* const stub = ZLoadBarrierStubC2::create(node, ref_addr, ref, tmp, ZLoadBarrierStrong);
  __ b(*stub->entry());
  __ bind(*stub->continuation());
}


#line 1738 "ad_aarch64.cpp"


#ifndef PRODUCT
void Compile::adlc_verification() {

  // Following assertions generated from definition section
  assert( INSN_COST == 100, "Expect (100) to equal 100");
  assert( BRANCH_COST == 200, "Expect (2 * INSN_COST) to equal 200");
  assert( CALL_COST == 200, "Expect (2 * INSN_COST) to equal 200");
  assert( VOLATILE_REF_COST == 1000, "Expect (10 * INSN_COST) to equal 1000");
  assert( SVE_COST == 200, "Expect (200) to equal 200");
}
#endif

// Map from machine-independent register number to register_save_policy
const        char register_save_policy[] = {
  'C', // R10
  'C', // R10_H
  'C', // R11
  'C', // R11_H
  'C', // R12
  'C', // R12_H
  'C', // R13
  'C', // R13_H
  'C', // R14
  'C', // R14_H
  'C', // R15
  'C', // R15_H
  'C', // R16
  'C', // R16_H
  'C', // R17
  'C', // R17_H
  'C', // R18
  'C', // R18_H
  'C', // R0
  'C', // R0_H
  'C', // R1
  'C', // R1_H
  'C', // R2
  'C', // R2_H
  'C', // R3
  'C', // R3_H
  'C', // R4
  'C', // R4_H
  'C', // R5
  'C', // R5_H
  'C', // R6
  'C', // R6_H
  'C', // R7
  'C', // R7_H
  'C', // R19
  'C', // R19_H
  'C', // R20
  'C', // R20_H
  'C', // R21
  'C', // R21_H
  'C', // R22
  'C', // R22_H
  'C', // R23
  'C', // R23_H
  'C', // R24
  'C', // R24_H
  'C', // R25
  'C', // R25_H
  'C', // R26
  'C', // R26_H
  'C', // R27
  'C', // R27_H
  'N', // R28
  'N', // R28_H
  'N', // R29
  'N', // R29_H
  'N', // R30
  'N', // R30_H
  'N', // R31
  'N', // R31_H
  'N', // R8
  'N', // R8_H
  'N', // R9
  'N', // R9_H
  'C', // V16
  'C', // V16_H
  'C', // V16_J
  'C', // V16_K
  'C', // V16_L
  'C', // V16_M
  'C', // V16_N
  'C', // V16_O
  'C', // V17
  'C', // V17_H
  'C', // V17_J
  'C', // V17_K
  'C', // V17_L
  'C', // V17_M
  'C', // V17_N
  'C', // V17_O
  'C', // V18
  'C', // V18_H
  'C', // V18_J
  'C', // V18_K
  'C', // V18_L
  'C', // V18_M
  'C', // V18_N
  'C', // V18_O
  'C', // V19
  'C', // V19_H
  'C', // V19_J
  'C', // V19_K
  'C', // V19_L
  'C', // V19_M
  'C', // V19_N
  'C', // V19_O
  'C', // V20
  'C', // V20_H
  'C', // V20_J
  'C', // V20_K
  'C', // V20_L
  'C', // V20_M
  'C', // V20_N
  'C', // V20_O
  'C', // V21
  'C', // V21_H
  'C', // V21_J
  'C', // V21_K
  'C', // V21_L
  'C', // V21_M
  'C', // V21_N
  'C', // V21_O
  'C', // V22
  'C', // V22_H
  'C', // V22_J
  'C', // V22_K
  'C', // V22_L
  'C', // V22_M
  'C', // V22_N
  'C', // V22_O
  'C', // V23
  'C', // V23_H
  'C', // V23_J
  'C', // V23_K
  'C', // V23_L
  'C', // V23_M
  'C', // V23_N
  'C', // V23_O
  'C', // V24
  'C', // V24_H
  'C', // V24_J
  'C', // V24_K
  'C', // V24_L
  'C', // V24_M
  'C', // V24_N
  'C', // V24_O
  'C', // V25
  'C', // V25_H
  'C', // V25_J
  'C', // V25_K
  'C', // V25_L
  'C', // V25_M
  'C', // V25_N
  'C', // V25_O
  'C', // V26
  'C', // V26_H
  'C', // V26_J
  'C', // V26_K
  'C', // V26_L
  'C', // V26_M
  'C', // V26_N
  'C', // V26_O
  'C', // V27
  'C', // V27_H
  'C', // V27_J
  'C', // V27_K
  'C', // V27_L
  'C', // V27_M
  'C', // V27_N
  'C', // V27_O
  'C', // V28
  'C', // V28_H
  'C', // V28_J
  'C', // V28_K
  'C', // V28_L
  'C', // V28_M
  'C', // V28_N
  'C', // V28_O
  'C', // V29
  'C', // V29_H
  'C', // V29_J
  'C', // V29_K
  'C', // V29_L
  'C', // V29_M
  'C', // V29_N
  'C', // V29_O
  'C', // V30
  'C', // V30_H
  'C', // V30_J
  'C', // V30_K
  'C', // V30_L
  'C', // V30_M
  'C', // V30_N
  'C', // V30_O
  'C', // V31
  'C', // V31_H
  'C', // V31_J
  'C', // V31_K
  'C', // V31_L
  'C', // V31_M
  'C', // V31_N
  'C', // V31_O
  'C', // V0
  'C', // V0_H
  'C', // V0_J
  'C', // V0_K
  'C', // V0_L
  'C', // V0_M
  'C', // V0_N
  'C', // V0_O
  'C', // V1
  'C', // V1_H
  'C', // V1_J
  'C', // V1_K
  'C', // V1_L
  'C', // V1_M
  'C', // V1_N
  'C', // V1_O
  'C', // V2
  'C', // V2_H
  'C', // V2_J
  'C', // V2_K
  'C', // V2_L
  'C', // V2_M
  'C', // V2_N
  'C', // V2_O
  'C', // V3
  'C', // V3_H
  'C', // V3_J
  'C', // V3_K
  'C', // V3_L
  'C', // V3_M
  'C', // V3_N
  'C', // V3_O
  'C', // V4
  'C', // V4_H
  'C', // V4_J
  'C', // V4_K
  'C', // V4_L
  'C', // V4_M
  'C', // V4_N
  'C', // V4_O
  'C', // V5
  'C', // V5_H
  'C', // V5_J
  'C', // V5_K
  'C', // V5_L
  'C', // V5_M
  'C', // V5_N
  'C', // V5_O
  'C', // V6
  'C', // V6_H
  'C', // V6_J
  'C', // V6_K
  'C', // V6_L
  'C', // V6_M
  'C', // V6_N
  'C', // V6_O
  'C', // V7
  'C', // V7_H
  'C', // V7_J
  'C', // V7_K
  'C', // V7_L
  'C', // V7_M
  'C', // V7_N
  'C', // V7_O
  'C', // V8
  'C', // V8_H
  'C', // V8_J
  'C', // V8_K
  'C', // V8_L
  'C', // V8_M
  'C', // V8_N
  'C', // V8_O
  'C', // V9
  'C', // V9_H
  'C', // V9_J
  'C', // V9_K
  'C', // V9_L
  'C', // V9_M
  'C', // V9_N
  'C', // V9_O
  'C', // V10
  'C', // V10_H
  'C', // V10_J
  'C', // V10_K
  'C', // V10_L
  'C', // V10_M
  'C', // V10_N
  'C', // V10_O
  'C', // V11
  'C', // V11_H
  'C', // V11_J
  'C', // V11_K
  'C', // V11_L
  'C', // V11_M
  'C', // V11_N
  'C', // V11_O
  'C', // V12
  'C', // V12_H
  'C', // V12_J
  'C', // V12_K
  'C', // V12_L
  'C', // V12_M
  'C', // V12_N
  'C', // V12_O
  'C', // V13
  'C', // V13_H
  'C', // V13_J
  'C', // V13_K
  'C', // V13_L
  'C', // V13_M
  'C', // V13_N
  'C', // V13_O
  'C', // V14
  'C', // V14_H
  'C', // V14_J
  'C', // V14_K
  'C', // V14_L
  'C', // V14_M
  'C', // V14_N
  'C', // V14_O
  'C', // V15
  'C', // V15_H
  'C', // V15_J
  'C', // V15_K
  'C', // V15_L
  'C', // V15_M
  'C', // V15_N
  'C', // V15_O
  'C', // P0
  'C', // P1
  'C', // P2
  'C', // P3
  'C', // P4
  'C', // P5
  'C', // P6
  'C', // P7
  'C', // P8
  'C', // P9
  'C', // P10
  'C', // P11
  'C', // P12
  'C', // P13
  'C', // P14
  'C', // P15
  'C' // no trailing comma // RFLAGS
};

// Map from machine-independent register number to c_reg_save_policy
const        char c_reg_save_policy[] = {
  'C', // R10
  'C', // R10_H
  'C', // R11
  'C', // R11_H
  'C', // R12
  'C', // R12_H
  'C', // R13
  'C', // R13_H
  'C', // R14
  'C', // R14_H
  'C', // R15
  'C', // R15_H
  'C', // R16
  'C', // R16_H
  'C', // R17
  'C', // R17_H
  'C', // R18
  'C', // R18_H
  'C', // R0
  'C', // R0_H
  'C', // R1
  'C', // R1_H
  'C', // R2
  'C', // R2_H
  'C', // R3
  'C', // R3_H
  'C', // R4
  'C', // R4_H
  'C', // R5
  'C', // R5_H
  'C', // R6
  'C', // R6_H
  'C', // R7
  'C', // R7_H
  'E', // R19
  'E', // R19_H
  'E', // R20
  'E', // R20_H
  'E', // R21
  'E', // R21_H
  'E', // R22
  'E', // R22_H
  'E', // R23
  'E', // R23_H
  'E', // R24
  'E', // R24_H
  'E', // R25
  'E', // R25_H
  'E', // R26
  'E', // R26_H
  'E', // R27
  'E', // R27_H
  'E', // R28
  'E', // R28_H
  'N', // R29
  'N', // R29_H
  'N', // R30
  'N', // R30_H
  'N', // R31
  'N', // R31_H
  'C', // R8
  'C', // R8_H
  'C', // R9
  'C', // R9_H
  'C', // V16
  'C', // V16_H
  'C', // V16_J
  'C', // V16_K
  'C', // V16_L
  'C', // V16_M
  'C', // V16_N
  'C', // V16_O
  'C', // V17
  'C', // V17_H
  'C', // V17_J
  'C', // V17_K
  'C', // V17_L
  'C', // V17_M
  'C', // V17_N
  'C', // V17_O
  'C', // V18
  'C', // V18_H
  'C', // V18_J
  'C', // V18_K
  'C', // V18_L
  'C', // V18_M
  'C', // V18_N
  'C', // V18_O
  'C', // V19
  'C', // V19_H
  'C', // V19_J
  'C', // V19_K
  'C', // V19_L
  'C', // V19_M
  'C', // V19_N
  'C', // V19_O
  'C', // V20
  'C', // V20_H
  'C', // V20_J
  'C', // V20_K
  'C', // V20_L
  'C', // V20_M
  'C', // V20_N
  'C', // V20_O
  'C', // V21
  'C', // V21_H
  'C', // V21_J
  'C', // V21_K
  'C', // V21_L
  'C', // V21_M
  'C', // V21_N
  'C', // V21_O
  'C', // V22
  'C', // V22_H
  'C', // V22_J
  'C', // V22_K
  'C', // V22_L
  'C', // V22_M
  'C', // V22_N
  'C', // V22_O
  'C', // V23
  'C', // V23_H
  'C', // V23_J
  'C', // V23_K
  'C', // V23_L
  'C', // V23_M
  'C', // V23_N
  'C', // V23_O
  'C', // V24
  'C', // V24_H
  'C', // V24_J
  'C', // V24_K
  'C', // V24_L
  'C', // V24_M
  'C', // V24_N
  'C', // V24_O
  'C', // V25
  'C', // V25_H
  'C', // V25_J
  'C', // V25_K
  'C', // V25_L
  'C', // V25_M
  'C', // V25_N
  'C', // V25_O
  'C', // V26
  'C', // V26_H
  'C', // V26_J
  'C', // V26_K
  'C', // V26_L
  'C', // V26_M
  'C', // V26_N
  'C', // V26_O
  'C', // V27
  'C', // V27_H
  'C', // V27_J
  'C', // V27_K
  'C', // V27_L
  'C', // V27_M
  'C', // V27_N
  'C', // V27_O
  'C', // V28
  'C', // V28_H
  'C', // V28_J
  'C', // V28_K
  'C', // V28_L
  'C', // V28_M
  'C', // V28_N
  'C', // V28_O
  'C', // V29
  'C', // V29_H
  'C', // V29_J
  'C', // V29_K
  'C', // V29_L
  'C', // V29_M
  'C', // V29_N
  'C', // V29_O
  'C', // V30
  'C', // V30_H
  'C', // V30_J
  'C', // V30_K
  'C', // V30_L
  'C', // V30_M
  'C', // V30_N
  'C', // V30_O
  'C', // V31
  'C', // V31_H
  'C', // V31_J
  'C', // V31_K
  'C', // V31_L
  'C', // V31_M
  'C', // V31_N
  'C', // V31_O
  'C', // V0
  'C', // V0_H
  'C', // V0_J
  'C', // V0_K
  'C', // V0_L
  'C', // V0_M
  'C', // V0_N
  'C', // V0_O
  'C', // V1
  'C', // V1_H
  'C', // V1_J
  'C', // V1_K
  'C', // V1_L
  'C', // V1_M
  'C', // V1_N
  'C', // V1_O
  'C', // V2
  'C', // V2_H
  'C', // V2_J
  'C', // V2_K
  'C', // V2_L
  'C', // V2_M
  'C', // V2_N
  'C', // V2_O
  'C', // V3
  'C', // V3_H
  'C', // V3_J
  'C', // V3_K
  'C', // V3_L
  'C', // V3_M
  'C', // V3_N
  'C', // V3_O
  'C', // V4
  'C', // V4_H
  'C', // V4_J
  'C', // V4_K
  'C', // V4_L
  'C', // V4_M
  'C', // V4_N
  'C', // V4_O
  'C', // V5
  'C', // V5_H
  'C', // V5_J
  'C', // V5_K
  'C', // V5_L
  'C', // V5_M
  'C', // V5_N
  'C', // V5_O
  'C', // V6
  'C', // V6_H
  'C', // V6_J
  'C', // V6_K
  'C', // V6_L
  'C', // V6_M
  'C', // V6_N
  'C', // V6_O
  'C', // V7
  'C', // V7_H
  'C', // V7_J
  'C', // V7_K
  'C', // V7_L
  'C', // V7_M
  'C', // V7_N
  'C', // V7_O
  'E', // V8
  'E', // V8_H
  'C', // V8_J
  'C', // V8_K
  'C', // V8_L
  'C', // V8_M
  'C', // V8_N
  'C', // V8_O
  'E', // V9
  'E', // V9_H
  'C', // V9_J
  'C', // V9_K
  'C', // V9_L
  'C', // V9_M
  'C', // V9_N
  'C', // V9_O
  'E', // V10
  'E', // V10_H
  'C', // V10_J
  'C', // V10_K
  'C', // V10_L
  'C', // V10_M
  'C', // V10_N
  'C', // V10_O
  'E', // V11
  'E', // V11_H
  'C', // V11_J
  'C', // V11_K
  'C', // V11_L
  'C', // V11_M
  'C', // V11_N
  'C', // V11_O
  'E', // V12
  'E', // V12_H
  'C', // V12_J
  'C', // V12_K
  'C', // V12_L
  'C', // V12_M
  'C', // V12_N
  'C', // V12_O
  'E', // V13
  'E', // V13_H
  'C', // V13_J
  'C', // V13_K
  'C', // V13_L
  'C', // V13_M
  'C', // V13_N
  'C', // V13_O
  'E', // V14
  'E', // V14_H
  'C', // V14_J
  'C', // V14_K
  'C', // V14_L
  'C', // V14_M
  'C', // V14_N
  'C', // V14_O
  'E', // V15
  'E', // V15_H
  'C', // V15_J
  'C', // V15_K
  'C', // V15_L
  'C', // V15_M
  'C', // V15_N
  'C', // V15_O
  'C', // P0
  'C', // P1
  'C', // P2
  'C', // P3
  'C', // P4
  'C', // P5
  'C', // P6
  'C', // P7
  'C', // P8
  'C', // P9
  'C', // P10
  'C', // P11
  'C', // P12
  'C', // P13
  'C', // P14
  'C', // P15
  'C' // no trailing comma // RFLAGS
};

// Map from machine-independent register number to register_save_type
const        int register_save_type[] = {
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  0 // no trailing comma
};


const        int   reduceOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  immI_rule,
  /*    9 */  immI0_rule,
  /*   10 */  immI_1_rule,
  /*   11 */  immI_M1_rule,
  /*   12 */  immIExt_rule,
  /*   13 */  immI_gt_1_rule,
  /*   14 */  immI_le_4_rule,
  /*   15 */  immI_31_rule,
  /*   16 */  immI_2_rule,
  /*   17 */  immI_4_rule,
  /*   18 */  immI_8_rule,
  /*   19 */  immI_16_rule,
  /*   20 */  immI_24_rule,
  /*   21 */  immI_32_rule,
  /*   22 */  immI_48_rule,
  /*   23 */  immI_56_rule,
  /*   24 */  immI_63_rule,
  /*   25 */  immI_64_rule,
  /*   26 */  immI_255_rule,
  /*   27 */  immI_65535_rule,
  /*   28 */  immL_255_rule,
  /*   29 */  immL_65535_rule,
  /*   30 */  immL_4294967295_rule,
  /*   31 */  immL_bitmask_rule,
  /*   32 */  immI_bitmask_rule,
  /*   33 */  immL_positive_bitmaskI_rule,
  /*   34 */  immIScale_rule,
  /*   35 */  immI26_rule,
  /*   36 */  immI19_rule,
  /*   37 */  immIU12_rule,
  /*   38 */  immLU12_rule,
  /*   39 */  immIOffset_rule,
  /*   40 */  immIOffset1_rule,
  /*   41 */  immIOffset2_rule,
  /*   42 */  immIOffset4_rule,
  /*   43 */  immIOffset8_rule,
  /*   44 */  immIOffset16_rule,
  /*   45 */  immLoffset_rule,
  /*   46 */  immLoffset1_rule,
  /*   47 */  immLoffset2_rule,
  /*   48 */  immLoffset4_rule,
  /*   49 */  immLoffset8_rule,
  /*   50 */  immLoffset16_rule,
  /*   51 */  immI8_rule,
  /*   52 */  immI8_shift8_rule,
  /*   53 */  immL8_shift8_rule,
  /*   54 */  immBAddSubV_rule,
  /*   55 */  immIAddSub_rule,
  /*   56 */  immIAddSubV_rule,
  /*   57 */  immBLog_rule,
  /*   58 */  immSLog_rule,
  /*   59 */  immILog_rule,
  /*   60 */  immL_rule,
  /*   61 */  immL0_rule,
  /*   62 */  immL_1_rule,
  /*   63 */  immL_M1_rule,
  /*   64 */  immL_pc_off_rule,
  /*   65 */  immLAddSub_rule,
  /*   66 */  immLAddSubV_rule,
  /*   67 */  immLLog_rule,
  /*   68 */  immL_32bits_rule,
  /*   69 */  immP_rule,
  /*   70 */  immP0_rule,
  /*   71 */  immP_1_rule,
  /*   72 */  immByteMapBase_rule,
  /*   73 */  immP_M1_rule,
  /*   74 */  immP_M2_rule,
  /*   75 */  immD_rule,
  /*   76 */  immD0_rule,
  /*   77 */  immDPacked_rule,
  /*   78 */  immF_rule,
  /*   79 */  immF0_rule,
  /*   80 */  immFPacked_rule,
  /*   81 */  immN_rule,
  /*   82 */  immN0_rule,
  /*   83 */  immNKlass_rule,
  /*   84 */  iRegI_rule,
  /*   85 */  iRegINoSp_rule,
  /*   86 */  iRegL_rule,
  /*   87 */  iRegLNoSp_rule,
  /*   88 */  iRegP_rule,
  /*   89 */  iRegPNoSp_rule,
  /*   90 */  iRegP_R0_rule,
  /*   91 */  iRegP_R1_rule,
  /*   92 */  iRegP_R2_rule,
  /*   93 */  iRegP_R3_rule,
  /*   94 */  iRegP_R4_rule,
  /*   95 */  iRegP_R5_rule,
  /*   96 */  iRegP_R10_rule,
  /*   97 */  iRegL_R0_rule,
  /*   98 */  iRegL_R2_rule,
  /*   99 */  iRegL_R3_rule,
  /*  100 */  iRegL_R11_rule,
  /*  101 */  iRegP_FP_rule,
  /*  102 */  iRegI_R0_rule,
  /*  103 */  iRegI_R2_rule,
  /*  104 */  iRegI_R3_rule,
  /*  105 */  iRegI_R4_rule,
  /*  106 */  iRegN_rule,
  /*  107 */  iRegN_R0_rule,
  /*  108 */  iRegN_R2_rule,
  /*  109 */  iRegN_R3_rule,
  /*  110 */  iRegNNoSp_rule,
  /*  111 */  iRegIHeapbase_rule,
  /*  112 */  vRegF_rule,
  /*  113 */  vRegD_rule,
  /*  114 */  vReg_rule,
  /*  115 */  vecD_rule,
  /*  116 */  vecX_rule,
  /*  117 */  vRegD_V0_rule,
  /*  118 */  vRegD_V1_rule,
  /*  119 */  vRegD_V2_rule,
  /*  120 */  vRegD_V3_rule,
  /*  121 */  vRegD_V4_rule,
  /*  122 */  vRegD_V5_rule,
  /*  123 */  vRegD_V6_rule,
  /*  124 */  vRegD_V7_rule,
  /*  125 */  vRegD_V8_rule,
  /*  126 */  vRegD_V9_rule,
  /*  127 */  vRegD_V10_rule,
  /*  128 */  vRegD_V11_rule,
  /*  129 */  vRegD_V12_rule,
  /*  130 */  vRegD_V13_rule,
  /*  131 */  vRegD_V14_rule,
  /*  132 */  vRegD_V15_rule,
  /*  133 */  vRegD_V16_rule,
  /*  134 */  vRegD_V17_rule,
  /*  135 */  vRegD_V18_rule,
  /*  136 */  vRegD_V19_rule,
  /*  137 */  vRegD_V20_rule,
  /*  138 */  vRegD_V21_rule,
  /*  139 */  vRegD_V22_rule,
  /*  140 */  vRegD_V23_rule,
  /*  141 */  vRegD_V24_rule,
  /*  142 */  vRegD_V25_rule,
  /*  143 */  vRegD_V26_rule,
  /*  144 */  vRegD_V27_rule,
  /*  145 */  vRegD_V28_rule,
  /*  146 */  vRegD_V29_rule,
  /*  147 */  vRegD_V30_rule,
  /*  148 */  vRegD_V31_rule,
  /*  149 */  pReg_rule,
  /*  150 */  pRegGov_rule,
  /*  151 */  rFlagsReg_rule,
  /*  152 */  rFlagsRegU_rule,
  /*  153 */  inline_cache_RegP_rule,
  /*  154 */  thread_RegP_rule,
  /*  155 */  lr_RegP_rule,
  /*  156 */  indirect_rule,
  /*  157 */  indIndexScaledI2L_rule,
  /*  158 */  indIndexScaled_rule,
  /*  159 */  indIndexI2L_rule,
  /*  160 */  indIndex_rule,
  /*  161 */  indOffI_rule,
  /*  162 */  indOffI1_rule,
  /*  163 */  indOffI2_rule,
  /*  164 */  indOffI4_rule,
  /*  165 */  indOffI8_rule,
  /*  166 */  indOffI16_rule,
  /*  167 */  indOffL_rule,
  /*  168 */  indOffL1_rule,
  /*  169 */  indOffL2_rule,
  /*  170 */  indOffL4_rule,
  /*  171 */  indOffL8_rule,
  /*  172 */  indOffL16_rule,
  /*  173 */  indirectN_rule,
  /*  174 */  indIndexScaledI2LN_rule,
  /*  175 */  indIndexScaledN_rule,
  /*  176 */  indIndexI2LN_rule,
  /*  177 */  indIndexN_rule,
  /*  178 */  indOffIN_rule,
  /*  179 */  indOffLN_rule,
  /*  180 */  thread_anchor_pc_rule,
  /*  181 */  stackSlotP_rule,
  /*  182 */  stackSlotI_rule,
  /*  183 */  stackSlotF_rule,
  /*  184 */  stackSlotD_rule,
  /*  185 */  stackSlotL_rule,
  /*  186 */  cmpOp_rule,
  /*  187 */  cmpOpU_rule,
  /*  188 */  cmpOpEqNe_rule,
  /*  189 */  cmpOpLtGe_rule,
  /*  190 */  cmpOpUEqNeLtGe_rule,
  /*  191 */  iRegL2I_rule,
  /*  192 */  vmemA_immIOffset4_rule,
  /*  193 */  vmemA_immLOffset4_rule,
  /*  194 */  vmemA_indOffI4_rule,
  /*  195 */  vmemA_indOffL4_rule,
  // last operand
  /*  196 */  vmem2_rule,
  /*  197 */  vmem4_rule,
  /*  198 */  vmem8_rule,
  /*  199 */  vmem16_rule,
  /*  200 */  memory1_rule,
  /*  201 */  memory2_rule,
  /*  202 */  memory4_rule,
  /*  203 */  memory8_rule,
  /*  204 */  memory_rule,
  /*  205 */  iRegIorL2I_rule,
  /*  206 */  vmemA_rule,
  // last operand class
  /*  207 */  _ConvI2L_iRegI__rule,
  /*  208 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  209 */  _LShiftL_iRegL_immIScale_rule,
  /*  210 */  _DecodeN_iRegN__rule,
  /*  211 */  _LoadB_memory1__rule,
  /*  212 */  _LoadUB_memory1__rule,
  /*  213 */  _LoadS_memory2__rule,
  /*  214 */  _LoadUS_memory2__rule,
  /*  215 */  _LoadI_memory4__rule,
  /*  216 */  _ConvI2L__LoadI_memory4___rule,
  /*  217 */  _LoadB_indirect__rule,
  /*  218 */  _LoadUB_indirect__rule,
  /*  219 */  _LoadUS_indirect__rule,
  /*  220 */  _LoadS_indirect__rule,
  /*  221 */  _LoadI_indirect__rule,
  /*  222 */  _ConvI2L__LoadI_indirect___rule,
  /*  223 */  _LoadL_memory8__rule,
  /*  224 */  _CastP2X_iRegP__rule,
  /*  225 */  _CastP2X__DecodeN_iRegN___rule,
  /*  226 */  _Binary_iRegP_iRegP_rule,
  /*  227 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  228 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  229 */  _Binary_iRegNNoSp_iRegNNoSp_rule,
  /*  230 */  _Binary_iRegI_iRegI_rule,
  /*  231 */  _Binary_iRegL_iRegL_rule,
  /*  232 */  _Binary_iRegN_iRegN_rule,
  /*  233 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  234 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  235 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  236 */  _Binary_immI0_iRegIorL2I_rule,
  /*  237 */  _Binary_iRegIorL2I_immI0_rule,
  /*  238 */  _Binary_immI_1_immI0_rule,
  /*  239 */  _Binary_iRegL_immL0_rule,
  /*  240 */  _Binary_immL0_iRegL_rule,
  /*  241 */  _Binary_iRegP_immP0_rule,
  /*  242 */  _Binary_immP0_iRegP_rule,
  /*  243 */  _Binary_iRegN_immN0_rule,
  /*  244 */  _Binary_immN0_iRegN_rule,
  /*  245 */  _Binary_vRegF_vRegF_rule,
  /*  246 */  _Binary_vRegD_vRegD_rule,
  /*  247 */  _ConvL2I_iRegL__rule,
  /*  248 */  _ConvI2L_iRegIorL2I__rule,
  /*  249 */  _LShiftL__ConvI2L_iRegIorL2I__immIScale_rule,
  /*  250 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  251 */  _SubI_immI0_iRegIorL2I_rule,
  /*  252 */  _MulL_iRegL_iRegL_rule,
  /*  253 */  _SubL_immL0_iRegL_rule,
  /*  254 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  255 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  256 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  257 */  _XorL_iRegL_immL_M1_rule,
  /*  258 */  _XorI_iRegIorL2I_iRegIorL2I_rule,
  /*  259 */  _XorL_iRegL_iRegL_rule,
  /*  260 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  261 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  262 */  _URShiftL_iRegL_immI_rule,
  /*  263 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  264 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  265 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  266 */  _RShiftL_iRegL_immI_rule,
  /*  267 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  268 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  269 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /*  270 */  _RotateRight_iRegL_immI_rule,
  /*  271 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /*  272 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  273 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  274 */  _LShiftL_iRegL_immI_rule,
  /*  275 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  276 */  _XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  277 */  _XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI_rule,
  /*  278 */  _XorL__URShiftL_iRegL_immI_iRegL_rule,
  /*  279 */  _XorL_iRegL__URShiftL_iRegL_immI_rule,
  /*  280 */  _XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  281 */  _XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI_rule,
  /*  282 */  _XorL__RShiftL_iRegL_immI_iRegL_rule,
  /*  283 */  _XorL_iRegL__RShiftL_iRegL_immI_rule,
  /*  284 */  _XorI__RotateRight_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  285 */  _XorI_iRegIorL2I__RotateRight_iRegIorL2I_immI_rule,
  /*  286 */  _XorL__RotateRight_iRegL_immI_iRegL_rule,
  /*  287 */  _XorL_iRegL__RotateRight_iRegL_immI_rule,
  /*  288 */  _XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  289 */  _XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI_rule,
  /*  290 */  _XorL__LShiftL_iRegL_immI_iRegL_rule,
  /*  291 */  _XorL_iRegL__LShiftL_iRegL_immI_rule,
  /*  292 */  _AndI__URShiftI_iRegIorL2I_immI_immI_bitmask_rule,
  /*  293 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /*  294 */  _AndL_iRegL_immL_bitmask_rule,
  /*  295 */  _LShiftI__AndI_iRegIorL2I_immI_bitmask_immI_rule,
  /*  296 */  _AndL_iRegL_immL_positive_bitmaskI_rule,
  /*  297 */  _LShiftL__AndL_iRegL_immL_positive_bitmaskI_immI_rule,
  /*  298 */  _ConvI2L__AndI_iRegIorL2I_immI_bitmask__rule,
  /*  299 */  _ConvL2I__AndL_iRegL_immL_positive_bitmaskI__rule,
  /*  300 */  _AndI_iRegI_immI_bitmask_rule,
  /*  301 */  _LShiftI_iRegIorL2I_immI_16_rule,
  /*  302 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /*  303 */  _LShiftI_iRegIorL2I_immI_24_rule,
  /*  304 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  305 */  _URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  306 */  _LShiftL_iRegL_immI_48_rule,
  /*  307 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /*  308 */  _LShiftL_iRegL_immI_32_rule,
  /*  309 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /*  310 */  _LShiftL_iRegL_immI_56_rule,
  /*  311 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  312 */  _URShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  313 */  _AndI_iRegIorL2I_immI_255_rule,
  /*  314 */  _AndI_iRegIorL2I_immI_65535_rule,
  /*  315 */  _AndL_iRegL_immL_255_rule,
  /*  316 */  _AndL_iRegL_immL_65535_rule,
  /*  317 */  _AndL_iRegL_immL_4294967295_rule,
  /*  318 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /*  319 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /*  320 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /*  321 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /*  322 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /*  323 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /*  324 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /*  325 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /*  326 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /*  327 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /*  328 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /*  329 */  _NegF_vRegF__rule,
  /*  330 */  _Binary__NegF_vRegF__vRegF_rule,
  /*  331 */  _Binary_vRegF__NegF_vRegF__rule,
  /*  332 */  _NegD_vRegD__rule,
  /*  333 */  _Binary__NegD_vRegD__vRegD_rule,
  /*  334 */  _Binary_vRegD__NegD_vRegD__rule,
  /*  335 */  _SubF_vRegF_vRegF_rule,
  /*  336 */  _SubD_vRegD_vRegD_rule,
  /*  337 */  _OverflowMulI_iRegIorL2I_iRegIorL2I_rule,
  /*  338 */  _OverflowMulL_iRegL_iRegL_rule,
  /*  339 */  _CmpI_iRegIorL2I_immI0_rule,
  /*  340 */  _CmpL_iRegL_immL0_rule,
  /*  341 */  _CmpP_iRegP_immP0_rule,
  /*  342 */  _CmpN_iRegN_immN0_rule,
  /*  343 */  _CmpP__DecodeN_iRegN__immP0_rule,
  /*  344 */  _CmpU_iRegIorL2I_immI0_rule,
  /*  345 */  _CmpUL_iRegL_immL0_rule,
  /*  346 */  _AndL_iRegL_immL_rule,
  /*  347 */  _CmpL__AndL_iRegL_immL_immL0_rule,
  /*  348 */  _AndI_iRegIorL2I_immI_rule,
  /*  349 */  _CmpI__AndI_iRegIorL2I_immI_immI0_rule,
  /*  350 */  _AndL_iRegL_iRegL_rule,
  /*  351 */  _AndI_iRegIorL2I_iRegIorL2I_rule,
  /*  352 */  _PartialSubtypeCheck_iRegP_R4_iRegP_R0_rule,
  /*  353 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /*  354 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /*  355 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /*  356 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /*  357 */  _Binary_iRegP_R3_immI_le_4_rule,
  /*  358 */  _Binary_iRegP_R3_immI_1_rule,
  /*  359 */  _Binary_iRegP_R1_iRegP_R3_rule,
  /*  360 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /*  361 */  _Binary_vecD_iRegIorL2I_rule,
  /*  362 */  _Binary_vecX_iRegIorL2I_rule,
  /*  363 */  _Binary_vecX_iRegL_rule,
  /*  364 */  _Binary_vecD_vRegF_rule,
  /*  365 */  _Binary_vecX_vRegF_rule,
  /*  366 */  _Binary_vecX_vRegD_rule,
  /*  367 */  _Binary_vecD_vecD_rule,
  /*  368 */  _Binary_vecX_vecX_rule,
  /*  369 */  _ReplicateB_immI_M1__rule,
  /*  370 */  _ReplicateS_immI_M1__rule,
  /*  371 */  _ReplicateI_immI_M1__rule,
  /*  372 */  _ReplicateL_immL_M1__rule,
  /*  373 */  _XorV_vecD__ReplicateB_immI_M1__rule,
  /*  374 */  _XorV__ReplicateB_immI_M1__vecD_rule,
  /*  375 */  _XorV_vecD__ReplicateS_immI_M1__rule,
  /*  376 */  _XorV__ReplicateS_immI_M1__vecD_rule,
  /*  377 */  _XorV_vecD__ReplicateI_immI_M1__rule,
  /*  378 */  _XorV__ReplicateI_immI_M1__vecD_rule,
  /*  379 */  _XorV_vecX__ReplicateB_immI_M1__rule,
  /*  380 */  _XorV__ReplicateB_immI_M1__vecX_rule,
  /*  381 */  _XorV_vecX__ReplicateS_immI_M1__rule,
  /*  382 */  _XorV__ReplicateS_immI_M1__vecX_rule,
  /*  383 */  _XorV_vecX__ReplicateI_immI_M1__rule,
  /*  384 */  _XorV__ReplicateI_immI_M1__vecX_rule,
  /*  385 */  _XorV_vecX__ReplicateL_immL_M1__rule,
  /*  386 */  _XorV__ReplicateL_immL_M1__vecX_rule,
  /*  387 */  _SubVF_vecD_vecD_rule,
  /*  388 */  _SubVF_vecX_vecX_rule,
  /*  389 */  _SubVD_vecX_vecX_rule,
  /*  390 */  _MulVS_vecD_vecD_rule,
  /*  391 */  _MulVS_vecX_vecX_rule,
  /*  392 */  _MulVI_vecD_vecD_rule,
  /*  393 */  _MulVI_vecX_vecX_rule,
  /*  394 */  _NegVF_vecD__rule,
  /*  395 */  _Binary__NegVF_vecD__vecD_rule,
  /*  396 */  _Binary_vecD__NegVF_vecD__rule,
  /*  397 */  _NegVF_vecX__rule,
  /*  398 */  _Binary__NegVF_vecX__vecX_rule,
  /*  399 */  _Binary_vecX__NegVF_vecX__rule,
  /*  400 */  _NegVD_vecX__rule,
  /*  401 */  _Binary__NegVD_vecX__vecX_rule,
  /*  402 */  _Binary_vecX__NegVD_vecX__rule,
  /*  403 */  _LShiftCntV_immI__rule,
  /*  404 */  _RShiftCntV_immI__rule,
  /*  405 */  _RShiftVB_vecD__RShiftCntV_immI__rule,
  /*  406 */  _RShiftVB_vecX__RShiftCntV_immI__rule,
  /*  407 */  _RShiftVS_vecD__RShiftCntV_immI__rule,
  /*  408 */  _RShiftVS_vecX__RShiftCntV_immI__rule,
  /*  409 */  _RShiftVI_vecD__RShiftCntV_immI__rule,
  /*  410 */  _RShiftVI_vecX__RShiftCntV_immI__rule,
  /*  411 */  _RShiftVL_vecX__RShiftCntV_immI__rule,
  /*  412 */  _URShiftVB_vecD__RShiftCntV_immI__rule,
  /*  413 */  _URShiftVB_vecX__RShiftCntV_immI__rule,
  /*  414 */  _URShiftVS_vecD__RShiftCntV_immI__rule,
  /*  415 */  _URShiftVS_vecX__RShiftCntV_immI__rule,
  /*  416 */  _URShiftVI_vecD__RShiftCntV_immI__rule,
  /*  417 */  _URShiftVI_vecX__RShiftCntV_immI__rule,
  /*  418 */  _URShiftVL_vecX__RShiftCntV_immI__rule,
  /*  419 */  _Binary_vReg_pRegGov_rule,
  /*  420 */  _MaskAll_immI_M1__rule,
  /*  421 */  _XorVMask_pRegGov__MaskAll_immI_M1__rule,
  /*  422 */  _MaskAll_immL_M1__rule,
  /*  423 */  _XorVMask_pRegGov__MaskAll_immL_M1__rule,
  /*  424 */  _Binary_vReg_vReg_rule,
  /*  425 */  _ReplicateB_immBAddSubV__rule,
  /*  426 */  _ReplicateS_immIAddSubV__rule,
  /*  427 */  _ReplicateI_immIAddSubV__rule,
  /*  428 */  _ReplicateL_immLAddSubV__rule,
  /*  429 */  _ReplicateB_immBLog__rule,
  /*  430 */  _ReplicateS_immSLog__rule,
  /*  431 */  _ReplicateI_immILog__rule,
  /*  432 */  _ReplicateL_immLLog__rule,
  /*  433 */  _XorV_vReg__ReplicateB_immI_M1__rule,
  /*  434 */  _XorV__ReplicateB_immI_M1__vReg_rule,
  /*  435 */  _XorV_vReg__ReplicateS_immI_M1__rule,
  /*  436 */  _XorV__ReplicateS_immI_M1__vReg_rule,
  /*  437 */  _XorV_vReg__ReplicateI_immI_M1__rule,
  /*  438 */  _XorV__ReplicateI_immI_M1__vReg_rule,
  /*  439 */  _XorV_vReg__ReplicateL_immL_M1__rule,
  /*  440 */  _XorV__ReplicateL_immL_M1__vReg_rule,
  /*  441 */  _NegVF_vReg__rule,
  /*  442 */  _Binary__NegVF_vReg__vReg_rule,
  /*  443 */  _Binary_vReg__NegVF_vReg__rule,
  /*  444 */  _NegVD_vReg__rule,
  /*  445 */  _Binary__NegVD_vReg__vReg_rule,
  /*  446 */  _Binary_vReg__NegVD_vReg__rule,
  /*  447 */  _MulVB_vReg_vReg_rule,
  /*  448 */  _MulVS_vReg_vReg_rule,
  /*  449 */  _MulVI_vReg_vReg_rule,
  /*  450 */  _MulVL_vReg_vReg_rule,
  /*  451 */  _Binary_immI_pRegGov_rule,
  /*  452 */  _LoadVector_indirect__rule,
  /*  453 */  _VectorStoreMask_pRegGov_immI_gt_1_rule,
  /*  454 */  _Binary_iRegIorL2I_vReg_rule,
  /*  455 */  _Binary_iRegL_vReg_rule,
  /*  456 */  _Binary_vRegF_vReg_rule,
  /*  457 */  _Binary_vRegD_vReg_rule,
  /*  458 */  _Binary_vReg__RShiftCntV_immI__rule,
  /*  459 */  _Binary_vReg__LShiftCntV_immI__rule,
  /*  460 */  _Binary_vReg_iRegIorL2I_rule,
  /*  461 */  _Binary_vReg_vRegF_rule,
  /*  462 */  _Binary_vReg_iRegL_rule,
  /*  463 */  _Binary_vReg_vRegD_rule,
  /*  464 */  _Binary_vReg__Binary_vReg_pRegGov_rule,
  // last internally defined operand
  /*  465 */  iRegINoSp_rule,
  /*  466 */  iRegLNoSp_rule,
  /*  467 */  iRegPNoSp_rule,
  /*  468 */  iRegPNoSp_rule,
  /*  469 */  iRegPNoSp_rule,
  /*  470 */  iRegPNoSp_rule,
  /*  471 */  iRegNNoSp_rule,
  /*  472 */  iRegNNoSp_rule,
  /*  473 */  iRegNNoSp_rule,
  /*  474 */  vRegF_rule,
  /*  475 */  vRegF_rule,
  /*  476 */  vRegD_rule,
  /*  477 */  vRegD_rule,
  /*  478 */  iRegINoSp_rule,
  /*  479 */  iRegINoSp_rule,
  /*  480 */  iRegINoSp_rule,
  /*  481 */  iRegINoSp_rule,
  /*  482 */  iRegPNoSp_rule,
  /*  483 */  iRegLNoSp_rule,
  /*  484 */  iRegPNoSp_rule,
  /*  485 */  iRegPNoSp_rule,
  /*  486 */  iRegI_rule,
  /*  487 */  iRegL_rule,
  /*  488 */  vRegF_rule,
  /*  489 */  vRegD_rule,
  /*  490 */  vecD_rule,
  /*  491 */  vecX_rule,
  /*  492 */  vReg_rule,
  /*  493 */  pRegGov_rule,
  /*  494 */  rFlagsReg_rule,
  /*  495 */  rFlagsReg_rule,
  /*  496 */  rFlagsReg_rule,
  /*  497 */  vRegF_rule,
  /*  498 */  vRegD_rule,
  /*  499 */  vRegF_rule,
  /*  500 */  vRegD_rule,
  /*  501 */  iRegINoSp_rule,
  /*  502 */  vRegF_rule,
  /*  503 */  iRegLNoSp_rule,
  /*  504 */  vRegD_rule,
  /*  505 */  iRegINoSp_rule,
  /*  506 */  vRegF_rule,
  /*  507 */  iRegLNoSp_rule,
  /*  508 */  vRegD_rule,
  /*  509 */  rFlagsReg_rule,
  /*  510 */  rFlagsReg_rule,
  /*  511 */  rFlagsReg_rule,
  /*  512 */  rFlagsReg_rule,
  /*  513 */  rFlagsReg_rule,
  /*  514 */  rFlagsReg_rule,
  /*  515 */  rFlagsReg_rule,
  /*  516 */  rFlagsReg_rule,
  /*  517 */  rFlagsReg_rule,
  /*  518 */  rFlagsReg_rule,
  /*  519 */  rFlagsReg_rule,
  /*  520 */  rFlagsReg_rule,
  /*  521 */  rFlagsReg_rule,
  /*  522 */  rFlagsReg_rule,
  /*  523 */  rFlagsReg_rule,
  /*  524 */  rFlagsReg_rule,
  /*  525 */  rFlagsRegU_rule,
  /*  526 */  rFlagsRegU_rule,
  /*  527 */  rFlagsRegU_rule,
  /*  528 */  rFlagsRegU_rule,
  /*  529 */  rFlagsReg_rule,
  /*  530 */  rFlagsReg_rule,
  /*  531 */  rFlagsReg_rule,
  /*  532 */  rFlagsReg_rule,
  /*  533 */  rFlagsRegU_rule,
  /*  534 */  rFlagsRegU_rule,
  /*  535 */  rFlagsRegU_rule,
  /*  536 */  rFlagsRegU_rule,
  /*  537 */  rFlagsRegU_rule,
  /*  538 */  rFlagsRegU_rule,
  /*  539 */  rFlagsRegU_rule,
  /*  540 */  rFlagsRegU_rule,
  /*  541 */  rFlagsReg_rule,
  /*  542 */  rFlagsReg_rule,
  /*  543 */  rFlagsReg_rule,
  /*  544 */  rFlagsReg_rule,
  /*  545 */  rFlagsReg_rule,
  /*  546 */  rFlagsReg_rule,
  /*  547 */  rFlagsReg_rule,
  /*  548 */  rFlagsReg_rule,
  /*  549 */  rFlagsReg_rule,
  /*  550 */  rFlagsReg_rule,
  /*  551 */  rFlagsReg_rule,
  /*  552 */  thread_RegP_rule,
  /*  553 */  vecD_rule,
  /*  554 */  vecX_rule,
  /*  555 */  vecX_rule,
  /*  556 */  vecD_rule,
  /*  557 */  vecX_rule,
  /*  558 */  vecD_rule,
  /*  559 */  vecD_rule,
  /*  560 */  vecD_rule,
  /*  561 */  vecX_rule,
  /*  562 */  vecD_rule,
  /*  563 */  vecD_rule,
  /*  564 */  vecD_rule,
  /*  565 */  vecX_rule,
  /*  566 */  vecD_rule,
  /*  567 */  vecX_rule,
  /*  568 */  vecD_rule,
  /*  569 */  vecD_rule,
  /*  570 */  vecX_rule,
  /*  571 */  vecD_rule,
  /*  572 */  vecD_rule,
  /*  573 */  vecX_rule,
  /*  574 */  vecX_rule,
  /*  575 */  vecX_rule,
  /*  576 */  vecX_rule,
  /*  577 */  vecX_rule,
  /*  578 */  vecX_rule,
  /*  579 */  vecD_rule,
  /*  580 */  vecX_rule,
  /*  581 */  vecX_rule,
  /*  582 */  vecD_rule,
  /*  583 */  vecD_rule,
  /*  584 */  vecX_rule,
  /*  585 */  vecD_rule,
  /*  586 */  vecD_rule,
  /*  587 */  vecX_rule,
  /*  588 */  vecD_rule,
  /*  589 */  vecX_rule,
  /*  590 */  vecD_rule,
  /*  591 */  vecX_rule,
  /*  592 */  vecX_rule,
  /*  593 */  vecD_rule,
  /*  594 */  vecX_rule,
  /*  595 */  vecD_rule,
  /*  596 */  vecX_rule,
  /*  597 */  vecD_rule,
  /*  598 */  vecX_rule,
  /*  599 */  vecD_rule,
  /*  600 */  vecX_rule,
  /*  601 */  vecX_rule,
  /*  602 */  vecD_rule,
  /*  603 */  vecX_rule,
  /*  604 */  vecD_rule,
  /*  605 */  vecX_rule,
  /*  606 */  vecD_rule,
  /*  607 */  vecX_rule,
  /*  608 */  vecX_rule,
  /*  609 */  vecD_rule,
  /*  610 */  vecX_rule,
  /*  611 */  vecX_rule,
  /*  612 */  vecD_rule,
  /*  613 */  vecX_rule,
  /*  614 */  vecX_rule,
  /*  615 */  vecD_rule,
  /*  616 */  vecX_rule,
  /*  617 */  vecX_rule,
  /*  618 */  vecD_rule,
  /*  619 */  vecD_rule,
  /*  620 */  vecX_rule,
  /*  621 */  vecX_rule,
  /*  622 */  vecX_rule,
  /*  623 */  vecD_rule,
  /*  624 */  iRegINoSp_rule,
  /*  625 */  iRegINoSp_rule,
  /*  626 */  iRegINoSp_rule,
  /*  627 */  iRegINoSp_rule,
  /*  628 */  iRegLNoSp_rule,
  /*  629 */  iRegLNoSp_rule,
  /*  630 */  vReg_rule,
  /*  631 */  pRegGov_rule,
  /*  632 */  vReg_rule,
  /*  633 */  vReg_rule,
  /*  634 */  vReg_rule,
  /*  635 */  vReg_rule,
  /*  636 */  vReg_rule,
  /*  637 */  vReg_rule,
  /*  638 */  vReg_rule,
  /*  639 */  vReg_rule,
  /*  640 */  vReg_rule,
  /*  641 */  vReg_rule,
  /*  642 */  vReg_rule,
  /*  643 */  vReg_rule,
  /*  644 */  vReg_rule,
  /*  645 */  vReg_rule,
  /*  646 */  vReg_rule,
  /*  647 */  vReg_rule,
  /*  648 */  vReg_rule,
  /*  649 */  vReg_rule,
  /*  650 */  vReg_rule,
  /*  651 */  pRegGov_rule,
  /*  652 */  pRegGov_rule,
  /*  653 */  pRegGov_rule,
  /*  654 */  vReg_rule,
  /*  655 */  vReg_rule,
  /*  656 */  vReg_rule,
  /*  657 */  vReg_rule,
  /*  658 */  vReg_rule,
  /*  659 */  vReg_rule,
  /*  660 */  vReg_rule,
  /*  661 */  vReg_rule,
  /*  662 */  vReg_rule,
  /*  663 */  vReg_rule,
  /*  664 */  vReg_rule,
  /*  665 */  vReg_rule,
  /*  666 */  iRegINoSp_rule,
  /*  667 */  iRegINoSp_rule,
  /*  668 */  iRegLNoSp_rule,
  /*  669 */  iRegINoSp_rule,
  /*  670 */  iRegLNoSp_rule,
  /*  671 */  iRegINoSp_rule,
  /*  672 */  iRegLNoSp_rule,
  /*  673 */  iRegINoSp_rule,
  /*  674 */  iRegLNoSp_rule,
  /*  675 */  iRegINoSp_rule,
  /*  676 */  iRegLNoSp_rule,
  /*  677 */  iRegLNoSp_rule,
  /*  678 */  iRegLNoSp_rule,
  /*  679 */  iRegINoSp_rule,
  /*  680 */  iRegPNoSp_rule,
  /*  681 */  iRegNNoSp_rule,
  /*  682 */  iRegPNoSp_rule,
  /*  683 */  iRegNNoSp_rule,
  /*  684 */  vRegF_rule,
  /*  685 */  vRegD_rule,
  /*  686 */  Universe_rule,
  /*  687 */  Universe_rule,
  /*  688 */  Universe_rule,
  /*  689 */  Universe_rule,
  /*  690 */  Universe_rule,
  /*  691 */  Universe_rule,
  /*  692 */  Universe_rule,
  /*  693 */  Universe_rule,
  /*  694 */  Universe_rule,
  /*  695 */  Universe_rule,
  /*  696 */  Universe_rule,
  /*  697 */  Universe_rule,
  /*  698 */  Universe_rule,
  /*  699 */  Universe_rule,
  /*  700 */  Universe_rule,
  /*  701 */  Universe_rule,
  /*  702 */  Universe_rule,
  /*  703 */  Universe_rule,
  /*  704 */  iRegINoSp_rule,
  /*  705 */  iRegLNoSp_rule,
  /*  706 */  iRegINoSp_rule,
  /*  707 */  iRegLNoSp_rule,
  /*  708 */  iRegINoSp_rule,
  /*  709 */  iRegINoSp_rule,
  /*  710 */  iRegLNoSp_rule,
  /*  711 */  iRegLNoSp_rule,
  /*  712 */  iRegINoSp_rule,
  /*  713 */  iRegLNoSp_rule,
  /*  714 */  iRegLNoSp_rule,
  /*  715 */  iRegPNoSp_rule,
  /*  716 */  iRegNNoSp_rule,
  /*  717 */  vRegF_rule,
  /*  718 */  vRegD_rule,
  /*  719 */  Universe_rule,
  /*  720 */  Universe_rule,
  /*  721 */  Universe_rule,
  /*  722 */  Universe_rule,
  /*  723 */  Universe_rule,
  /*  724 */  Universe_rule,
  /*  725 */  Universe_rule,
  /*  726 */  Universe_rule,
  /*  727 */  Universe_rule,
  /*  728 */  Universe_rule,
  /*  729 */  Universe_rule,
  /*  730 */  iRegINoSp_rule,
  /*  731 */  iRegLNoSp_rule,
  /*  732 */  iRegINoSp_rule,
  /*  733 */  iRegINoSp_rule,
  /*  734 */  iRegINoSp_rule,
  /*  735 */  iRegINoSp_rule,
  /*  736 */  iRegINoSp_rule,
  /*  737 */  iRegINoSp_rule,
  /*  738 */  Universe_rule,
  /*  739 */  Universe_rule,
  /*  740 */  Universe_rule,
  /*  741 */  Universe_rule,
  /*  742 */  Universe_rule,
  /*  743 */  Universe_rule,
  /*  744 */  Universe_rule,
  /*  745 */  Universe_rule,
  /*  746 */  Universe_rule,
  /*  747 */  Universe_rule,
  /*  748 */  Universe_rule,
  /*  749 */  Universe_rule,
  /*  750 */  iRegINoSp_rule,
  /*  751 */  iRegINoSp_rule,
  /*  752 */  iRegNNoSp_rule,
  /*  753 */  iRegNNoSp_rule,
  /*  754 */  iRegPNoSp_rule,
  /*  755 */  iRegPNoSp_rule,
  /*  756 */  iRegNNoSp_rule,
  /*  757 */  iRegPNoSp_rule,
  /*  758 */  iRegPNoSp_rule,
  /*  759 */  iRegINoSp_rule,
  /*  760 */  iRegINoSp_rule,
  /*  761 */  iRegINoSp_rule,
  /*  762 */  iRegINoSp_rule,
  /*  763 */  iRegINoSp_rule,
  /*  764 */  iRegINoSp_rule,
  /*  765 */  iRegINoSp_rule,
  /*  766 */  iRegINoSp_rule,
  /*  767 */  iRegINoSp_rule,
  /*  768 */  iRegINoSp_rule,
  /*  769 */  iRegINoSp_rule,
  /*  770 */  iRegINoSp_rule,
  /*  771 */  iRegINoSp_rule,
  /*  772 */  iRegINoSp_rule,
  /*  773 */  iRegINoSp_rule,
  /*  774 */  iRegLNoSp_rule,
  /*  775 */  iRegNNoSp_rule,
  /*  776 */  iRegPNoSp_rule,
  /*  777 */  iRegINoSp_rule,
  /*  778 */  iRegINoSp_rule,
  /*  779 */  iRegINoSp_rule,
  /*  780 */  iRegLNoSp_rule,
  /*  781 */  iRegNNoSp_rule,
  /*  782 */  iRegPNoSp_rule,
  /*  783 */  iRegINoSp_rule,
  /*  784 */  iRegINoSp_rule,
  /*  785 */  iRegINoSp_rule,
  /*  786 */  iRegINoSp_rule,
  /*  787 */  iRegINoSp_rule,
  /*  788 */  iRegINoSp_rule,
  /*  789 */  iRegINoSp_rule,
  /*  790 */  iRegINoSp_rule,
  /*  791 */  iRegINoSp_rule,
  /*  792 */  iRegINoSp_rule,
  /*  793 */  iRegINoSp_rule,
  /*  794 */  iRegINoSp_rule,
  /*  795 */  iRegINoSp_rule,
  /*  796 */  iRegLNoSp_rule,
  /*  797 */  iRegINoSp_rule,
  /*  798 */  iRegPNoSp_rule,
  /*  799 */  iRegINoSp_rule,
  /*  800 */  iRegLNoSp_rule,
  /*  801 */  iRegINoSp_rule,
  /*  802 */  iRegPNoSp_rule,
  /*  803 */  iRegLNoSp_rule,
  /*  804 */  Universe_rule,
  /*  805 */  iRegLNoSp_rule,
  /*  806 */  Universe_rule,
  /*  807 */  iRegINoSp_rule,
  /*  808 */  Universe_rule,
  /*  809 */  iRegINoSp_rule,
  /*  810 */  Universe_rule,
  /*  811 */  iRegLNoSp_rule,
  /*  812 */  Universe_rule,
  /*  813 */  iRegLNoSp_rule,
  /*  814 */  Universe_rule,
  /*  815 */  iRegINoSp_rule,
  /*  816 */  Universe_rule,
  /*  817 */  iRegINoSp_rule,
  /*  818 */  Universe_rule,
  /*  819 */  iRegINoSp_rule,
  /*  820 */  iRegINoSp_rule,
  /*  821 */  iRegINoSp_rule,
  /*  822 */  iRegINoSp_rule,
  /*  823 */  iRegINoSp_rule,
  /*  824 */  iRegINoSp_rule,
  /*  825 */  iRegINoSp_rule,
  /*  826 */  iRegINoSp_rule,
  /*  827 */  iRegINoSp_rule,
  /*  828 */  iRegINoSp_rule,
  /*  829 */  iRegLNoSp_rule,
  /*  830 */  iRegLNoSp_rule,
  /*  831 */  iRegLNoSp_rule,
  /*  832 */  iRegLNoSp_rule,
  /*  833 */  iRegLNoSp_rule,
  /*  834 */  iRegLNoSp_rule,
  /*  835 */  iRegPNoSp_rule,
  /*  836 */  iRegPNoSp_rule,
  /*  837 */  iRegPNoSp_rule,
  /*  838 */  iRegPNoSp_rule,
  /*  839 */  iRegPNoSp_rule,
  /*  840 */  iRegPNoSp_rule,
  /*  841 */  iRegNNoSp_rule,
  /*  842 */  iRegNNoSp_rule,
  /*  843 */  iRegNNoSp_rule,
  /*  844 */  iRegNNoSp_rule,
  /*  845 */  iRegNNoSp_rule,
  /*  846 */  iRegNNoSp_rule,
  /*  847 */  vRegF_rule,
  /*  848 */  vRegF_rule,
  /*  849 */  vRegD_rule,
  /*  850 */  vRegD_rule,
  /*  851 */  iRegINoSp_rule,
  /*  852 */  iRegINoSp_rule,
  /*  853 */  iRegINoSp_rule,
  /*  854 */  iRegPNoSp_rule,
  /*  855 */  iRegPNoSp_rule,
  /*  856 */  iRegPNoSp_rule,
  /*  857 */  iRegPNoSp_rule,
  /*  858 */  iRegLNoSp_rule,
  /*  859 */  iRegPNoSp_rule,
  /*  860 */  iRegLNoSp_rule,
  /*  861 */  iRegLNoSp_rule,
  /*  862 */  iRegINoSp_rule,
  /*  863 */  iRegINoSp_rule,
  /*  864 */  iRegLNoSp_rule,
  /*  865 */  iRegLNoSp_rule,
  /*  866 */  iRegINoSp_rule,
  /*  867 */  iRegLNoSp_rule,
  /*  868 */  iRegINoSp_rule,
  /*  869 */  iRegLNoSp_rule,
  /*  870 */  iRegLNoSp_rule,
  /*  871 */  iRegLNoSp_rule,
  /*  872 */  iRegLNoSp_rule,
  /*  873 */  iRegINoSp_rule,
  /*  874 */  iRegINoSp_rule,
  /*  875 */  iRegINoSp_rule,
  /*  876 */  iRegINoSp_rule,
  /*  877 */  iRegINoSp_rule,
  /*  878 */  iRegLNoSp_rule,
  /*  879 */  iRegLNoSp_rule,
  /*  880 */  iRegLNoSp_rule,
  /*  881 */  iRegLNoSp_rule,
  /*  882 */  iRegLNoSp_rule,
  /*  883 */  iRegLNoSp_rule,
  /*  884 */  iRegLNoSp_rule,
  /*  885 */  iRegLNoSp_rule,
  /*  886 */  iRegLNoSp_rule,
  /*  887 */  iRegLNoSp_rule,
  /*  888 */  iRegLNoSp_rule,
  /*  889 */  iRegLNoSp_rule,
  /*  890 */  iRegLNoSp_rule,
  /*  891 */  iRegINoSp_rule,
  /*  892 */  iRegINoSp_rule,
  /*  893 */  iRegLNoSp_rule,
  /*  894 */  iRegINoSp_rule,
  /*  895 */  iRegLNoSp_rule,
  /*  896 */  iRegINoSp_rule,
  /*  897 */  iRegINoSp_rule,
  /*  898 */  iRegINoSp_rule,
  /*  899 */  iRegINoSp_rule,
  /*  900 */  iRegINoSp_rule,
  /*  901 */  iRegINoSp_rule,
  /*  902 */  iRegLNoSp_rule,
  /*  903 */  iRegLNoSp_rule,
  /*  904 */  iRegLNoSp_rule,
  /*  905 */  iRegLNoSp_rule,
  /*  906 */  iRegLNoSp_rule,
  /*  907 */  iRegLNoSp_rule,
  /*  908 */  iRegLNoSp_rule,
  /*  909 */  iRegLNoSp_rule,
  /*  910 */  iRegINoSp_rule,
  /*  911 */  iRegINoSp_rule,
  /*  912 */  iRegINoSp_rule,
  /*  913 */  iRegLNoSp_rule,
  /*  914 */  iRegLNoSp_rule,
  /*  915 */  iRegINoSp_rule,
  /*  916 */  iRegINoSp_rule,
  /*  917 */  iRegLNoSp_rule,
  /*  918 */  iRegLNoSp_rule,
  /*  919 */  iRegINoSp_rule,
  /*  920 */  iRegINoSp_rule,
  /*  921 */  iRegLNoSp_rule,
  /*  922 */  iRegLNoSp_rule,
  /*  923 */  iRegINoSp_rule,
  /*  924 */  iRegINoSp_rule,
  /*  925 */  iRegLNoSp_rule,
  /*  926 */  iRegLNoSp_rule,
  /*  927 */  iRegINoSp_rule,
  /*  928 */  iRegINoSp_rule,
  /*  929 */  iRegLNoSp_rule,
  /*  930 */  iRegLNoSp_rule,
  /*  931 */  iRegINoSp_rule,
  /*  932 */  iRegINoSp_rule,
  /*  933 */  iRegLNoSp_rule,
  /*  934 */  iRegLNoSp_rule,
  /*  935 */  iRegINoSp_rule,
  /*  936 */  iRegINoSp_rule,
  /*  937 */  iRegLNoSp_rule,
  /*  938 */  iRegLNoSp_rule,
  /*  939 */  iRegINoSp_rule,
  /*  940 */  iRegINoSp_rule,
  /*  941 */  iRegINoSp_rule,
  /*  942 */  iRegINoSp_rule,
  /*  943 */  iRegLNoSp_rule,
  /*  944 */  iRegLNoSp_rule,
  /*  945 */  iRegLNoSp_rule,
  /*  946 */  iRegLNoSp_rule,
  /*  947 */  iRegINoSp_rule,
  /*  948 */  iRegINoSp_rule,
  /*  949 */  iRegINoSp_rule,
  /*  950 */  iRegINoSp_rule,
  /*  951 */  iRegLNoSp_rule,
  /*  952 */  iRegLNoSp_rule,
  /*  953 */  iRegLNoSp_rule,
  /*  954 */  iRegLNoSp_rule,
  /*  955 */  iRegINoSp_rule,
  /*  956 */  iRegINoSp_rule,
  /*  957 */  iRegINoSp_rule,
  /*  958 */  iRegINoSp_rule,
  /*  959 */  iRegLNoSp_rule,
  /*  960 */  iRegLNoSp_rule,
  /*  961 */  iRegLNoSp_rule,
  /*  962 */  iRegLNoSp_rule,
  /*  963 */  iRegINoSp_rule,
  /*  964 */  iRegINoSp_rule,
  /*  965 */  iRegINoSp_rule,
  /*  966 */  iRegINoSp_rule,
  /*  967 */  iRegLNoSp_rule,
  /*  968 */  iRegLNoSp_rule,
  /*  969 */  iRegLNoSp_rule,
  /*  970 */  iRegLNoSp_rule,
  /*  971 */  iRegINoSp_rule,
  /*  972 */  iRegINoSp_rule,
  /*  973 */  iRegLNoSp_rule,
  /*  974 */  iRegLNoSp_rule,
  /*  975 */  iRegINoSp_rule,
  /*  976 */  iRegINoSp_rule,
  /*  977 */  iRegLNoSp_rule,
  /*  978 */  iRegLNoSp_rule,
  /*  979 */  iRegINoSp_rule,
  /*  980 */  iRegINoSp_rule,
  /*  981 */  iRegLNoSp_rule,
  /*  982 */  iRegLNoSp_rule,
  /*  983 */  iRegINoSp_rule,
  /*  984 */  iRegINoSp_rule,
  /*  985 */  iRegLNoSp_rule,
  /*  986 */  iRegLNoSp_rule,
  /*  987 */  iRegINoSp_rule,
  /*  988 */  iRegINoSp_rule,
  /*  989 */  iRegLNoSp_rule,
  /*  990 */  iRegLNoSp_rule,
  /*  991 */  iRegINoSp_rule,
  /*  992 */  iRegINoSp_rule,
  /*  993 */  iRegLNoSp_rule,
  /*  994 */  iRegLNoSp_rule,
  /*  995 */  iRegINoSp_rule,
  /*  996 */  iRegINoSp_rule,
  /*  997 */  iRegLNoSp_rule,
  /*  998 */  iRegLNoSp_rule,
  /*  999 */  iRegINoSp_rule,
  /* 1000 */  iRegINoSp_rule,
  /* 1001 */  iRegLNoSp_rule,
  /* 1002 */  iRegLNoSp_rule,
  /* 1003 */  iRegINoSp_rule,
  /* 1004 */  iRegINoSp_rule,
  /* 1005 */  iRegLNoSp_rule,
  /* 1006 */  iRegLNoSp_rule,
  /* 1007 */  iRegINoSp_rule,
  /* 1008 */  iRegINoSp_rule,
  /* 1009 */  iRegLNoSp_rule,
  /* 1010 */  iRegLNoSp_rule,
  /* 1011 */  iRegINoSp_rule,
  /* 1012 */  iRegINoSp_rule,
  /* 1013 */  iRegLNoSp_rule,
  /* 1014 */  iRegLNoSp_rule,
  /* 1015 */  iRegINoSp_rule,
  /* 1016 */  iRegINoSp_rule,
  /* 1017 */  iRegLNoSp_rule,
  /* 1018 */  iRegLNoSp_rule,
  /* 1019 */  iRegINoSp_rule,
  /* 1020 */  iRegINoSp_rule,
  /* 1021 */  iRegLNoSp_rule,
  /* 1022 */  iRegLNoSp_rule,
  /* 1023 */  iRegINoSp_rule,
  /* 1024 */  iRegINoSp_rule,
  /* 1025 */  iRegLNoSp_rule,
  /* 1026 */  iRegLNoSp_rule,
  /* 1027 */  iRegINoSp_rule,
  /* 1028 */  iRegINoSp_rule,
  /* 1029 */  iRegLNoSp_rule,
  /* 1030 */  iRegLNoSp_rule,
  /* 1031 */  iRegINoSp_rule,
  /* 1032 */  iRegINoSp_rule,
  /* 1033 */  iRegLNoSp_rule,
  /* 1034 */  iRegLNoSp_rule,
  /* 1035 */  iRegINoSp_rule,
  /* 1036 */  iRegINoSp_rule,
  /* 1037 */  iRegLNoSp_rule,
  /* 1038 */  iRegLNoSp_rule,
  /* 1039 */  iRegINoSp_rule,
  /* 1040 */  iRegINoSp_rule,
  /* 1041 */  iRegLNoSp_rule,
  /* 1042 */  iRegLNoSp_rule,
  /* 1043 */  iRegINoSp_rule,
  /* 1044 */  iRegINoSp_rule,
  /* 1045 */  iRegLNoSp_rule,
  /* 1046 */  iRegLNoSp_rule,
  /* 1047 */  iRegINoSp_rule,
  /* 1048 */  iRegLNoSp_rule,
  /* 1049 */  iRegINoSp_rule,
  /* 1050 */  iRegLNoSp_rule,
  /* 1051 */  iRegINoSp_rule,
  /* 1052 */  iRegLNoSp_rule,
  /* 1053 */  iRegLNoSp_rule,
  /* 1054 */  iRegINoSp_rule,
  /* 1055 */  iRegLNoSp_rule,
  /* 1056 */  iRegINoSp_rule,
  /* 1057 */  iRegINoSp_rule,
  /* 1058 */  iRegLNoSp_rule,
  /* 1059 */  iRegLNoSp_rule,
  /* 1060 */  iRegINoSp_rule,
  /* 1061 */  iRegLNoSp_rule,
  /* 1062 */  iRegLNoSp_rule,
  /* 1063 */  iRegINoSp_rule,
  /* 1064 */  iRegLNoSp_rule,
  /* 1065 */  iRegINoSp_rule,
  /* 1066 */  iRegLNoSp_rule,
  /* 1067 */  iRegLNoSp_rule,
  /* 1068 */  iRegLNoSp_rule,
  /* 1069 */  iRegINoSp_rule,
  /* 1070 */  iRegINoSp_rule,
  /* 1071 */  iRegLNoSp_rule,
  /* 1072 */  iRegLNoSp_rule,
  /* 1073 */  iRegINoSp_rule,
  /* 1074 */  iRegINoSp_rule,
  /* 1075 */  iRegINoSp_rule,
  /* 1076 */  iRegLNoSp_rule,
  /* 1077 */  iRegINoSp_rule,
  /* 1078 */  iRegLNoSp_rule,
  /* 1079 */  iRegINoSp_rule,
  /* 1080 */  iRegLNoSp_rule,
  /* 1081 */  iRegLNoSp_rule,
  /* 1082 */  iRegLNoSp_rule,
  /* 1083 */  iRegLNoSp_rule,
  /* 1084 */  iRegINoSp_rule,
  /* 1085 */  iRegINoSp_rule,
  /* 1086 */  iRegINoSp_rule,
  /* 1087 */  iRegINoSp_rule,
  /* 1088 */  iRegINoSp_rule,
  /* 1089 */  iRegINoSp_rule,
  /* 1090 */  iRegLNoSp_rule,
  /* 1091 */  iRegLNoSp_rule,
  /* 1092 */  iRegLNoSp_rule,
  /* 1093 */  iRegLNoSp_rule,
  /* 1094 */  iRegLNoSp_rule,
  /* 1095 */  iRegLNoSp_rule,
  /* 1096 */  iRegLNoSp_rule,
  /* 1097 */  iRegLNoSp_rule,
  /* 1098 */  iRegINoSp_rule,
  /* 1099 */  iRegINoSp_rule,
  /* 1100 */  iRegINoSp_rule,
  /* 1101 */  iRegINoSp_rule,
  /* 1102 */  iRegLNoSp_rule,
  /* 1103 */  iRegLNoSp_rule,
  /* 1104 */  iRegLNoSp_rule,
  /* 1105 */  iRegLNoSp_rule,
  /* 1106 */  iRegLNoSp_rule,
  /* 1107 */  iRegLNoSp_rule,
  /* 1108 */  iRegINoSp_rule,
  /* 1109 */  iRegINoSp_rule,
  /* 1110 */  iRegLNoSp_rule,
  /* 1111 */  iRegLNoSp_rule,
  /* 1112 */  iRegLNoSp_rule,
  /* 1113 */  iRegLNoSp_rule,
  /* 1114 */  iRegLNoSp_rule,
  /* 1115 */  iRegLNoSp_rule,
  /* 1116 */  iRegLNoSp_rule,
  /* 1117 */  iRegLNoSp_rule,
  /* 1118 */  iRegLNoSp_rule,
  /* 1119 */  iRegLNoSp_rule,
  /* 1120 */  iRegLNoSp_rule,
  /* 1121 */  iRegLNoSp_rule,
  /* 1122 */  iRegINoSp_rule,
  /* 1123 */  iRegINoSp_rule,
  /* 1124 */  iRegINoSp_rule,
  /* 1125 */  iRegINoSp_rule,
  /* 1126 */  iRegINoSp_rule,
  /* 1127 */  iRegINoSp_rule,
  /* 1128 */  iRegLNoSp_rule,
  /* 1129 */  iRegLNoSp_rule,
  /* 1130 */  iRegLNoSp_rule,
  /* 1131 */  iRegLNoSp_rule,
  /* 1132 */  iRegLNoSp_rule,
  /* 1133 */  iRegLNoSp_rule,
  /* 1134 */  iRegLNoSp_rule,
  /* 1135 */  iRegLNoSp_rule,
  /* 1136 */  iRegLNoSp_rule,
  /* 1137 */  iRegLNoSp_rule,
  /* 1138 */  iRegLNoSp_rule,
  /* 1139 */  iRegLNoSp_rule,
  /* 1140 */  iRegINoSp_rule,
  /* 1141 */  iRegINoSp_rule,
  /* 1142 */  iRegINoSp_rule,
  /* 1143 */  iRegINoSp_rule,
  /* 1144 */  iRegINoSp_rule,
  /* 1145 */  iRegINoSp_rule,
  /* 1146 */  vRegF_rule,
  /* 1147 */  vRegD_rule,
  /* 1148 */  vRegF_rule,
  /* 1149 */  vRegD_rule,
  /* 1150 */  vRegF_rule,
  /* 1151 */  vRegD_rule,
  /* 1152 */  vRegF_rule,
  /* 1153 */  vRegD_rule,
  /* 1154 */  vRegF_rule,
  /* 1155 */  vRegF_rule,
  /* 1156 */  vRegD_rule,
  /* 1157 */  vRegD_rule,
  /* 1158 */  vRegF_rule,
  /* 1159 */  vRegF_rule,
  /* 1160 */  vRegD_rule,
  /* 1161 */  vRegD_rule,
  /* 1162 */  vRegF_rule,
  /* 1163 */  vRegD_rule,
  /* 1164 */  vRegF_rule,
  /* 1165 */  vRegF_rule,
  /* 1166 */  vRegD_rule,
  /* 1167 */  vRegD_rule,
  /* 1168 */  vRegF_rule,
  /* 1169 */  vRegD_rule,
  /* 1170 */  iRegINoSp_rule,
  /* 1171 */  iRegLNoSp_rule,
  /* 1172 */  vRegF_rule,
  /* 1173 */  vRegD_rule,
  /* 1174 */  vRegD_rule,
  /* 1175 */  vRegF_rule,
  /* 1176 */  vRegD_rule,
  /* 1177 */  vRegD_rule,
  /* 1178 */  vRegF_rule,
  /* 1179 */  vRegD_rule,
  /* 1180 */  vRegF_rule,
  /* 1181 */  Universe_rule,
  /* 1182 */  iRegINoSp_rule,
  /* 1183 */  iRegINoSp_rule,
  /* 1184 */  iRegINoSp_rule,
  /* 1185 */  iRegINoSp_rule,
  /* 1186 */  iRegINoSp_rule,
  /* 1187 */  iRegINoSp_rule,
  /* 1188 */  iRegLNoSp_rule,
  /* 1189 */  iRegLNoSp_rule,
  /* 1190 */  iRegLNoSp_rule,
  /* 1191 */  iRegLNoSp_rule,
  /* 1192 */  iRegLNoSp_rule,
  /* 1193 */  iRegLNoSp_rule,
  /* 1194 */  iRegLNoSp_rule,
  /* 1195 */  iRegLNoSp_rule,
  /* 1196 */  iRegINoSp_rule,
  /* 1197 */  iRegINoSp_rule,
  /* 1198 */  iRegINoSp_rule,
  /* 1199 */  vRegF_rule,
  /* 1200 */  vRegD_rule,
  /* 1201 */  iRegINoSp_rule,
  /* 1202 */  iRegLNoSp_rule,
  /* 1203 */  vRegF_rule,
  /* 1204 */  vRegF_rule,
  /* 1205 */  iRegINoSp_rule,
  /* 1206 */  iRegLNoSp_rule,
  /* 1207 */  vRegD_rule,
  /* 1208 */  vRegD_rule,
  /* 1209 */  stackSlotI_rule,
  /* 1210 */  stackSlotF_rule,
  /* 1211 */  stackSlotL_rule,
  /* 1212 */  stackSlotD_rule,
  /* 1213 */  Universe_rule,
  /* 1214 */  Universe_rule,
  /* 1215 */  Universe_rule,
  /* 1216 */  Universe_rule,
  /* 1217 */  iRegINoSp_rule,
  /* 1218 */  iRegINoSp_rule,
  /* 1219 */  iRegINoSp_rule,
  /* 1220 */  iRegINoSp_rule,
  /* 1221 */  iRegINoSp_rule,
  /* 1222 */  iRegINoSp_rule,
  /* 1223 */  0,
  /* 1224 */  iRegINoSp_rule,
  /* 1225 */  0,
  /* 1226 */  iRegINoSp_rule,
  /* 1227 */  Universe_rule,
  /* 1228 */  Universe_rule,
  /* 1229 */  Universe_rule,
  /* 1230 */  Universe_rule,
  /* 1231 */  Universe_rule,
  /* 1232 */  Universe_rule,
  /* 1233 */  Universe_rule,
  /* 1234 */  Universe_rule,
  /* 1235 */  Universe_rule,
  /* 1236 */  Universe_rule,
  /* 1237 */  Universe_rule,
  /* 1238 */  Universe_rule,
  /* 1239 */  Universe_rule,
  /* 1240 */  Universe_rule,
  /* 1241 */  Universe_rule,
  /* 1242 */  Universe_rule,
  /* 1243 */  Universe_rule,
  /* 1244 */  Universe_rule,
  /* 1245 */  Universe_rule,
  /* 1246 */  Universe_rule,
  /* 1247 */  Universe_rule,
  /* 1248 */  Universe_rule,
  /* 1249 */  Universe_rule,
  /* 1250 */  Universe_rule,
  /* 1251 */  Universe_rule,
  /* 1252 */  Universe_rule,
  /* 1253 */  Universe_rule,
  /* 1254 */  Universe_rule,
  /* 1255 */  Universe_rule,
  /* 1256 */  iRegP_R0_rule,
  /* 1257 */  Universe_rule,
  /* 1258 */  Universe_rule,
  /* 1259 */  Universe_rule,
  /* 1260 */  iRegP_R5_rule,
  /* 1261 */  iRegI_R0_rule,
  /* 1262 */  iRegI_R0_rule,
  /* 1263 */  iRegI_R0_rule,
  /* 1264 */  iRegI_R0_rule,
  /* 1265 */  iRegI_R0_rule,
  /* 1266 */  iRegI_R0_rule,
  /* 1267 */  iRegI_R0_rule,
  /* 1268 */  iRegI_R0_rule,
  /* 1269 */  iRegI_R0_rule,
  /* 1270 */  iRegI_R0_rule,
  /* 1271 */  iRegI_R0_rule,
  /* 1272 */  iRegI_R0_rule,
  /* 1273 */  iRegI_R0_rule,
  /* 1274 */  iRegI_R0_rule,
  /* 1275 */  iRegI_R0_rule,
  /* 1276 */  iRegI_R0_rule,
  /* 1277 */  iRegI_R0_rule,
  /* 1278 */  iRegI_R0_rule,
  /* 1279 */  Universe_rule,
  /* 1280 */  iRegI_R0_rule,
  /* 1281 */  vecD_rule,
  /* 1282 */  vecD_rule,
  /* 1283 */  vecD_rule,
  /* 1284 */  vecX_rule,
  /* 1285 */  Universe_rule,
  /* 1286 */  Universe_rule,
  /* 1287 */  Universe_rule,
  /* 1288 */  Universe_rule,
  /* 1289 */  vecD_rule,
  /* 1290 */  iRegINoSp_rule,
  /* 1291 */  iRegINoSp_rule,
  /* 1292 */  iRegINoSp_rule,
  /* 1293 */  iRegINoSp_rule,
  /* 1294 */  iRegLNoSp_rule,
  /* 1295 */  iRegINoSp_rule,
  /* 1296 */  iRegINoSp_rule,
  /* 1297 */  iRegINoSp_rule,
  /* 1298 */  iRegINoSp_rule,
  /* 1299 */  iRegLNoSp_rule,
  /* 1300 */  iRegINoSp_rule,
  /* 1301 */  iRegINoSp_rule,
  /* 1302 */  iRegINoSp_rule,
  /* 1303 */  iRegINoSp_rule,
  /* 1304 */  iRegINoSp_rule,
  /* 1305 */  iRegINoSp_rule,
  /* 1306 */  iRegINoSp_rule,
  /* 1307 */  iRegINoSp_rule,
  /* 1308 */  iRegINoSp_rule,
  /* 1309 */  iRegINoSp_rule,
  /* 1310 */  iRegINoSp_rule,
  /* 1311 */  iRegINoSp_rule,
  /* 1312 */  iRegLNoSp_rule,
  /* 1313 */  iRegLNoSp_rule,
  /* 1314 */  vRegF_rule,
  /* 1315 */  vRegF_rule,
  /* 1316 */  vRegD_rule,
  /* 1317 */  vRegF_rule,
  /* 1318 */  vRegF_rule,
  /* 1319 */  vRegD_rule,
  /* 1320 */  iRegINoSp_rule,
  /* 1321 */  iRegINoSp_rule,
  /* 1322 */  iRegINoSp_rule,
  /* 1323 */  iRegINoSp_rule,
  /* 1324 */  iRegINoSp_rule,
  /* 1325 */  iRegINoSp_rule,
  /* 1326 */  iRegINoSp_rule,
  /* 1327 */  iRegINoSp_rule,
  /* 1328 */  iRegINoSp_rule,
  /* 1329 */  iRegINoSp_rule,
  /* 1330 */  iRegINoSp_rule,
  /* 1331 */  iRegINoSp_rule,
  /* 1332 */  iRegINoSp_rule,
  /* 1333 */  iRegINoSp_rule,
  /* 1334 */  iRegINoSp_rule,
  /* 1335 */  iRegINoSp_rule,
  /* 1336 */  iRegINoSp_rule,
  /* 1337 */  iRegINoSp_rule,
  /* 1338 */  iRegLNoSp_rule,
  /* 1339 */  iRegLNoSp_rule,
  /* 1340 */  iRegLNoSp_rule,
  /* 1341 */  vecD_rule,
  /* 1342 */  vecX_rule,
  /* 1343 */  vecD_rule,
  /* 1344 */  vecX_rule,
  /* 1345 */  vecD_rule,
  /* 1346 */  vecX_rule,
  /* 1347 */  vecX_rule,
  /* 1348 */  vecD_rule,
  /* 1349 */  vecX_rule,
  /* 1350 */  vecX_rule,
  /* 1351 */  iRegINoSp_rule,
  /* 1352 */  iRegINoSp_rule,
  /* 1353 */  iRegINoSp_rule,
  /* 1354 */  iRegINoSp_rule,
  /* 1355 */  iRegINoSp_rule,
  /* 1356 */  iRegINoSp_rule,
  /* 1357 */  iRegLNoSp_rule,
  /* 1358 */  vRegF_rule,
  /* 1359 */  vRegF_rule,
  /* 1360 */  vRegD_rule,
  /* 1361 */  vecD_rule,
  /* 1362 */  vecX_rule,
  /* 1363 */  vecX_rule,
  /* 1364 */  vecD_rule,
  /* 1365 */  vecD_rule,
  /* 1366 */  vecD_rule,
  /* 1367 */  vecD_rule,
  /* 1368 */  vecD_rule,
  /* 1369 */  vecD_rule,
  /* 1370 */  vecX_rule,
  /* 1371 */  vecX_rule,
  /* 1372 */  vecX_rule,
  /* 1373 */  vecX_rule,
  /* 1374 */  vecX_rule,
  /* 1375 */  vecX_rule,
  /* 1376 */  vecX_rule,
  /* 1377 */  vecX_rule,
  /* 1378 */  vecD_rule,
  /* 1379 */  vecD_rule,
  /* 1380 */  vecD_rule,
  /* 1381 */  vecD_rule,
  /* 1382 */  vecD_rule,
  /* 1383 */  vecD_rule,
  /* 1384 */  vecD_rule,
  /* 1385 */  vecD_rule,
  /* 1386 */  vecD_rule,
  /* 1387 */  vecD_rule,
  /* 1388 */  vecD_rule,
  /* 1389 */  vecD_rule,
  /* 1390 */  vecX_rule,
  /* 1391 */  vecX_rule,
  /* 1392 */  vecX_rule,
  /* 1393 */  vecX_rule,
  /* 1394 */  vecX_rule,
  /* 1395 */  vecX_rule,
  /* 1396 */  vecX_rule,
  /* 1397 */  vecX_rule,
  /* 1398 */  vecX_rule,
  /* 1399 */  vecX_rule,
  /* 1400 */  vecX_rule,
  /* 1401 */  vecX_rule,
  /* 1402 */  vecX_rule,
  /* 1403 */  vecX_rule,
  /* 1404 */  vecX_rule,
  /* 1405 */  vecX_rule,
  /* 1406 */  vecD_rule,
  /* 1407 */  vecX_rule,
  /* 1408 */  vecD_rule,
  /* 1409 */  vecX_rule,
  /* 1410 */  vecD_rule,
  /* 1411 */  vecX_rule,
  /* 1412 */  vecD_rule,
  /* 1413 */  vecX_rule,
  /* 1414 */  vecD_rule,
  /* 1415 */  vecX_rule,
  /* 1416 */  vecD_rule,
  /* 1417 */  vecX_rule,
  /* 1418 */  vecX_rule,
  /* 1419 */  vecX_rule,
  /* 1420 */  vecD_rule,
  /* 1421 */  vecX_rule,
  /* 1422 */  vecD_rule,
  /* 1423 */  vecX_rule,
  /* 1424 */  vecD_rule,
  /* 1425 */  vecD_rule,
  /* 1426 */  vecD_rule,
  /* 1427 */  vecD_rule,
  /* 1428 */  vecD_rule,
  /* 1429 */  vecD_rule,
  /* 1430 */  vecX_rule,
  /* 1431 */  vecD_rule,
  /* 1432 */  vecX_rule,
  /* 1433 */  vecX_rule,
  /* 1434 */  iRegINoSp_rule,
  /* 1435 */  iRegINoSp_rule,
  /* 1436 */  iRegINoSp_rule,
  /* 1437 */  iRegINoSp_rule,
  /* 1438 */  vecD_rule,
  /* 1439 */  vecX_rule,
  /* 1440 */  vecX_rule,
  /* 1441 */  vecD_rule,
  /* 1442 */  vecX_rule,
  /* 1443 */  vecD_rule,
  /* 1444 */  vecX_rule,
  /* 1445 */  vecD_rule,
  /* 1446 */  vecX_rule,
  /* 1447 */  vecD_rule,
  /* 1448 */  vecX_rule,
  /* 1449 */  vecD_rule,
  /* 1450 */  vecX_rule,
  /* 1451 */  vecD_rule,
  /* 1452 */  vecX_rule,
  /* 1453 */  vecX_rule,
  /* 1454 */  vecX_rule,
  /* 1455 */  vecD_rule,
  /* 1456 */  vecX_rule,
  /* 1457 */  vecX_rule,
  /* 1458 */  iRegINoSp_rule,
  /* 1459 */  iRegINoSp_rule,
  /* 1460 */  iRegINoSp_rule,
  /* 1461 */  iRegINoSp_rule,
  /* 1462 */  vRegF_rule,
  /* 1463 */  vRegF_rule,
  /* 1464 */  vRegF_rule,
  /* 1465 */  vRegF_rule,
  /* 1466 */  vRegD_rule,
  /* 1467 */  vRegD_rule,
  /* 1468 */  vecD_rule,
  /* 1469 */  vecX_rule,
  /* 1470 */  vecD_rule,
  /* 1471 */  vecX_rule,
  /* 1472 */  vecD_rule,
  /* 1473 */  vecX_rule,
  /* 1474 */  vecX_rule,
  /* 1475 */  vecD_rule,
  /* 1476 */  vecX_rule,
  /* 1477 */  vecX_rule,
  /* 1478 */  vecD_rule,
  /* 1479 */  vecX_rule,
  /* 1480 */  vecD_rule,
  /* 1481 */  vecX_rule,
  /* 1482 */  vecD_rule,
  /* 1483 */  vecX_rule,
  /* 1484 */  vecX_rule,
  /* 1485 */  vecD_rule,
  /* 1486 */  vecX_rule,
  /* 1487 */  vecX_rule,
  /* 1488 */  vecD_rule,
  /* 1489 */  vecX_rule,
  /* 1490 */  vecD_rule,
  /* 1491 */  vecX_rule,
  /* 1492 */  vecD_rule,
  /* 1493 */  vecX_rule,
  /* 1494 */  vecD_rule,
  /* 1495 */  vecX_rule,
  /* 1496 */  vecX_rule,
  /* 1497 */  vecD_rule,
  /* 1498 */  vecD_rule,
  /* 1499 */  vecX_rule,
  /* 1500 */  vecX_rule,
  /* 1501 */  vecD_rule,
  /* 1502 */  vecD_rule,
  /* 1503 */  vecX_rule,
  /* 1504 */  vecX_rule,
  /* 1505 */  vecD_rule,
  /* 1506 */  vecX_rule,
  /* 1507 */  vecX_rule,
  /* 1508 */  vecD_rule,
  /* 1509 */  vecX_rule,
  /* 1510 */  vecD_rule,
  /* 1511 */  vecX_rule,
  /* 1512 */  vecD_rule,
  /* 1513 */  vecD_rule,
  /* 1514 */  vecX_rule,
  /* 1515 */  vecX_rule,
  /* 1516 */  vecX_rule,
  /* 1517 */  vecX_rule,
  /* 1518 */  vecX_rule,
  /* 1519 */  vecD_rule,
  /* 1520 */  vecX_rule,
  /* 1521 */  vecX_rule,
  /* 1522 */  vecD_rule,
  /* 1523 */  vecX_rule,
  /* 1524 */  vecD_rule,
  /* 1525 */  vecX_rule,
  /* 1526 */  vecD_rule,
  /* 1527 */  vecX_rule,
  /* 1528 */  vecD_rule,
  /* 1529 */  vecX_rule,
  /* 1530 */  vecD_rule,
  /* 1531 */  vecX_rule,
  /* 1532 */  vecD_rule,
  /* 1533 */  vecX_rule,
  /* 1534 */  vecD_rule,
  /* 1535 */  vecX_rule,
  /* 1536 */  vecD_rule,
  /* 1537 */  vecX_rule,
  /* 1538 */  vecD_rule,
  /* 1539 */  vecX_rule,
  /* 1540 */  vecD_rule,
  /* 1541 */  vecX_rule,
  /* 1542 */  vecD_rule,
  /* 1543 */  vecX_rule,
  /* 1544 */  vecD_rule,
  /* 1545 */  vecX_rule,
  /* 1546 */  vecD_rule,
  /* 1547 */  vecX_rule,
  /* 1548 */  vecD_rule,
  /* 1549 */  vecX_rule,
  /* 1550 */  vecD_rule,
  /* 1551 */  vecX_rule,
  /* 1552 */  vecD_rule,
  /* 1553 */  vecX_rule,
  /* 1554 */  vecD_rule,
  /* 1555 */  vecX_rule,
  /* 1556 */  vecD_rule,
  /* 1557 */  vecX_rule,
  /* 1558 */  vecD_rule,
  /* 1559 */  vecX_rule,
  /* 1560 */  vecD_rule,
  /* 1561 */  vecX_rule,
  /* 1562 */  vecD_rule,
  /* 1563 */  vecX_rule,
  /* 1564 */  vecX_rule,
  /* 1565 */  vecX_rule,
  /* 1566 */  vecX_rule,
  /* 1567 */  vecX_rule,
  /* 1568 */  vecX_rule,
  /* 1569 */  vecX_rule,
  /* 1570 */  vecD_rule,
  /* 1571 */  vecD_rule,
  /* 1572 */  vecX_rule,
  /* 1573 */  vecX_rule,
  /* 1574 */  vecD_rule,
  /* 1575 */  vecD_rule,
  /* 1576 */  vecX_rule,
  /* 1577 */  vecX_rule,
  /* 1578 */  vecD_rule,
  /* 1579 */  vecD_rule,
  /* 1580 */  vecX_rule,
  /* 1581 */  vecX_rule,
  /* 1582 */  vecX_rule,
  /* 1583 */  vecX_rule,
  /* 1584 */  vecD_rule,
  /* 1585 */  vecD_rule,
  /* 1586 */  vecX_rule,
  /* 1587 */  vecX_rule,
  /* 1588 */  vecD_rule,
  /* 1589 */  vecD_rule,
  /* 1590 */  vecX_rule,
  /* 1591 */  vecX_rule,
  /* 1592 */  vecD_rule,
  /* 1593 */  vecD_rule,
  /* 1594 */  vecX_rule,
  /* 1595 */  vecX_rule,
  /* 1596 */  vecX_rule,
  /* 1597 */  vecX_rule,
  /* 1598 */  vecD_rule,
  /* 1599 */  vecX_rule,
  /* 1600 */  vecX_rule,
  /* 1601 */  vecD_rule,
  /* 1602 */  vecX_rule,
  /* 1603 */  vecX_rule,
  /* 1604 */  vecX_rule,
  /* 1605 */  iRegINoSp_rule,
  /* 1606 */  iRegINoSp_rule,
  /* 1607 */  iRegINoSp_rule,
  /* 1608 */  vReg_rule,
  /* 1609 */  Universe_rule,
  /* 1610 */  vReg_rule,
  /* 1611 */  Universe_rule,
  /* 1612 */  vReg_rule,
  /* 1613 */  Universe_rule,
  /* 1614 */  vReg_rule,
  /* 1615 */  Universe_rule,
  /* 1616 */  vReg_rule,
  /* 1617 */  Universe_rule,
  /* 1618 */  vReg_rule,
  /* 1619 */  Universe_rule,
  /* 1620 */  vReg_rule,
  /* 1621 */  vReg_rule,
  /* 1622 */  Universe_rule,
  /* 1623 */  Universe_rule,
  /* 1624 */  pRegGov_rule,
  /* 1625 */  pRegGov_rule,
  /* 1626 */  pRegGov_rule,
  /* 1627 */  pRegGov_rule,
  /* 1628 */  pRegGov_rule,
  /* 1629 */  pRegGov_rule,
  /* 1630 */  pRegGov_rule,
  /* 1631 */  pRegGov_rule,
  /* 1632 */  pRegGov_rule,
  /* 1633 */  vReg_rule,
  /* 1634 */  pRegGov_rule,
  /* 1635 */  vReg_rule,
  /* 1636 */  vReg_rule,
  /* 1637 */  vReg_rule,
  /* 1638 */  vReg_rule,
  /* 1639 */  vReg_rule,
  /* 1640 */  vReg_rule,
  /* 1641 */  vReg_rule,
  /* 1642 */  vReg_rule,
  /* 1643 */  vReg_rule,
  /* 1644 */  vReg_rule,
  /* 1645 */  vReg_rule,
  /* 1646 */  vReg_rule,
  /* 1647 */  vReg_rule,
  /* 1648 */  vReg_rule,
  /* 1649 */  vReg_rule,
  /* 1650 */  vReg_rule,
  /* 1651 */  vReg_rule,
  /* 1652 */  vReg_rule,
  /* 1653 */  vReg_rule,
  /* 1654 */  vReg_rule,
  /* 1655 */  vReg_rule,
  /* 1656 */  vReg_rule,
  /* 1657 */  vReg_rule,
  /* 1658 */  vReg_rule,
  /* 1659 */  vReg_rule,
  /* 1660 */  vReg_rule,
  /* 1661 */  vReg_rule,
  /* 1662 */  vReg_rule,
  /* 1663 */  vReg_rule,
  /* 1664 */  vReg_rule,
  /* 1665 */  vReg_rule,
  /* 1666 */  vReg_rule,
  /* 1667 */  vReg_rule,
  /* 1668 */  vReg_rule,
  /* 1669 */  vReg_rule,
  /* 1670 */  vReg_rule,
  /* 1671 */  vReg_rule,
  /* 1672 */  vReg_rule,
  /* 1673 */  vReg_rule,
  /* 1674 */  vReg_rule,
  /* 1675 */  vReg_rule,
  /* 1676 */  vReg_rule,
  /* 1677 */  vReg_rule,
  /* 1678 */  vReg_rule,
  /* 1679 */  vReg_rule,
  /* 1680 */  vReg_rule,
  /* 1681 */  vReg_rule,
  /* 1682 */  vReg_rule,
  /* 1683 */  vReg_rule,
  /* 1684 */  vReg_rule,
  /* 1685 */  vReg_rule,
  /* 1686 */  vReg_rule,
  /* 1687 */  vReg_rule,
  /* 1688 */  vReg_rule,
  /* 1689 */  vReg_rule,
  /* 1690 */  vReg_rule,
  /* 1691 */  vReg_rule,
  /* 1692 */  vReg_rule,
  /* 1693 */  vReg_rule,
  /* 1694 */  vReg_rule,
  /* 1695 */  vReg_rule,
  /* 1696 */  vReg_rule,
  /* 1697 */  vReg_rule,
  /* 1698 */  vReg_rule,
  /* 1699 */  vReg_rule,
  /* 1700 */  vReg_rule,
  /* 1701 */  vReg_rule,
  /* 1702 */  vReg_rule,
  /* 1703 */  vReg_rule,
  /* 1704 */  vReg_rule,
  /* 1705 */  vReg_rule,
  /* 1706 */  vReg_rule,
  /* 1707 */  vReg_rule,
  /* 1708 */  vReg_rule,
  /* 1709 */  vReg_rule,
  /* 1710 */  vReg_rule,
  /* 1711 */  vReg_rule,
  /* 1712 */  vReg_rule,
  /* 1713 */  vReg_rule,
  /* 1714 */  vReg_rule,
  /* 1715 */  vReg_rule,
  /* 1716 */  vReg_rule,
  /* 1717 */  vReg_rule,
  /* 1718 */  vReg_rule,
  /* 1719 */  vReg_rule,
  /* 1720 */  vReg_rule,
  /* 1721 */  vReg_rule,
  /* 1722 */  vReg_rule,
  /* 1723 */  vReg_rule,
  /* 1724 */  vReg_rule,
  /* 1725 */  vReg_rule,
  /* 1726 */  vReg_rule,
  /* 1727 */  vReg_rule,
  /* 1728 */  vReg_rule,
  /* 1729 */  vReg_rule,
  /* 1730 */  vReg_rule,
  /* 1731 */  vReg_rule,
  /* 1732 */  vReg_rule,
  /* 1733 */  vReg_rule,
  /* 1734 */  vReg_rule,
  /* 1735 */  vReg_rule,
  /* 1736 */  vReg_rule,
  /* 1737 */  vReg_rule,
  /* 1738 */  vReg_rule,
  /* 1739 */  vReg_rule,
  /* 1740 */  vReg_rule,
  /* 1741 */  vReg_rule,
  /* 1742 */  vReg_rule,
  /* 1743 */  vReg_rule,
  /* 1744 */  vReg_rule,
  /* 1745 */  vReg_rule,
  /* 1746 */  vReg_rule,
  /* 1747 */  vReg_rule,
  /* 1748 */  vReg_rule,
  /* 1749 */  vReg_rule,
  /* 1750 */  vReg_rule,
  /* 1751 */  vReg_rule,
  /* 1752 */  vReg_rule,
  /* 1753 */  vReg_rule,
  /* 1754 */  vReg_rule,
  /* 1755 */  vReg_rule,
  /* 1756 */  vReg_rule,
  /* 1757 */  vReg_rule,
  /* 1758 */  vReg_rule,
  /* 1759 */  vReg_rule,
  /* 1760 */  vReg_rule,
  /* 1761 */  vReg_rule,
  /* 1762 */  vReg_rule,
  /* 1763 */  pRegGov_rule,
  /* 1764 */  pRegGov_rule,
  /* 1765 */  vReg_rule,
  /* 1766 */  pRegGov_rule,
  /* 1767 */  pRegGov_rule,
  /* 1768 */  vReg_rule,
  /* 1769 */  vReg_rule,
  /* 1770 */  pRegGov_rule,
  /* 1771 */  pRegGov_rule,
  /* 1772 */  Universe_rule,
  /* 1773 */  Universe_rule,
  /* 1774 */  iRegINoSp_rule,
  /* 1775 */  iRegLNoSp_rule,
  /* 1776 */  vRegF_rule,
  /* 1777 */  vRegD_rule,
  /* 1778 */  iRegINoSp_rule,
  /* 1779 */  iRegLNoSp_rule,
  /* 1780 */  vRegF_rule,
  /* 1781 */  vRegD_rule,
  /* 1782 */  iRegINoSp_rule,
  /* 1783 */  iRegLNoSp_rule,
  /* 1784 */  vRegF_rule,
  /* 1785 */  vRegD_rule,
  /* 1786 */  iRegINoSp_rule,
  /* 1787 */  iRegLNoSp_rule,
  /* 1788 */  vRegF_rule,
  /* 1789 */  vRegD_rule,
  /* 1790 */  iRegINoSp_rule,
  /* 1791 */  iRegLNoSp_rule,
  /* 1792 */  iRegINoSp_rule,
  /* 1793 */  iRegLNoSp_rule,
  /* 1794 */  iRegINoSp_rule,
  /* 1795 */  iRegLNoSp_rule,
  /* 1796 */  iRegINoSp_rule,
  /* 1797 */  iRegLNoSp_rule,
  /* 1798 */  iRegINoSp_rule,
  /* 1799 */  iRegLNoSp_rule,
  /* 1800 */  iRegINoSp_rule,
  /* 1801 */  iRegLNoSp_rule,
  /* 1802 */  iRegINoSp_rule,
  /* 1803 */  iRegLNoSp_rule,
  /* 1804 */  iRegINoSp_rule,
  /* 1805 */  iRegLNoSp_rule,
  /* 1806 */  iRegINoSp_rule,
  /* 1807 */  iRegLNoSp_rule,
  /* 1808 */  iRegINoSp_rule,
  /* 1809 */  iRegLNoSp_rule,
  /* 1810 */  iRegINoSp_rule,
  /* 1811 */  iRegLNoSp_rule,
  /* 1812 */  iRegINoSp_rule,
  /* 1813 */  iRegLNoSp_rule,
  /* 1814 */  iRegINoSp_rule,
  /* 1815 */  iRegLNoSp_rule,
  /* 1816 */  iRegINoSp_rule,
  /* 1817 */  iRegLNoSp_rule,
  /* 1818 */  vRegF_rule,
  /* 1819 */  vRegF_rule,
  /* 1820 */  vRegD_rule,
  /* 1821 */  vRegD_rule,
  /* 1822 */  iRegINoSp_rule,
  /* 1823 */  iRegLNoSp_rule,
  /* 1824 */  iRegINoSp_rule,
  /* 1825 */  iRegLNoSp_rule,
  /* 1826 */  vRegF_rule,
  /* 1827 */  vRegD_rule,
  /* 1828 */  vRegF_rule,
  /* 1829 */  vRegD_rule,
  /* 1830 */  iRegINoSp_rule,
  /* 1831 */  iRegLNoSp_rule,
  /* 1832 */  iRegINoSp_rule,
  /* 1833 */  iRegLNoSp_rule,
  /* 1834 */  vRegF_rule,
  /* 1835 */  vRegF_rule,
  /* 1836 */  vRegD_rule,
  /* 1837 */  vRegD_rule,
  /* 1838 */  iRegINoSp_rule,
  /* 1839 */  iRegLNoSp_rule,
  /* 1840 */  iRegINoSp_rule,
  /* 1841 */  iRegLNoSp_rule,
  /* 1842 */  vRegF_rule,
  /* 1843 */  vRegD_rule,
  /* 1844 */  vRegF_rule,
  /* 1845 */  vRegD_rule,
  /* 1846 */  vReg_rule,
  /* 1847 */  vReg_rule,
  /* 1848 */  vReg_rule,
  /* 1849 */  vReg_rule,
  /* 1850 */  vReg_rule,
  /* 1851 */  vReg_rule,
  /* 1852 */  vReg_rule,
  /* 1853 */  vReg_rule,
  /* 1854 */  vReg_rule,
  /* 1855 */  vReg_rule,
  /* 1856 */  vReg_rule,
  /* 1857 */  vReg_rule,
  /* 1858 */  vReg_rule,
  /* 1859 */  vReg_rule,
  /* 1860 */  vReg_rule,
  /* 1861 */  vReg_rule,
  /* 1862 */  vReg_rule,
  /* 1863 */  vReg_rule,
  /* 1864 */  vReg_rule,
  /* 1865 */  vReg_rule,
  /* 1866 */  vReg_rule,
  /* 1867 */  vReg_rule,
  /* 1868 */  vReg_rule,
  /* 1869 */  vReg_rule,
  /* 1870 */  vReg_rule,
  /* 1871 */  vReg_rule,
  /* 1872 */  vReg_rule,
  /* 1873 */  vReg_rule,
  /* 1874 */  vReg_rule,
  /* 1875 */  vReg_rule,
  /* 1876 */  vReg_rule,
  /* 1877 */  vReg_rule,
  /* 1878 */  vReg_rule,
  /* 1879 */  vReg_rule,
  /* 1880 */  vReg_rule,
  /* 1881 */  vReg_rule,
  /* 1882 */  vReg_rule,
  /* 1883 */  vReg_rule,
  /* 1884 */  vReg_rule,
  /* 1885 */  vReg_rule,
  /* 1886 */  vReg_rule,
  /* 1887 */  vReg_rule,
  /* 1888 */  vReg_rule,
  /* 1889 */  vReg_rule,
  /* 1890 */  vReg_rule,
  /* 1891 */  vReg_rule,
  /* 1892 */  vReg_rule,
  /* 1893 */  vReg_rule,
  /* 1894 */  vReg_rule,
  /* 1895 */  vReg_rule,
  /* 1896 */  vReg_rule,
  /* 1897 */  vReg_rule,
  /* 1898 */  vReg_rule,
  /* 1899 */  vReg_rule,
  /* 1900 */  vReg_rule,
  /* 1901 */  vReg_rule,
  /* 1902 */  vReg_rule,
  /* 1903 */  vReg_rule,
  /* 1904 */  vReg_rule,
  /* 1905 */  vReg_rule,
  /* 1906 */  vReg_rule,
  /* 1907 */  vReg_rule,
  /* 1908 */  vReg_rule,
  /* 1909 */  vReg_rule,
  /* 1910 */  vReg_rule,
  /* 1911 */  vReg_rule,
  /* 1912 */  vReg_rule,
  /* 1913 */  vReg_rule,
  /* 1914 */  vReg_rule,
  /* 1915 */  vReg_rule,
  /* 1916 */  vReg_rule,
  /* 1917 */  vReg_rule,
  /* 1918 */  vReg_rule,
  /* 1919 */  vReg_rule,
  /* 1920 */  vReg_rule,
  /* 1921 */  vReg_rule,
  /* 1922 */  vReg_rule,
  /* 1923 */  vReg_rule,
  /* 1924 */  vReg_rule,
  /* 1925 */  vReg_rule,
  /* 1926 */  vReg_rule,
  /* 1927 */  iRegINoSp_rule,
  /* 1928 */  iRegINoSp_rule,
  /* 1929 */  iRegINoSp_rule,
  /* 1930 */  iRegLNoSp_rule,
  /* 1931 */  vRegF_rule,
  /* 1932 */  vRegD_rule,
  /* 1933 */  iRegINoSp_rule,
  /* 1934 */  iRegINoSp_rule,
  /* 1935 */  iRegINoSp_rule,
  /* 1936 */  iRegINoSp_rule,
  /* 1937 */  vReg_rule,
  /* 1938 */  vReg_rule,
  /* 1939 */  vReg_rule,
  /* 1940 */  vReg_rule,
  /* 1941 */  vReg_rule,
  /* 1942 */  vReg_rule,
  /* 1943 */  vReg_rule,
  /* 1944 */  vReg_rule,
  /* 1945 */  vReg_rule,
  /* 1946 */  vReg_rule,
  /* 1947 */  vReg_rule,
  /* 1948 */  vReg_rule,
  /* 1949 */  vReg_rule,
  /* 1950 */  vReg_rule,
  /* 1951 */  vReg_rule,
  /* 1952 */  Universe_rule,
  /* 1953 */  Universe_rule,
  /* 1954 */  Universe_rule,
  /* 1955 */  Universe_rule,
  /* 1956 */  Universe_rule,
  /* 1957 */  Universe_rule,
  /* 1958 */  Universe_rule,
  /* 1959 */  Universe_rule,
  /* 1960 */  iRegI_R0_rule,
  /* 1961 */  iRegI_R0_rule,
  /* 1962 */  iRegINoSp_rule,
  /* 1963 */  iRegINoSp_rule,
  /* 1964 */  iRegINoSp_rule,
  /* 1965 */  iRegINoSp_rule,
  /* 1966 */  iRegINoSp_rule,
  /* 1967 */  iRegLNoSp_rule,
  /* 1968 */  pRegGov_rule,
  /* 1969 */  iRegINoSp_rule,
  /* 1970 */  iRegINoSp_rule,
  /* 1971 */  iRegINoSp_rule,
  /* 1972 */  iRegINoSp_rule,
  /* 1973 */  iRegNNoSp_rule,
  /* 1974 */  iRegPNoSp_rule,
  /* 1975 */  iRegNNoSp_rule,
  /* 1976 */  iRegPNoSp_rule,
  /* 1977 */  iRegINoSp_rule,
  /* 1978 */  iRegINoSp_rule,
  /* 1979 */  iRegINoSp_rule,
  /* 1980 */  iRegINoSp_rule,
  /* 1981 */  iRegPNoSp_rule,
  /* 1982 */  iRegPNoSp_rule,
  /* 1983 */  iRegINoSp_rule,
  /* 1984 */  iRegINoSp_rule,
  /* 1985 */  iRegINoSp_rule,
  /* 1986 */  iRegINoSp_rule,
  /* 1987 */  iRegPNoSp_rule,
  /* 1988 */  iRegPNoSp_rule,
  /* 1989 */  iRegPNoSp_rule,
  /* 1990 */  iRegPNoSp_rule,
  // last instruction
  0 // no trailing comma
};

const        int   leftOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  0,
  /*   78 */  0,
  /*   79 */  0,
  /*   80 */  0,
  /*   81 */  0,
  /*   82 */  0,
  /*   83 */  0,
  /*   84 */  0,
  /*   85 */  0,
  /*   86 */  0,
  /*   87 */  0,
  /*   88 */  0,
  /*   89 */  0,
  /*   90 */  0,
  /*   91 */  0,
  /*   92 */  0,
  /*   93 */  0,
  /*   94 */  0,
  /*   95 */  0,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  /*  101 */  0,
  /*  102 */  0,
  /*  103 */  0,
  /*  104 */  0,
  /*  105 */  0,
  /*  106 */  0,
  /*  107 */  0,
  /*  108 */  0,
  /*  109 */  0,
  /*  110 */  0,
  /*  111 */  0,
  /*  112 */  0,
  /*  113 */  0,
  /*  114 */  0,
  /*  115 */  0,
  /*  116 */  0,
  /*  117 */  0,
  /*  118 */  0,
  /*  119 */  0,
  /*  120 */  0,
  /*  121 */  0,
  /*  122 */  0,
  /*  123 */  0,
  /*  124 */  0,
  /*  125 */  0,
  /*  126 */  0,
  /*  127 */  0,
  /*  128 */  0,
  /*  129 */  0,
  /*  130 */  0,
  /*  131 */  0,
  /*  132 */  0,
  /*  133 */  0,
  /*  134 */  0,
  /*  135 */  0,
  /*  136 */  0,
  /*  137 */  0,
  /*  138 */  0,
  /*  139 */  0,
  /*  140 */  0,
  /*  141 */  0,
  /*  142 */  0,
  /*  143 */  0,
  /*  144 */  0,
  /*  145 */  0,
  /*  146 */  0,
  /*  147 */  0,
  /*  148 */  0,
  /*  149 */  0,
  /*  150 */  0,
  /*  151 */  0,
  /*  152 */  0,
  /*  153 */  0,
  /*  154 */  0,
  /*  155 */  0,
  /*  156 */  0,
  /*  157 */  iRegP_rule,
  /*  158 */  iRegP_rule,
  /*  159 */  iRegP_rule,
  /*  160 */  iRegP_rule,
  /*  161 */  iRegP_rule,
  /*  162 */  iRegP_rule,
  /*  163 */  iRegP_rule,
  /*  164 */  iRegP_rule,
  /*  165 */  iRegP_rule,
  /*  166 */  iRegP_rule,
  /*  167 */  iRegP_rule,
  /*  168 */  iRegP_rule,
  /*  169 */  iRegP_rule,
  /*  170 */  iRegP_rule,
  /*  171 */  iRegP_rule,
  /*  172 */  iRegP_rule,
  /*  173 */  iRegN_rule,
  /*  174 */  _DecodeN_iRegN__rule,
  /*  175 */  _DecodeN_iRegN__rule,
  /*  176 */  _DecodeN_iRegN__rule,
  /*  177 */  _DecodeN_iRegN__rule,
  /*  178 */  _DecodeN_iRegN__rule,
  /*  179 */  _DecodeN_iRegN__rule,
  /*  180 */  thread_RegP_rule,
  /*  181 */  0,
  /*  182 */  0,
  /*  183 */  0,
  /*  184 */  0,
  /*  185 */  0,
  /*  186 */  0,
  /*  187 */  0,
  /*  188 */  0,
  /*  189 */  0,
  /*  190 */  0,
  /*  191 */  iRegL_rule,
  /*  192 */  0,
  /*  193 */  0,
  /*  194 */  iRegP_rule,
  /*  195 */  iRegP_rule,
  // last operand
  /*  196 */  0,
  /*  197 */  0,
  /*  198 */  0,
  /*  199 */  0,
  /*  200 */  0,
  /*  201 */  0,
  /*  202 */  0,
  /*  203 */  0,
  /*  204 */  0,
  /*  205 */  0,
  /*  206 */  0,
  // last operand class
  /*  207 */  iRegI_rule,
  /*  208 */  _ConvI2L_iRegI__rule,
  /*  209 */  iRegL_rule,
  /*  210 */  iRegN_rule,
  /*  211 */  memory1_rule,
  /*  212 */  memory1_rule,
  /*  213 */  memory2_rule,
  /*  214 */  memory2_rule,
  /*  215 */  memory4_rule,
  /*  216 */  _LoadI_memory4__rule,
  /*  217 */  indirect_rule,
  /*  218 */  indirect_rule,
  /*  219 */  indirect_rule,
  /*  220 */  indirect_rule,
  /*  221 */  indirect_rule,
  /*  222 */  _LoadI_indirect__rule,
  /*  223 */  memory8_rule,
  /*  224 */  iRegP_rule,
  /*  225 */  _DecodeN_iRegN__rule,
  /*  226 */  iRegP_rule,
  /*  227 */  iRegLNoSp_rule,
  /*  228 */  iRegINoSp_rule,
  /*  229 */  iRegNNoSp_rule,
  /*  230 */  iRegI_rule,
  /*  231 */  iRegL_rule,
  /*  232 */  iRegN_rule,
  /*  233 */  cmpOp_rule,
  /*  234 */  iRegIorL2I_rule,
  /*  235 */  cmpOpU_rule,
  /*  236 */  immI0_rule,
  /*  237 */  iRegIorL2I_rule,
  /*  238 */  immI_1_rule,
  /*  239 */  iRegL_rule,
  /*  240 */  immL0_rule,
  /*  241 */  iRegP_rule,
  /*  242 */  immP0_rule,
  /*  243 */  iRegN_rule,
  /*  244 */  immN0_rule,
  /*  245 */  vRegF_rule,
  /*  246 */  vRegD_rule,
  /*  247 */  iRegL_rule,
  /*  248 */  iRegIorL2I_rule,
  /*  249 */  _ConvI2L_iRegIorL2I__rule,
  /*  250 */  iRegIorL2I_rule,
  /*  251 */  immI0_rule,
  /*  252 */  iRegL_rule,
  /*  253 */  immL0_rule,
  /*  254 */  _ConvI2L_iRegIorL2I__rule,
  /*  255 */  immL0_rule,
  /*  256 */  iRegIorL2I_rule,
  /*  257 */  iRegL_rule,
  /*  258 */  iRegIorL2I_rule,
  /*  259 */  iRegL_rule,
  /*  260 */  iRegIorL2I_rule,
  /*  261 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  262 */  iRegL_rule,
  /*  263 */  _URShiftL_iRegL_immI_rule,
  /*  264 */  iRegIorL2I_rule,
  /*  265 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  266 */  iRegL_rule,
  /*  267 */  _RShiftL_iRegL_immI_rule,
  /*  268 */  iRegIorL2I_rule,
  /*  269 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  270 */  iRegL_rule,
  /*  271 */  _RotateRight_iRegL_immI_rule,
  /*  272 */  iRegIorL2I_rule,
  /*  273 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  274 */  iRegL_rule,
  /*  275 */  _LShiftL_iRegL_immI_rule,
  /*  276 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  277 */  iRegIorL2I_rule,
  /*  278 */  _URShiftL_iRegL_immI_rule,
  /*  279 */  iRegL_rule,
  /*  280 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  281 */  iRegIorL2I_rule,
  /*  282 */  _RShiftL_iRegL_immI_rule,
  /*  283 */  iRegL_rule,
  /*  284 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  285 */  iRegIorL2I_rule,
  /*  286 */  _RotateRight_iRegL_immI_rule,
  /*  287 */  iRegL_rule,
  /*  288 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  289 */  iRegIorL2I_rule,
  /*  290 */  _LShiftL_iRegL_immI_rule,
  /*  291 */  iRegL_rule,
  /*  292 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  293 */  iRegIorL2I_rule,
  /*  294 */  iRegL_rule,
  /*  295 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /*  296 */  iRegL_rule,
  /*  297 */  _AndL_iRegL_immL_positive_bitmaskI_rule,
  /*  298 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /*  299 */  _AndL_iRegL_immL_positive_bitmaskI_rule,
  /*  300 */  iRegI_rule,
  /*  301 */  iRegIorL2I_rule,
  /*  302 */  _LShiftI_iRegIorL2I_immI_16_rule,
  /*  303 */  iRegIorL2I_rule,
  /*  304 */  _LShiftI_iRegIorL2I_immI_24_rule,
  /*  305 */  _LShiftI_iRegIorL2I_immI_24_rule,
  /*  306 */  iRegL_rule,
  /*  307 */  _LShiftL_iRegL_immI_48_rule,
  /*  308 */  iRegL_rule,
  /*  309 */  _LShiftL_iRegL_immI_32_rule,
  /*  310 */  iRegL_rule,
  /*  311 */  _LShiftL_iRegL_immI_56_rule,
  /*  312 */  _LShiftL_iRegL_immI_56_rule,
  /*  313 */  iRegIorL2I_rule,
  /*  314 */  iRegIorL2I_rule,
  /*  315 */  iRegL_rule,
  /*  316 */  iRegL_rule,
  /*  317 */  iRegL_rule,
  /*  318 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  319 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /*  320 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /*  321 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  322 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /*  323 */  _ConvI2L_iRegIorL2I__rule,
  /*  324 */  _AndL_iRegL_immL_255_rule,
  /*  325 */  _AndL_iRegL_immL_65535_rule,
  /*  326 */  _AndL_iRegL_immL_4294967295_rule,
  /*  327 */  _AndI_iRegIorL2I_immI_255_rule,
  /*  328 */  _AndI_iRegIorL2I_immI_65535_rule,
  /*  329 */  vRegF_rule,
  /*  330 */  _NegF_vRegF__rule,
  /*  331 */  vRegF_rule,
  /*  332 */  vRegD_rule,
  /*  333 */  _NegD_vRegD__rule,
  /*  334 */  vRegD_rule,
  /*  335 */  vRegF_rule,
  /*  336 */  vRegD_rule,
  /*  337 */  iRegIorL2I_rule,
  /*  338 */  iRegL_rule,
  /*  339 */  iRegIorL2I_rule,
  /*  340 */  iRegL_rule,
  /*  341 */  iRegP_rule,
  /*  342 */  iRegN_rule,
  /*  343 */  _DecodeN_iRegN__rule,
  /*  344 */  iRegIorL2I_rule,
  /*  345 */  iRegL_rule,
  /*  346 */  iRegL_rule,
  /*  347 */  _AndL_iRegL_immL_rule,
  /*  348 */  iRegIorL2I_rule,
  /*  349 */  _AndI_iRegIorL2I_immI_rule,
  /*  350 */  iRegL_rule,
  /*  351 */  iRegIorL2I_rule,
  /*  352 */  iRegP_R4_rule,
  /*  353 */  iRegP_R1_rule,
  /*  354 */  iRegP_R3_rule,
  /*  355 */  iRegP_R1_rule,
  /*  356 */  iRegP_R3_rule,
  /*  357 */  iRegP_R3_rule,
  /*  358 */  iRegP_R3_rule,
  /*  359 */  iRegP_R1_rule,
  /*  360 */  iRegP_R1_rule,
  /*  361 */  vecD_rule,
  /*  362 */  vecX_rule,
  /*  363 */  vecX_rule,
  /*  364 */  vecD_rule,
  /*  365 */  vecX_rule,
  /*  366 */  vecX_rule,
  /*  367 */  vecD_rule,
  /*  368 */  vecX_rule,
  /*  369 */  immI_M1_rule,
  /*  370 */  immI_M1_rule,
  /*  371 */  immI_M1_rule,
  /*  372 */  immL_M1_rule,
  /*  373 */  vecD_rule,
  /*  374 */  _ReplicateB_immI_M1__rule,
  /*  375 */  vecD_rule,
  /*  376 */  _ReplicateS_immI_M1__rule,
  /*  377 */  vecD_rule,
  /*  378 */  _ReplicateI_immI_M1__rule,
  /*  379 */  vecX_rule,
  /*  380 */  _ReplicateB_immI_M1__rule,
  /*  381 */  vecX_rule,
  /*  382 */  _ReplicateS_immI_M1__rule,
  /*  383 */  vecX_rule,
  /*  384 */  _ReplicateI_immI_M1__rule,
  /*  385 */  vecX_rule,
  /*  386 */  _ReplicateL_immL_M1__rule,
  /*  387 */  vecD_rule,
  /*  388 */  vecX_rule,
  /*  389 */  vecX_rule,
  /*  390 */  vecD_rule,
  /*  391 */  vecX_rule,
  /*  392 */  vecD_rule,
  /*  393 */  vecX_rule,
  /*  394 */  vecD_rule,
  /*  395 */  _NegVF_vecD__rule,
  /*  396 */  vecD_rule,
  /*  397 */  vecX_rule,
  /*  398 */  _NegVF_vecX__rule,
  /*  399 */  vecX_rule,
  /*  400 */  vecX_rule,
  /*  401 */  _NegVD_vecX__rule,
  /*  402 */  vecX_rule,
  /*  403 */  immI_rule,
  /*  404 */  immI_rule,
  /*  405 */  vecD_rule,
  /*  406 */  vecX_rule,
  /*  407 */  vecD_rule,
  /*  408 */  vecX_rule,
  /*  409 */  vecD_rule,
  /*  410 */  vecX_rule,
  /*  411 */  vecX_rule,
  /*  412 */  vecD_rule,
  /*  413 */  vecX_rule,
  /*  414 */  vecD_rule,
  /*  415 */  vecX_rule,
  /*  416 */  vecD_rule,
  /*  417 */  vecX_rule,
  /*  418 */  vecX_rule,
  /*  419 */  vReg_rule,
  /*  420 */  immI_M1_rule,
  /*  421 */  pRegGov_rule,
  /*  422 */  immL_M1_rule,
  /*  423 */  pRegGov_rule,
  /*  424 */  vReg_rule,
  /*  425 */  immBAddSubV_rule,
  /*  426 */  immIAddSubV_rule,
  /*  427 */  immIAddSubV_rule,
  /*  428 */  immLAddSubV_rule,
  /*  429 */  immBLog_rule,
  /*  430 */  immSLog_rule,
  /*  431 */  immILog_rule,
  /*  432 */  immLLog_rule,
  /*  433 */  vReg_rule,
  /*  434 */  _ReplicateB_immI_M1__rule,
  /*  435 */  vReg_rule,
  /*  436 */  _ReplicateS_immI_M1__rule,
  /*  437 */  vReg_rule,
  /*  438 */  _ReplicateI_immI_M1__rule,
  /*  439 */  vReg_rule,
  /*  440 */  _ReplicateL_immL_M1__rule,
  /*  441 */  vReg_rule,
  /*  442 */  _NegVF_vReg__rule,
  /*  443 */  vReg_rule,
  /*  444 */  vReg_rule,
  /*  445 */  _NegVD_vReg__rule,
  /*  446 */  vReg_rule,
  /*  447 */  vReg_rule,
  /*  448 */  vReg_rule,
  /*  449 */  vReg_rule,
  /*  450 */  vReg_rule,
  /*  451 */  immI_rule,
  /*  452 */  indirect_rule,
  /*  453 */  pRegGov_rule,
  /*  454 */  iRegIorL2I_rule,
  /*  455 */  iRegL_rule,
  /*  456 */  vRegF_rule,
  /*  457 */  vRegD_rule,
  /*  458 */  vReg_rule,
  /*  459 */  vReg_rule,
  /*  460 */  vReg_rule,
  /*  461 */  vReg_rule,
  /*  462 */  vReg_rule,
  /*  463 */  vReg_rule,
  /*  464 */  vReg_rule,
  // last internally defined operand
  /*  465 */  immI_rule,
  /*  466 */  immL_rule,
  /*  467 */  immP_rule,
  /*  468 */  immP0_rule,
  /*  469 */  immP_1_rule,
  /*  470 */  immByteMapBase_rule,
  /*  471 */  immN_rule,
  /*  472 */  immN0_rule,
  /*  473 */  immNKlass_rule,
  /*  474 */  immFPacked_rule,
  /*  475 */  immF_rule,
  /*  476 */  immDPacked_rule,
  /*  477 */  immD_rule,
  /*  478 */  iRegIorL2I_rule,
  /*  479 */  iRegL_rule,
  /*  480 */  iRegIorL2I_rule,
  /*  481 */  iRegL_rule,
  /*  482 */  iRegL_rule,
  /*  483 */  iRegP_rule,
  /*  484 */  iRegPNoSp_rule,
  /*  485 */  iRegPNoSp_rule,
  /*  486 */  iRegI_rule,
  /*  487 */  iRegL_rule,
  /*  488 */  vRegF_rule,
  /*  489 */  vRegD_rule,
  /*  490 */  vecD_rule,
  /*  491 */  vecX_rule,
  /*  492 */  vReg_rule,
  /*  493 */  pRegGov_rule,
  /*  494 */  memory8_rule,
  /*  495 */  indirect_rule,
  /*  496 */  indirect_rule,
  /*  497 */  vRegF_rule,
  /*  498 */  vRegD_rule,
  /*  499 */  vRegF_rule,
  /*  500 */  vRegD_rule,
  /*  501 */  stackSlotF_rule,
  /*  502 */  stackSlotI_rule,
  /*  503 */  stackSlotD_rule,
  /*  504 */  stackSlotL_rule,
  /*  505 */  vRegF_rule,
  /*  506 */  iRegI_rule,
  /*  507 */  vRegD_rule,
  /*  508 */  iRegL_rule,
  /*  509 */  iRegIorL2I_rule,
  /*  510 */  iRegIorL2I_rule,
  /*  511 */  iRegL_rule,
  /*  512 */  iRegL_rule,
  /*  513 */  iRegIorL2I_rule,
  /*  514 */  iRegIorL2I_rule,
  /*  515 */  iRegL_rule,
  /*  516 */  iRegL_rule,
  /*  517 */  immI0_rule,
  /*  518 */  immI0_rule,
  /*  519 */  iRegIorL2I_rule,
  /*  520 */  iRegL_rule,
  /*  521 */  iRegI_rule,
  /*  522 */  iRegI_rule,
  /*  523 */  iRegI_rule,
  /*  524 */  iRegI_rule,
  /*  525 */  iRegI_rule,
  /*  526 */  iRegI_rule,
  /*  527 */  iRegI_rule,
  /*  528 */  iRegI_rule,
  /*  529 */  iRegL_rule,
  /*  530 */  iRegL_rule,
  /*  531 */  iRegL_rule,
  /*  532 */  iRegL_rule,
  /*  533 */  iRegL_rule,
  /*  534 */  iRegL_rule,
  /*  535 */  iRegL_rule,
  /*  536 */  iRegL_rule,
  /*  537 */  iRegP_rule,
  /*  538 */  iRegN_rule,
  /*  539 */  iRegP_rule,
  /*  540 */  iRegN_rule,
  /*  541 */  vRegF_rule,
  /*  542 */  vRegF_rule,
  /*  543 */  vRegD_rule,
  /*  544 */  vRegD_rule,
  /*  545 */  _AndL_iRegL_immL_rule,
  /*  546 */  _AndI_iRegIorL2I_immI_rule,
  /*  547 */  _AndL_iRegL_iRegL_rule,
  /*  548 */  _AndI_iRegIorL2I_iRegIorL2I_rule,
  /*  549 */  iRegP_rule,
  /*  550 */  iRegP_rule,
  /*  551 */  _PartialSubtypeCheck_iRegP_R4_iRegP_R0_rule,
  /*  552 */  0,
  /*  553 */  vecD_rule,
  /*  554 */  vecX_rule,
  /*  555 */  vecD_rule,
  /*  556 */  vecX_rule,
  /*  557 */  vecD_rule,
  /*  558 */  vecX_rule,
  /*  559 */  vecD_rule,
  /*  560 */  vecD_rule,
  /*  561 */  vecD_rule,
  /*  562 */  vecD_rule,
  /*  563 */  vecX_rule,
  /*  564 */  vecD_rule,
  /*  565 */  vecD_rule,
  /*  566 */  vecX_rule,
  /*  567 */  vecD_rule,
  /*  568 */  vecX_rule,
  /*  569 */  vecX_rule,
  /*  570 */  vecD_rule,
  /*  571 */  vecX_rule,
  /*  572 */  vecD_rule,
  /*  573 */  vecX_rule,
  /*  574 */  vecX_rule,
  /*  575 */  vecD_rule,
  /*  576 */  vecD_rule,
  /*  577 */  vecD_rule,
  /*  578 */  vecD_rule,
  /*  579 */  vecD_rule,
  /*  580 */  vecX_rule,
  /*  581 */  vecX_rule,
  /*  582 */  vecX_rule,
  /*  583 */  vecX_rule,
  /*  584 */  vecD_rule,
  /*  585 */  vecX_rule,
  /*  586 */  vecD_rule,
  /*  587 */  vecX_rule,
  /*  588 */  vecD_rule,
  /*  589 */  vecD_rule,
  /*  590 */  vecD_rule,
  /*  591 */  vecD_rule,
  /*  592 */  vecD_rule,
  /*  593 */  vecD_rule,
  /*  594 */  vecX_rule,
  /*  595 */  immI0_rule,
  /*  596 */  immI0_rule,
  /*  597 */  vecD_rule,
  /*  598 */  vecX_rule,
  /*  599 */  vecD_rule,
  /*  600 */  vecD_rule,
  /*  601 */  vecD_rule,
  /*  602 */  vecD_rule,
  /*  603 */  vecX_rule,
  /*  604 */  vecD_rule,
  /*  605 */  vecX_rule,
  /*  606 */  vecD_rule,
  /*  607 */  vecX_rule,
  /*  608 */  vecX_rule,
  /*  609 */  vecD_rule,
  /*  610 */  vecX_rule,
  /*  611 */  vecX_rule,
  /*  612 */  vecD_rule,
  /*  613 */  vecX_rule,
  /*  614 */  vecX_rule,
  /*  615 */  vecD_rule,
  /*  616 */  vecX_rule,
  /*  617 */  vecX_rule,
  /*  618 */  iRegIorL2I_rule,
  /*  619 */  iRegIorL2I_rule,
  /*  620 */  iRegIorL2I_rule,
  /*  621 */  iRegIorL2I_rule,
  /*  622 */  vecX_rule,
  /*  623 */  vecD_rule,
  /*  624 */  vecD_rule,
  /*  625 */  vecX_rule,
  /*  626 */  vecD_rule,
  /*  627 */  vecX_rule,
  /*  628 */  vecD_rule,
  /*  629 */  vecX_rule,
  /*  630 */  vReg_rule,
  /*  631 */  pRegGov_rule,
  /*  632 */  vReg_rule,
  /*  633 */  vReg_rule,
  /*  634 */  vReg_rule,
  /*  635 */  vReg_rule,
  /*  636 */  vReg_rule,
  /*  637 */  vReg_rule,
  /*  638 */  vReg_rule,
  /*  639 */  vReg_rule,
  /*  640 */  vReg_rule,
  /*  641 */  iRegIorL2I_rule,
  /*  642 */  iRegIorL2I_rule,
  /*  643 */  iRegIorL2I_rule,
  /*  644 */  iRegIorL2I_rule,
  /*  645 */  iRegIorL2I_rule,
  /*  646 */  iRegIorL2I_rule,
  /*  647 */  iRegIorL2I_rule,
  /*  648 */  iRegIorL2I_rule,
  /*  649 */  vReg_rule,
  /*  650 */  vReg_rule,
  /*  651 */  pRegGov_rule,
  /*  652 */  pReg_rule,
  /*  653 */  pReg_rule,
  /*  654 */  vReg_rule,
  /*  655 */  vReg_rule,
  /*  656 */  vReg_rule,
  /*  657 */  vReg_rule,
  /*  658 */  vReg_rule,
  /*  659 */  vReg_rule,
  /*  660 */  vReg_rule,
  /*  661 */  vReg_rule,
  /*  662 */  vReg_rule,
  /*  663 */  vReg_rule,
  /*  664 */  vReg_rule,
  /*  665 */  immI0_rule,
  /*  666 */  pReg_rule,
  /*  667 */  memory1_rule,
  /*  668 */  _LoadB_memory1__rule,
  /*  669 */  memory1_rule,
  /*  670 */  _LoadUB_memory1__rule,
  /*  671 */  memory2_rule,
  /*  672 */  _LoadS_memory2__rule,
  /*  673 */  memory2_rule,
  /*  674 */  _LoadUS_memory2__rule,
  /*  675 */  memory4_rule,
  /*  676 */  _LoadI_memory4__rule,
  /*  677 */  _ConvI2L__LoadI_memory4___rule,
  /*  678 */  memory8_rule,
  /*  679 */  memory4_rule,
  /*  680 */  memory8_rule,
  /*  681 */  memory4_rule,
  /*  682 */  memory8_rule,
  /*  683 */  memory4_rule,
  /*  684 */  memory4_rule,
  /*  685 */  memory8_rule,
  /*  686 */  memory1_rule,
  /*  687 */  memory1_rule,
  /*  688 */  memory1_rule,
  /*  689 */  memory1_rule,
  /*  690 */  memory2_rule,
  /*  691 */  memory2_rule,
  /*  692 */  memory4_rule,
  /*  693 */  memory4_rule,
  /*  694 */  memory8_rule,
  /*  695 */  memory8_rule,
  /*  696 */  memory8_rule,
  /*  697 */  memory8_rule,
  /*  698 */  memory4_rule,
  /*  699 */  memory4_rule,
  /*  700 */  memory4_rule,
  /*  701 */  memory8_rule,
  /*  702 */  memory4_rule,
  /*  703 */  memory8_rule,
  /*  704 */  indirect_rule,
  /*  705 */  _LoadB_indirect__rule,
  /*  706 */  indirect_rule,
  /*  707 */  _LoadUB_indirect__rule,
  /*  708 */  indirect_rule,
  /*  709 */  indirect_rule,
  /*  710 */  _LoadUS_indirect__rule,
  /*  711 */  _LoadS_indirect__rule,
  /*  712 */  indirect_rule,
  /*  713 */  _ConvI2L__LoadI_indirect___rule,
  /*  714 */  indirect_rule,
  /*  715 */  indirect_rule,
  /*  716 */  indirect_rule,
  /*  717 */  indirect_rule,
  /*  718 */  indirect_rule,
  /*  719 */  indirect_rule,
  /*  720 */  indirect_rule,
  /*  721 */  indirect_rule,
  /*  722 */  indirect_rule,
  /*  723 */  indirect_rule,
  /*  724 */  indirect_rule,
  /*  725 */  indirect_rule,
  /*  726 */  indirect_rule,
  /*  727 */  indirect_rule,
  /*  728 */  0,
  /*  729 */  0,
  /*  730 */  iRegIorL2I_rule,
  /*  731 */  iRegL_rule,
  /*  732 */  iRegIorL2I_rule,
  /*  733 */  iRegIorL2I_rule,
  /*  734 */  iRegIorL2I_rule,
  /*  735 */  _LoadI_memory4__rule,
  /*  736 */  iRegL_rule,
  /*  737 */  _LoadL_memory8__rule,
  /*  738 */  0,
  /*  739 */  0,
  /*  740 */  0,
  /*  741 */  0,
  /*  742 */  0,
  /*  743 */  0,
  /*  744 */  0,
  /*  745 */  0,
  /*  746 */  0,
  /*  747 */  0,
  /*  748 */  0,
  /*  749 */  0,
  /*  750 */  _CastP2X_iRegP__rule,
  /*  751 */  _CastP2X__DecodeN_iRegN___rule,
  /*  752 */  iRegP_rule,
  /*  753 */  iRegP_rule,
  /*  754 */  iRegN_rule,
  /*  755 */  iRegN_rule,
  /*  756 */  iRegP_rule,
  /*  757 */  iRegN_rule,
  /*  758 */  indirect_rule,
  /*  759 */  indirect_rule,
  /*  760 */  indirect_rule,
  /*  761 */  indirect_rule,
  /*  762 */  indirect_rule,
  /*  763 */  indirect_rule,
  /*  764 */  indirect_rule,
  /*  765 */  indirect_rule,
  /*  766 */  indirect_rule,
  /*  767 */  indirect_rule,
  /*  768 */  indirect_rule,
  /*  769 */  indirect_rule,
  /*  770 */  indirect_rule,
  /*  771 */  indirect_rule,
  /*  772 */  indirect_rule,
  /*  773 */  indirect_rule,
  /*  774 */  indirect_rule,
  /*  775 */  indirect_rule,
  /*  776 */  indirect_rule,
  /*  777 */  indirect_rule,
  /*  778 */  indirect_rule,
  /*  779 */  indirect_rule,
  /*  780 */  indirect_rule,
  /*  781 */  indirect_rule,
  /*  782 */  indirect_rule,
  /*  783 */  indirect_rule,
  /*  784 */  indirect_rule,
  /*  785 */  indirect_rule,
  /*  786 */  indirect_rule,
  /*  787 */  indirect_rule,
  /*  788 */  indirect_rule,
  /*  789 */  indirect_rule,
  /*  790 */  indirect_rule,
  /*  791 */  indirect_rule,
  /*  792 */  indirect_rule,
  /*  793 */  indirect_rule,
  /*  794 */  indirect_rule,
  /*  795 */  indirect_rule,
  /*  796 */  indirect_rule,
  /*  797 */  indirect_rule,
  /*  798 */  indirect_rule,
  /*  799 */  indirect_rule,
  /*  800 */  indirect_rule,
  /*  801 */  indirect_rule,
  /*  802 */  indirect_rule,
  /*  803 */  indirect_rule,
  /*  804 */  indirect_rule,
  /*  805 */  indirect_rule,
  /*  806 */  indirect_rule,
  /*  807 */  indirect_rule,
  /*  808 */  indirect_rule,
  /*  809 */  indirect_rule,
  /*  810 */  indirect_rule,
  /*  811 */  indirect_rule,
  /*  812 */  indirect_rule,
  /*  813 */  indirect_rule,
  /*  814 */  indirect_rule,
  /*  815 */  indirect_rule,
  /*  816 */  indirect_rule,
  /*  817 */  indirect_rule,
  /*  818 */  indirect_rule,
  /*  819 */  iRegL_rule,
  /*  820 */  iRegL_rule,
  /*  821 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  822 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  823 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  824 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  825 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  826 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  827 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  828 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  829 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  830 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  831 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  832 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  833 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  834 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  835 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  836 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  837 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  838 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  839 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  840 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  841 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  842 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  843 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  844 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  845 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  846 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  847 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  848 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  849 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  850 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  851 */  iRegIorL2I_rule,
  /*  852 */  iRegIorL2I_rule,
  /*  853 */  _ConvL2I_iRegL__rule,
  /*  854 */  iRegP_rule,
  /*  855 */  iRegP_rule,
  /*  856 */  iRegP_rule,
  /*  857 */  iRegP_rule,
  /*  858 */  _ConvI2L_iRegIorL2I__rule,
  /*  859 */  iRegP_rule,
  /*  860 */  iRegL_rule,
  /*  861 */  iRegL_rule,
  /*  862 */  iRegIorL2I_rule,
  /*  863 */  iRegIorL2I_rule,
  /*  864 */  iRegL_rule,
  /*  865 */  iRegL_rule,
  /*  866 */  immI0_rule,
  /*  867 */  immL0_rule,
  /*  868 */  iRegIorL2I_rule,
  /*  869 */  _ConvI2L_iRegIorL2I__rule,
  /*  870 */  _ConvI2L_iRegIorL2I__rule,
  /*  871 */  iRegL_rule,
  /*  872 */  iRegL_rule,
  /*  873 */  iRegIorL2I_rule,
  /*  874 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  875 */  iRegIorL2I_rule,
  /*  876 */  _SubI_immI0_iRegIorL2I_rule,
  /*  877 */  iRegIorL2I_rule,
  /*  878 */  iRegL_rule,
  /*  879 */  _MulL_iRegL_iRegL_rule,
  /*  880 */  iRegL_rule,
  /*  881 */  _SubL_immL0_iRegL_rule,
  /*  882 */  iRegL_rule,
  /*  883 */  iRegLNoSp_rule,
  /*  884 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  885 */  iRegLNoSp_rule,
  /*  886 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  887 */  iRegLNoSp_rule,
  /*  888 */  iRegLNoSp_rule,
  /*  889 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  890 */  _ConvI2L_iRegIorL2I__rule,
  /*  891 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  892 */  iRegIorL2I_rule,
  /*  893 */  iRegL_rule,
  /*  894 */  iRegIorL2I_rule,
  /*  895 */  iRegL_rule,
  /*  896 */  iRegIorL2I_rule,
  /*  897 */  iRegIorL2I_rule,
  /*  898 */  iRegIorL2I_rule,
  /*  899 */  iRegIorL2I_rule,
  /*  900 */  iRegIorL2I_rule,
  /*  901 */  iRegIorL2I_rule,
  /*  902 */  iRegL_rule,
  /*  903 */  iRegL_rule,
  /*  904 */  iRegL_rule,
  /*  905 */  iRegL_rule,
  /*  906 */  _CastP2X_iRegP__rule,
  /*  907 */  iRegL_rule,
  /*  908 */  iRegL_rule,
  /*  909 */  iRegL_rule,
  /*  910 */  iRegIorL2I_rule,
  /*  911 */  iRegIorL2I_rule,
  /*  912 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  913 */  iRegL_rule,
  /*  914 */  _XorL_iRegL_immL_M1_rule,
  /*  915 */  iRegIorL2I_rule,
  /*  916 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  917 */  iRegL_rule,
  /*  918 */  _XorL_iRegL_immL_M1_rule,
  /*  919 */  immI_M1_rule,
  /*  920 */  _XorI_iRegIorL2I_iRegIorL2I_rule,
  /*  921 */  immL_M1_rule,
  /*  922 */  _XorL_iRegL_iRegL_rule,
  /*  923 */  iRegIorL2I_rule,
  /*  924 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  925 */  iRegL_rule,
  /*  926 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  927 */  iRegIorL2I_rule,
  /*  928 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  929 */  iRegL_rule,
  /*  930 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  931 */  iRegIorL2I_rule,
  /*  932 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /*  933 */  iRegL_rule,
  /*  934 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /*  935 */  iRegIorL2I_rule,
  /*  936 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  937 */  iRegL_rule,
  /*  938 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  939 */  immI_M1_rule,
  /*  940 */  _XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  941 */  immI_M1_rule,
  /*  942 */  _XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI_rule,
  /*  943 */  immL_M1_rule,
  /*  944 */  _XorL__URShiftL_iRegL_immI_iRegL_rule,
  /*  945 */  immL_M1_rule,
  /*  946 */  _XorL_iRegL__URShiftL_iRegL_immI_rule,
  /*  947 */  immI_M1_rule,
  /*  948 */  _XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  949 */  immI_M1_rule,
  /*  950 */  _XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI_rule,
  /*  951 */  immL_M1_rule,
  /*  952 */  _XorL__RShiftL_iRegL_immI_iRegL_rule,
  /*  953 */  immL_M1_rule,
  /*  954 */  _XorL_iRegL__RShiftL_iRegL_immI_rule,
  /*  955 */  immI_M1_rule,
  /*  956 */  _XorI__RotateRight_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  957 */  immI_M1_rule,
  /*  958 */  _XorI_iRegIorL2I__RotateRight_iRegIorL2I_immI_rule,
  /*  959 */  immL_M1_rule,
  /*  960 */  _XorL__RotateRight_iRegL_immI_iRegL_rule,
  /*  961 */  immL_M1_rule,
  /*  962 */  _XorL_iRegL__RotateRight_iRegL_immI_rule,
  /*  963 */  immI_M1_rule,
  /*  964 */  _XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  965 */  immI_M1_rule,
  /*  966 */  _XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI_rule,
  /*  967 */  immL_M1_rule,
  /*  968 */  _XorL__LShiftL_iRegL_immI_iRegL_rule,
  /*  969 */  immL_M1_rule,
  /*  970 */  _XorL_iRegL__LShiftL_iRegL_immI_rule,
  /*  971 */  iRegIorL2I_rule,
  /*  972 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  973 */  iRegL_rule,
  /*  974 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  975 */  iRegIorL2I_rule,
  /*  976 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  977 */  iRegL_rule,
  /*  978 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  979 */  iRegIorL2I_rule,
  /*  980 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /*  981 */  iRegL_rule,
  /*  982 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /*  983 */  iRegIorL2I_rule,
  /*  984 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  985 */  iRegL_rule,
  /*  986 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  987 */  iRegIorL2I_rule,
  /*  988 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  989 */  iRegL_rule,
  /*  990 */  _URShiftL_iRegL_immI_rule,
  /*  991 */  iRegIorL2I_rule,
  /*  992 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  993 */  iRegL_rule,
  /*  994 */  _RShiftL_iRegL_immI_rule,
  /*  995 */  iRegIorL2I_rule,
  /*  996 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  997 */  iRegL_rule,
  /*  998 */  _LShiftL_iRegL_immI_rule,
  /*  999 */  iRegIorL2I_rule,
  /* 1000 */  _RotateRight_iRegIorL2I_immI_rule,
  /* 1001 */  iRegL_rule,
  /* 1002 */  _RotateRight_iRegL_immI_rule,
  /* 1003 */  iRegIorL2I_rule,
  /* 1004 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1005 */  iRegL_rule,
  /* 1006 */  _URShiftL_iRegL_immI_rule,
  /* 1007 */  iRegIorL2I_rule,
  /* 1008 */  _RShiftI_iRegIorL2I_immI_rule,
  /* 1009 */  iRegL_rule,
  /* 1010 */  _RShiftL_iRegL_immI_rule,
  /* 1011 */  iRegIorL2I_rule,
  /* 1012 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1013 */  iRegL_rule,
  /* 1014 */  _LShiftL_iRegL_immI_rule,
  /* 1015 */  iRegIorL2I_rule,
  /* 1016 */  _RotateRight_iRegIorL2I_immI_rule,
  /* 1017 */  iRegL_rule,
  /* 1018 */  _RotateRight_iRegL_immI_rule,
  /* 1019 */  iRegIorL2I_rule,
  /* 1020 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1021 */  iRegL_rule,
  /* 1022 */  _URShiftL_iRegL_immI_rule,
  /* 1023 */  iRegIorL2I_rule,
  /* 1024 */  _RShiftI_iRegIorL2I_immI_rule,
  /* 1025 */  iRegL_rule,
  /* 1026 */  _RShiftL_iRegL_immI_rule,
  /* 1027 */  iRegIorL2I_rule,
  /* 1028 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1029 */  iRegL_rule,
  /* 1030 */  _LShiftL_iRegL_immI_rule,
  /* 1031 */  iRegIorL2I_rule,
  /* 1032 */  _RotateRight_iRegIorL2I_immI_rule,
  /* 1033 */  iRegL_rule,
  /* 1034 */  _RotateRight_iRegL_immI_rule,
  /* 1035 */  iRegIorL2I_rule,
  /* 1036 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1037 */  iRegL_rule,
  /* 1038 */  _URShiftL_iRegL_immI_rule,
  /* 1039 */  iRegIorL2I_rule,
  /* 1040 */  _RShiftI_iRegIorL2I_immI_rule,
  /* 1041 */  iRegL_rule,
  /* 1042 */  _RShiftL_iRegL_immI_rule,
  /* 1043 */  iRegIorL2I_rule,
  /* 1044 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1045 */  iRegL_rule,
  /* 1046 */  _LShiftL_iRegL_immI_rule,
  /* 1047 */  iRegIorL2I_rule,
  /* 1048 */  iRegL_rule,
  /* 1049 */  iRegIorL2I_rule,
  /* 1050 */  iRegL_rule,
  /* 1051 */  iRegIorL2I_rule,
  /* 1052 */  iRegL_rule,
  /* 1053 */  _LShiftL_iRegL_immI_rule,
  /* 1054 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1055 */  _LShiftL_iRegL_immI_rule,
  /* 1056 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1057 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1058 */  _URShiftL_iRegL_immI_rule,
  /* 1059 */  _AndI__URShiftI_iRegIorL2I_immI_immI_bitmask_rule,
  /* 1060 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /* 1061 */  _AndL_iRegL_immL_bitmask_rule,
  /* 1062 */  _LShiftI__AndI_iRegIorL2I_immI_bitmask_immI_rule,
  /* 1063 */  _LShiftL__AndL_iRegL_immL_positive_bitmaskI_immI_rule,
  /* 1064 */  _ConvI2L__AndI_iRegIorL2I_immI_bitmask__rule,
  /* 1065 */  _ConvL2I__AndL_iRegL_immL_positive_bitmaskI__rule,
  /* 1066 */  _AndI_iRegI_immI_bitmask_rule,
  /* 1067 */  _LShiftL_iRegL_immI_rule,
  /* 1068 */  _URShiftL_iRegL_immI_rule,
  /* 1069 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1070 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1071 */  _LShiftL_iRegL_immI_rule,
  /* 1072 */  _URShiftL_iRegL_immI_rule,
  /* 1073 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1074 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1075 */  iRegI_rule,
  /* 1076 */  iRegL_rule,
  /* 1077 */  iRegI_rule,
  /* 1078 */  iRegL_rule,
  /* 1079 */  iRegI_rule,
  /* 1080 */  iRegL_rule,
  /* 1081 */  iRegL_rule,
  /* 1082 */  _ConvI2L_iRegIorL2I__rule,
  /* 1083 */  iRegL_rule,
  /* 1084 */  iRegIorL2I_rule,
  /* 1085 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /* 1086 */  iRegIorL2I_rule,
  /* 1087 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /* 1088 */  iRegIorL2I_rule,
  /* 1089 */  _URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /* 1090 */  iRegL_rule,
  /* 1091 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /* 1092 */  iRegL_rule,
  /* 1093 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /* 1094 */  iRegL_rule,
  /* 1095 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /* 1096 */  iRegL_rule,
  /* 1097 */  _URShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /* 1098 */  iRegIorL2I_rule,
  /* 1099 */  _AndI_iRegIorL2I_immI_255_rule,
  /* 1100 */  iRegIorL2I_rule,
  /* 1101 */  _AndI_iRegIorL2I_immI_65535_rule,
  /* 1102 */  iRegL_rule,
  /* 1103 */  _AndL_iRegL_immL_255_rule,
  /* 1104 */  iRegL_rule,
  /* 1105 */  _AndL_iRegL_immL_65535_rule,
  /* 1106 */  iRegL_rule,
  /* 1107 */  _AndL_iRegL_immL_4294967295_rule,
  /* 1108 */  iRegIorL2I_rule,
  /* 1109 */  iRegIorL2I_rule,
  /* 1110 */  iRegL_rule,
  /* 1111 */  iRegL_rule,
  /* 1112 */  iRegL_rule,
  /* 1113 */  iRegL_rule,
  /* 1114 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /* 1115 */  iRegL_rule,
  /* 1116 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /* 1117 */  iRegL_rule,
  /* 1118 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /* 1119 */  iRegL_rule,
  /* 1120 */  iRegL_rule,
  /* 1121 */  iRegL_rule,
  /* 1122 */  iRegIorL2I_rule,
  /* 1123 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /* 1124 */  iRegIorL2I_rule,
  /* 1125 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /* 1126 */  iRegIorL2I_rule,
  /* 1127 */  iRegIorL2I_rule,
  /* 1128 */  iRegL_rule,
  /* 1129 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /* 1130 */  iRegL_rule,
  /* 1131 */  iRegL_rule,
  /* 1132 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /* 1133 */  iRegL_rule,
  /* 1134 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /* 1135 */  iRegL_rule,
  /* 1136 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /* 1137 */  iRegL_rule,
  /* 1138 */  iRegL_rule,
  /* 1139 */  iRegL_rule,
  /* 1140 */  iRegIorL2I_rule,
  /* 1141 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /* 1142 */  iRegIorL2I_rule,
  /* 1143 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /* 1144 */  iRegIorL2I_rule,
  /* 1145 */  iRegIorL2I_rule,
  /* 1146 */  vRegF_rule,
  /* 1147 */  vRegD_rule,
  /* 1148 */  vRegF_rule,
  /* 1149 */  vRegD_rule,
  /* 1150 */  vRegF_rule,
  /* 1151 */  vRegD_rule,
  /* 1152 */  vRegF_rule,
  /* 1153 */  vRegD_rule,
  /* 1154 */  vRegF_rule,
  /* 1155 */  vRegF_rule,
  /* 1156 */  vRegD_rule,
  /* 1157 */  vRegD_rule,
  /* 1158 */  _NegF_vRegF__rule,
  /* 1159 */  _NegF_vRegF__rule,
  /* 1160 */  _NegD_vRegD__rule,
  /* 1161 */  _NegD_vRegD__rule,
  /* 1162 */  _NegF_vRegF__rule,
  /* 1163 */  _NegD_vRegD__rule,
  /* 1164 */  vRegF_rule,
  /* 1165 */  vRegF_rule,
  /* 1166 */  vRegD_rule,
  /* 1167 */  vRegD_rule,
  /* 1168 */  vRegF_rule,
  /* 1169 */  vRegD_rule,
  /* 1170 */  iRegIorL2I_rule,
  /* 1171 */  iRegL_rule,
  /* 1172 */  _SubF_vRegF_vRegF_rule,
  /* 1173 */  _SubD_vRegD_vRegD_rule,
  /* 1174 */  vRegD_rule,
  /* 1175 */  vRegF_rule,
  /* 1176 */  vRegD_rule,
  /* 1177 */  vRegD_rule,
  /* 1178 */  vRegF_rule,
  /* 1179 */  vRegD_rule,
  /* 1180 */  vRegF_rule,
  /* 1181 */  0,
  /* 1182 */  iRegIorL2I_rule,
  /* 1183 */  iRegIorL2I_rule,
  /* 1184 */  iRegIorL2I_rule,
  /* 1185 */  iRegIorL2I_rule,
  /* 1186 */  iRegIorL2I_rule,
  /* 1187 */  iRegIorL2I_rule,
  /* 1188 */  iRegL_rule,
  /* 1189 */  iRegL_rule,
  /* 1190 */  iRegL_rule,
  /* 1191 */  iRegL_rule,
  /* 1192 */  iRegL_rule,
  /* 1193 */  iRegL_rule,
  /* 1194 */  iRegIorL2I_rule,
  /* 1195 */  _ConvI2L_iRegIorL2I__rule,
  /* 1196 */  iRegL_rule,
  /* 1197 */  iRegIorL2I_rule,
  /* 1198 */  iRegP_rule,
  /* 1199 */  vRegD_rule,
  /* 1200 */  vRegF_rule,
  /* 1201 */  vRegF_rule,
  /* 1202 */  vRegF_rule,
  /* 1203 */  iRegIorL2I_rule,
  /* 1204 */  iRegL_rule,
  /* 1205 */  vRegD_rule,
  /* 1206 */  vRegD_rule,
  /* 1207 */  iRegIorL2I_rule,
  /* 1208 */  iRegL_rule,
  /* 1209 */  vRegF_rule,
  /* 1210 */  iRegI_rule,
  /* 1211 */  vRegD_rule,
  /* 1212 */  iRegL_rule,
  /* 1213 */  iRegL_R11_rule,
  /* 1214 */  immL_rule,
  /* 1215 */  cmpOp_rule,
  /* 1216 */  cmpOp_rule,
  /* 1217 */  vRegF_rule,
  /* 1218 */  vRegD_rule,
  /* 1219 */  vRegF_rule,
  /* 1220 */  vRegD_rule,
  /* 1221 */  iRegIorL2I_rule,
  /* 1222 */  iRegIorL2I_rule,
  /* 1223 */  0,
  /* 1224 */  iRegI_rule,
  /* 1225 */  0,
  /* 1226 */  iRegI_rule,
  /* 1227 */  0,
  /* 1228 */  cmpOp_rule,
  /* 1229 */  cmpOpU_rule,
  /* 1230 */  cmpOpEqNe_rule,
  /* 1231 */  cmpOpEqNe_rule,
  /* 1232 */  cmpOpEqNe_rule,
  /* 1233 */  cmpOpEqNe_rule,
  /* 1234 */  cmpOpEqNe_rule,
  /* 1235 */  cmpOpUEqNeLtGe_rule,
  /* 1236 */  cmpOpUEqNeLtGe_rule,
  /* 1237 */  cmpOpLtGe_rule,
  /* 1238 */  cmpOpLtGe_rule,
  /* 1239 */  cmpOpEqNe_rule,
  /* 1240 */  cmpOpEqNe_rule,
  /* 1241 */  cmpOpLtGe_rule,
  /* 1242 */  cmpOpLtGe_rule,
  /* 1243 */  cmpOpEqNe_rule,
  /* 1244 */  cmpOpEqNe_rule,
  /* 1245 */  cmpOp_rule,
  /* 1246 */  cmpOpU_rule,
  /* 1247 */  iRegP_rule,
  /* 1248 */  0,
  /* 1249 */  0,
  /* 1250 */  0,
  /* 1251 */  0,
  /* 1252 */  0,
  /* 1253 */  0,
  /* 1254 */  iRegPNoSp_rule,
  /* 1255 */  iRegPNoSp_rule,
  /* 1256 */  0,
  /* 1257 */  0,
  /* 1258 */  0,
  /* 1259 */  0,
  /* 1260 */  iRegP_R4_rule,
  /* 1261 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1262 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1263 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1264 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1265 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1266 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1267 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1268 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1269 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1270 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1271 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1272 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1273 */  _Binary_iRegP_R1_iRegP_R3_rule,
  /* 1274 */  _Binary_iRegP_R1_iRegP_R3_rule,
  /* 1275 */  iRegP_R1_rule,
  /* 1276 */  iRegP_R1_rule,
  /* 1277 */  iRegP_R1_rule,
  /* 1278 */  iRegP_R2_rule,
  /* 1279 */  iRegP_R0_rule,
  /* 1280 */  iRegP_R2_rule,
  /* 1281 */  vmem2_rule,
  /* 1282 */  vmem4_rule,
  /* 1283 */  vmem8_rule,
  /* 1284 */  vmem16_rule,
  /* 1285 */  vmem2_rule,
  /* 1286 */  vmem4_rule,
  /* 1287 */  vmem8_rule,
  /* 1288 */  vmem16_rule,
  /* 1289 */  vecX_rule,
  /* 1290 */  iRegIorL2I_rule,
  /* 1291 */  iRegIorL2I_rule,
  /* 1292 */  iRegIorL2I_rule,
  /* 1293 */  iRegIorL2I_rule,
  /* 1294 */  iRegL_rule,
  /* 1295 */  iRegIorL2I_rule,
  /* 1296 */  iRegIorL2I_rule,
  /* 1297 */  iRegIorL2I_rule,
  /* 1298 */  iRegIorL2I_rule,
  /* 1299 */  iRegL_rule,
  /* 1300 */  iRegIorL2I_rule,
  /* 1301 */  iRegIorL2I_rule,
  /* 1302 */  iRegIorL2I_rule,
  /* 1303 */  iRegIorL2I_rule,
  /* 1304 */  iRegIorL2I_rule,
  /* 1305 */  iRegIorL2I_rule,
  /* 1306 */  iRegIorL2I_rule,
  /* 1307 */  iRegIorL2I_rule,
  /* 1308 */  iRegIorL2I_rule,
  /* 1309 */  iRegIorL2I_rule,
  /* 1310 */  iRegIorL2I_rule,
  /* 1311 */  iRegIorL2I_rule,
  /* 1312 */  iRegL_rule,
  /* 1313 */  iRegL_rule,
  /* 1314 */  vRegF_rule,
  /* 1315 */  vRegF_rule,
  /* 1316 */  vRegD_rule,
  /* 1317 */  vRegF_rule,
  /* 1318 */  vRegF_rule,
  /* 1319 */  vRegD_rule,
  /* 1320 */  iRegIorL2I_rule,
  /* 1321 */  iRegIorL2I_rule,
  /* 1322 */  iRegIorL2I_rule,
  /* 1323 */  iRegIorL2I_rule,
  /* 1324 */  iRegIorL2I_rule,
  /* 1325 */  iRegIorL2I_rule,
  /* 1326 */  iRegIorL2I_rule,
  /* 1327 */  iRegIorL2I_rule,
  /* 1328 */  iRegIorL2I_rule,
  /* 1329 */  iRegIorL2I_rule,
  /* 1330 */  iRegIorL2I_rule,
  /* 1331 */  iRegIorL2I_rule,
  /* 1332 */  iRegIorL2I_rule,
  /* 1333 */  iRegIorL2I_rule,
  /* 1334 */  iRegIorL2I_rule,
  /* 1335 */  iRegIorL2I_rule,
  /* 1336 */  iRegIorL2I_rule,
  /* 1337 */  iRegIorL2I_rule,
  /* 1338 */  iRegL_rule,
  /* 1339 */  iRegL_rule,
  /* 1340 */  iRegL_rule,
  /* 1341 */  _Binary_vecD_iRegIorL2I_rule,
  /* 1342 */  _Binary_vecX_iRegIorL2I_rule,
  /* 1343 */  _Binary_vecD_iRegIorL2I_rule,
  /* 1344 */  _Binary_vecX_iRegIorL2I_rule,
  /* 1345 */  _Binary_vecD_iRegIorL2I_rule,
  /* 1346 */  _Binary_vecX_iRegIorL2I_rule,
  /* 1347 */  _Binary_vecX_iRegL_rule,
  /* 1348 */  _Binary_vecD_vRegF_rule,
  /* 1349 */  _Binary_vecX_vRegF_rule,
  /* 1350 */  _Binary_vecX_vRegD_rule,
  /* 1351 */  vecD_rule,
  /* 1352 */  vecX_rule,
  /* 1353 */  vecD_rule,
  /* 1354 */  vecX_rule,
  /* 1355 */  vecD_rule,
  /* 1356 */  vecX_rule,
  /* 1357 */  vecX_rule,
  /* 1358 */  vecD_rule,
  /* 1359 */  vecX_rule,
  /* 1360 */  vecX_rule,
  /* 1361 */  _Binary_vecD_vecD_rule,
  /* 1362 */  _Binary_vecX_vecX_rule,
  /* 1363 */  vecX_rule,
  /* 1364 */  vecD_rule,
  /* 1365 */  _ReplicateB_immI_M1__rule,
  /* 1366 */  vecD_rule,
  /* 1367 */  _ReplicateS_immI_M1__rule,
  /* 1368 */  vecD_rule,
  /* 1369 */  _ReplicateI_immI_M1__rule,
  /* 1370 */  vecX_rule,
  /* 1371 */  _ReplicateB_immI_M1__rule,
  /* 1372 */  vecX_rule,
  /* 1373 */  _ReplicateS_immI_M1__rule,
  /* 1374 */  vecX_rule,
  /* 1375 */  _ReplicateI_immI_M1__rule,
  /* 1376 */  vecX_rule,
  /* 1377 */  _ReplicateL_immL_M1__rule,
  /* 1378 */  vecD_rule,
  /* 1379 */  _XorV_vecD__ReplicateB_immI_M1__rule,
  /* 1380 */  vecD_rule,
  /* 1381 */  _XorV__ReplicateB_immI_M1__vecD_rule,
  /* 1382 */  vecD_rule,
  /* 1383 */  _XorV_vecD__ReplicateS_immI_M1__rule,
  /* 1384 */  vecD_rule,
  /* 1385 */  _XorV__ReplicateS_immI_M1__vecD_rule,
  /* 1386 */  vecD_rule,
  /* 1387 */  _XorV_vecD__ReplicateI_immI_M1__rule,
  /* 1388 */  vecD_rule,
  /* 1389 */  _XorV__ReplicateI_immI_M1__vecD_rule,
  /* 1390 */  vecX_rule,
  /* 1391 */  _XorV_vecX__ReplicateB_immI_M1__rule,
  /* 1392 */  vecX_rule,
  /* 1393 */  _XorV__ReplicateB_immI_M1__vecX_rule,
  /* 1394 */  vecX_rule,
  /* 1395 */  _XorV_vecX__ReplicateS_immI_M1__rule,
  /* 1396 */  vecX_rule,
  /* 1397 */  _XorV__ReplicateS_immI_M1__vecX_rule,
  /* 1398 */  vecX_rule,
  /* 1399 */  _XorV_vecX__ReplicateI_immI_M1__rule,
  /* 1400 */  vecX_rule,
  /* 1401 */  _XorV__ReplicateI_immI_M1__vecX_rule,
  /* 1402 */  vecX_rule,
  /* 1403 */  _XorV_vecX__ReplicateL_immL_M1__rule,
  /* 1404 */  vecX_rule,
  /* 1405 */  _XorV__ReplicateL_immL_M1__vecX_rule,
  /* 1406 */  vecD_rule,
  /* 1407 */  vecX_rule,
  /* 1408 */  vecD_rule,
  /* 1409 */  vecX_rule,
  /* 1410 */  vecD_rule,
  /* 1411 */  vecX_rule,
  /* 1412 */  vecD_rule,
  /* 1413 */  vecX_rule,
  /* 1414 */  vecD_rule,
  /* 1415 */  vecX_rule,
  /* 1416 */  vecD_rule,
  /* 1417 */  vecX_rule,
  /* 1418 */  vecX_rule,
  /* 1419 */  vecX_rule,
  /* 1420 */  _Binary_vecD_vecD_rule,
  /* 1421 */  _Binary_vecX_vecX_rule,
  /* 1422 */  vecD_rule,
  /* 1423 */  vecX_rule,
  /* 1424 */  vecD_rule,
  /* 1425 */  vecX_rule,
  /* 1426 */  vecD_rule,
  /* 1427 */  vecX_rule,
  /* 1428 */  vecX_rule,
  /* 1429 */  vecD_rule,
  /* 1430 */  vecX_rule,
  /* 1431 */  vecD_rule,
  /* 1432 */  vecX_rule,
  /* 1433 */  vecX_rule,
  /* 1434 */  vecD_rule,
  /* 1435 */  vecX_rule,
  /* 1436 */  vecD_rule,
  /* 1437 */  vecX_rule,
  /* 1438 */  _SubVF_vecD_vecD_rule,
  /* 1439 */  _SubVF_vecX_vecX_rule,
  /* 1440 */  _SubVD_vecX_vecX_rule,
  /* 1441 */  iRegIorL2I_rule,
  /* 1442 */  iRegIorL2I_rule,
  /* 1443 */  immI_rule,
  /* 1444 */  immI_rule,
  /* 1445 */  iRegIorL2I_rule,
  /* 1446 */  iRegIorL2I_rule,
  /* 1447 */  immI_rule,
  /* 1448 */  immI_rule,
  /* 1449 */  iRegIorL2I_rule,
  /* 1450 */  iRegIorL2I_rule,
  /* 1451 */  immI_rule,
  /* 1452 */  immI_rule,
  /* 1453 */  iRegL_rule,
  /* 1454 */  immI0_rule,
  /* 1455 */  vRegF_rule,
  /* 1456 */  vRegF_rule,
  /* 1457 */  vRegD_rule,
  /* 1458 */  iRegIorL2I_rule,
  /* 1459 */  iRegIorL2I_rule,
  /* 1460 */  iRegIorL2I_rule,
  /* 1461 */  iRegIorL2I_rule,
  /* 1462 */  vRegF_rule,
  /* 1463 */  vRegF_rule,
  /* 1464 */  vRegF_rule,
  /* 1465 */  vRegF_rule,
  /* 1466 */  vRegD_rule,
  /* 1467 */  vRegD_rule,
  /* 1468 */  vecD_rule,
  /* 1469 */  vecX_rule,
  /* 1470 */  vecD_rule,
  /* 1471 */  vecX_rule,
  /* 1472 */  vecD_rule,
  /* 1473 */  vecX_rule,
  /* 1474 */  vecX_rule,
  /* 1475 */  vecD_rule,
  /* 1476 */  vecX_rule,
  /* 1477 */  vecX_rule,
  /* 1478 */  vecD_rule,
  /* 1479 */  vecX_rule,
  /* 1480 */  vecD_rule,
  /* 1481 */  vecX_rule,
  /* 1482 */  vecD_rule,
  /* 1483 */  vecX_rule,
  /* 1484 */  vecX_rule,
  /* 1485 */  vecD_rule,
  /* 1486 */  vecX_rule,
  /* 1487 */  vecX_rule,
  /* 1488 */  vecD_rule,
  /* 1489 */  vecX_rule,
  /* 1490 */  vecD_rule,
  /* 1491 */  vecX_rule,
  /* 1492 */  vecD_rule,
  /* 1493 */  vecX_rule,
  /* 1494 */  vecD_rule,
  /* 1495 */  vecX_rule,
  /* 1496 */  vecX_rule,
  /* 1497 */  vecD_rule,
  /* 1498 */  _MulVS_vecD_vecD_rule,
  /* 1499 */  vecX_rule,
  /* 1500 */  _MulVS_vecX_vecX_rule,
  /* 1501 */  vecD_rule,
  /* 1502 */  _MulVI_vecD_vecD_rule,
  /* 1503 */  vecX_rule,
  /* 1504 */  _MulVI_vecX_vecX_rule,
  /* 1505 */  vecD_rule,
  /* 1506 */  vecX_rule,
  /* 1507 */  vecX_rule,
  /* 1508 */  vecD_rule,
  /* 1509 */  vecX_rule,
  /* 1510 */  vecD_rule,
  /* 1511 */  vecX_rule,
  /* 1512 */  vecD_rule,
  /* 1513 */  vecD_rule,
  /* 1514 */  vecX_rule,
  /* 1515 */  vecX_rule,
  /* 1516 */  vecX_rule,
  /* 1517 */  vecX_rule,
  /* 1518 */  vecX_rule,
  /* 1519 */  vecD_rule,
  /* 1520 */  vecX_rule,
  /* 1521 */  vecX_rule,
  /* 1522 */  vecD_rule,
  /* 1523 */  vecX_rule,
  /* 1524 */  vecD_rule,
  /* 1525 */  vecX_rule,
  /* 1526 */  vecD_rule,
  /* 1527 */  vecX_rule,
  /* 1528 */  vecD_rule,
  /* 1529 */  vecX_rule,
  /* 1530 */  vecD_rule,
  /* 1531 */  vecX_rule,
  /* 1532 */  vecD_rule,
  /* 1533 */  vecX_rule,
  /* 1534 */  vecD_rule,
  /* 1535 */  vecX_rule,
  /* 1536 */  vecD_rule,
  /* 1537 */  vecX_rule,
  /* 1538 */  vecD_rule,
  /* 1539 */  vecX_rule,
  /* 1540 */  vecD_rule,
  /* 1541 */  vecX_rule,
  /* 1542 */  vecD_rule,
  /* 1543 */  vecX_rule,
  /* 1544 */  vecD_rule,
  /* 1545 */  vecX_rule,
  /* 1546 */  vecD_rule,
  /* 1547 */  vecX_rule,
  /* 1548 */  vecD_rule,
  /* 1549 */  vecX_rule,
  /* 1550 */  vecD_rule,
  /* 1551 */  vecX_rule,
  /* 1552 */  vecD_rule,
  /* 1553 */  vecX_rule,
  /* 1554 */  vecD_rule,
  /* 1555 */  vecX_rule,
  /* 1556 */  vecD_rule,
  /* 1557 */  vecX_rule,
  /* 1558 */  vecD_rule,
  /* 1559 */  vecX_rule,
  /* 1560 */  vecD_rule,
  /* 1561 */  vecX_rule,
  /* 1562 */  vecD_rule,
  /* 1563 */  vecX_rule,
  /* 1564 */  vecX_rule,
  /* 1565 */  vecX_rule,
  /* 1566 */  vecX_rule,
  /* 1567 */  vecX_rule,
  /* 1568 */  vecX_rule,
  /* 1569 */  vecX_rule,
  /* 1570 */  vecD_rule,
  /* 1571 */  _RShiftVB_vecD__RShiftCntV_immI__rule,
  /* 1572 */  vecX_rule,
  /* 1573 */  _RShiftVB_vecX__RShiftCntV_immI__rule,
  /* 1574 */  vecD_rule,
  /* 1575 */  _RShiftVS_vecD__RShiftCntV_immI__rule,
  /* 1576 */  vecX_rule,
  /* 1577 */  _RShiftVS_vecX__RShiftCntV_immI__rule,
  /* 1578 */  vecD_rule,
  /* 1579 */  _RShiftVI_vecD__RShiftCntV_immI__rule,
  /* 1580 */  vecX_rule,
  /* 1581 */  _RShiftVI_vecX__RShiftCntV_immI__rule,
  /* 1582 */  vecX_rule,
  /* 1583 */  _RShiftVL_vecX__RShiftCntV_immI__rule,
  /* 1584 */  vecD_rule,
  /* 1585 */  _URShiftVB_vecD__RShiftCntV_immI__rule,
  /* 1586 */  vecX_rule,
  /* 1587 */  _URShiftVB_vecX__RShiftCntV_immI__rule,
  /* 1588 */  vecD_rule,
  /* 1589 */  _URShiftVS_vecD__RShiftCntV_immI__rule,
  /* 1590 */  vecX_rule,
  /* 1591 */  _URShiftVS_vecX__RShiftCntV_immI__rule,
  /* 1592 */  vecD_rule,
  /* 1593 */  _URShiftVI_vecD__RShiftCntV_immI__rule,
  /* 1594 */  vecX_rule,
  /* 1595 */  _URShiftVI_vecX__RShiftCntV_immI__rule,
  /* 1596 */  vecX_rule,
  /* 1597 */  _URShiftVL_vecX__RShiftCntV_immI__rule,
  /* 1598 */  vecD_rule,
  /* 1599 */  vecX_rule,
  /* 1600 */  vecX_rule,
  /* 1601 */  vecD_rule,
  /* 1602 */  vecX_rule,
  /* 1603 */  vecX_rule,
  /* 1604 */  vecX_rule,
  /* 1605 */  vecD_rule,
  /* 1606 */  vecX_rule,
  /* 1607 */  vecD_rule,
  /* 1608 */  vmemA_rule,
  /* 1609 */  vmemA_rule,
  /* 1610 */  vmem2_rule,
  /* 1611 */  vmem2_rule,
  /* 1612 */  vmem4_rule,
  /* 1613 */  vmem4_rule,
  /* 1614 */  vmem8_rule,
  /* 1615 */  vmem8_rule,
  /* 1616 */  vmem16_rule,
  /* 1617 */  vmem16_rule,
  /* 1618 */  vmemA_rule,
  /* 1619 */  vmemA_rule,
  /* 1620 */  vmemA_rule,
  /* 1621 */  vmemA_rule,
  /* 1622 */  vmemA_rule,
  /* 1623 */  vmemA_rule,
  /* 1624 */  immI_rule,
  /* 1625 */  iRegIorL2I_rule,
  /* 1626 */  immL_rule,
  /* 1627 */  iRegL_rule,
  /* 1628 */  pRegGov_rule,
  /* 1629 */  pRegGov_rule,
  /* 1630 */  pRegGov_rule,
  /* 1631 */  pRegGov_rule,
  /* 1632 */  pRegGov_rule,
  /* 1633 */  vReg_rule,
  /* 1634 */  pRegGov_rule,
  /* 1635 */  vReg_rule,
  /* 1636 */  vReg_rule,
  /* 1637 */  vReg_rule,
  /* 1638 */  vReg_rule,
  /* 1639 */  vReg_rule,
  /* 1640 */  vReg_rule,
  /* 1641 */  vReg_rule,
  /* 1642 */  vReg_rule,
  /* 1643 */  vReg_rule,
  /* 1644 */  vReg_rule,
  /* 1645 */  vReg_rule,
  /* 1646 */  vReg_rule,
  /* 1647 */  _Binary_vReg_vReg_rule,
  /* 1648 */  _Binary_vReg_vReg_rule,
  /* 1649 */  _Binary_vReg_vReg_rule,
  /* 1650 */  _Binary_vReg_vReg_rule,
  /* 1651 */  _Binary_vReg_vReg_rule,
  /* 1652 */  _Binary_vReg_vReg_rule,
  /* 1653 */  vReg_rule,
  /* 1654 */  _ReplicateB_immBAddSubV__rule,
  /* 1655 */  vReg_rule,
  /* 1656 */  _ReplicateS_immIAddSubV__rule,
  /* 1657 */  vReg_rule,
  /* 1658 */  _ReplicateI_immIAddSubV__rule,
  /* 1659 */  vReg_rule,
  /* 1660 */  _ReplicateL_immLAddSubV__rule,
  /* 1661 */  vReg_rule,
  /* 1662 */  _ReplicateB_immBLog__rule,
  /* 1663 */  vReg_rule,
  /* 1664 */  _ReplicateS_immSLog__rule,
  /* 1665 */  vReg_rule,
  /* 1666 */  _ReplicateI_immILog__rule,
  /* 1667 */  vReg_rule,
  /* 1668 */  _ReplicateL_immLLog__rule,
  /* 1669 */  vReg_rule,
  /* 1670 */  _ReplicateB_immBLog__rule,
  /* 1671 */  vReg_rule,
  /* 1672 */  _ReplicateS_immSLog__rule,
  /* 1673 */  vReg_rule,
  /* 1674 */  _ReplicateI_immILog__rule,
  /* 1675 */  vReg_rule,
  /* 1676 */  _ReplicateL_immLLog__rule,
  /* 1677 */  vReg_rule,
  /* 1678 */  _ReplicateB_immBLog__rule,
  /* 1679 */  vReg_rule,
  /* 1680 */  _ReplicateS_immSLog__rule,
  /* 1681 */  vReg_rule,
  /* 1682 */  _ReplicateI_immILog__rule,
  /* 1683 */  vReg_rule,
  /* 1684 */  _ReplicateL_immLLog__rule,
  /* 1685 */  vReg_rule,
  /* 1686 */  vReg_rule,
  /* 1687 */  vReg_rule,
  /* 1688 */  _Binary_vReg_vReg_rule,
  /* 1689 */  _Binary_vReg_vReg_rule,
  /* 1690 */  _Binary_vReg_vReg_rule,
  /* 1691 */  vReg_rule,
  /* 1692 */  _ReplicateB_immI_M1__rule,
  /* 1693 */  vReg_rule,
  /* 1694 */  _ReplicateS_immI_M1__rule,
  /* 1695 */  vReg_rule,
  /* 1696 */  _ReplicateI_immI_M1__rule,
  /* 1697 */  vReg_rule,
  /* 1698 */  _ReplicateL_immL_M1__rule,
  /* 1699 */  vReg_rule,
  /* 1700 */  _XorV_vReg__ReplicateB_immI_M1__rule,
  /* 1701 */  vReg_rule,
  /* 1702 */  _XorV__ReplicateB_immI_M1__vReg_rule,
  /* 1703 */  vReg_rule,
  /* 1704 */  _XorV_vReg__ReplicateS_immI_M1__rule,
  /* 1705 */  vReg_rule,
  /* 1706 */  _XorV__ReplicateS_immI_M1__vReg_rule,
  /* 1707 */  vReg_rule,
  /* 1708 */  _XorV_vReg__ReplicateI_immI_M1__rule,
  /* 1709 */  vReg_rule,
  /* 1710 */  _XorV__ReplicateI_immI_M1__vReg_rule,
  /* 1711 */  vReg_rule,
  /* 1712 */  _XorV_vReg__ReplicateL_immL_M1__rule,
  /* 1713 */  vReg_rule,
  /* 1714 */  _XorV__ReplicateL_immL_M1__vReg_rule,
  /* 1715 */  vReg_rule,
  /* 1716 */  vReg_rule,
  /* 1717 */  _Binary_vReg_vReg_rule,
  /* 1718 */  _Binary_vReg_vReg_rule,
  /* 1719 */  vReg_rule,
  /* 1720 */  vReg_rule,
  /* 1721 */  _Binary_vReg_vReg_rule,
  /* 1722 */  _Binary_vReg_vReg_rule,
  /* 1723 */  vReg_rule,
  /* 1724 */  vReg_rule,
  /* 1725 */  _Binary_vReg_vReg_rule,
  /* 1726 */  _Binary_vReg_vReg_rule,
  /* 1727 */  vReg_rule,
  /* 1728 */  vReg_rule,
  /* 1729 */  vReg_rule,
  /* 1730 */  vReg_rule,
  /* 1731 */  _NegVF_vReg__rule,
  /* 1732 */  _NegVF_vReg__rule,
  /* 1733 */  _NegVD_vReg__rule,
  /* 1734 */  _NegVD_vReg__rule,
  /* 1735 */  _NegVF_vReg__rule,
  /* 1736 */  _NegVD_vReg__rule,
  /* 1737 */  vReg_rule,
  /* 1738 */  _MulVB_vReg_vReg_rule,
  /* 1739 */  vReg_rule,
  /* 1740 */  _MulVS_vReg_vReg_rule,
  /* 1741 */  vReg_rule,
  /* 1742 */  _MulVI_vReg_vReg_rule,
  /* 1743 */  vReg_rule,
  /* 1744 */  _MulVL_vReg_vReg_rule,
  /* 1745 */  vReg_rule,
  /* 1746 */  vReg_rule,
  /* 1747 */  vReg_rule,
  /* 1748 */  vReg_rule,
  /* 1749 */  vReg_rule,
  /* 1750 */  vReg_rule,
  /* 1751 */  vReg_rule,
  /* 1752 */  vReg_rule,
  /* 1753 */  vReg_rule,
  /* 1754 */  vReg_rule,
  /* 1755 */  _Binary_vReg_vReg_rule,
  /* 1756 */  _Binary_vReg_vReg_rule,
  /* 1757 */  _Binary_vReg_vReg_rule,
  /* 1758 */  _Binary_vReg_vReg_rule,
  /* 1759 */  _Binary_vReg_vReg_rule,
  /* 1760 */  _Binary_vReg_vReg_rule,
  /* 1761 */  vReg_rule,
  /* 1762 */  vReg_rule,
  /* 1763 */  _Binary_vReg_vReg_rule,
  /* 1764 */  _Binary_vReg_vReg_rule,
  /* 1765 */  _Binary_vReg_vReg_rule,
  /* 1766 */  vReg_rule,
  /* 1767 */  vReg_rule,
  /* 1768 */  pRegGov_rule,
  /* 1769 */  pRegGov_rule,
  /* 1770 */  _LoadVector_indirect__rule,
  /* 1771 */  _LoadVector_indirect__rule,
  /* 1772 */  indirect_rule,
  /* 1773 */  indirect_rule,
  /* 1774 */  iRegIorL2I_rule,
  /* 1775 */  iRegL_rule,
  /* 1776 */  vRegF_rule,
  /* 1777 */  vRegD_rule,
  /* 1778 */  iRegIorL2I_rule,
  /* 1779 */  iRegL_rule,
  /* 1780 */  vRegF_rule,
  /* 1781 */  vRegD_rule,
  /* 1782 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1783 */  _Binary_iRegL_vReg_rule,
  /* 1784 */  _Binary_vRegF_vReg_rule,
  /* 1785 */  _Binary_vRegD_vReg_rule,
  /* 1786 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1787 */  _Binary_iRegL_vReg_rule,
  /* 1788 */  _Binary_vRegF_vReg_rule,
  /* 1789 */  _Binary_vRegD_vReg_rule,
  /* 1790 */  iRegIorL2I_rule,
  /* 1791 */  iRegL_rule,
  /* 1792 */  iRegIorL2I_rule,
  /* 1793 */  iRegL_rule,
  /* 1794 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1795 */  _Binary_iRegL_vReg_rule,
  /* 1796 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1797 */  _Binary_iRegL_vReg_rule,
  /* 1798 */  iRegIorL2I_rule,
  /* 1799 */  iRegL_rule,
  /* 1800 */  iRegIorL2I_rule,
  /* 1801 */  iRegL_rule,
  /* 1802 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1803 */  _Binary_iRegL_vReg_rule,
  /* 1804 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1805 */  _Binary_iRegL_vReg_rule,
  /* 1806 */  iRegIorL2I_rule,
  /* 1807 */  iRegL_rule,
  /* 1808 */  iRegIorL2I_rule,
  /* 1809 */  iRegL_rule,
  /* 1810 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1811 */  _Binary_iRegL_vReg_rule,
  /* 1812 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1813 */  _Binary_iRegL_vReg_rule,
  /* 1814 */  iRegIorL2I_rule,
  /* 1815 */  iRegL_rule,
  /* 1816 */  iRegIorL2I_rule,
  /* 1817 */  iRegL_rule,
  /* 1818 */  vRegF_rule,
  /* 1819 */  vRegF_rule,
  /* 1820 */  vRegD_rule,
  /* 1821 */  vRegD_rule,
  /* 1822 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1823 */  _Binary_iRegL_vReg_rule,
  /* 1824 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1825 */  _Binary_iRegL_vReg_rule,
  /* 1826 */  _Binary_vRegF_vReg_rule,
  /* 1827 */  _Binary_vRegD_vReg_rule,
  /* 1828 */  _Binary_vRegF_vReg_rule,
  /* 1829 */  _Binary_vRegD_vReg_rule,
  /* 1830 */  iRegIorL2I_rule,
  /* 1831 */  iRegL_rule,
  /* 1832 */  iRegIorL2I_rule,
  /* 1833 */  iRegL_rule,
  /* 1834 */  vRegF_rule,
  /* 1835 */  vRegF_rule,
  /* 1836 */  vRegD_rule,
  /* 1837 */  vRegD_rule,
  /* 1838 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1839 */  _Binary_iRegL_vReg_rule,
  /* 1840 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1841 */  _Binary_iRegL_vReg_rule,
  /* 1842 */  _Binary_vRegF_vReg_rule,
  /* 1843 */  _Binary_vRegD_vReg_rule,
  /* 1844 */  _Binary_vRegF_vReg_rule,
  /* 1845 */  _Binary_vRegD_vReg_rule,
  /* 1846 */  vReg_rule,
  /* 1847 */  iRegIorL2I_rule,
  /* 1848 */  iRegIorL2I_rule,
  /* 1849 */  iRegIorL2I_rule,
  /* 1850 */  iRegL_rule,
  /* 1851 */  immI8_rule,
  /* 1852 */  immI8_shift8_rule,
  /* 1853 */  immI8_shift8_rule,
  /* 1854 */  immL8_shift8_rule,
  /* 1855 */  vRegF_rule,
  /* 1856 */  vRegD_rule,
  /* 1857 */  vReg_rule,
  /* 1858 */  vReg_rule,
  /* 1859 */  vReg_rule,
  /* 1860 */  vReg_rule,
  /* 1861 */  vReg_rule,
  /* 1862 */  vReg_rule,
  /* 1863 */  vReg_rule,
  /* 1864 */  vReg_rule,
  /* 1865 */  vReg_rule,
  /* 1866 */  vReg_rule,
  /* 1867 */  vReg_rule,
  /* 1868 */  vReg_rule,
  /* 1869 */  vReg_rule,
  /* 1870 */  vReg_rule,
  /* 1871 */  vReg_rule,
  /* 1872 */  vReg_rule,
  /* 1873 */  vReg_rule,
  /* 1874 */  vReg_rule,
  /* 1875 */  vReg_rule,
  /* 1876 */  vReg_rule,
  /* 1877 */  vReg_rule,
  /* 1878 */  vReg_rule,
  /* 1879 */  vReg_rule,
  /* 1880 */  vReg_rule,
  /* 1881 */  _Binary_vReg_vReg_rule,
  /* 1882 */  _Binary_vReg_vReg_rule,
  /* 1883 */  _Binary_vReg_vReg_rule,
  /* 1884 */  _Binary_vReg_vReg_rule,
  /* 1885 */  _Binary_vReg_vReg_rule,
  /* 1886 */  _Binary_vReg_vReg_rule,
  /* 1887 */  _Binary_vReg_vReg_rule,
  /* 1888 */  _Binary_vReg_vReg_rule,
  /* 1889 */  _Binary_vReg_vReg_rule,
  /* 1890 */  _Binary_vReg_vReg_rule,
  /* 1891 */  _Binary_vReg_vReg_rule,
  /* 1892 */  _Binary_vReg_vReg_rule,
  /* 1893 */  _Binary_vReg__RShiftCntV_immI__rule,
  /* 1894 */  _Binary_vReg__RShiftCntV_immI__rule,
  /* 1895 */  _Binary_vReg__RShiftCntV_immI__rule,
  /* 1896 */  _Binary_vReg__RShiftCntV_immI__rule,
  /* 1897 */  _Binary_vReg__RShiftCntV_immI__rule,
  /* 1898 */  _Binary_vReg__RShiftCntV_immI__rule,
  /* 1899 */  _Binary_vReg__RShiftCntV_immI__rule,
  /* 1900 */  _Binary_vReg__RShiftCntV_immI__rule,
  /* 1901 */  _Binary_vReg__LShiftCntV_immI__rule,
  /* 1902 */  _Binary_vReg__LShiftCntV_immI__rule,
  /* 1903 */  _Binary_vReg__LShiftCntV_immI__rule,
  /* 1904 */  _Binary_vReg__LShiftCntV_immI__rule,
  /* 1905 */  vReg_rule,
  /* 1906 */  vReg_rule,
  /* 1907 */  vReg_rule,
  /* 1908 */  vReg_rule,
  /* 1909 */  vReg_rule,
  /* 1910 */  vReg_rule,
  /* 1911 */  vReg_rule,
  /* 1912 */  vReg_rule,
  /* 1913 */  _Binary_vReg_vReg_rule,
  /* 1914 */  _Binary_vReg_vReg_rule,
  /* 1915 */  _Binary_vReg_vReg_rule,
  /* 1916 */  _Binary_vReg_vReg_rule,
  /* 1917 */  _Binary_vReg_vReg_rule,
  /* 1918 */  _Binary_vReg_vReg_rule,
  /* 1919 */  vReg_rule,
  /* 1920 */  vReg_rule,
  /* 1921 */  vReg_rule,
  /* 1922 */  vReg_rule,
  /* 1923 */  vReg_rule,
  /* 1924 */  vReg_rule,
  /* 1925 */  vReg_rule,
  /* 1926 */  vReg_rule,
  /* 1927 */  vReg_rule,
  /* 1928 */  vReg_rule,
  /* 1929 */  vReg_rule,
  /* 1930 */  vReg_rule,
  /* 1931 */  vReg_rule,
  /* 1932 */  vReg_rule,
  /* 1933 */  pRegGov_rule,
  /* 1934 */  pRegGov_rule,
  /* 1935 */  pRegGov_rule,
  /* 1936 */  pRegGov_rule,
  /* 1937 */  _Binary_vReg_iRegIorL2I_rule,
  /* 1938 */  _Binary_vReg_vRegF_rule,
  /* 1939 */  _Binary_vReg_iRegIorL2I_rule,
  /* 1940 */  _Binary_vReg_iRegL_rule,
  /* 1941 */  _Binary_vReg_vRegD_rule,
  /* 1942 */  _Binary_vReg_vRegF_rule,
  /* 1943 */  vReg_rule,
  /* 1944 */  indirect_rule,
  /* 1945 */  indirect_rule,
  /* 1946 */  indirect_rule,
  /* 1947 */  indirect_rule,
  /* 1948 */  indirect_rule,
  /* 1949 */  indirect_rule,
  /* 1950 */  indirect_rule,
  /* 1951 */  indirect_rule,
  /* 1952 */  indirect_rule,
  /* 1953 */  indirect_rule,
  /* 1954 */  indirect_rule,
  /* 1955 */  indirect_rule,
  /* 1956 */  indirect_rule,
  /* 1957 */  indirect_rule,
  /* 1958 */  indirect_rule,
  /* 1959 */  indirect_rule,
  /* 1960 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1961 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1962 */  pReg_rule,
  /* 1963 */  pReg_rule,
  /* 1964 */  pReg_rule,
  /* 1965 */  pReg_rule,
  /* 1966 */  pReg_rule,
  /* 1967 */  pReg_rule,
  /* 1968 */  iRegL_rule,
  /* 1969 */  indirect_rule,
  /* 1970 */  indirect_rule,
  /* 1971 */  indirect_rule,
  /* 1972 */  indirect_rule,
  /* 1973 */  indirect_rule,
  /* 1974 */  indirect_rule,
  /* 1975 */  indirect_rule,
  /* 1976 */  indirect_rule,
  /* 1977 */  indirect_rule,
  /* 1978 */  indirect_rule,
  /* 1979 */  indirect_rule,
  /* 1980 */  indirect_rule,
  /* 1981 */  memory8_rule,
  /* 1982 */  indirect_rule,
  /* 1983 */  indirect_rule,
  /* 1984 */  indirect_rule,
  /* 1985 */  indirect_rule,
  /* 1986 */  indirect_rule,
  /* 1987 */  indirect_rule,
  /* 1988 */  indirect_rule,
  /* 1989 */  indirect_rule,
  /* 1990 */  indirect_rule,
  // last instruction
  0 // no trailing comma
};

const        int   rightOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  0,
  /*   78 */  0,
  /*   79 */  0,
  /*   80 */  0,
  /*   81 */  0,
  /*   82 */  0,
  /*   83 */  0,
  /*   84 */  0,
  /*   85 */  0,
  /*   86 */  0,
  /*   87 */  0,
  /*   88 */  0,
  /*   89 */  0,
  /*   90 */  0,
  /*   91 */  0,
  /*   92 */  0,
  /*   93 */  0,
  /*   94 */  0,
  /*   95 */  0,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  /*  101 */  0,
  /*  102 */  0,
  /*  103 */  0,
  /*  104 */  0,
  /*  105 */  0,
  /*  106 */  0,
  /*  107 */  0,
  /*  108 */  0,
  /*  109 */  0,
  /*  110 */  0,
  /*  111 */  0,
  /*  112 */  0,
  /*  113 */  0,
  /*  114 */  0,
  /*  115 */  0,
  /*  116 */  0,
  /*  117 */  0,
  /*  118 */  0,
  /*  119 */  0,
  /*  120 */  0,
  /*  121 */  0,
  /*  122 */  0,
  /*  123 */  0,
  /*  124 */  0,
  /*  125 */  0,
  /*  126 */  0,
  /*  127 */  0,
  /*  128 */  0,
  /*  129 */  0,
  /*  130 */  0,
  /*  131 */  0,
  /*  132 */  0,
  /*  133 */  0,
  /*  134 */  0,
  /*  135 */  0,
  /*  136 */  0,
  /*  137 */  0,
  /*  138 */  0,
  /*  139 */  0,
  /*  140 */  0,
  /*  141 */  0,
  /*  142 */  0,
  /*  143 */  0,
  /*  144 */  0,
  /*  145 */  0,
  /*  146 */  0,
  /*  147 */  0,
  /*  148 */  0,
  /*  149 */  0,
  /*  150 */  0,
  /*  151 */  0,
  /*  152 */  0,
  /*  153 */  0,
  /*  154 */  0,
  /*  155 */  0,
  /*  156 */  0,
  /*  157 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  158 */  _LShiftL_iRegL_immIScale_rule,
  /*  159 */  _ConvI2L_iRegI__rule,
  /*  160 */  iRegL_rule,
  /*  161 */  immIOffset_rule,
  /*  162 */  immIOffset1_rule,
  /*  163 */  immIOffset2_rule,
  /*  164 */  immIOffset4_rule,
  /*  165 */  immIOffset8_rule,
  /*  166 */  immIOffset16_rule,
  /*  167 */  immLoffset_rule,
  /*  168 */  immLoffset1_rule,
  /*  169 */  immLoffset2_rule,
  /*  170 */  immLoffset4_rule,
  /*  171 */  immLoffset8_rule,
  /*  172 */  immLoffset16_rule,
  /*  173 */  0,
  /*  174 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  175 */  _LShiftL_iRegL_immIScale_rule,
  /*  176 */  _ConvI2L_iRegI__rule,
  /*  177 */  iRegL_rule,
  /*  178 */  immIOffset_rule,
  /*  179 */  immLoffset_rule,
  /*  180 */  immL_pc_off_rule,
  /*  181 */  0,
  /*  182 */  0,
  /*  183 */  0,
  /*  184 */  0,
  /*  185 */  0,
  /*  186 */  0,
  /*  187 */  0,
  /*  188 */  0,
  /*  189 */  0,
  /*  190 */  0,
  /*  191 */  0,
  /*  192 */  0,
  /*  193 */  0,
  /*  194 */  vmemA_immIOffset4_rule,
  /*  195 */  vmemA_immLOffset4_rule,
  // last operand
  /*  196 */  0,
  /*  197 */  0,
  /*  198 */  0,
  /*  199 */  0,
  /*  200 */  0,
  /*  201 */  0,
  /*  202 */  0,
  /*  203 */  0,
  /*  204 */  0,
  /*  205 */  0,
  /*  206 */  0,
  // last operand class
  /*  207 */  0,
  /*  208 */  immIScale_rule,
  /*  209 */  immIScale_rule,
  /*  210 */  0,
  /*  211 */  0,
  /*  212 */  0,
  /*  213 */  0,
  /*  214 */  0,
  /*  215 */  0,
  /*  216 */  0,
  /*  217 */  0,
  /*  218 */  0,
  /*  219 */  0,
  /*  220 */  0,
  /*  221 */  0,
  /*  222 */  0,
  /*  223 */  0,
  /*  224 */  0,
  /*  225 */  0,
  /*  226 */  iRegP_rule,
  /*  227 */  iRegLNoSp_rule,
  /*  228 */  iRegINoSp_rule,
  /*  229 */  iRegNNoSp_rule,
  /*  230 */  iRegI_rule,
  /*  231 */  iRegL_rule,
  /*  232 */  iRegN_rule,
  /*  233 */  rFlagsReg_rule,
  /*  234 */  iRegIorL2I_rule,
  /*  235 */  rFlagsRegU_rule,
  /*  236 */  iRegIorL2I_rule,
  /*  237 */  immI0_rule,
  /*  238 */  immI0_rule,
  /*  239 */  immL0_rule,
  /*  240 */  iRegL_rule,
  /*  241 */  immP0_rule,
  /*  242 */  iRegP_rule,
  /*  243 */  immN0_rule,
  /*  244 */  iRegN_rule,
  /*  245 */  vRegF_rule,
  /*  246 */  vRegD_rule,
  /*  247 */  0,
  /*  248 */  0,
  /*  249 */  immIScale_rule,
  /*  250 */  iRegIorL2I_rule,
  /*  251 */  iRegIorL2I_rule,
  /*  252 */  iRegL_rule,
  /*  253 */  iRegL_rule,
  /*  254 */  _ConvI2L_iRegIorL2I__rule,
  /*  255 */  _ConvI2L_iRegIorL2I__rule,
  /*  256 */  immI_M1_rule,
  /*  257 */  immL_M1_rule,
  /*  258 */  iRegIorL2I_rule,
  /*  259 */  iRegL_rule,
  /*  260 */  immI_rule,
  /*  261 */  immI_M1_rule,
  /*  262 */  immI_rule,
  /*  263 */  immL_M1_rule,
  /*  264 */  immI_rule,
  /*  265 */  immI_M1_rule,
  /*  266 */  immI_rule,
  /*  267 */  immL_M1_rule,
  /*  268 */  immI_rule,
  /*  269 */  immI_M1_rule,
  /*  270 */  immI_rule,
  /*  271 */  immL_M1_rule,
  /*  272 */  immI_rule,
  /*  273 */  immI_M1_rule,
  /*  274 */  immI_rule,
  /*  275 */  immL_M1_rule,
  /*  276 */  iRegIorL2I_rule,
  /*  277 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  278 */  iRegL_rule,
  /*  279 */  _URShiftL_iRegL_immI_rule,
  /*  280 */  iRegIorL2I_rule,
  /*  281 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  282 */  iRegL_rule,
  /*  283 */  _RShiftL_iRegL_immI_rule,
  /*  284 */  iRegIorL2I_rule,
  /*  285 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  286 */  iRegL_rule,
  /*  287 */  _RotateRight_iRegL_immI_rule,
  /*  288 */  iRegIorL2I_rule,
  /*  289 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  290 */  iRegL_rule,
  /*  291 */  _LShiftL_iRegL_immI_rule,
  /*  292 */  immI_bitmask_rule,
  /*  293 */  immI_bitmask_rule,
  /*  294 */  immL_bitmask_rule,
  /*  295 */  immI_rule,
  /*  296 */  immL_positive_bitmaskI_rule,
  /*  297 */  immI_rule,
  /*  298 */  0,
  /*  299 */  0,
  /*  300 */  immI_bitmask_rule,
  /*  301 */  immI_16_rule,
  /*  302 */  immI_16_rule,
  /*  303 */  immI_24_rule,
  /*  304 */  immI_24_rule,
  /*  305 */  immI_24_rule,
  /*  306 */  immI_48_rule,
  /*  307 */  immI_48_rule,
  /*  308 */  immI_32_rule,
  /*  309 */  immI_32_rule,
  /*  310 */  immI_56_rule,
  /*  311 */  immI_56_rule,
  /*  312 */  immI_56_rule,
  /*  313 */  immI_255_rule,
  /*  314 */  immI_65535_rule,
  /*  315 */  immL_255_rule,
  /*  316 */  immL_65535_rule,
  /*  317 */  immL_4294967295_rule,
  /*  318 */  immIExt_rule,
  /*  319 */  immIExt_rule,
  /*  320 */  immIExt_rule,
  /*  321 */  immIExt_rule,
  /*  322 */  immIExt_rule,
  /*  323 */  immIExt_rule,
  /*  324 */  immIExt_rule,
  /*  325 */  immIExt_rule,
  /*  326 */  immIExt_rule,
  /*  327 */  immIExt_rule,
  /*  328 */  immIExt_rule,
  /*  329 */  0,
  /*  330 */  vRegF_rule,
  /*  331 */  _NegF_vRegF__rule,
  /*  332 */  0,
  /*  333 */  vRegD_rule,
  /*  334 */  _NegD_vRegD__rule,
  /*  335 */  vRegF_rule,
  /*  336 */  vRegD_rule,
  /*  337 */  iRegIorL2I_rule,
  /*  338 */  iRegL_rule,
  /*  339 */  immI0_rule,
  /*  340 */  immL0_rule,
  /*  341 */  immP0_rule,
  /*  342 */  immN0_rule,
  /*  343 */  immP0_rule,
  /*  344 */  immI0_rule,
  /*  345 */  immL0_rule,
  /*  346 */  immL_rule,
  /*  347 */  immL0_rule,
  /*  348 */  immI_rule,
  /*  349 */  immI0_rule,
  /*  350 */  iRegL_rule,
  /*  351 */  iRegIorL2I_rule,
  /*  352 */  iRegP_R0_rule,
  /*  353 */  iRegI_R2_rule,
  /*  354 */  iRegI_R4_rule,
  /*  355 */  iRegI_R4_rule,
  /*  356 */  iRegI_R2_rule,
  /*  357 */  immI_le_4_rule,
  /*  358 */  immI_1_rule,
  /*  359 */  iRegP_R3_rule,
  /*  360 */  iRegI_R3_rule,
  /*  361 */  iRegIorL2I_rule,
  /*  362 */  iRegIorL2I_rule,
  /*  363 */  iRegL_rule,
  /*  364 */  vRegF_rule,
  /*  365 */  vRegF_rule,
  /*  366 */  vRegD_rule,
  /*  367 */  vecD_rule,
  /*  368 */  vecX_rule,
  /*  369 */  0,
  /*  370 */  0,
  /*  371 */  0,
  /*  372 */  0,
  /*  373 */  _ReplicateB_immI_M1__rule,
  /*  374 */  vecD_rule,
  /*  375 */  _ReplicateS_immI_M1__rule,
  /*  376 */  vecD_rule,
  /*  377 */  _ReplicateI_immI_M1__rule,
  /*  378 */  vecD_rule,
  /*  379 */  _ReplicateB_immI_M1__rule,
  /*  380 */  vecX_rule,
  /*  381 */  _ReplicateS_immI_M1__rule,
  /*  382 */  vecX_rule,
  /*  383 */  _ReplicateI_immI_M1__rule,
  /*  384 */  vecX_rule,
  /*  385 */  _ReplicateL_immL_M1__rule,
  /*  386 */  vecX_rule,
  /*  387 */  vecD_rule,
  /*  388 */  vecX_rule,
  /*  389 */  vecX_rule,
  /*  390 */  vecD_rule,
  /*  391 */  vecX_rule,
  /*  392 */  vecD_rule,
  /*  393 */  vecX_rule,
  /*  394 */  0,
  /*  395 */  vecD_rule,
  /*  396 */  _NegVF_vecD__rule,
  /*  397 */  0,
  /*  398 */  vecX_rule,
  /*  399 */  _NegVF_vecX__rule,
  /*  400 */  0,
  /*  401 */  vecX_rule,
  /*  402 */  _NegVD_vecX__rule,
  /*  403 */  0,
  /*  404 */  0,
  /*  405 */  _RShiftCntV_immI__rule,
  /*  406 */  _RShiftCntV_immI__rule,
  /*  407 */  _RShiftCntV_immI__rule,
  /*  408 */  _RShiftCntV_immI__rule,
  /*  409 */  _RShiftCntV_immI__rule,
  /*  410 */  _RShiftCntV_immI__rule,
  /*  411 */  _RShiftCntV_immI__rule,
  /*  412 */  _RShiftCntV_immI__rule,
  /*  413 */  _RShiftCntV_immI__rule,
  /*  414 */  _RShiftCntV_immI__rule,
  /*  415 */  _RShiftCntV_immI__rule,
  /*  416 */  _RShiftCntV_immI__rule,
  /*  417 */  _RShiftCntV_immI__rule,
  /*  418 */  _RShiftCntV_immI__rule,
  /*  419 */  pRegGov_rule,
  /*  420 */  0,
  /*  421 */  _MaskAll_immI_M1__rule,
  /*  422 */  0,
  /*  423 */  _MaskAll_immL_M1__rule,
  /*  424 */  vReg_rule,
  /*  425 */  0,
  /*  426 */  0,
  /*  427 */  0,
  /*  428 */  0,
  /*  429 */  0,
  /*  430 */  0,
  /*  431 */  0,
  /*  432 */  0,
  /*  433 */  _ReplicateB_immI_M1__rule,
  /*  434 */  vReg_rule,
  /*  435 */  _ReplicateS_immI_M1__rule,
  /*  436 */  vReg_rule,
  /*  437 */  _ReplicateI_immI_M1__rule,
  /*  438 */  vReg_rule,
  /*  439 */  _ReplicateL_immL_M1__rule,
  /*  440 */  vReg_rule,
  /*  441 */  0,
  /*  442 */  vReg_rule,
  /*  443 */  _NegVF_vReg__rule,
  /*  444 */  0,
  /*  445 */  vReg_rule,
  /*  446 */  _NegVD_vReg__rule,
  /*  447 */  vReg_rule,
  /*  448 */  vReg_rule,
  /*  449 */  vReg_rule,
  /*  450 */  vReg_rule,
  /*  451 */  pRegGov_rule,
  /*  452 */  0,
  /*  453 */  immI_gt_1_rule,
  /*  454 */  vReg_rule,
  /*  455 */  vReg_rule,
  /*  456 */  vReg_rule,
  /*  457 */  vReg_rule,
  /*  458 */  _RShiftCntV_immI__rule,
  /*  459 */  _LShiftCntV_immI__rule,
  /*  460 */  iRegIorL2I_rule,
  /*  461 */  vRegF_rule,
  /*  462 */  iRegL_rule,
  /*  463 */  vRegD_rule,
  /*  464 */  _Binary_vReg_pRegGov_rule,
  // last internally defined operand
  /*  465 */  0,
  /*  466 */  0,
  /*  467 */  0,
  /*  468 */  0,
  /*  469 */  0,
  /*  470 */  0,
  /*  471 */  0,
  /*  472 */  0,
  /*  473 */  0,
  /*  474 */  0,
  /*  475 */  0,
  /*  476 */  0,
  /*  477 */  0,
  /*  478 */  0,
  /*  479 */  0,
  /*  480 */  0,
  /*  481 */  0,
  /*  482 */  0,
  /*  483 */  0,
  /*  484 */  0,
  /*  485 */  0,
  /*  486 */  0,
  /*  487 */  0,
  /*  488 */  0,
  /*  489 */  0,
  /*  490 */  0,
  /*  491 */  0,
  /*  492 */  0,
  /*  493 */  0,
  /*  494 */  _Binary_iRegP_iRegP_rule,
  /*  495 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  496 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  497 */  0,
  /*  498 */  0,
  /*  499 */  0,
  /*  500 */  0,
  /*  501 */  0,
  /*  502 */  0,
  /*  503 */  0,
  /*  504 */  0,
  /*  505 */  0,
  /*  506 */  0,
  /*  507 */  0,
  /*  508 */  0,
  /*  509 */  iRegIorL2I_rule,
  /*  510 */  immIAddSub_rule,
  /*  511 */  iRegL_rule,
  /*  512 */  immLAddSub_rule,
  /*  513 */  iRegIorL2I_rule,
  /*  514 */  immIAddSub_rule,
  /*  515 */  iRegL_rule,
  /*  516 */  immLAddSub_rule,
  /*  517 */  iRegIorL2I_rule,
  /*  518 */  iRegL_rule,
  /*  519 */  iRegIorL2I_rule,
  /*  520 */  iRegL_rule,
  /*  521 */  iRegI_rule,
  /*  522 */  immI0_rule,
  /*  523 */  immIAddSub_rule,
  /*  524 */  immI_rule,
  /*  525 */  iRegI_rule,
  /*  526 */  immI0_rule,
  /*  527 */  immIAddSub_rule,
  /*  528 */  immI_rule,
  /*  529 */  iRegL_rule,
  /*  530 */  immL0_rule,
  /*  531 */  immLAddSub_rule,
  /*  532 */  immL_rule,
  /*  533 */  iRegL_rule,
  /*  534 */  immL0_rule,
  /*  535 */  immLAddSub_rule,
  /*  536 */  immL_rule,
  /*  537 */  iRegP_rule,
  /*  538 */  iRegN_rule,
  /*  539 */  immP0_rule,
  /*  540 */  immN0_rule,
  /*  541 */  vRegF_rule,
  /*  542 */  immF0_rule,
  /*  543 */  vRegD_rule,
  /*  544 */  immD0_rule,
  /*  545 */  immL0_rule,
  /*  546 */  immI0_rule,
  /*  547 */  immL0_rule,
  /*  548 */  immI0_rule,
  /*  549 */  iRegP_rule,
  /*  550 */  iRegP_rule,
  /*  551 */  immP0_rule,
  /*  552 */  0,
  /*  553 */  0,
  /*  554 */  0,
  /*  555 */  0,
  /*  556 */  0,
  /*  557 */  0,
  /*  558 */  0,
  /*  559 */  0,
  /*  560 */  0,
  /*  561 */  0,
  /*  562 */  0,
  /*  563 */  0,
  /*  564 */  0,
  /*  565 */  0,
  /*  566 */  0,
  /*  567 */  0,
  /*  568 */  0,
  /*  569 */  0,
  /*  570 */  0,
  /*  571 */  0,
  /*  572 */  0,
  /*  573 */  0,
  /*  574 */  0,
  /*  575 */  0,
  /*  576 */  0,
  /*  577 */  0,
  /*  578 */  0,
  /*  579 */  0,
  /*  580 */  0,
  /*  581 */  0,
  /*  582 */  0,
  /*  583 */  0,
  /*  584 */  0,
  /*  585 */  0,
  /*  586 */  0,
  /*  587 */  0,
  /*  588 */  0,
  /*  589 */  0,
  /*  590 */  0,
  /*  591 */  0,
  /*  592 */  0,
  /*  593 */  0,
  /*  594 */  0,
  /*  595 */  0,
  /*  596 */  0,
  /*  597 */  0,
  /*  598 */  0,
  /*  599 */  0,
  /*  600 */  0,
  /*  601 */  0,
  /*  602 */  0,
  /*  603 */  0,
  /*  604 */  0,
  /*  605 */  0,
  /*  606 */  0,
  /*  607 */  0,
  /*  608 */  0,
  /*  609 */  0,
  /*  610 */  0,
  /*  611 */  0,
  /*  612 */  0,
  /*  613 */  0,
  /*  614 */  0,
  /*  615 */  0,
  /*  616 */  0,
  /*  617 */  0,
  /*  618 */  0,
  /*  619 */  0,
  /*  620 */  0,
  /*  621 */  0,
  /*  622 */  0,
  /*  623 */  0,
  /*  624 */  0,
  /*  625 */  0,
  /*  626 */  0,
  /*  627 */  0,
  /*  628 */  0,
  /*  629 */  0,
  /*  630 */  0,
  /*  631 */  0,
  /*  632 */  0,
  /*  633 */  0,
  /*  634 */  0,
  /*  635 */  0,
  /*  636 */  0,
  /*  637 */  0,
  /*  638 */  0,
  /*  639 */  0,
  /*  640 */  0,
  /*  641 */  0,
  /*  642 */  0,
  /*  643 */  0,
  /*  644 */  0,
  /*  645 */  0,
  /*  646 */  0,
  /*  647 */  0,
  /*  648 */  0,
  /*  649 */  0,
  /*  650 */  0,
  /*  651 */  0,
  /*  652 */  0,
  /*  653 */  0,
  /*  654 */  0,
  /*  655 */  0,
  /*  656 */  0,
  /*  657 */  0,
  /*  658 */  0,
  /*  659 */  0,
  /*  660 */  0,
  /*  661 */  0,
  /*  662 */  0,
  /*  663 */  0,
  /*  664 */  0,
  /*  665 */  0,
  /*  666 */  0,
  /*  667 */  0,
  /*  668 */  0,
  /*  669 */  0,
  /*  670 */  0,
  /*  671 */  0,
  /*  672 */  0,
  /*  673 */  0,
  /*  674 */  0,
  /*  675 */  0,
  /*  676 */  0,
  /*  677 */  immL_32bits_rule,
  /*  678 */  0,
  /*  679 */  0,
  /*  680 */  0,
  /*  681 */  0,
  /*  682 */  0,
  /*  683 */  0,
  /*  684 */  0,
  /*  685 */  0,
  /*  686 */  immI0_rule,
  /*  687 */  immI0_rule,
  /*  688 */  iRegIorL2I_rule,
  /*  689 */  immI0_rule,
  /*  690 */  iRegIorL2I_rule,
  /*  691 */  immI0_rule,
  /*  692 */  iRegIorL2I_rule,
  /*  693 */  immI0_rule,
  /*  694 */  iRegL_rule,
  /*  695 */  immL0_rule,
  /*  696 */  iRegP_rule,
  /*  697 */  immP0_rule,
  /*  698 */  iRegN_rule,
  /*  699 */  immN0_rule,
  /*  700 */  vRegF_rule,
  /*  701 */  vRegD_rule,
  /*  702 */  iRegN_rule,
  /*  703 */  0,
  /*  704 */  0,
  /*  705 */  0,
  /*  706 */  0,
  /*  707 */  0,
  /*  708 */  0,
  /*  709 */  0,
  /*  710 */  0,
  /*  711 */  0,
  /*  712 */  0,
  /*  713 */  immL_32bits_rule,
  /*  714 */  0,
  /*  715 */  0,
  /*  716 */  0,
  /*  717 */  0,
  /*  718 */  0,
  /*  719 */  iRegIorL2I_rule,
  /*  720 */  iRegIorL2I_rule,
  /*  721 */  iRegIorL2I_rule,
  /*  722 */  iRegL_rule,
  /*  723 */  iRegP_rule,
  /*  724 */  iRegN_rule,
  /*  725 */  vRegF_rule,
  /*  726 */  vRegD_rule,
  /*  727 */  0,
  /*  728 */  0,
  /*  729 */  0,
  /*  730 */  0,
  /*  731 */  0,
  /*  732 */  0,
  /*  733 */  0,
  /*  734 */  0,
  /*  735 */  0,
  /*  736 */  0,
  /*  737 */  0,
  /*  738 */  0,
  /*  739 */  0,
  /*  740 */  0,
  /*  741 */  0,
  /*  742 */  0,
  /*  743 */  0,
  /*  744 */  0,
  /*  745 */  0,
  /*  746 */  0,
  /*  747 */  0,
  /*  748 */  0,
  /*  749 */  0,
  /*  750 */  0,
  /*  751 */  0,
  /*  752 */  0,
  /*  753 */  0,
  /*  754 */  0,
  /*  755 */  0,
  /*  756 */  0,
  /*  757 */  0,
  /*  758 */  0,
  /*  759 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  760 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  761 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  762 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  763 */  _Binary_iRegP_iRegP_rule,
  /*  764 */  _Binary_iRegNNoSp_iRegNNoSp_rule,
  /*  765 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  766 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  767 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  768 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  769 */  _Binary_iRegP_iRegP_rule,
  /*  770 */  _Binary_iRegNNoSp_iRegNNoSp_rule,
  /*  771 */  _Binary_iRegI_iRegI_rule,
  /*  772 */  _Binary_iRegI_iRegI_rule,
  /*  773 */  _Binary_iRegI_iRegI_rule,
  /*  774 */  _Binary_iRegL_iRegL_rule,
  /*  775 */  _Binary_iRegN_iRegN_rule,
  /*  776 */  _Binary_iRegP_iRegP_rule,
  /*  777 */  _Binary_iRegI_iRegI_rule,
  /*  778 */  _Binary_iRegI_iRegI_rule,
  /*  779 */  _Binary_iRegI_iRegI_rule,
  /*  780 */  _Binary_iRegL_iRegL_rule,
  /*  781 */  _Binary_iRegN_iRegN_rule,
  /*  782 */  _Binary_iRegP_iRegP_rule,
  /*  783 */  _Binary_iRegI_iRegI_rule,
  /*  784 */  _Binary_iRegI_iRegI_rule,
  /*  785 */  _Binary_iRegI_iRegI_rule,
  /*  786 */  _Binary_iRegL_iRegL_rule,
  /*  787 */  _Binary_iRegN_iRegN_rule,
  /*  788 */  _Binary_iRegP_iRegP_rule,
  /*  789 */  _Binary_iRegI_iRegI_rule,
  /*  790 */  _Binary_iRegI_iRegI_rule,
  /*  791 */  _Binary_iRegI_iRegI_rule,
  /*  792 */  _Binary_iRegL_iRegL_rule,
  /*  793 */  _Binary_iRegN_iRegN_rule,
  /*  794 */  _Binary_iRegP_iRegP_rule,
  /*  795 */  iRegI_rule,
  /*  796 */  iRegL_rule,
  /*  797 */  iRegN_rule,
  /*  798 */  iRegP_rule,
  /*  799 */  iRegI_rule,
  /*  800 */  iRegL_rule,
  /*  801 */  iRegN_rule,
  /*  802 */  iRegP_rule,
  /*  803 */  iRegL_rule,
  /*  804 */  iRegL_rule,
  /*  805 */  immLAddSub_rule,
  /*  806 */  immLAddSub_rule,
  /*  807 */  iRegIorL2I_rule,
  /*  808 */  iRegIorL2I_rule,
  /*  809 */  immIAddSub_rule,
  /*  810 */  immIAddSub_rule,
  /*  811 */  iRegL_rule,
  /*  812 */  iRegL_rule,
  /*  813 */  immLAddSub_rule,
  /*  814 */  immLAddSub_rule,
  /*  815 */  iRegIorL2I_rule,
  /*  816 */  iRegIorL2I_rule,
  /*  817 */  immIAddSub_rule,
  /*  818 */  immIAddSub_rule,
  /*  819 */  iRegL_rule,
  /*  820 */  immLAddSub_rule,
  /*  821 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  822 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  823 */  _Binary_immI0_iRegIorL2I_rule,
  /*  824 */  _Binary_immI0_iRegIorL2I_rule,
  /*  825 */  _Binary_iRegIorL2I_immI0_rule,
  /*  826 */  _Binary_iRegIorL2I_immI0_rule,
  /*  827 */  _Binary_immI_1_immI0_rule,
  /*  828 */  _Binary_immI_1_immI0_rule,
  /*  829 */  _Binary_iRegL_iRegL_rule,
  /*  830 */  _Binary_iRegL_iRegL_rule,
  /*  831 */  _Binary_iRegL_immL0_rule,
  /*  832 */  _Binary_iRegL_immL0_rule,
  /*  833 */  _Binary_immL0_iRegL_rule,
  /*  834 */  _Binary_immL0_iRegL_rule,
  /*  835 */  _Binary_iRegP_iRegP_rule,
  /*  836 */  _Binary_iRegP_iRegP_rule,
  /*  837 */  _Binary_iRegP_immP0_rule,
  /*  838 */  _Binary_iRegP_immP0_rule,
  /*  839 */  _Binary_immP0_iRegP_rule,
  /*  840 */  _Binary_immP0_iRegP_rule,
  /*  841 */  _Binary_iRegN_iRegN_rule,
  /*  842 */  _Binary_iRegN_iRegN_rule,
  /*  843 */  _Binary_iRegN_immN0_rule,
  /*  844 */  _Binary_iRegN_immN0_rule,
  /*  845 */  _Binary_immN0_iRegN_rule,
  /*  846 */  _Binary_immN0_iRegN_rule,
  /*  847 */  _Binary_vRegF_vRegF_rule,
  /*  848 */  _Binary_vRegF_vRegF_rule,
  /*  849 */  _Binary_vRegD_vRegD_rule,
  /*  850 */  _Binary_vRegD_vRegD_rule,
  /*  851 */  iRegIorL2I_rule,
  /*  852 */  immIAddSub_rule,
  /*  853 */  immIAddSub_rule,
  /*  854 */  iRegL_rule,
  /*  855 */  _ConvI2L_iRegIorL2I__rule,
  /*  856 */  _LShiftL_iRegL_immIScale_rule,
  /*  857 */  _LShiftL__ConvI2L_iRegIorL2I__immIScale_rule,
  /*  858 */  immI_rule,
  /*  859 */  immLAddSub_rule,
  /*  860 */  iRegL_rule,
  /*  861 */  immLAddSub_rule,
  /*  862 */  iRegIorL2I_rule,
  /*  863 */  immIAddSub_rule,
  /*  864 */  iRegL_rule,
  /*  865 */  immLAddSub_rule,
  /*  866 */  iRegIorL2I_rule,
  /*  867 */  iRegL_rule,
  /*  868 */  iRegIorL2I_rule,
  /*  869 */  _ConvI2L_iRegIorL2I__rule,
  /*  870 */  _ConvI2L_iRegIorL2I__rule,
  /*  871 */  iRegL_rule,
  /*  872 */  iRegL_rule,
  /*  873 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  874 */  iRegIorL2I_rule,
  /*  875 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  876 */  iRegIorL2I_rule,
  /*  877 */  _SubI_immI0_iRegIorL2I_rule,
  /*  878 */  _MulL_iRegL_iRegL_rule,
  /*  879 */  iRegL_rule,
  /*  880 */  _MulL_iRegL_iRegL_rule,
  /*  881 */  iRegL_rule,
  /*  882 */  _SubL_immL0_iRegL_rule,
  /*  883 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  884 */  iRegLNoSp_rule,
  /*  885 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  886 */  iRegLNoSp_rule,
  /*  887 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  888 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  889 */  _ConvI2L_iRegIorL2I__rule,
  /*  890 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  891 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  892 */  iRegIorL2I_rule,
  /*  893 */  iRegL_rule,
  /*  894 */  iRegIorL2I_rule,
  /*  895 */  iRegL_rule,
  /*  896 */  iRegIorL2I_rule,
  /*  897 */  immI_rule,
  /*  898 */  iRegIorL2I_rule,
  /*  899 */  immI_rule,
  /*  900 */  iRegIorL2I_rule,
  /*  901 */  immI_rule,
  /*  902 */  iRegIorL2I_rule,
  /*  903 */  immI_rule,
  /*  904 */  iRegIorL2I_rule,
  /*  905 */  immI_rule,
  /*  906 */  immI_rule,
  /*  907 */  iRegIorL2I_rule,
  /*  908 */  immI_rule,
  /*  909 */  immL_M1_rule,
  /*  910 */  immI_M1_rule,
  /*  911 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  912 */  iRegIorL2I_rule,
  /*  913 */  _XorL_iRegL_immL_M1_rule,
  /*  914 */  iRegL_rule,
  /*  915 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  916 */  iRegIorL2I_rule,
  /*  917 */  _XorL_iRegL_immL_M1_rule,
  /*  918 */  iRegL_rule,
  /*  919 */  _XorI_iRegIorL2I_iRegIorL2I_rule,
  /*  920 */  immI_M1_rule,
  /*  921 */  _XorL_iRegL_iRegL_rule,
  /*  922 */  immL_M1_rule,
  /*  923 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  924 */  iRegIorL2I_rule,
  /*  925 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  926 */  iRegL_rule,
  /*  927 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  928 */  iRegIorL2I_rule,
  /*  929 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  930 */  iRegL_rule,
  /*  931 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /*  932 */  iRegIorL2I_rule,
  /*  933 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /*  934 */  iRegL_rule,
  /*  935 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  936 */  iRegIorL2I_rule,
  /*  937 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  938 */  iRegL_rule,
  /*  939 */  _XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  940 */  immI_M1_rule,
  /*  941 */  _XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI_rule,
  /*  942 */  immI_M1_rule,
  /*  943 */  _XorL__URShiftL_iRegL_immI_iRegL_rule,
  /*  944 */  immL_M1_rule,
  /*  945 */  _XorL_iRegL__URShiftL_iRegL_immI_rule,
  /*  946 */  immL_M1_rule,
  /*  947 */  _XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  948 */  immI_M1_rule,
  /*  949 */  _XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI_rule,
  /*  950 */  immI_M1_rule,
  /*  951 */  _XorL__RShiftL_iRegL_immI_iRegL_rule,
  /*  952 */  immL_M1_rule,
  /*  953 */  _XorL_iRegL__RShiftL_iRegL_immI_rule,
  /*  954 */  immL_M1_rule,
  /*  955 */  _XorI__RotateRight_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  956 */  immI_M1_rule,
  /*  957 */  _XorI_iRegIorL2I__RotateRight_iRegIorL2I_immI_rule,
  /*  958 */  immI_M1_rule,
  /*  959 */  _XorL__RotateRight_iRegL_immI_iRegL_rule,
  /*  960 */  immL_M1_rule,
  /*  961 */  _XorL_iRegL__RotateRight_iRegL_immI_rule,
  /*  962 */  immL_M1_rule,
  /*  963 */  _XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  964 */  immI_M1_rule,
  /*  965 */  _XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI_rule,
  /*  966 */  immI_M1_rule,
  /*  967 */  _XorL__LShiftL_iRegL_immI_iRegL_rule,
  /*  968 */  immL_M1_rule,
  /*  969 */  _XorL_iRegL__LShiftL_iRegL_immI_rule,
  /*  970 */  immL_M1_rule,
  /*  971 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  972 */  iRegIorL2I_rule,
  /*  973 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  974 */  iRegL_rule,
  /*  975 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  976 */  iRegIorL2I_rule,
  /*  977 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  978 */  iRegL_rule,
  /*  979 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /*  980 */  iRegIorL2I_rule,
  /*  981 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /*  982 */  iRegL_rule,
  /*  983 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  984 */  iRegIorL2I_rule,
  /*  985 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  986 */  iRegL_rule,
  /*  987 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  988 */  iRegIorL2I_rule,
  /*  989 */  _URShiftL_iRegL_immI_rule,
  /*  990 */  iRegL_rule,
  /*  991 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  992 */  iRegIorL2I_rule,
  /*  993 */  _RShiftL_iRegL_immI_rule,
  /*  994 */  iRegL_rule,
  /*  995 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  996 */  iRegIorL2I_rule,
  /*  997 */  _LShiftL_iRegL_immI_rule,
  /*  998 */  iRegL_rule,
  /*  999 */  _RotateRight_iRegIorL2I_immI_rule,
  /* 1000 */  iRegIorL2I_rule,
  /* 1001 */  _RotateRight_iRegL_immI_rule,
  /* 1002 */  iRegL_rule,
  /* 1003 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1004 */  iRegIorL2I_rule,
  /* 1005 */  _URShiftL_iRegL_immI_rule,
  /* 1006 */  iRegL_rule,
  /* 1007 */  _RShiftI_iRegIorL2I_immI_rule,
  /* 1008 */  iRegIorL2I_rule,
  /* 1009 */  _RShiftL_iRegL_immI_rule,
  /* 1010 */  iRegL_rule,
  /* 1011 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1012 */  iRegIorL2I_rule,
  /* 1013 */  _LShiftL_iRegL_immI_rule,
  /* 1014 */  iRegL_rule,
  /* 1015 */  _RotateRight_iRegIorL2I_immI_rule,
  /* 1016 */  iRegIorL2I_rule,
  /* 1017 */  _RotateRight_iRegL_immI_rule,
  /* 1018 */  iRegL_rule,
  /* 1019 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1020 */  iRegIorL2I_rule,
  /* 1021 */  _URShiftL_iRegL_immI_rule,
  /* 1022 */  iRegL_rule,
  /* 1023 */  _RShiftI_iRegIorL2I_immI_rule,
  /* 1024 */  iRegIorL2I_rule,
  /* 1025 */  _RShiftL_iRegL_immI_rule,
  /* 1026 */  iRegL_rule,
  /* 1027 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1028 */  iRegIorL2I_rule,
  /* 1029 */  _LShiftL_iRegL_immI_rule,
  /* 1030 */  iRegL_rule,
  /* 1031 */  _RotateRight_iRegIorL2I_immI_rule,
  /* 1032 */  iRegIorL2I_rule,
  /* 1033 */  _RotateRight_iRegL_immI_rule,
  /* 1034 */  iRegL_rule,
  /* 1035 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1036 */  iRegIorL2I_rule,
  /* 1037 */  _URShiftL_iRegL_immI_rule,
  /* 1038 */  iRegL_rule,
  /* 1039 */  _RShiftI_iRegIorL2I_immI_rule,
  /* 1040 */  iRegIorL2I_rule,
  /* 1041 */  _RShiftL_iRegL_immI_rule,
  /* 1042 */  iRegL_rule,
  /* 1043 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1044 */  iRegIorL2I_rule,
  /* 1045 */  _LShiftL_iRegL_immI_rule,
  /* 1046 */  iRegL_rule,
  /* 1047 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1048 */  _URShiftL_iRegL_immI_rule,
  /* 1049 */  _RShiftI_iRegIorL2I_immI_rule,
  /* 1050 */  _RShiftL_iRegL_immI_rule,
  /* 1051 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1052 */  _LShiftL_iRegL_immI_rule,
  /* 1053 */  immI_rule,
  /* 1054 */  immI_rule,
  /* 1055 */  immI_rule,
  /* 1056 */  immI_rule,
  /* 1057 */  immI_bitmask_rule,
  /* 1058 */  immL_bitmask_rule,
  /* 1059 */  0,
  /* 1060 */  immI_rule,
  /* 1061 */  immI_rule,
  /* 1062 */  0,
  /* 1063 */  0,
  /* 1064 */  immI_rule,
  /* 1065 */  immI_rule,
  /* 1066 */  0,
  /* 1067 */  _URShiftL_iRegL_immI_rule,
  /* 1068 */  _LShiftL_iRegL_immI_rule,
  /* 1069 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1070 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1071 */  _URShiftL_iRegL_immI_rule,
  /* 1072 */  _LShiftL_iRegL_immI_rule,
  /* 1073 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1074 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1075 */  immI_rule,
  /* 1076 */  immI_rule,
  /* 1077 */  iRegI_rule,
  /* 1078 */  iRegI_rule,
  /* 1079 */  iRegI_rule,
  /* 1080 */  iRegI_rule,
  /* 1081 */  _ConvI2L_iRegIorL2I__rule,
  /* 1082 */  iRegL_rule,
  /* 1083 */  _ConvI2L_iRegIorL2I__rule,
  /* 1084 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /* 1085 */  iRegIorL2I_rule,
  /* 1086 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /* 1087 */  iRegIorL2I_rule,
  /* 1088 */  _URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /* 1089 */  iRegIorL2I_rule,
  /* 1090 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /* 1091 */  iRegL_rule,
  /* 1092 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /* 1093 */  iRegL_rule,
  /* 1094 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /* 1095 */  iRegL_rule,
  /* 1096 */  _URShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /* 1097 */  iRegL_rule,
  /* 1098 */  _AndI_iRegIorL2I_immI_255_rule,
  /* 1099 */  iRegIorL2I_rule,
  /* 1100 */  _AndI_iRegIorL2I_immI_65535_rule,
  /* 1101 */  iRegIorL2I_rule,
  /* 1102 */  _AndL_iRegL_immL_255_rule,
  /* 1103 */  iRegL_rule,
  /* 1104 */  _AndL_iRegL_immL_65535_rule,
  /* 1105 */  iRegL_rule,
  /* 1106 */  _AndL_iRegL_immL_4294967295_rule,
  /* 1107 */  iRegL_rule,
  /* 1108 */  _AndI_iRegIorL2I_immI_255_rule,
  /* 1109 */  _AndI_iRegIorL2I_immI_65535_rule,
  /* 1110 */  _AndL_iRegL_immL_255_rule,
  /* 1111 */  _AndL_iRegL_immL_65535_rule,
  /* 1112 */  _AndL_iRegL_immL_4294967295_rule,
  /* 1113 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /* 1114 */  iRegL_rule,
  /* 1115 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /* 1116 */  iRegL_rule,
  /* 1117 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /* 1118 */  iRegL_rule,
  /* 1119 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /* 1120 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /* 1121 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /* 1122 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /* 1123 */  iRegIorL2I_rule,
  /* 1124 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /* 1125 */  iRegIorL2I_rule,
  /* 1126 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /* 1127 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /* 1128 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /* 1129 */  iRegL_rule,
  /* 1130 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /* 1131 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /* 1132 */  iRegL_rule,
  /* 1133 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /* 1134 */  iRegL_rule,
  /* 1135 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /* 1136 */  iRegL_rule,
  /* 1137 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /* 1138 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /* 1139 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /* 1140 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /* 1141 */  iRegIorL2I_rule,
  /* 1142 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /* 1143 */  iRegIorL2I_rule,
  /* 1144 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /* 1145 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /* 1146 */  vRegF_rule,
  /* 1147 */  vRegD_rule,
  /* 1148 */  vRegF_rule,
  /* 1149 */  vRegD_rule,
  /* 1150 */  vRegF_rule,
  /* 1151 */  vRegD_rule,
  /* 1152 */  _Binary_vRegF_vRegF_rule,
  /* 1153 */  _Binary_vRegD_vRegD_rule,
  /* 1154 */  _Binary__NegF_vRegF__vRegF_rule,
  /* 1155 */  _Binary_vRegF__NegF_vRegF__rule,
  /* 1156 */  _Binary__NegD_vRegD__vRegD_rule,
  /* 1157 */  _Binary_vRegD__NegD_vRegD__rule,
  /* 1158 */  _Binary__NegF_vRegF__vRegF_rule,
  /* 1159 */  _Binary_vRegF__NegF_vRegF__rule,
  /* 1160 */  _Binary__NegD_vRegD__vRegD_rule,
  /* 1161 */  _Binary_vRegD__NegD_vRegD__rule,
  /* 1162 */  _Binary_vRegF_vRegF_rule,
  /* 1163 */  _Binary_vRegD_vRegD_rule,
  /* 1164 */  vRegF_rule,
  /* 1165 */  vRegF_rule,
  /* 1166 */  vRegD_rule,
  /* 1167 */  vRegD_rule,
  /* 1168 */  vRegF_rule,
  /* 1169 */  vRegD_rule,
  /* 1170 */  0,
  /* 1171 */  0,
  /* 1172 */  0,
  /* 1173 */  0,
  /* 1174 */  0,
  /* 1175 */  0,
  /* 1176 */  immI_rule,
  /* 1177 */  _Binary_vRegD_vRegD_rule,
  /* 1178 */  vRegF_rule,
  /* 1179 */  _Binary_vRegD_vRegD_rule,
  /* 1180 */  _Binary_vRegF_vRegF_rule,
  /* 1181 */  0,
  /* 1182 */  iRegIorL2I_rule,
  /* 1183 */  immILog_rule,
  /* 1184 */  iRegIorL2I_rule,
  /* 1185 */  immILog_rule,
  /* 1186 */  iRegIorL2I_rule,
  /* 1187 */  immILog_rule,
  /* 1188 */  iRegL_rule,
  /* 1189 */  immLLog_rule,
  /* 1190 */  iRegL_rule,
  /* 1191 */  immLLog_rule,
  /* 1192 */  iRegL_rule,
  /* 1193 */  immLLog_rule,
  /* 1194 */  0,
  /* 1195 */  immL_32bits_rule,
  /* 1196 */  0,
  /* 1197 */  0,
  /* 1198 */  0,
  /* 1199 */  0,
  /* 1200 */  0,
  /* 1201 */  0,
  /* 1202 */  0,
  /* 1203 */  0,
  /* 1204 */  0,
  /* 1205 */  0,
  /* 1206 */  0,
  /* 1207 */  0,
  /* 1208 */  0,
  /* 1209 */  0,
  /* 1210 */  0,
  /* 1211 */  0,
  /* 1212 */  0,
  /* 1213 */  iRegP_R10_rule,
  /* 1214 */  iRegP_R10_rule,
  /* 1215 */  _OverflowMulI_iRegIorL2I_iRegIorL2I_rule,
  /* 1216 */  _OverflowMulL_iRegL_iRegL_rule,
  /* 1217 */  vRegF_rule,
  /* 1218 */  vRegD_rule,
  /* 1219 */  immF0_rule,
  /* 1220 */  immD0_rule,
  /* 1221 */  iRegIorL2I_rule,
  /* 1222 */  immI0_rule,
  /* 1223 */  0,
  /* 1224 */  iRegI_rule,
  /* 1225 */  0,
  /* 1226 */  iRegI_rule,
  /* 1227 */  0,
  /* 1228 */  rFlagsReg_rule,
  /* 1229 */  rFlagsRegU_rule,
  /* 1230 */  _CmpI_iRegIorL2I_immI0_rule,
  /* 1231 */  _CmpL_iRegL_immL0_rule,
  /* 1232 */  _CmpP_iRegP_immP0_rule,
  /* 1233 */  _CmpN_iRegN_immN0_rule,
  /* 1234 */  _CmpP__DecodeN_iRegN__immP0_rule,
  /* 1235 */  _CmpU_iRegIorL2I_immI0_rule,
  /* 1236 */  _CmpUL_iRegL_immL0_rule,
  /* 1237 */  _CmpL_iRegL_immL0_rule,
  /* 1238 */  _CmpI_iRegIorL2I_immI0_rule,
  /* 1239 */  _CmpL__AndL_iRegL_immL_immL0_rule,
  /* 1240 */  _CmpI__AndI_iRegIorL2I_immI_immI0_rule,
  /* 1241 */  _CmpL_iRegL_immL0_rule,
  /* 1242 */  _CmpI_iRegIorL2I_immI0_rule,
  /* 1243 */  _CmpL__AndL_iRegL_immL_immL0_rule,
  /* 1244 */  _CmpI__AndI_iRegIorL2I_immI_immI0_rule,
  /* 1245 */  rFlagsReg_rule,
  /* 1246 */  rFlagsRegU_rule,
  /* 1247 */  0,
  /* 1248 */  0,
  /* 1249 */  0,
  /* 1250 */  0,
  /* 1251 */  0,
  /* 1252 */  0,
  /* 1253 */  0,
  /* 1254 */  inline_cache_RegP_rule,
  /* 1255 */  iRegP_R0_rule,
  /* 1256 */  0,
  /* 1257 */  0,
  /* 1258 */  0,
  /* 1259 */  0,
  /* 1260 */  iRegP_R0_rule,
  /* 1261 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1262 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1263 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1264 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1265 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /* 1266 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /* 1267 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /* 1268 */  _Binary_iRegP_R3_immI_le_4_rule,
  /* 1269 */  _Binary_iRegP_R3_immI_le_4_rule,
  /* 1270 */  _Binary_iRegP_R3_immI_1_rule,
  /* 1271 */  iRegI_R3_rule,
  /* 1272 */  iRegI_R3_rule,
  /* 1273 */  iRegI_R4_rule,
  /* 1274 */  iRegI_R4_rule,
  /* 1275 */  iRegP_R2_rule,
  /* 1276 */  iRegP_R2_rule,
  /* 1277 */  iRegI_R2_rule,
  /* 1278 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /* 1279 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1280 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /* 1281 */  0,
  /* 1282 */  0,
  /* 1283 */  0,
  /* 1284 */  0,
  /* 1285 */  vecD_rule,
  /* 1286 */  vecD_rule,
  /* 1287 */  vecD_rule,
  /* 1288 */  vecX_rule,
  /* 1289 */  0,
  /* 1290 */  vecD_rule,
  /* 1291 */  vecX_rule,
  /* 1292 */  vecD_rule,
  /* 1293 */  vecX_rule,
  /* 1294 */  vecX_rule,
  /* 1295 */  vecD_rule,
  /* 1296 */  vecX_rule,
  /* 1297 */  vecD_rule,
  /* 1298 */  vecX_rule,
  /* 1299 */  vecX_rule,
  /* 1300 */  vecD_rule,
  /* 1301 */  vecX_rule,
  /* 1302 */  vecD_rule,
  /* 1303 */  vecX_rule,
  /* 1304 */  vecX_rule,
  /* 1305 */  vecD_rule,
  /* 1306 */  vecX_rule,
  /* 1307 */  vecD_rule,
  /* 1308 */  vecX_rule,
  /* 1309 */  vecX_rule,
  /* 1310 */  vecD_rule,
  /* 1311 */  vecD_rule,
  /* 1312 */  vecX_rule,
  /* 1313 */  vecX_rule,
  /* 1314 */  vecD_rule,
  /* 1315 */  vecX_rule,
  /* 1316 */  vecX_rule,
  /* 1317 */  vecD_rule,
  /* 1318 */  vecX_rule,
  /* 1319 */  vecX_rule,
  /* 1320 */  vecD_rule,
  /* 1321 */  vecD_rule,
  /* 1322 */  vecD_rule,
  /* 1323 */  vecX_rule,
  /* 1324 */  vecX_rule,
  /* 1325 */  vecX_rule,
  /* 1326 */  vecD_rule,
  /* 1327 */  vecD_rule,
  /* 1328 */  vecD_rule,
  /* 1329 */  vecX_rule,
  /* 1330 */  vecX_rule,
  /* 1331 */  vecX_rule,
  /* 1332 */  vecD_rule,
  /* 1333 */  vecD_rule,
  /* 1334 */  vecD_rule,
  /* 1335 */  vecX_rule,
  /* 1336 */  vecX_rule,
  /* 1337 */  vecX_rule,
  /* 1338 */  vecX_rule,
  /* 1339 */  vecX_rule,
  /* 1340 */  vecX_rule,
  /* 1341 */  immI_rule,
  /* 1342 */  immI_rule,
  /* 1343 */  immI_rule,
  /* 1344 */  immI_rule,
  /* 1345 */  immI_rule,
  /* 1346 */  immI_rule,
  /* 1347 */  immI_rule,
  /* 1348 */  immI_rule,
  /* 1349 */  immI_rule,
  /* 1350 */  immI_rule,
  /* 1351 */  immI_rule,
  /* 1352 */  immI_rule,
  /* 1353 */  immI_rule,
  /* 1354 */  immI_rule,
  /* 1355 */  immI_rule,
  /* 1356 */  immI_rule,
  /* 1357 */  immI_rule,
  /* 1358 */  immI_rule,
  /* 1359 */  immI_rule,
  /* 1360 */  immI_rule,
  /* 1361 */  immI_rule,
  /* 1362 */  immI_rule,
  /* 1363 */  vecX_rule,
  /* 1364 */  _ReplicateB_immI_M1__rule,
  /* 1365 */  vecD_rule,
  /* 1366 */  _ReplicateS_immI_M1__rule,
  /* 1367 */  vecD_rule,
  /* 1368 */  _ReplicateI_immI_M1__rule,
  /* 1369 */  vecD_rule,
  /* 1370 */  _ReplicateB_immI_M1__rule,
  /* 1371 */  vecX_rule,
  /* 1372 */  _ReplicateS_immI_M1__rule,
  /* 1373 */  vecX_rule,
  /* 1374 */  _ReplicateI_immI_M1__rule,
  /* 1375 */  vecX_rule,
  /* 1376 */  _ReplicateL_immL_M1__rule,
  /* 1377 */  vecX_rule,
  /* 1378 */  _XorV_vecD__ReplicateB_immI_M1__rule,
  /* 1379 */  vecD_rule,
  /* 1380 */  _XorV__ReplicateB_immI_M1__vecD_rule,
  /* 1381 */  vecD_rule,
  /* 1382 */  _XorV_vecD__ReplicateS_immI_M1__rule,
  /* 1383 */  vecD_rule,
  /* 1384 */  _XorV__ReplicateS_immI_M1__vecD_rule,
  /* 1385 */  vecD_rule,
  /* 1386 */  _XorV_vecD__ReplicateI_immI_M1__rule,
  /* 1387 */  vecD_rule,
  /* 1388 */  _XorV__ReplicateI_immI_M1__vecD_rule,
  /* 1389 */  vecD_rule,
  /* 1390 */  _XorV_vecX__ReplicateB_immI_M1__rule,
  /* 1391 */  vecX_rule,
  /* 1392 */  _XorV__ReplicateB_immI_M1__vecX_rule,
  /* 1393 */  vecX_rule,
  /* 1394 */  _XorV_vecX__ReplicateS_immI_M1__rule,
  /* 1395 */  vecX_rule,
  /* 1396 */  _XorV__ReplicateS_immI_M1__vecX_rule,
  /* 1397 */  vecX_rule,
  /* 1398 */  _XorV_vecX__ReplicateI_immI_M1__rule,
  /* 1399 */  vecX_rule,
  /* 1400 */  _XorV__ReplicateI_immI_M1__vecX_rule,
  /* 1401 */  vecX_rule,
  /* 1402 */  _XorV_vecX__ReplicateL_immL_M1__rule,
  /* 1403 */  vecX_rule,
  /* 1404 */  _XorV__ReplicateL_immL_M1__vecX_rule,
  /* 1405 */  vecX_rule,
  /* 1406 */  vecD_rule,
  /* 1407 */  vecX_rule,
  /* 1408 */  vecD_rule,
  /* 1409 */  vecX_rule,
  /* 1410 */  vecD_rule,
  /* 1411 */  vecX_rule,
  /* 1412 */  vecD_rule,
  /* 1413 */  vecX_rule,
  /* 1414 */  vecD_rule,
  /* 1415 */  vecX_rule,
  /* 1416 */  vecD_rule,
  /* 1417 */  vecX_rule,
  /* 1418 */  vecX_rule,
  /* 1419 */  vecX_rule,
  /* 1420 */  vecD_rule,
  /* 1421 */  vecX_rule,
  /* 1422 */  immI_1_rule,
  /* 1423 */  immI_1_rule,
  /* 1424 */  immI_2_rule,
  /* 1425 */  immI_2_rule,
  /* 1426 */  immI_4_rule,
  /* 1427 */  immI_4_rule,
  /* 1428 */  immI_8_rule,
  /* 1429 */  vecD_rule,
  /* 1430 */  vecX_rule,
  /* 1431 */  vecD_rule,
  /* 1432 */  vecX_rule,
  /* 1433 */  vecX_rule,
  /* 1434 */  vecD_rule,
  /* 1435 */  vecX_rule,
  /* 1436 */  vecD_rule,
  /* 1437 */  vecX_rule,
  /* 1438 */  0,
  /* 1439 */  0,
  /* 1440 */  0,
  /* 1441 */  0,
  /* 1442 */  0,
  /* 1443 */  0,
  /* 1444 */  0,
  /* 1445 */  0,
  /* 1446 */  0,
  /* 1447 */  0,
  /* 1448 */  0,
  /* 1449 */  0,
  /* 1450 */  0,
  /* 1451 */  0,
  /* 1452 */  0,
  /* 1453 */  0,
  /* 1454 */  0,
  /* 1455 */  0,
  /* 1456 */  0,
  /* 1457 */  0,
  /* 1458 */  vecD_rule,
  /* 1459 */  vecX_rule,
  /* 1460 */  vecD_rule,
  /* 1461 */  vecX_rule,
  /* 1462 */  vecD_rule,
  /* 1463 */  vecX_rule,
  /* 1464 */  vecD_rule,
  /* 1465 */  vecX_rule,
  /* 1466 */  vecX_rule,
  /* 1467 */  vecX_rule,
  /* 1468 */  vecD_rule,
  /* 1469 */  vecX_rule,
  /* 1470 */  vecD_rule,
  /* 1471 */  vecX_rule,
  /* 1472 */  vecD_rule,
  /* 1473 */  vecX_rule,
  /* 1474 */  vecX_rule,
  /* 1475 */  vecD_rule,
  /* 1476 */  vecX_rule,
  /* 1477 */  vecX_rule,
  /* 1478 */  vecD_rule,
  /* 1479 */  vecX_rule,
  /* 1480 */  vecD_rule,
  /* 1481 */  vecX_rule,
  /* 1482 */  vecD_rule,
  /* 1483 */  vecX_rule,
  /* 1484 */  vecX_rule,
  /* 1485 */  vecD_rule,
  /* 1486 */  vecX_rule,
  /* 1487 */  vecX_rule,
  /* 1488 */  vecD_rule,
  /* 1489 */  vecX_rule,
  /* 1490 */  vecD_rule,
  /* 1491 */  vecX_rule,
  /* 1492 */  vecD_rule,
  /* 1493 */  vecX_rule,
  /* 1494 */  vecD_rule,
  /* 1495 */  vecX_rule,
  /* 1496 */  vecX_rule,
  /* 1497 */  _MulVS_vecD_vecD_rule,
  /* 1498 */  vecD_rule,
  /* 1499 */  _MulVS_vecX_vecX_rule,
  /* 1500 */  vecX_rule,
  /* 1501 */  _MulVI_vecD_vecD_rule,
  /* 1502 */  vecD_rule,
  /* 1503 */  _MulVI_vecX_vecX_rule,
  /* 1504 */  vecX_rule,
  /* 1505 */  _Binary_vecD_vecD_rule,
  /* 1506 */  _Binary_vecX_vecX_rule,
  /* 1507 */  _Binary_vecX_vecX_rule,
  /* 1508 */  _MulVS_vecD_vecD_rule,
  /* 1509 */  _MulVS_vecX_vecX_rule,
  /* 1510 */  _MulVI_vecD_vecD_rule,
  /* 1511 */  _MulVI_vecX_vecX_rule,
  /* 1512 */  _Binary__NegVF_vecD__vecD_rule,
  /* 1513 */  _Binary_vecD__NegVF_vecD__rule,
  /* 1514 */  _Binary__NegVF_vecX__vecX_rule,
  /* 1515 */  _Binary_vecX__NegVF_vecX__rule,
  /* 1516 */  _Binary__NegVD_vecX__vecX_rule,
  /* 1517 */  _Binary_vecX__NegVD_vecX__rule,
  /* 1518 */  vecX_rule,
  /* 1519 */  vecD_rule,
  /* 1520 */  vecX_rule,
  /* 1521 */  vecX_rule,
  /* 1522 */  vecD_rule,
  /* 1523 */  vecX_rule,
  /* 1524 */  vecD_rule,
  /* 1525 */  vecX_rule,
  /* 1526 */  vecD_rule,
  /* 1527 */  vecX_rule,
  /* 1528 */  vecD_rule,
  /* 1529 */  vecX_rule,
  /* 1530 */  vecD_rule,
  /* 1531 */  vecX_rule,
  /* 1532 */  vecD_rule,
  /* 1533 */  vecX_rule,
  /* 1534 */  _LShiftCntV_immI__rule,
  /* 1535 */  _LShiftCntV_immI__rule,
  /* 1536 */  _RShiftCntV_immI__rule,
  /* 1537 */  _RShiftCntV_immI__rule,
  /* 1538 */  _RShiftCntV_immI__rule,
  /* 1539 */  _RShiftCntV_immI__rule,
  /* 1540 */  vecD_rule,
  /* 1541 */  vecX_rule,
  /* 1542 */  vecD_rule,
  /* 1543 */  vecX_rule,
  /* 1544 */  vecD_rule,
  /* 1545 */  vecX_rule,
  /* 1546 */  _LShiftCntV_immI__rule,
  /* 1547 */  _LShiftCntV_immI__rule,
  /* 1548 */  _RShiftCntV_immI__rule,
  /* 1549 */  _RShiftCntV_immI__rule,
  /* 1550 */  _RShiftCntV_immI__rule,
  /* 1551 */  _RShiftCntV_immI__rule,
  /* 1552 */  vecD_rule,
  /* 1553 */  vecX_rule,
  /* 1554 */  vecD_rule,
  /* 1555 */  vecX_rule,
  /* 1556 */  vecD_rule,
  /* 1557 */  vecX_rule,
  /* 1558 */  _LShiftCntV_immI__rule,
  /* 1559 */  _LShiftCntV_immI__rule,
  /* 1560 */  _RShiftCntV_immI__rule,
  /* 1561 */  _RShiftCntV_immI__rule,
  /* 1562 */  _RShiftCntV_immI__rule,
  /* 1563 */  _RShiftCntV_immI__rule,
  /* 1564 */  vecX_rule,
  /* 1565 */  vecX_rule,
  /* 1566 */  vecX_rule,
  /* 1567 */  _LShiftCntV_immI__rule,
  /* 1568 */  _RShiftCntV_immI__rule,
  /* 1569 */  _RShiftCntV_immI__rule,
  /* 1570 */  _RShiftVB_vecD__RShiftCntV_immI__rule,
  /* 1571 */  vecD_rule,
  /* 1572 */  _RShiftVB_vecX__RShiftCntV_immI__rule,
  /* 1573 */  vecX_rule,
  /* 1574 */  _RShiftVS_vecD__RShiftCntV_immI__rule,
  /* 1575 */  vecD_rule,
  /* 1576 */  _RShiftVS_vecX__RShiftCntV_immI__rule,
  /* 1577 */  vecX_rule,
  /* 1578 */  _RShiftVI_vecD__RShiftCntV_immI__rule,
  /* 1579 */  vecD_rule,
  /* 1580 */  _RShiftVI_vecX__RShiftCntV_immI__rule,
  /* 1581 */  vecX_rule,
  /* 1582 */  _RShiftVL_vecX__RShiftCntV_immI__rule,
  /* 1583 */  vecX_rule,
  /* 1584 */  _URShiftVB_vecD__RShiftCntV_immI__rule,
  /* 1585 */  vecD_rule,
  /* 1586 */  _URShiftVB_vecX__RShiftCntV_immI__rule,
  /* 1587 */  vecX_rule,
  /* 1588 */  _URShiftVS_vecD__RShiftCntV_immI__rule,
  /* 1589 */  vecD_rule,
  /* 1590 */  _URShiftVS_vecX__RShiftCntV_immI__rule,
  /* 1591 */  vecX_rule,
  /* 1592 */  _URShiftVI_vecD__RShiftCntV_immI__rule,
  /* 1593 */  vecD_rule,
  /* 1594 */  _URShiftVI_vecX__RShiftCntV_immI__rule,
  /* 1595 */  vecX_rule,
  /* 1596 */  _URShiftVL_vecX__RShiftCntV_immI__rule,
  /* 1597 */  vecX_rule,
  /* 1598 */  vecD_rule,
  /* 1599 */  vecX_rule,
  /* 1600 */  vecX_rule,
  /* 1601 */  vecD_rule,
  /* 1602 */  vecX_rule,
  /* 1603 */  vecX_rule,
  /* 1604 */  immI_rule,
  /* 1605 */  0,
  /* 1606 */  0,
  /* 1607 */  0,
  /* 1608 */  0,
  /* 1609 */  vReg_rule,
  /* 1610 */  0,
  /* 1611 */  vReg_rule,
  /* 1612 */  0,
  /* 1613 */  vReg_rule,
  /* 1614 */  0,
  /* 1615 */  vReg_rule,
  /* 1616 */  0,
  /* 1617 */  vReg_rule,
  /* 1618 */  0,
  /* 1619 */  vReg_rule,
  /* 1620 */  pRegGov_rule,
  /* 1621 */  pRegGov_rule,
  /* 1622 */  _Binary_vReg_pRegGov_rule,
  /* 1623 */  _Binary_vReg_pRegGov_rule,
  /* 1624 */  0,
  /* 1625 */  0,
  /* 1626 */  0,
  /* 1627 */  0,
  /* 1628 */  pRegGov_rule,
  /* 1629 */  pRegGov_rule,
  /* 1630 */  pRegGov_rule,
  /* 1631 */  _XorVMask_pRegGov__MaskAll_immI_M1__rule,
  /* 1632 */  _XorVMask_pRegGov__MaskAll_immL_M1__rule,
  /* 1633 */  0,
  /* 1634 */  0,
  /* 1635 */  pRegGov_rule,
  /* 1636 */  pRegGov_rule,
  /* 1637 */  pRegGov_rule,
  /* 1638 */  pRegGov_rule,
  /* 1639 */  pRegGov_rule,
  /* 1640 */  pRegGov_rule,
  /* 1641 */  vReg_rule,
  /* 1642 */  vReg_rule,
  /* 1643 */  vReg_rule,
  /* 1644 */  vReg_rule,
  /* 1645 */  vReg_rule,
  /* 1646 */  vReg_rule,
  /* 1647 */  pRegGov_rule,
  /* 1648 */  pRegGov_rule,
  /* 1649 */  pRegGov_rule,
  /* 1650 */  pRegGov_rule,
  /* 1651 */  pRegGov_rule,
  /* 1652 */  pRegGov_rule,
  /* 1653 */  _ReplicateB_immBAddSubV__rule,
  /* 1654 */  vReg_rule,
  /* 1655 */  _ReplicateS_immIAddSubV__rule,
  /* 1656 */  vReg_rule,
  /* 1657 */  _ReplicateI_immIAddSubV__rule,
  /* 1658 */  vReg_rule,
  /* 1659 */  _ReplicateL_immLAddSubV__rule,
  /* 1660 */  vReg_rule,
  /* 1661 */  _ReplicateB_immBLog__rule,
  /* 1662 */  vReg_rule,
  /* 1663 */  _ReplicateS_immSLog__rule,
  /* 1664 */  vReg_rule,
  /* 1665 */  _ReplicateI_immILog__rule,
  /* 1666 */  vReg_rule,
  /* 1667 */  _ReplicateL_immLLog__rule,
  /* 1668 */  vReg_rule,
  /* 1669 */  _ReplicateB_immBLog__rule,
  /* 1670 */  vReg_rule,
  /* 1671 */  _ReplicateS_immSLog__rule,
  /* 1672 */  vReg_rule,
  /* 1673 */  _ReplicateI_immILog__rule,
  /* 1674 */  vReg_rule,
  /* 1675 */  _ReplicateL_immLLog__rule,
  /* 1676 */  vReg_rule,
  /* 1677 */  _ReplicateB_immBLog__rule,
  /* 1678 */  vReg_rule,
  /* 1679 */  _ReplicateS_immSLog__rule,
  /* 1680 */  vReg_rule,
  /* 1681 */  _ReplicateI_immILog__rule,
  /* 1682 */  vReg_rule,
  /* 1683 */  _ReplicateL_immLLog__rule,
  /* 1684 */  vReg_rule,
  /* 1685 */  vReg_rule,
  /* 1686 */  vReg_rule,
  /* 1687 */  vReg_rule,
  /* 1688 */  pRegGov_rule,
  /* 1689 */  pRegGov_rule,
  /* 1690 */  pRegGov_rule,
  /* 1691 */  _ReplicateB_immI_M1__rule,
  /* 1692 */  vReg_rule,
  /* 1693 */  _ReplicateS_immI_M1__rule,
  /* 1694 */  vReg_rule,
  /* 1695 */  _ReplicateI_immI_M1__rule,
  /* 1696 */  vReg_rule,
  /* 1697 */  _ReplicateL_immL_M1__rule,
  /* 1698 */  vReg_rule,
  /* 1699 */  _XorV_vReg__ReplicateB_immI_M1__rule,
  /* 1700 */  vReg_rule,
  /* 1701 */  _XorV__ReplicateB_immI_M1__vReg_rule,
  /* 1702 */  vReg_rule,
  /* 1703 */  _XorV_vReg__ReplicateS_immI_M1__rule,
  /* 1704 */  vReg_rule,
  /* 1705 */  _XorV__ReplicateS_immI_M1__vReg_rule,
  /* 1706 */  vReg_rule,
  /* 1707 */  _XorV_vReg__ReplicateI_immI_M1__rule,
  /* 1708 */  vReg_rule,
  /* 1709 */  _XorV__ReplicateI_immI_M1__vReg_rule,
  /* 1710 */  vReg_rule,
  /* 1711 */  _XorV_vReg__ReplicateL_immL_M1__rule,
  /* 1712 */  vReg_rule,
  /* 1713 */  _XorV__ReplicateL_immL_M1__vReg_rule,
  /* 1714 */  vReg_rule,
  /* 1715 */  vReg_rule,
  /* 1716 */  vReg_rule,
  /* 1717 */  pRegGov_rule,
  /* 1718 */  pRegGov_rule,
  /* 1719 */  vReg_rule,
  /* 1720 */  vReg_rule,
  /* 1721 */  pRegGov_rule,
  /* 1722 */  pRegGov_rule,
  /* 1723 */  _Binary_vReg_vReg_rule,
  /* 1724 */  _Binary_vReg_vReg_rule,
  /* 1725 */  _Binary_vReg_pRegGov_rule,
  /* 1726 */  _Binary_vReg_pRegGov_rule,
  /* 1727 */  _Binary__NegVF_vReg__vReg_rule,
  /* 1728 */  _Binary_vReg__NegVF_vReg__rule,
  /* 1729 */  _Binary__NegVD_vReg__vReg_rule,
  /* 1730 */  _Binary_vReg__NegVD_vReg__rule,
  /* 1731 */  _Binary__NegVF_vReg__vReg_rule,
  /* 1732 */  _Binary_vReg__NegVF_vReg__rule,
  /* 1733 */  _Binary__NegVD_vReg__vReg_rule,
  /* 1734 */  _Binary_vReg__NegVD_vReg__rule,
  /* 1735 */  _Binary_vReg_vReg_rule,
  /* 1736 */  _Binary_vReg_vReg_rule,
  /* 1737 */  _MulVB_vReg_vReg_rule,
  /* 1738 */  vReg_rule,
  /* 1739 */  _MulVS_vReg_vReg_rule,
  /* 1740 */  vReg_rule,
  /* 1741 */  _MulVI_vReg_vReg_rule,
  /* 1742 */  vReg_rule,
  /* 1743 */  _MulVL_vReg_vReg_rule,
  /* 1744 */  vReg_rule,
  /* 1745 */  _MulVB_vReg_vReg_rule,
  /* 1746 */  _MulVS_vReg_vReg_rule,
  /* 1747 */  _MulVI_vReg_vReg_rule,
  /* 1748 */  _MulVL_vReg_vReg_rule,
  /* 1749 */  vReg_rule,
  /* 1750 */  vReg_rule,
  /* 1751 */  vReg_rule,
  /* 1752 */  vReg_rule,
  /* 1753 */  vReg_rule,
  /* 1754 */  vReg_rule,
  /* 1755 */  pRegGov_rule,
  /* 1756 */  pRegGov_rule,
  /* 1757 */  pRegGov_rule,
  /* 1758 */  pRegGov_rule,
  /* 1759 */  pRegGov_rule,
  /* 1760 */  pRegGov_rule,
  /* 1761 */  pRegGov_rule,
  /* 1762 */  pRegGov_rule,
  /* 1763 */  immI_rule,
  /* 1764 */  _Binary_immI_pRegGov_rule,
  /* 1765 */  pRegGov_rule,
  /* 1766 */  0,
  /* 1767 */  0,
  /* 1768 */  immI_1_rule,
  /* 1769 */  immI_gt_1_rule,
  /* 1770 */  0,
  /* 1771 */  0,
  /* 1772 */  _VectorStoreMask_pRegGov_immI_gt_1_rule,
  /* 1773 */  _VectorStoreMask_pRegGov_immI_gt_1_rule,
  /* 1774 */  vReg_rule,
  /* 1775 */  vReg_rule,
  /* 1776 */  vReg_rule,
  /* 1777 */  vReg_rule,
  /* 1778 */  vReg_rule,
  /* 1779 */  vReg_rule,
  /* 1780 */  vReg_rule,
  /* 1781 */  vReg_rule,
  /* 1782 */  pRegGov_rule,
  /* 1783 */  pRegGov_rule,
  /* 1784 */  pRegGov_rule,
  /* 1785 */  pRegGov_rule,
  /* 1786 */  pRegGov_rule,
  /* 1787 */  pRegGov_rule,
  /* 1788 */  pRegGov_rule,
  /* 1789 */  pRegGov_rule,
  /* 1790 */  vReg_rule,
  /* 1791 */  vReg_rule,
  /* 1792 */  vReg_rule,
  /* 1793 */  vReg_rule,
  /* 1794 */  pRegGov_rule,
  /* 1795 */  pRegGov_rule,
  /* 1796 */  pRegGov_rule,
  /* 1797 */  pRegGov_rule,
  /* 1798 */  vReg_rule,
  /* 1799 */  vReg_rule,
  /* 1800 */  vReg_rule,
  /* 1801 */  vReg_rule,
  /* 1802 */  pRegGov_rule,
  /* 1803 */  pRegGov_rule,
  /* 1804 */  pRegGov_rule,
  /* 1805 */  pRegGov_rule,
  /* 1806 */  vReg_rule,
  /* 1807 */  vReg_rule,
  /* 1808 */  vReg_rule,
  /* 1809 */  vReg_rule,
  /* 1810 */  pRegGov_rule,
  /* 1811 */  pRegGov_rule,
  /* 1812 */  pRegGov_rule,
  /* 1813 */  pRegGov_rule,
  /* 1814 */  vReg_rule,
  /* 1815 */  vReg_rule,
  /* 1816 */  vReg_rule,
  /* 1817 */  vReg_rule,
  /* 1818 */  vReg_rule,
  /* 1819 */  vReg_rule,
  /* 1820 */  vReg_rule,
  /* 1821 */  vReg_rule,
  /* 1822 */  pRegGov_rule,
  /* 1823 */  pRegGov_rule,
  /* 1824 */  pRegGov_rule,
  /* 1825 */  pRegGov_rule,
  /* 1826 */  pRegGov_rule,
  /* 1827 */  pRegGov_rule,
  /* 1828 */  pRegGov_rule,
  /* 1829 */  pRegGov_rule,
  /* 1830 */  vReg_rule,
  /* 1831 */  vReg_rule,
  /* 1832 */  vReg_rule,
  /* 1833 */  vReg_rule,
  /* 1834 */  vReg_rule,
  /* 1835 */  vReg_rule,
  /* 1836 */  vReg_rule,
  /* 1837 */  vReg_rule,
  /* 1838 */  pRegGov_rule,
  /* 1839 */  pRegGov_rule,
  /* 1840 */  pRegGov_rule,
  /* 1841 */  pRegGov_rule,
  /* 1842 */  pRegGov_rule,
  /* 1843 */  pRegGov_rule,
  /* 1844 */  pRegGov_rule,
  /* 1845 */  pRegGov_rule,
  /* 1846 */  immI_rule,
  /* 1847 */  0,
  /* 1848 */  0,
  /* 1849 */  0,
  /* 1850 */  0,
  /* 1851 */  0,
  /* 1852 */  0,
  /* 1853 */  0,
  /* 1854 */  0,
  /* 1855 */  0,
  /* 1856 */  0,
  /* 1857 */  vReg_rule,
  /* 1858 */  vReg_rule,
  /* 1859 */  vReg_rule,
  /* 1860 */  vReg_rule,
  /* 1861 */  vReg_rule,
  /* 1862 */  vReg_rule,
  /* 1863 */  vReg_rule,
  /* 1864 */  vReg_rule,
  /* 1865 */  vReg_rule,
  /* 1866 */  vReg_rule,
  /* 1867 */  vReg_rule,
  /* 1868 */  vReg_rule,
  /* 1869 */  _RShiftCntV_immI__rule,
  /* 1870 */  _RShiftCntV_immI__rule,
  /* 1871 */  _RShiftCntV_immI__rule,
  /* 1872 */  _RShiftCntV_immI__rule,
  /* 1873 */  _RShiftCntV_immI__rule,
  /* 1874 */  _RShiftCntV_immI__rule,
  /* 1875 */  _RShiftCntV_immI__rule,
  /* 1876 */  _RShiftCntV_immI__rule,
  /* 1877 */  _LShiftCntV_immI__rule,
  /* 1878 */  _LShiftCntV_immI__rule,
  /* 1879 */  _LShiftCntV_immI__rule,
  /* 1880 */  _LShiftCntV_immI__rule,
  /* 1881 */  pRegGov_rule,
  /* 1882 */  pRegGov_rule,
  /* 1883 */  pRegGov_rule,
  /* 1884 */  pRegGov_rule,
  /* 1885 */  pRegGov_rule,
  /* 1886 */  pRegGov_rule,
  /* 1887 */  pRegGov_rule,
  /* 1888 */  pRegGov_rule,
  /* 1889 */  pRegGov_rule,
  /* 1890 */  pRegGov_rule,
  /* 1891 */  pRegGov_rule,
  /* 1892 */  pRegGov_rule,
  /* 1893 */  pRegGov_rule,
  /* 1894 */  pRegGov_rule,
  /* 1895 */  pRegGov_rule,
  /* 1896 */  pRegGov_rule,
  /* 1897 */  pRegGov_rule,
  /* 1898 */  pRegGov_rule,
  /* 1899 */  pRegGov_rule,
  /* 1900 */  pRegGov_rule,
  /* 1901 */  pRegGov_rule,
  /* 1902 */  pRegGov_rule,
  /* 1903 */  pRegGov_rule,
  /* 1904 */  pRegGov_rule,
  /* 1905 */  pRegGov_rule,
  /* 1906 */  pRegGov_rule,
  /* 1907 */  vReg_rule,
  /* 1908 */  vReg_rule,
  /* 1909 */  vReg_rule,
  /* 1910 */  vReg_rule,
  /* 1911 */  vReg_rule,
  /* 1912 */  vReg_rule,
  /* 1913 */  pRegGov_rule,
  /* 1914 */  pRegGov_rule,
  /* 1915 */  pRegGov_rule,
  /* 1916 */  pRegGov_rule,
  /* 1917 */  pRegGov_rule,
  /* 1918 */  pRegGov_rule,
  /* 1919 */  0,
  /* 1920 */  0,
  /* 1921 */  0,
  /* 1922 */  0,
  /* 1923 */  0,
  /* 1924 */  0,
  /* 1925 */  0,
  /* 1926 */  0,
  /* 1927 */  immI_rule,
  /* 1928 */  immI_rule,
  /* 1929 */  immI_rule,
  /* 1930 */  immI_rule,
  /* 1931 */  immI_rule,
  /* 1932 */  immI_rule,
  /* 1933 */  pRegGov_rule,
  /* 1934 */  pRegGov_rule,
  /* 1935 */  pRegGov_rule,
  /* 1936 */  pRegGov_rule,
  /* 1937 */  immI_rule,
  /* 1938 */  immI_rule,
  /* 1939 */  immI_rule,
  /* 1940 */  immI_rule,
  /* 1941 */  immI_rule,
  /* 1942 */  immI_rule,
  /* 1943 */  vReg_rule,
  /* 1944 */  vReg_rule,
  /* 1945 */  vReg_rule,
  /* 1946 */  vReg_rule,
  /* 1947 */  vReg_rule,
  /* 1948 */  _Binary_vReg_pRegGov_rule,
  /* 1949 */  _Binary_vReg_pRegGov_rule,
  /* 1950 */  _Binary_vReg_pRegGov_rule,
  /* 1951 */  _Binary_vReg_pRegGov_rule,
  /* 1952 */  _Binary_vReg_vReg_rule,
  /* 1953 */  _Binary_vReg_vReg_rule,
  /* 1954 */  _Binary_vReg_vReg_rule,
  /* 1955 */  _Binary_vReg_vReg_rule,
  /* 1956 */  _Binary_vReg__Binary_vReg_pRegGov_rule,
  /* 1957 */  _Binary_vReg__Binary_vReg_pRegGov_rule,
  /* 1958 */  _Binary_vReg__Binary_vReg_pRegGov_rule,
  /* 1959 */  _Binary_vReg__Binary_vReg_pRegGov_rule,
  /* 1960 */  iRegI_R3_rule,
  /* 1961 */  iRegI_R3_rule,
  /* 1962 */  0,
  /* 1963 */  0,
  /* 1964 */  0,
  /* 1965 */  0,
  /* 1966 */  0,
  /* 1967 */  0,
  /* 1968 */  0,
  /* 1969 */  _Binary_iRegP_iRegP_rule,
  /* 1970 */  _Binary_iRegN_iRegN_rule,
  /* 1971 */  _Binary_iRegP_iRegP_rule,
  /* 1972 */  _Binary_iRegN_iRegN_rule,
  /* 1973 */  _Binary_iRegN_iRegN_rule,
  /* 1974 */  _Binary_iRegP_iRegP_rule,
  /* 1975 */  _Binary_iRegN_iRegN_rule,
  /* 1976 */  _Binary_iRegP_iRegP_rule,
  /* 1977 */  _Binary_iRegN_iRegN_rule,
  /* 1978 */  _Binary_iRegP_iRegP_rule,
  /* 1979 */  _Binary_iRegN_iRegN_rule,
  /* 1980 */  _Binary_iRegP_iRegP_rule,
  /* 1981 */  0,
  /* 1982 */  0,
  /* 1983 */  _Binary_iRegP_iRegP_rule,
  /* 1984 */  _Binary_iRegP_iRegP_rule,
  /* 1985 */  _Binary_iRegP_iRegP_rule,
  /* 1986 */  _Binary_iRegP_iRegP_rule,
  /* 1987 */  _Binary_iRegP_iRegP_rule,
  /* 1988 */  _Binary_iRegP_iRegP_rule,
  /* 1989 */  iRegP_rule,
  /* 1990 */  iRegP_rule,
  // last instruction
  0 // no trailing comma
};

const char        *ruleName[] = {
  /*    0 */  "UNIVERSE",
  /*    1 */  "LABEL",
  /*    2 */  "SREGI",
  /*    3 */  "SREGP",
  /*    4 */  "SREGF",
  /*    5 */  "SREGD",
  /*    6 */  "SREGL",
  /*    7 */  "METHOD",
  /*    8 */  "IMMI",
  /*    9 */  "IMMI0",
  /*   10 */  "IMMI_1",
  /*   11 */  "IMMI_M1",
  /*   12 */  "IMMIEXT",
  /*   13 */  "IMMI_GT_1",
  /*   14 */  "IMMI_LE_4",
  /*   15 */  "IMMI_31",
  /*   16 */  "IMMI_2",
  /*   17 */  "IMMI_4",
  /*   18 */  "IMMI_8",
  /*   19 */  "IMMI_16",
  /*   20 */  "IMMI_24",
  /*   21 */  "IMMI_32",
  /*   22 */  "IMMI_48",
  /*   23 */  "IMMI_56",
  /*   24 */  "IMMI_63",
  /*   25 */  "IMMI_64",
  /*   26 */  "IMMI_255",
  /*   27 */  "IMMI_65535",
  /*   28 */  "IMML_255",
  /*   29 */  "IMML_65535",
  /*   30 */  "IMML_4294967295",
  /*   31 */  "IMML_BITMASK",
  /*   32 */  "IMMI_BITMASK",
  /*   33 */  "IMML_POSITIVE_BITMASKI",
  /*   34 */  "IMMISCALE",
  /*   35 */  "IMMI26",
  /*   36 */  "IMMI19",
  /*   37 */  "IMMIU12",
  /*   38 */  "IMMLU12",
  /*   39 */  "IMMIOFFSET",
  /*   40 */  "IMMIOFFSET1",
  /*   41 */  "IMMIOFFSET2",
  /*   42 */  "IMMIOFFSET4",
  /*   43 */  "IMMIOFFSET8",
  /*   44 */  "IMMIOFFSET16",
  /*   45 */  "IMMLOFFSET",
  /*   46 */  "IMMLOFFSET1",
  /*   47 */  "IMMLOFFSET2",
  /*   48 */  "IMMLOFFSET4",
  /*   49 */  "IMMLOFFSET8",
  /*   50 */  "IMMLOFFSET16",
  /*   51 */  "IMMI8",
  /*   52 */  "IMMI8_SHIFT8",
  /*   53 */  "IMML8_SHIFT8",
  /*   54 */  "IMMBADDSUBV",
  /*   55 */  "IMMIADDSUB",
  /*   56 */  "IMMIADDSUBV",
  /*   57 */  "IMMBLOG",
  /*   58 */  "IMMSLOG",
  /*   59 */  "IMMILOG",
  /*   60 */  "IMML",
  /*   61 */  "IMML0",
  /*   62 */  "IMML_1",
  /*   63 */  "IMML_M1",
  /*   64 */  "IMML_PC_OFF",
  /*   65 */  "IMMLADDSUB",
  /*   66 */  "IMMLADDSUBV",
  /*   67 */  "IMMLLOG",
  /*   68 */  "IMML_32BITS",
  /*   69 */  "IMMP",
  /*   70 */  "IMMP0",
  /*   71 */  "IMMP_1",
  /*   72 */  "IMMBYTEMAPBASE",
  /*   73 */  "IMMP_M1",
  /*   74 */  "IMMP_M2",
  /*   75 */  "IMMD",
  /*   76 */  "IMMD0",
  /*   77 */  "IMMDPACKED",
  /*   78 */  "IMMF",
  /*   79 */  "IMMF0",
  /*   80 */  "IMMFPACKED",
  /*   81 */  "IMMN",
  /*   82 */  "IMMN0",
  /*   83 */  "IMMNKLASS",
  /*   84 */  "IREGI",
  /*   85 */  "IREGINOSP",
  /*   86 */  "IREGL",
  /*   87 */  "IREGLNOSP",
  /*   88 */  "IREGP",
  /*   89 */  "IREGPNOSP",
  /*   90 */  "IREGP_R0",
  /*   91 */  "IREGP_R1",
  /*   92 */  "IREGP_R2",
  /*   93 */  "IREGP_R3",
  /*   94 */  "IREGP_R4",
  /*   95 */  "IREGP_R5",
  /*   96 */  "IREGP_R10",
  /*   97 */  "IREGL_R0",
  /*   98 */  "IREGL_R2",
  /*   99 */  "IREGL_R3",
  /*  100 */  "IREGL_R11",
  /*  101 */  "IREGP_FP",
  /*  102 */  "IREGI_R0",
  /*  103 */  "IREGI_R2",
  /*  104 */  "IREGI_R3",
  /*  105 */  "IREGI_R4",
  /*  106 */  "IREGN",
  /*  107 */  "IREGN_R0",
  /*  108 */  "IREGN_R2",
  /*  109 */  "IREGN_R3",
  /*  110 */  "IREGNNOSP",
  /*  111 */  "IREGIHEAPBASE",
  /*  112 */  "VREGF",
  /*  113 */  "VREGD",
  /*  114 */  "VREG",
  /*  115 */  "VECD",
  /*  116 */  "VECX",
  /*  117 */  "VREGD_V0",
  /*  118 */  "VREGD_V1",
  /*  119 */  "VREGD_V2",
  /*  120 */  "VREGD_V3",
  /*  121 */  "VREGD_V4",
  /*  122 */  "VREGD_V5",
  /*  123 */  "VREGD_V6",
  /*  124 */  "VREGD_V7",
  /*  125 */  "VREGD_V8",
  /*  126 */  "VREGD_V9",
  /*  127 */  "VREGD_V10",
  /*  128 */  "VREGD_V11",
  /*  129 */  "VREGD_V12",
  /*  130 */  "VREGD_V13",
  /*  131 */  "VREGD_V14",
  /*  132 */  "VREGD_V15",
  /*  133 */  "VREGD_V16",
  /*  134 */  "VREGD_V17",
  /*  135 */  "VREGD_V18",
  /*  136 */  "VREGD_V19",
  /*  137 */  "VREGD_V20",
  /*  138 */  "VREGD_V21",
  /*  139 */  "VREGD_V22",
  /*  140 */  "VREGD_V23",
  /*  141 */  "VREGD_V24",
  /*  142 */  "VREGD_V25",
  /*  143 */  "VREGD_V26",
  /*  144 */  "VREGD_V27",
  /*  145 */  "VREGD_V28",
  /*  146 */  "VREGD_V29",
  /*  147 */  "VREGD_V30",
  /*  148 */  "VREGD_V31",
  /*  149 */  "PREG",
  /*  150 */  "PREGGOV",
  /*  151 */  "RFLAGSREG",
  /*  152 */  "RFLAGSREGU",
  /*  153 */  "INLINE_CACHE_REGP",
  /*  154 */  "THREAD_REGP",
  /*  155 */  "LR_REGP",
  /*  156 */  "INDIRECT",
  /*  157 */  "INDINDEXSCALEDI2L",
  /*  158 */  "INDINDEXSCALED",
  /*  159 */  "INDINDEXI2L",
  /*  160 */  "INDINDEX",
  /*  161 */  "INDOFFI",
  /*  162 */  "INDOFFI1",
  /*  163 */  "INDOFFI2",
  /*  164 */  "INDOFFI4",
  /*  165 */  "INDOFFI8",
  /*  166 */  "INDOFFI16",
  /*  167 */  "INDOFFL",
  /*  168 */  "INDOFFL1",
  /*  169 */  "INDOFFL2",
  /*  170 */  "INDOFFL4",
  /*  171 */  "INDOFFL8",
  /*  172 */  "INDOFFL16",
  /*  173 */  "INDIRECTN",
  /*  174 */  "INDINDEXSCALEDI2LN",
  /*  175 */  "INDINDEXSCALEDN",
  /*  176 */  "INDINDEXI2LN",
  /*  177 */  "INDINDEXN",
  /*  178 */  "INDOFFIN",
  /*  179 */  "INDOFFLN",
  /*  180 */  "THREAD_ANCHOR_PC",
  /*  181 */  "STACKSLOTP",
  /*  182 */  "STACKSLOTI",
  /*  183 */  "STACKSLOTF",
  /*  184 */  "STACKSLOTD",
  /*  185 */  "STACKSLOTL",
  /*  186 */  "CMPOP",
  /*  187 */  "CMPOPU",
  /*  188 */  "CMPOPEQNE",
  /*  189 */  "CMPOPLTGE",
  /*  190 */  "CMPOPUEQNELTGE",
  /*  191 */  "IREGL2I",
  /*  192 */  "VMEMA_IMMIOFFSET4",
  /*  193 */  "VMEMA_IMMLOFFSET4",
  /*  194 */  "VMEMA_INDOFFI4",
  /*  195 */  "VMEMA_INDOFFL4",
  // last operand
  /*  196 */  "VMEM2",
  /*  197 */  "VMEM4",
  /*  198 */  "VMEM8",
  /*  199 */  "VMEM16",
  /*  200 */  "MEMORY1",
  /*  201 */  "MEMORY2",
  /*  202 */  "MEMORY4",
  /*  203 */  "MEMORY8",
  /*  204 */  "MEMORY",
  /*  205 */  "IREGIORL2I",
  /*  206 */  "VMEMA",
  // last operand class
  /*  207 */  "_ConvI2L_iRegI_",
  /*  208 */  "_LShiftL__ConvI2L_iRegI__immIScale",
  /*  209 */  "_LShiftL_iRegL_immIScale",
  /*  210 */  "_DecodeN_iRegN_",
  /*  211 */  "_LoadB_memory1_",
  /*  212 */  "_LoadUB_memory1_",
  /*  213 */  "_LoadS_memory2_",
  /*  214 */  "_LoadUS_memory2_",
  /*  215 */  "_LoadI_memory4_",
  /*  216 */  "_ConvI2L__LoadI_memory4__",
  /*  217 */  "_LoadB_indirect_",
  /*  218 */  "_LoadUB_indirect_",
  /*  219 */  "_LoadUS_indirect_",
  /*  220 */  "_LoadS_indirect_",
  /*  221 */  "_LoadI_indirect_",
  /*  222 */  "_ConvI2L__LoadI_indirect__",
  /*  223 */  "_LoadL_memory8_",
  /*  224 */  "_CastP2X_iRegP_",
  /*  225 */  "_CastP2X__DecodeN_iRegN__",
  /*  226 */  "_Binary_iRegP_iRegP",
  /*  227 */  "_Binary_iRegLNoSp_iRegLNoSp",
  /*  228 */  "_Binary_iRegINoSp_iRegINoSp",
  /*  229 */  "_Binary_iRegNNoSp_iRegNNoSp",
  /*  230 */  "_Binary_iRegI_iRegI",
  /*  231 */  "_Binary_iRegL_iRegL",
  /*  232 */  "_Binary_iRegN_iRegN",
  /*  233 */  "_Binary_cmpOp_rFlagsReg",
  /*  234 */  "_Binary_iRegIorL2I_iRegIorL2I",
  /*  235 */  "_Binary_cmpOpU_rFlagsRegU",
  /*  236 */  "_Binary_immI0_iRegIorL2I",
  /*  237 */  "_Binary_iRegIorL2I_immI0",
  /*  238 */  "_Binary_immI_1_immI0",
  /*  239 */  "_Binary_iRegL_immL0",
  /*  240 */  "_Binary_immL0_iRegL",
  /*  241 */  "_Binary_iRegP_immP0",
  /*  242 */  "_Binary_immP0_iRegP",
  /*  243 */  "_Binary_iRegN_immN0",
  /*  244 */  "_Binary_immN0_iRegN",
  /*  245 */  "_Binary_vRegF_vRegF",
  /*  246 */  "_Binary_vRegD_vRegD",
  /*  247 */  "_ConvL2I_iRegL_",
  /*  248 */  "_ConvI2L_iRegIorL2I_",
  /*  249 */  "_LShiftL__ConvI2L_iRegIorL2I__immIScale",
  /*  250 */  "_MulI_iRegIorL2I_iRegIorL2I",
  /*  251 */  "_SubI_immI0_iRegIorL2I",
  /*  252 */  "_MulL_iRegL_iRegL",
  /*  253 */  "_SubL_immL0_iRegL",
  /*  254 */  "_MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I_",
  /*  255 */  "_SubL_immL0__ConvI2L_iRegIorL2I_",
  /*  256 */  "_XorI_iRegIorL2I_immI_M1",
  /*  257 */  "_XorL_iRegL_immL_M1",
  /*  258 */  "_XorI_iRegIorL2I_iRegIorL2I",
  /*  259 */  "_XorL_iRegL_iRegL",
  /*  260 */  "_URShiftI_iRegIorL2I_immI",
  /*  261 */  "_XorI__URShiftI_iRegIorL2I_immI_immI_M1",
  /*  262 */  "_URShiftL_iRegL_immI",
  /*  263 */  "_XorL__URShiftL_iRegL_immI_immL_M1",
  /*  264 */  "_RShiftI_iRegIorL2I_immI",
  /*  265 */  "_XorI__RShiftI_iRegIorL2I_immI_immI_M1",
  /*  266 */  "_RShiftL_iRegL_immI",
  /*  267 */  "_XorL__RShiftL_iRegL_immI_immL_M1",
  /*  268 */  "_RotateRight_iRegIorL2I_immI",
  /*  269 */  "_XorI__RotateRight_iRegIorL2I_immI_immI_M1",
  /*  270 */  "_RotateRight_iRegL_immI",
  /*  271 */  "_XorL__RotateRight_iRegL_immI_immL_M1",
  /*  272 */  "_LShiftI_iRegIorL2I_immI",
  /*  273 */  "_XorI__LShiftI_iRegIorL2I_immI_immI_M1",
  /*  274 */  "_LShiftL_iRegL_immI",
  /*  275 */  "_XorL__LShiftL_iRegL_immI_immL_M1",
  /*  276 */  "_XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I",
  /*  277 */  "_XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI",
  /*  278 */  "_XorL__URShiftL_iRegL_immI_iRegL",
  /*  279 */  "_XorL_iRegL__URShiftL_iRegL_immI",
  /*  280 */  "_XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I",
  /*  281 */  "_XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI",
  /*  282 */  "_XorL__RShiftL_iRegL_immI_iRegL",
  /*  283 */  "_XorL_iRegL__RShiftL_iRegL_immI",
  /*  284 */  "_XorI__RotateRight_iRegIorL2I_immI_iRegIorL2I",
  /*  285 */  "_XorI_iRegIorL2I__RotateRight_iRegIorL2I_immI",
  /*  286 */  "_XorL__RotateRight_iRegL_immI_iRegL",
  /*  287 */  "_XorL_iRegL__RotateRight_iRegL_immI",
  /*  288 */  "_XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I",
  /*  289 */  "_XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI",
  /*  290 */  "_XorL__LShiftL_iRegL_immI_iRegL",
  /*  291 */  "_XorL_iRegL__LShiftL_iRegL_immI",
  /*  292 */  "_AndI__URShiftI_iRegIorL2I_immI_immI_bitmask",
  /*  293 */  "_AndI_iRegIorL2I_immI_bitmask",
  /*  294 */  "_AndL_iRegL_immL_bitmask",
  /*  295 */  "_LShiftI__AndI_iRegIorL2I_immI_bitmask_immI",
  /*  296 */  "_AndL_iRegL_immL_positive_bitmaskI",
  /*  297 */  "_LShiftL__AndL_iRegL_immL_positive_bitmaskI_immI",
  /*  298 */  "_ConvI2L__AndI_iRegIorL2I_immI_bitmask_",
  /*  299 */  "_ConvL2I__AndL_iRegL_immL_positive_bitmaskI_",
  /*  300 */  "_AndI_iRegI_immI_bitmask",
  /*  301 */  "_LShiftI_iRegIorL2I_immI_16",
  /*  302 */  "_RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16",
  /*  303 */  "_LShiftI_iRegIorL2I_immI_24",
  /*  304 */  "_RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24",
  /*  305 */  "_URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24",
  /*  306 */  "_LShiftL_iRegL_immI_48",
  /*  307 */  "_RShiftL__LShiftL_iRegL_immI_48_immI_48",
  /*  308 */  "_LShiftL_iRegL_immI_32",
  /*  309 */  "_RShiftL__LShiftL_iRegL_immI_32_immI_32",
  /*  310 */  "_LShiftL_iRegL_immI_56",
  /*  311 */  "_RShiftL__LShiftL_iRegL_immI_56_immI_56",
  /*  312 */  "_URShiftL__LShiftL_iRegL_immI_56_immI_56",
  /*  313 */  "_AndI_iRegIorL2I_immI_255",
  /*  314 */  "_AndI_iRegIorL2I_immI_65535",
  /*  315 */  "_AndL_iRegL_immL_255",
  /*  316 */  "_AndL_iRegL_immL_65535",
  /*  317 */  "_AndL_iRegL_immL_4294967295",
  /*  318 */  "_LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt",
  /*  319 */  "_LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt",
  /*  320 */  "_LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt",
  /*  321 */  "_LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt",
  /*  322 */  "_LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt",
  /*  323 */  "_LShiftL__ConvI2L_iRegIorL2I__immIExt",
  /*  324 */  "_LShiftL__AndL_iRegL_immL_255_immIExt",
  /*  325 */  "_LShiftL__AndL_iRegL_immL_65535_immIExt",
  /*  326 */  "_LShiftL__AndL_iRegL_immL_4294967295_immIExt",
  /*  327 */  "_LShiftI__AndI_iRegIorL2I_immI_255_immIExt",
  /*  328 */  "_LShiftI__AndI_iRegIorL2I_immI_65535_immIExt",
  /*  329 */  "_NegF_vRegF_",
  /*  330 */  "_Binary__NegF_vRegF__vRegF",
  /*  331 */  "_Binary_vRegF__NegF_vRegF_",
  /*  332 */  "_NegD_vRegD_",
  /*  333 */  "_Binary__NegD_vRegD__vRegD",
  /*  334 */  "_Binary_vRegD__NegD_vRegD_",
  /*  335 */  "_SubF_vRegF_vRegF",
  /*  336 */  "_SubD_vRegD_vRegD",
  /*  337 */  "_OverflowMulI_iRegIorL2I_iRegIorL2I",
  /*  338 */  "_OverflowMulL_iRegL_iRegL",
  /*  339 */  "_CmpI_iRegIorL2I_immI0",
  /*  340 */  "_CmpL_iRegL_immL0",
  /*  341 */  "_CmpP_iRegP_immP0",
  /*  342 */  "_CmpN_iRegN_immN0",
  /*  343 */  "_CmpP__DecodeN_iRegN__immP0",
  /*  344 */  "_CmpU_iRegIorL2I_immI0",
  /*  345 */  "_CmpUL_iRegL_immL0",
  /*  346 */  "_AndL_iRegL_immL",
  /*  347 */  "_CmpL__AndL_iRegL_immL_immL0",
  /*  348 */  "_AndI_iRegIorL2I_immI",
  /*  349 */  "_CmpI__AndI_iRegIorL2I_immI_immI0",
  /*  350 */  "_AndL_iRegL_iRegL",
  /*  351 */  "_AndI_iRegIorL2I_iRegIorL2I",
  /*  352 */  "_PartialSubtypeCheck_iRegP_R4_iRegP_R0",
  /*  353 */  "_Binary_iRegP_R1_iRegI_R2",
  /*  354 */  "_Binary_iRegP_R3_iRegI_R4",
  /*  355 */  "_Binary_iRegP_R1_iRegI_R4",
  /*  356 */  "_Binary_iRegP_R3_iRegI_R2",
  /*  357 */  "_Binary_iRegP_R3_immI_le_4",
  /*  358 */  "_Binary_iRegP_R3_immI_1",
  /*  359 */  "_Binary_iRegP_R1_iRegP_R3",
  /*  360 */  "_Binary_iRegP_R1_iRegI_R3",
  /*  361 */  "_Binary_vecD_iRegIorL2I",
  /*  362 */  "_Binary_vecX_iRegIorL2I",
  /*  363 */  "_Binary_vecX_iRegL",
  /*  364 */  "_Binary_vecD_vRegF",
  /*  365 */  "_Binary_vecX_vRegF",
  /*  366 */  "_Binary_vecX_vRegD",
  /*  367 */  "_Binary_vecD_vecD",
  /*  368 */  "_Binary_vecX_vecX",
  /*  369 */  "_ReplicateB_immI_M1_",
  /*  370 */  "_ReplicateS_immI_M1_",
  /*  371 */  "_ReplicateI_immI_M1_",
  /*  372 */  "_ReplicateL_immL_M1_",
  /*  373 */  "_XorV_vecD__ReplicateB_immI_M1_",
  /*  374 */  "_XorV__ReplicateB_immI_M1__vecD",
  /*  375 */  "_XorV_vecD__ReplicateS_immI_M1_",
  /*  376 */  "_XorV__ReplicateS_immI_M1__vecD",
  /*  377 */  "_XorV_vecD__ReplicateI_immI_M1_",
  /*  378 */  "_XorV__ReplicateI_immI_M1__vecD",
  /*  379 */  "_XorV_vecX__ReplicateB_immI_M1_",
  /*  380 */  "_XorV__ReplicateB_immI_M1__vecX",
  /*  381 */  "_XorV_vecX__ReplicateS_immI_M1_",
  /*  382 */  "_XorV__ReplicateS_immI_M1__vecX",
  /*  383 */  "_XorV_vecX__ReplicateI_immI_M1_",
  /*  384 */  "_XorV__ReplicateI_immI_M1__vecX",
  /*  385 */  "_XorV_vecX__ReplicateL_immL_M1_",
  /*  386 */  "_XorV__ReplicateL_immL_M1__vecX",
  /*  387 */  "_SubVF_vecD_vecD",
  /*  388 */  "_SubVF_vecX_vecX",
  /*  389 */  "_SubVD_vecX_vecX",
  /*  390 */  "_MulVS_vecD_vecD",
  /*  391 */  "_MulVS_vecX_vecX",
  /*  392 */  "_MulVI_vecD_vecD",
  /*  393 */  "_MulVI_vecX_vecX",
  /*  394 */  "_NegVF_vecD_",
  /*  395 */  "_Binary__NegVF_vecD__vecD",
  /*  396 */  "_Binary_vecD__NegVF_vecD_",
  /*  397 */  "_NegVF_vecX_",
  /*  398 */  "_Binary__NegVF_vecX__vecX",
  /*  399 */  "_Binary_vecX__NegVF_vecX_",
  /*  400 */  "_NegVD_vecX_",
  /*  401 */  "_Binary__NegVD_vecX__vecX",
  /*  402 */  "_Binary_vecX__NegVD_vecX_",
  /*  403 */  "_LShiftCntV_immI_",
  /*  404 */  "_RShiftCntV_immI_",
  /*  405 */  "_RShiftVB_vecD__RShiftCntV_immI_",
  /*  406 */  "_RShiftVB_vecX__RShiftCntV_immI_",
  /*  407 */  "_RShiftVS_vecD__RShiftCntV_immI_",
  /*  408 */  "_RShiftVS_vecX__RShiftCntV_immI_",
  /*  409 */  "_RShiftVI_vecD__RShiftCntV_immI_",
  /*  410 */  "_RShiftVI_vecX__RShiftCntV_immI_",
  /*  411 */  "_RShiftVL_vecX__RShiftCntV_immI_",
  /*  412 */  "_URShiftVB_vecD__RShiftCntV_immI_",
  /*  413 */  "_URShiftVB_vecX__RShiftCntV_immI_",
  /*  414 */  "_URShiftVS_vecD__RShiftCntV_immI_",
  /*  415 */  "_URShiftVS_vecX__RShiftCntV_immI_",
  /*  416 */  "_URShiftVI_vecD__RShiftCntV_immI_",
  /*  417 */  "_URShiftVI_vecX__RShiftCntV_immI_",
  /*  418 */  "_URShiftVL_vecX__RShiftCntV_immI_",
  /*  419 */  "_Binary_vReg_pRegGov",
  /*  420 */  "_MaskAll_immI_M1_",
  /*  421 */  "_XorVMask_pRegGov__MaskAll_immI_M1_",
  /*  422 */  "_MaskAll_immL_M1_",
  /*  423 */  "_XorVMask_pRegGov__MaskAll_immL_M1_",
  /*  424 */  "_Binary_vReg_vReg",
  /*  425 */  "_ReplicateB_immBAddSubV_",
  /*  426 */  "_ReplicateS_immIAddSubV_",
  /*  427 */  "_ReplicateI_immIAddSubV_",
  /*  428 */  "_ReplicateL_immLAddSubV_",
  /*  429 */  "_ReplicateB_immBLog_",
  /*  430 */  "_ReplicateS_immSLog_",
  /*  431 */  "_ReplicateI_immILog_",
  /*  432 */  "_ReplicateL_immLLog_",
  /*  433 */  "_XorV_vReg__ReplicateB_immI_M1_",
  /*  434 */  "_XorV__ReplicateB_immI_M1__vReg",
  /*  435 */  "_XorV_vReg__ReplicateS_immI_M1_",
  /*  436 */  "_XorV__ReplicateS_immI_M1__vReg",
  /*  437 */  "_XorV_vReg__ReplicateI_immI_M1_",
  /*  438 */  "_XorV__ReplicateI_immI_M1__vReg",
  /*  439 */  "_XorV_vReg__ReplicateL_immL_M1_",
  /*  440 */  "_XorV__ReplicateL_immL_M1__vReg",
  /*  441 */  "_NegVF_vReg_",
  /*  442 */  "_Binary__NegVF_vReg__vReg",
  /*  443 */  "_Binary_vReg__NegVF_vReg_",
  /*  444 */  "_NegVD_vReg_",
  /*  445 */  "_Binary__NegVD_vReg__vReg",
  /*  446 */  "_Binary_vReg__NegVD_vReg_",
  /*  447 */  "_MulVB_vReg_vReg",
  /*  448 */  "_MulVS_vReg_vReg",
  /*  449 */  "_MulVI_vReg_vReg",
  /*  450 */  "_MulVL_vReg_vReg",
  /*  451 */  "_Binary_immI_pRegGov",
  /*  452 */  "_LoadVector_indirect_",
  /*  453 */  "_VectorStoreMask_pRegGov_immI_gt_1",
  /*  454 */  "_Binary_iRegIorL2I_vReg",
  /*  455 */  "_Binary_iRegL_vReg",
  /*  456 */  "_Binary_vRegF_vReg",
  /*  457 */  "_Binary_vRegD_vReg",
  /*  458 */  "_Binary_vReg__RShiftCntV_immI_",
  /*  459 */  "_Binary_vReg__LShiftCntV_immI_",
  /*  460 */  "_Binary_vReg_iRegIorL2I",
  /*  461 */  "_Binary_vReg_vRegF",
  /*  462 */  "_Binary_vReg_iRegL",
  /*  463 */  "_Binary_vReg_vRegD",
  /*  464 */  "_Binary_vReg__Binary_vReg_pRegGov",
  // last internally defined operand
  /*  465 */  "loadConI",
  /*  466 */  "loadConL",
  /*  467 */  "loadConP",
  /*  468 */  "loadConP0",
  /*  469 */  "loadConP1",
  /*  470 */  "loadByteMapBase",
  /*  471 */  "loadConN",
  /*  472 */  "loadConN0",
  /*  473 */  "loadConNKlass",
  /*  474 */  "loadConF_packed",
  /*  475 */  "loadConF",
  /*  476 */  "loadConD_packed",
  /*  477 */  "loadConD",
  /*  478 */  "countLeadingZerosI",
  /*  479 */  "countLeadingZerosL",
  /*  480 */  "countTrailingZerosI",
  /*  481 */  "countTrailingZerosL",
  /*  482 */  "castX2P",
  /*  483 */  "castP2X",
  /*  484 */  "checkCastPP",
  /*  485 */  "castPP",
  /*  486 */  "castII",
  /*  487 */  "castLL",
  /*  488 */  "castFF",
  /*  489 */  "castDD",
  /*  490 */  "castVVD",
  /*  491 */  "castVVX",
  /*  492 */  "castVV",
  /*  493 */  "castVVMask",
  /*  494 */  "storePConditional",
  /*  495 */  "storeLConditional",
  /*  496 */  "storeIConditional",
  /*  497 */  "negF_reg_reg",
  /*  498 */  "negD_reg_reg",
  /*  499 */  "absF_reg",
  /*  500 */  "absD_reg",
  /*  501 */  "MoveF2I_stack_reg",
  /*  502 */  "MoveI2F_stack_reg",
  /*  503 */  "MoveD2L_stack_reg",
  /*  504 */  "MoveL2D_stack_reg",
  /*  505 */  "MoveF2I_reg_reg",
  /*  506 */  "MoveI2F_reg_reg",
  /*  507 */  "MoveD2L_reg_reg",
  /*  508 */  "MoveL2D_reg_reg",
  /*  509 */  "overflowAddI_reg_reg",
  /*  510 */  "overflowAddI_reg_imm",
  /*  511 */  "overflowAddL_reg_reg",
  /*  512 */  "overflowAddL_reg_imm",
  /*  513 */  "overflowSubI_reg_reg",
  /*  514 */  "overflowSubI_reg_imm",
  /*  515 */  "overflowSubL_reg_reg",
  /*  516 */  "overflowSubL_reg_imm",
  /*  517 */  "overflowNegI_reg",
  /*  518 */  "overflowNegL_reg",
  /*  519 */  "overflowMulI_reg",
  /*  520 */  "overflowMulL_reg",
  /*  521 */  "compI_reg_reg",
  /*  522 */  "compI_reg_immI0",
  /*  523 */  "compI_reg_immIAddSub",
  /*  524 */  "compI_reg_immI",
  /*  525 */  "compU_reg_reg",
  /*  526 */  "compU_reg_immI0",
  /*  527 */  "compU_reg_immIAddSub",
  /*  528 */  "compU_reg_immI",
  /*  529 */  "compL_reg_reg",
  /*  530 */  "compL_reg_immL0",
  /*  531 */  "compL_reg_immLAddSub",
  /*  532 */  "compL_reg_immL",
  /*  533 */  "compUL_reg_reg",
  /*  534 */  "compUL_reg_immL0",
  /*  535 */  "compUL_reg_immLAddSub",
  /*  536 */  "compUL_reg_immL",
  /*  537 */  "compP_reg_reg",
  /*  538 */  "compN_reg_reg",
  /*  539 */  "testP_reg",
  /*  540 */  "testN_reg",
  /*  541 */  "compF_reg_reg",
  /*  542 */  "compF_reg_zero",
  /*  543 */  "compD_reg_reg",
  /*  544 */  "compD_reg_zero",
  /*  545 */  "cmpL_and",
  /*  546 */  "cmpI_and",
  /*  547 */  "cmpL_and_reg",
  /*  548 */  "cmpI_and_reg",
  /*  549 */  "cmpFastLock",
  /*  550 */  "cmpFastUnlock",
  /*  551 */  "partialSubtypeCheckVsZero",
  /*  552 */  "tlsLoadP",
  /*  553 */  "reinterpretD",
  /*  554 */  "reinterpretX",
  /*  555 */  "reinterpretD2X",
  /*  556 */  "reinterpretX2D",
  /*  557 */  "reinterpretS2X",
  /*  558 */  "reinterpretX2S",
  /*  559 */  "reinterpretS2D",
  /*  560 */  "reinterpretD2S",
  /*  561 */  "vcvt8Bto8S",
  /*  562 */  "vcvt4Bto4S",
  /*  563 */  "vcvt8Sto8B",
  /*  564 */  "vcvt4Sto4B",
  /*  565 */  "vcvt4Sto4I",
  /*  566 */  "vcvt4Ito4S",
  /*  567 */  "vcvt2Ito2L",
  /*  568 */  "vcvt2Lto2I",
  /*  569 */  "vcvt4Ito4B",
  /*  570 */  "vcvt4Bto4I",
  /*  571 */  "vcvt2Lto2F",
  /*  572 */  "vcvt2Ito2F",
  /*  573 */  "vcvt4Ito4F",
  /*  574 */  "vcvt2Lto2D",
  /*  575 */  "vcvt4Sto4F",
  /*  576 */  "vcvt2Ito2D",
  /*  577 */  "vcvt4Bto4F",
  /*  578 */  "vcvt2Fto2L",
  /*  579 */  "vcvt2Fto2I",
  /*  580 */  "vcvt4Fto4I",
  /*  581 */  "vcvt2Dto2L",
  /*  582 */  "vcvt4Fto4S",
  /*  583 */  "vcvt4Fto4B",
  /*  584 */  "vcvt2Fto2D",
  /*  585 */  "vcvt2Dto2F",
  /*  586 */  "loadmask8B",
  /*  587 */  "loadmask16B",
  /*  588 */  "loadmask4S",
  /*  589 */  "loadmask8S",
  /*  590 */  "loadmask2I",
  /*  591 */  "loadmask4I",
  /*  592 */  "loadmask2L",
  /*  593 */  "vmaskcastD",
  /*  594 */  "vmaskcastX",
  /*  595 */  "loadcon8B",
  /*  596 */  "loadcon16B",
  /*  597 */  "loadshuffle8B",
  /*  598 */  "loadshuffle16B",
  /*  599 */  "loadshuffle4S",
  /*  600 */  "loadshuffle8S",
  /*  601 */  "loadshuffle4I",
  /*  602 */  "vabs8B",
  /*  603 */  "vabs16B",
  /*  604 */  "vabs4S",
  /*  605 */  "vabs8S",
  /*  606 */  "vabs2I",
  /*  607 */  "vabs4I",
  /*  608 */  "vabs2L",
  /*  609 */  "vabs2F",
  /*  610 */  "vabs4F",
  /*  611 */  "vabs2D",
  /*  612 */  "vsqrt2F",
  /*  613 */  "vsqrt4F",
  /*  614 */  "vsqrt2D",
  /*  615 */  "vneg2F",
  /*  616 */  "vneg4F",
  /*  617 */  "vneg2D",
  /*  618 */  "vshiftcnt8B",
  /*  619 */  "vshiftcnt8B_0",
  /*  620 */  "vshiftcnt16B",
  /*  621 */  "vshiftcnt16B_0",
  /*  622 */  "vpopcount4I",
  /*  623 */  "vpopcount2I",
  /*  624 */  "vmask_firsttrue8B",
  /*  625 */  "vmask_firsttrue16B",
  /*  626 */  "vmask_lasttrue8B",
  /*  627 */  "vmask_lasttrue16B",
  /*  628 */  "vmask_tolong8B",
  /*  629 */  "vmask_tolong16B",
  /*  630 */  "reinterpret",
  /*  631 */  "vmask_reinterpret_same_esize",
  /*  632 */  "vabsB",
  /*  633 */  "vabsS",
  /*  634 */  "vabsI",
  /*  635 */  "vabsL",
  /*  636 */  "vabsF",
  /*  637 */  "vabsD",
  /*  638 */  "vnegF",
  /*  639 */  "vnegD",
  /*  640 */  "vpopcountI",
  /*  641 */  "vshiftcntB",
  /*  642 */  "vshiftcntB_0",
  /*  643 */  "vshiftcntS",
  /*  644 */  "vshiftcntS_0",
  /*  645 */  "vshiftcntI",
  /*  646 */  "vshiftcntI_0",
  /*  647 */  "vshiftcntL",
  /*  648 */  "vshiftcntL_0",
  /*  649 */  "vsqrtF",
  /*  650 */  "vsqrtD",
  /*  651 */  "vmaskcast",
  /*  652 */  "vmaskcast_extend",
  /*  653 */  "vmaskcast_narrow",
  /*  654 */  "vcvtBtoX_extend",
  /*  655 */  "vcvtStoX_extend",
  /*  656 */  "vcvtItoL",
  /*  657 */  "vcvtItoF",
  /*  658 */  "vcvtItoD",
  /*  659 */  "vcvtLtoD",
  /*  660 */  "vcvtFtoI",
  /*  661 */  "vcvtFtoL",
  /*  662 */  "vcvtFtoD",
  /*  663 */  "vcvtDtoL",
  /*  664 */  "loadshuffle",
  /*  665 */  "loadconB",
  /*  666 */  "vmask_truecount",
  /*  667 */  "loadB",
  /*  668 */  "loadB2L",
  /*  669 */  "loadUB",
  /*  670 */  "loadUB2L",
  /*  671 */  "loadS",
  /*  672 */  "loadS2L",
  /*  673 */  "loadUS",
  /*  674 */  "loadUS2L",
  /*  675 */  "loadI",
  /*  676 */  "loadI2L",
  /*  677 */  "loadUI2L",
  /*  678 */  "loadL",
  /*  679 */  "loadRange",
  /*  680 */  "loadP",
  /*  681 */  "loadN",
  /*  682 */  "loadKlass",
  /*  683 */  "loadNKlass",
  /*  684 */  "loadF",
  /*  685 */  "loadD",
  /*  686 */  "storeimmCM0",
  /*  687 */  "storeimmCM0_ordered",
  /*  688 */  "storeB",
  /*  689 */  "storeimmB0",
  /*  690 */  "storeC",
  /*  691 */  "storeimmC0",
  /*  692 */  "storeI",
  /*  693 */  "storeimmI0",
  /*  694 */  "storeL",
  /*  695 */  "storeimmL0",
  /*  696 */  "storeP",
  /*  697 */  "storeimmP0",
  /*  698 */  "storeN",
  /*  699 */  "storeImmN0",
  /*  700 */  "storeF",
  /*  701 */  "storeD",
  /*  702 */  "storeNKlass",
  /*  703 */  "prefetchalloc",
  /*  704 */  "loadB_volatile",
  /*  705 */  "loadB2L_volatile",
  /*  706 */  "loadUB_volatile",
  /*  707 */  "loadUB2L_volatile",
  /*  708 */  "loadS_volatile",
  /*  709 */  "loadUS_volatile",
  /*  710 */  "loadUS2L_volatile",
  /*  711 */  "loadS2L_volatile",
  /*  712 */  "loadI_volatile",
  /*  713 */  "loadUI2L_volatile",
  /*  714 */  "loadL_volatile",
  /*  715 */  "loadP_volatile",
  /*  716 */  "loadN_volatile",
  /*  717 */  "loadF_volatile",
  /*  718 */  "loadD_volatile",
  /*  719 */  "storeB_volatile",
  /*  720 */  "storeC_volatile",
  /*  721 */  "storeI_volatile",
  /*  722 */  "storeL_volatile",
  /*  723 */  "storeP_volatile",
  /*  724 */  "storeN_volatile",
  /*  725 */  "storeF_volatile",
  /*  726 */  "storeD_volatile",
  /*  727 */  "cacheWB",
  /*  728 */  "cacheWBPreSync",
  /*  729 */  "cacheWBPostSync",
  /*  730 */  "bytes_reverse_int",
  /*  731 */  "bytes_reverse_long",
  /*  732 */  "bytes_reverse_unsigned_short",
  /*  733 */  "bytes_reverse_short",
  /*  734 */  "popCountI",
  /*  735 */  "popCountI_mem",
  /*  736 */  "popCountL",
  /*  737 */  "popCountL_mem",
  /*  738 */  "load_fence",
  /*  739 */  "unnecessary_membar_acquire",
  /*  740 */  "membar_acquire",
  /*  741 */  "membar_acquire_lock",
  /*  742 */  "store_fence",
  /*  743 */  "unnecessary_membar_release",
  /*  744 */  "membar_release",
  /*  745 */  "membar_storestore",
  /*  746 */  "membar_storestore_0",
  /*  747 */  "membar_release_lock",
  /*  748 */  "unnecessary_membar_volatile",
  /*  749 */  "membar_volatile",
  /*  750 */  "convP2I",
  /*  751 */  "convN2I",
  /*  752 */  "encodeHeapOop",
  /*  753 */  "encodeHeapOop_not_null",
  /*  754 */  "decodeHeapOop",
  /*  755 */  "decodeHeapOop_not_null",
  /*  756 */  "encodeKlass_not_null",
  /*  757 */  "decodeKlass_not_null",
  /*  758 */  "loadPLocked",
  /*  759 */  "compareAndSwapB",
  /*  760 */  "compareAndSwapS",
  /*  761 */  "compareAndSwapI",
  /*  762 */  "compareAndSwapL",
  /*  763 */  "compareAndSwapP",
  /*  764 */  "compareAndSwapN",
  /*  765 */  "compareAndSwapBAcq",
  /*  766 */  "compareAndSwapSAcq",
  /*  767 */  "compareAndSwapIAcq",
  /*  768 */  "compareAndSwapLAcq",
  /*  769 */  "compareAndSwapPAcq",
  /*  770 */  "compareAndSwapNAcq",
  /*  771 */  "compareAndExchangeB",
  /*  772 */  "compareAndExchangeS",
  /*  773 */  "compareAndExchangeI",
  /*  774 */  "compareAndExchangeL",
  /*  775 */  "compareAndExchangeN",
  /*  776 */  "compareAndExchangeP",
  /*  777 */  "compareAndExchangeBAcq",
  /*  778 */  "compareAndExchangeSAcq",
  /*  779 */  "compareAndExchangeIAcq",
  /*  780 */  "compareAndExchangeLAcq",
  /*  781 */  "compareAndExchangeNAcq",
  /*  782 */  "compareAndExchangePAcq",
  /*  783 */  "weakCompareAndSwapB",
  /*  784 */  "weakCompareAndSwapS",
  /*  785 */  "weakCompareAndSwapI",
  /*  786 */  "weakCompareAndSwapL",
  /*  787 */  "weakCompareAndSwapN",
  /*  788 */  "weakCompareAndSwapP",
  /*  789 */  "weakCompareAndSwapBAcq",
  /*  790 */  "weakCompareAndSwapSAcq",
  /*  791 */  "weakCompareAndSwapIAcq",
  /*  792 */  "weakCompareAndSwapLAcq",
  /*  793 */  "weakCompareAndSwapNAcq",
  /*  794 */  "weakCompareAndSwapPAcq",
  /*  795 */  "get_and_setI",
  /*  796 */  "get_and_setL",
  /*  797 */  "get_and_setN",
  /*  798 */  "get_and_setP",
  /*  799 */  "get_and_setIAcq",
  /*  800 */  "get_and_setLAcq",
  /*  801 */  "get_and_setNAcq",
  /*  802 */  "get_and_setPAcq",
  /*  803 */  "get_and_addL",
  /*  804 */  "get_and_addL_no_res",
  /*  805 */  "get_and_addLi",
  /*  806 */  "get_and_addLi_no_res",
  /*  807 */  "get_and_addI",
  /*  808 */  "get_and_addI_no_res",
  /*  809 */  "get_and_addIi",
  /*  810 */  "get_and_addIi_no_res",
  /*  811 */  "get_and_addLAcq",
  /*  812 */  "get_and_addL_no_resAcq",
  /*  813 */  "get_and_addLiAcq",
  /*  814 */  "get_and_addLi_no_resAcq",
  /*  815 */  "get_and_addIAcq",
  /*  816 */  "get_and_addI_no_resAcq",
  /*  817 */  "get_and_addIiAcq",
  /*  818 */  "get_and_addIi_no_resAcq",
  /*  819 */  "cmpL3_reg_reg",
  /*  820 */  "cmpL3_reg_imm",
  /*  821 */  "cmovI_reg_reg",
  /*  822 */  "cmovUI_reg_reg",
  /*  823 */  "cmovI_zero_reg",
  /*  824 */  "cmovUI_zero_reg",
  /*  825 */  "cmovI_reg_zero",
  /*  826 */  "cmovUI_reg_zero",
  /*  827 */  "cmovI_reg_zero_one",
  /*  828 */  "cmovUI_reg_zero_one",
  /*  829 */  "cmovL_reg_reg",
  /*  830 */  "cmovUL_reg_reg",
  /*  831 */  "cmovL_reg_zero",
  /*  832 */  "cmovUL_reg_zero",
  /*  833 */  "cmovL_zero_reg",
  /*  834 */  "cmovUL_zero_reg",
  /*  835 */  "cmovP_reg_reg",
  /*  836 */  "cmovUP_reg_reg",
  /*  837 */  "cmovP_reg_zero",
  /*  838 */  "cmovUP_reg_zero",
  /*  839 */  "cmovP_zero_reg",
  /*  840 */  "cmovUP_zero_reg",
  /*  841 */  "cmovN_reg_reg",
  /*  842 */  "cmovUN_reg_reg",
  /*  843 */  "cmovN_reg_zero",
  /*  844 */  "cmovUN_reg_zero",
  /*  845 */  "cmovN_zero_reg",
  /*  846 */  "cmovUN_zero_reg",
  /*  847 */  "cmovF_reg",
  /*  848 */  "cmovUF_reg",
  /*  849 */  "cmovD_reg",
  /*  850 */  "cmovUD_reg",
  /*  851 */  "addI_reg_reg",
  /*  852 */  "addI_reg_imm",
  /*  853 */  "addI_reg_imm_i2l",
  /*  854 */  "addP_reg_reg",
  /*  855 */  "addP_reg_reg_ext",
  /*  856 */  "addP_reg_reg_lsl",
  /*  857 */  "addP_reg_reg_ext_shift",
  /*  858 */  "lshift_ext",
  /*  859 */  "addP_reg_imm",
  /*  860 */  "addL_reg_reg",
  /*  861 */  "addL_reg_imm",
  /*  862 */  "subI_reg_reg",
  /*  863 */  "subI_reg_imm",
  /*  864 */  "subL_reg_reg",
  /*  865 */  "subL_reg_imm",
  /*  866 */  "negI_reg",
  /*  867 */  "negL_reg",
  /*  868 */  "mulI",
  /*  869 */  "smulI",
  /*  870 */  "smulI_0",
  /*  871 */  "mulL",
  /*  872 */  "mulHiL_rReg",
  /*  873 */  "maddI",
  /*  874 */  "maddI_0",
  /*  875 */  "msubI",
  /*  876 */  "mnegI",
  /*  877 */  "mnegI_0",
  /*  878 */  "maddL",
  /*  879 */  "maddL_0",
  /*  880 */  "msubL",
  /*  881 */  "mnegL",
  /*  882 */  "mnegL_0",
  /*  883 */  "smaddL",
  /*  884 */  "smaddL_1",
  /*  885 */  "smaddL_0",
  /*  886 */  "smaddL_2",
  /*  887 */  "smsubL",
  /*  888 */  "smsubL_0",
  /*  889 */  "smnegL",
  /*  890 */  "smnegL_0",
  /*  891 */  "muladdS2I",
  /*  892 */  "divI",
  /*  893 */  "divL",
  /*  894 */  "modI",
  /*  895 */  "modL",
  /*  896 */  "lShiftI_reg_reg",
  /*  897 */  "lShiftI_reg_imm",
  /*  898 */  "urShiftI_reg_reg",
  /*  899 */  "urShiftI_reg_imm",
  /*  900 */  "rShiftI_reg_reg",
  /*  901 */  "rShiftI_reg_imm",
  /*  902 */  "lShiftL_reg_reg",
  /*  903 */  "lShiftL_reg_imm",
  /*  904 */  "urShiftL_reg_reg",
  /*  905 */  "urShiftL_reg_imm",
  /*  906 */  "urShiftP_reg_imm",
  /*  907 */  "rShiftL_reg_reg",
  /*  908 */  "rShiftL_reg_imm",
  /*  909 */  "regL_not_reg",
  /*  910 */  "regI_not_reg",
  /*  911 */  "AndI_reg_not_reg",
  /*  912 */  "AndI_reg_not_reg_0",
  /*  913 */  "AndL_reg_not_reg",
  /*  914 */  "AndL_reg_not_reg_0",
  /*  915 */  "OrI_reg_not_reg",
  /*  916 */  "OrI_reg_not_reg_0",
  /*  917 */  "OrL_reg_not_reg",
  /*  918 */  "OrL_reg_not_reg_0",
  /*  919 */  "XorI_reg_not_reg",
  /*  920 */  "XorI_reg_not_reg_0",
  /*  921 */  "XorL_reg_not_reg",
  /*  922 */  "XorL_reg_not_reg_0",
  /*  923 */  "AndI_reg_URShift_not_reg",
  /*  924 */  "AndI_reg_URShift_not_reg_0",
  /*  925 */  "AndL_reg_URShift_not_reg",
  /*  926 */  "AndL_reg_URShift_not_reg_0",
  /*  927 */  "AndI_reg_RShift_not_reg",
  /*  928 */  "AndI_reg_RShift_not_reg_0",
  /*  929 */  "AndL_reg_RShift_not_reg",
  /*  930 */  "AndL_reg_RShift_not_reg_0",
  /*  931 */  "AndI_reg_RotateRight_not_reg",
  /*  932 */  "AndI_reg_RotateRight_not_reg_0",
  /*  933 */  "AndL_reg_RotateRight_not_reg",
  /*  934 */  "AndL_reg_RotateRight_not_reg_0",
  /*  935 */  "AndI_reg_LShift_not_reg",
  /*  936 */  "AndI_reg_LShift_not_reg_0",
  /*  937 */  "AndL_reg_LShift_not_reg",
  /*  938 */  "AndL_reg_LShift_not_reg_0",
  /*  939 */  "XorI_reg_URShift_not_reg",
  /*  940 */  "XorI_reg_URShift_not_reg_1",
  /*  941 */  "XorI_reg_URShift_not_reg_0",
  /*  942 */  "XorI_reg_URShift_not_reg_2",
  /*  943 */  "XorL_reg_URShift_not_reg",
  /*  944 */  "XorL_reg_URShift_not_reg_1",
  /*  945 */  "XorL_reg_URShift_not_reg_0",
  /*  946 */  "XorL_reg_URShift_not_reg_2",
  /*  947 */  "XorI_reg_RShift_not_reg",
  /*  948 */  "XorI_reg_RShift_not_reg_1",
  /*  949 */  "XorI_reg_RShift_not_reg_0",
  /*  950 */  "XorI_reg_RShift_not_reg_2",
  /*  951 */  "XorL_reg_RShift_not_reg",
  /*  952 */  "XorL_reg_RShift_not_reg_1",
  /*  953 */  "XorL_reg_RShift_not_reg_0",
  /*  954 */  "XorL_reg_RShift_not_reg_2",
  /*  955 */  "XorI_reg_RotateRight_not_reg",
  /*  956 */  "XorI_reg_RotateRight_not_reg_1",
  /*  957 */  "XorI_reg_RotateRight_not_reg_0",
  /*  958 */  "XorI_reg_RotateRight_not_reg_2",
  /*  959 */  "XorL_reg_RotateRight_not_reg",
  /*  960 */  "XorL_reg_RotateRight_not_reg_1",
  /*  961 */  "XorL_reg_RotateRight_not_reg_0",
  /*  962 */  "XorL_reg_RotateRight_not_reg_2",
  /*  963 */  "XorI_reg_LShift_not_reg",
  /*  964 */  "XorI_reg_LShift_not_reg_1",
  /*  965 */  "XorI_reg_LShift_not_reg_0",
  /*  966 */  "XorI_reg_LShift_not_reg_2",
  /*  967 */  "XorL_reg_LShift_not_reg",
  /*  968 */  "XorL_reg_LShift_not_reg_1",
  /*  969 */  "XorL_reg_LShift_not_reg_0",
  /*  970 */  "XorL_reg_LShift_not_reg_2",
  /*  971 */  "OrI_reg_URShift_not_reg",
  /*  972 */  "OrI_reg_URShift_not_reg_0",
  /*  973 */  "OrL_reg_URShift_not_reg",
  /*  974 */  "OrL_reg_URShift_not_reg_0",
  /*  975 */  "OrI_reg_RShift_not_reg",
  /*  976 */  "OrI_reg_RShift_not_reg_0",
  /*  977 */  "OrL_reg_RShift_not_reg",
  /*  978 */  "OrL_reg_RShift_not_reg_0",
  /*  979 */  "OrI_reg_RotateRight_not_reg",
  /*  980 */  "OrI_reg_RotateRight_not_reg_0",
  /*  981 */  "OrL_reg_RotateRight_not_reg",
  /*  982 */  "OrL_reg_RotateRight_not_reg_0",
  /*  983 */  "OrI_reg_LShift_not_reg",
  /*  984 */  "OrI_reg_LShift_not_reg_0",
  /*  985 */  "OrL_reg_LShift_not_reg",
  /*  986 */  "OrL_reg_LShift_not_reg_0",
  /*  987 */  "AndI_reg_URShift_reg",
  /*  988 */  "AndI_reg_URShift_reg_0",
  /*  989 */  "AndL_reg_URShift_reg",
  /*  990 */  "AndL_reg_URShift_reg_0",
  /*  991 */  "AndI_reg_RShift_reg",
  /*  992 */  "AndI_reg_RShift_reg_0",
  /*  993 */  "AndL_reg_RShift_reg",
  /*  994 */  "AndL_reg_RShift_reg_0",
  /*  995 */  "AndI_reg_LShift_reg",
  /*  996 */  "AndI_reg_LShift_reg_0",
  /*  997 */  "AndL_reg_LShift_reg",
  /*  998 */  "AndL_reg_LShift_reg_0",
  /*  999 */  "AndI_reg_RotateRight_reg",
  /* 1000 */  "AndI_reg_RotateRight_reg_0",
  /* 1001 */  "AndL_reg_RotateRight_reg",
  /* 1002 */  "AndL_reg_RotateRight_reg_0",
  /* 1003 */  "XorI_reg_URShift_reg",
  /* 1004 */  "XorI_reg_URShift_reg_0",
  /* 1005 */  "XorL_reg_URShift_reg",
  /* 1006 */  "XorL_reg_URShift_reg_0",
  /* 1007 */  "XorI_reg_RShift_reg",
  /* 1008 */  "XorI_reg_RShift_reg_0",
  /* 1009 */  "XorL_reg_RShift_reg",
  /* 1010 */  "XorL_reg_RShift_reg_0",
  /* 1011 */  "XorI_reg_LShift_reg",
  /* 1012 */  "XorI_reg_LShift_reg_0",
  /* 1013 */  "XorL_reg_LShift_reg",
  /* 1014 */  "XorL_reg_LShift_reg_0",
  /* 1015 */  "XorI_reg_RotateRight_reg",
  /* 1016 */  "XorI_reg_RotateRight_reg_0",
  /* 1017 */  "XorL_reg_RotateRight_reg",
  /* 1018 */  "XorL_reg_RotateRight_reg_0",
  /* 1019 */  "OrI_reg_URShift_reg",
  /* 1020 */  "OrI_reg_URShift_reg_0",
  /* 1021 */  "OrL_reg_URShift_reg",
  /* 1022 */  "OrL_reg_URShift_reg_0",
  /* 1023 */  "OrI_reg_RShift_reg",
  /* 1024 */  "OrI_reg_RShift_reg_0",
  /* 1025 */  "OrL_reg_RShift_reg",
  /* 1026 */  "OrL_reg_RShift_reg_0",
  /* 1027 */  "OrI_reg_LShift_reg",
  /* 1028 */  "OrI_reg_LShift_reg_0",
  /* 1029 */  "OrL_reg_LShift_reg",
  /* 1030 */  "OrL_reg_LShift_reg_0",
  /* 1031 */  "OrI_reg_RotateRight_reg",
  /* 1032 */  "OrI_reg_RotateRight_reg_0",
  /* 1033 */  "OrL_reg_RotateRight_reg",
  /* 1034 */  "OrL_reg_RotateRight_reg_0",
  /* 1035 */  "AddI_reg_URShift_reg",
  /* 1036 */  "AddI_reg_URShift_reg_0",
  /* 1037 */  "AddL_reg_URShift_reg",
  /* 1038 */  "AddL_reg_URShift_reg_0",
  /* 1039 */  "AddI_reg_RShift_reg",
  /* 1040 */  "AddI_reg_RShift_reg_0",
  /* 1041 */  "AddL_reg_RShift_reg",
  /* 1042 */  "AddL_reg_RShift_reg_0",
  /* 1043 */  "AddI_reg_LShift_reg",
  /* 1044 */  "AddI_reg_LShift_reg_0",
  /* 1045 */  "AddL_reg_LShift_reg",
  /* 1046 */  "AddL_reg_LShift_reg_0",
  /* 1047 */  "SubI_reg_URShift_reg",
  /* 1048 */  "SubL_reg_URShift_reg",
  /* 1049 */  "SubI_reg_RShift_reg",
  /* 1050 */  "SubL_reg_RShift_reg",
  /* 1051 */  "SubI_reg_LShift_reg",
  /* 1052 */  "SubL_reg_LShift_reg",
  /* 1053 */  "sbfmL",
  /* 1054 */  "sbfmwI",
  /* 1055 */  "ubfmL",
  /* 1056 */  "ubfmwI",
  /* 1057 */  "ubfxwI",
  /* 1058 */  "ubfxL",
  /* 1059 */  "ubfxIConvI2L",
  /* 1060 */  "ubfizwI",
  /* 1061 */  "ubfizL",
  /* 1062 */  "ubfizwIConvI2L",
  /* 1063 */  "ubfizLConvL2I",
  /* 1064 */  "ubfizIConvI2L",
  /* 1065 */  "ubfizLConvL2Ix",
  /* 1066 */  "ubfizIConvI2LAndI",
  /* 1067 */  "extrOrL",
  /* 1068 */  "extrOrL_0",
  /* 1069 */  "extrOrI",
  /* 1070 */  "extrOrI_0",
  /* 1071 */  "extrAddL",
  /* 1072 */  "extrAddL_0",
  /* 1073 */  "extrAddI",
  /* 1074 */  "extrAddI_0",
  /* 1075 */  "rorI_imm",
  /* 1076 */  "rorL_imm",
  /* 1077 */  "rorI_reg",
  /* 1078 */  "rorL_reg",
  /* 1079 */  "rolI_reg",
  /* 1080 */  "rolL_reg",
  /* 1081 */  "AddExtI",
  /* 1082 */  "AddExtI_0",
  /* 1083 */  "SubExtI",
  /* 1084 */  "AddExtI_sxth",
  /* 1085 */  "AddExtI_sxth_0",
  /* 1086 */  "AddExtI_sxtb",
  /* 1087 */  "AddExtI_sxtb_0",
  /* 1088 */  "AddExtI_uxtb",
  /* 1089 */  "AddExtI_uxtb_0",
  /* 1090 */  "AddExtL_sxth",
  /* 1091 */  "AddExtL_sxth_0",
  /* 1092 */  "AddExtL_sxtw",
  /* 1093 */  "AddExtL_sxtw_0",
  /* 1094 */  "AddExtL_sxtb",
  /* 1095 */  "AddExtL_sxtb_0",
  /* 1096 */  "AddExtL_uxtb",
  /* 1097 */  "AddExtL_uxtb_0",
  /* 1098 */  "AddExtI_uxtb_and",
  /* 1099 */  "AddExtI_uxtb_and_0",
  /* 1100 */  "AddExtI_uxth_and",
  /* 1101 */  "AddExtI_uxth_and_0",
  /* 1102 */  "AddExtL_uxtb_and",
  /* 1103 */  "AddExtL_uxtb_and_0",
  /* 1104 */  "AddExtL_uxth_and",
  /* 1105 */  "AddExtL_uxth_and_0",
  /* 1106 */  "AddExtL_uxtw_and",
  /* 1107 */  "AddExtL_uxtw_and_0",
  /* 1108 */  "SubExtI_uxtb_and",
  /* 1109 */  "SubExtI_uxth_and",
  /* 1110 */  "SubExtL_uxtb_and",
  /* 1111 */  "SubExtL_uxth_and",
  /* 1112 */  "SubExtL_uxtw_and",
  /* 1113 */  "AddExtL_sxtb_shift",
  /* 1114 */  "AddExtL_sxtb_shift_0",
  /* 1115 */  "AddExtL_sxth_shift",
  /* 1116 */  "AddExtL_sxth_shift_0",
  /* 1117 */  "AddExtL_sxtw_shift",
  /* 1118 */  "AddExtL_sxtw_shift_0",
  /* 1119 */  "SubExtL_sxtb_shift",
  /* 1120 */  "SubExtL_sxth_shift",
  /* 1121 */  "SubExtL_sxtw_shift",
  /* 1122 */  "AddExtI_sxtb_shift",
  /* 1123 */  "AddExtI_sxtb_shift_0",
  /* 1124 */  "AddExtI_sxth_shift",
  /* 1125 */  "AddExtI_sxth_shift_0",
  /* 1126 */  "SubExtI_sxtb_shift",
  /* 1127 */  "SubExtI_sxth_shift",
  /* 1128 */  "AddExtI_shift",
  /* 1129 */  "AddExtI_shift_0",
  /* 1130 */  "SubExtI_shift",
  /* 1131 */  "AddExtL_uxtb_and_shift",
  /* 1132 */  "AddExtL_uxtb_and_shift_0",
  /* 1133 */  "AddExtL_uxth_and_shift",
  /* 1134 */  "AddExtL_uxth_and_shift_0",
  /* 1135 */  "AddExtL_uxtw_and_shift",
  /* 1136 */  "AddExtL_uxtw_and_shift_0",
  /* 1137 */  "SubExtL_uxtb_and_shift",
  /* 1138 */  "SubExtL_uxth_and_shift",
  /* 1139 */  "SubExtL_uxtw_and_shift",
  /* 1140 */  "AddExtI_uxtb_and_shift",
  /* 1141 */  "AddExtI_uxtb_and_shift_0",
  /* 1142 */  "AddExtI_uxth_and_shift",
  /* 1143 */  "AddExtI_uxth_and_shift_0",
  /* 1144 */  "SubExtI_uxtb_and_shift",
  /* 1145 */  "SubExtI_uxth_and_shift",
  /* 1146 */  "addF_reg_reg",
  /* 1147 */  "addD_reg_reg",
  /* 1148 */  "subF_reg_reg",
  /* 1149 */  "subD_reg_reg",
  /* 1150 */  "mulF_reg_reg",
  /* 1151 */  "mulD_reg_reg",
  /* 1152 */  "maddF_reg_reg",
  /* 1153 */  "maddD_reg_reg",
  /* 1154 */  "msubF_reg_reg",
  /* 1155 */  "msubF_reg_reg_0",
  /* 1156 */  "msubD_reg_reg",
  /* 1157 */  "msubD_reg_reg_0",
  /* 1158 */  "mnaddF_reg_reg",
  /* 1159 */  "mnaddF_reg_reg_0",
  /* 1160 */  "mnaddD_reg_reg",
  /* 1161 */  "mnaddD_reg_reg_0",
  /* 1162 */  "mnsubF_reg_reg",
  /* 1163 */  "mnsubD_reg_reg",
  /* 1164 */  "maxF_reg_reg",
  /* 1165 */  "minF_reg_reg",
  /* 1166 */  "maxD_reg_reg",
  /* 1167 */  "minD_reg_reg",
  /* 1168 */  "divF_reg_reg",
  /* 1169 */  "divD_reg_reg",
  /* 1170 */  "absI_reg",
  /* 1171 */  "absL_reg",
  /* 1172 */  "absdF_reg",
  /* 1173 */  "absdD_reg",
  /* 1174 */  "sqrtD_reg",
  /* 1175 */  "sqrtF_reg",
  /* 1176 */  "roundD_reg",
  /* 1177 */  "copySignD_reg",
  /* 1178 */  "copySignF_reg",
  /* 1179 */  "signumD_reg",
  /* 1180 */  "signumF_reg",
  /* 1181 */  "onspinwait",
  /* 1182 */  "andI_reg_reg",
  /* 1183 */  "andI_reg_imm",
  /* 1184 */  "orI_reg_reg",
  /* 1185 */  "orI_reg_imm",
  /* 1186 */  "xorI_reg_reg",
  /* 1187 */  "xorI_reg_imm",
  /* 1188 */  "andL_reg_reg",
  /* 1189 */  "andL_reg_imm",
  /* 1190 */  "orL_reg_reg",
  /* 1191 */  "orL_reg_imm",
  /* 1192 */  "xorL_reg_reg",
  /* 1193 */  "xorL_reg_imm",
  /* 1194 */  "convI2L_reg_reg",
  /* 1195 */  "convUI2L_reg_reg",
  /* 1196 */  "convL2I_reg",
  /* 1197 */  "convI2B",
  /* 1198 */  "convP2B",
  /* 1199 */  "convD2F_reg",
  /* 1200 */  "convF2D_reg",
  /* 1201 */  "convF2I_reg_reg",
  /* 1202 */  "convF2L_reg_reg",
  /* 1203 */  "convI2F_reg_reg",
  /* 1204 */  "convL2F_reg_reg",
  /* 1205 */  "convD2I_reg_reg",
  /* 1206 */  "convD2L_reg_reg",
  /* 1207 */  "convI2D_reg_reg",
  /* 1208 */  "convL2D_reg_reg",
  /* 1209 */  "MoveF2I_reg_stack",
  /* 1210 */  "MoveI2F_reg_stack",
  /* 1211 */  "MoveD2L_reg_stack",
  /* 1212 */  "MoveL2D_reg_stack",
  /* 1213 */  "clearArray_reg_reg",
  /* 1214 */  "clearArray_imm_reg",
  /* 1215 */  "overflowMulI_reg_branch",
  /* 1216 */  "overflowMulL_reg_branch",
  /* 1217 */  "compF3_reg_reg",
  /* 1218 */  "compD3_reg_reg",
  /* 1219 */  "compF3_reg_immF0",
  /* 1220 */  "compD3_reg_immD0",
  /* 1221 */  "cmpLTMask_reg_reg",
  /* 1222 */  "cmpLTMask_reg_zero",
  /* 1223 */  "cmovI_reg_reg_lt",
  /* 1224 */  "minI_rReg",
  /* 1225 */  "cmovI_reg_reg_gt",
  /* 1226 */  "maxI_rReg",
  /* 1227 */  "branch",
  /* 1228 */  "branchCon",
  /* 1229 */  "branchConU",
  /* 1230 */  "cmpI_imm0_branch",
  /* 1231 */  "cmpL_imm0_branch",
  /* 1232 */  "cmpP_imm0_branch",
  /* 1233 */  "cmpN_imm0_branch",
  /* 1234 */  "cmpP_narrowOop_imm0_branch",
  /* 1235 */  "cmpUI_imm0_branch",
  /* 1236 */  "cmpUL_imm0_branch",
  /* 1237 */  "cmpL_branch_sign",
  /* 1238 */  "cmpI_branch_sign",
  /* 1239 */  "cmpL_branch_bit",
  /* 1240 */  "cmpI_branch_bit",
  /* 1241 */  "far_cmpL_branch_sign",
  /* 1242 */  "far_cmpI_branch_sign",
  /* 1243 */  "far_cmpL_branch_bit",
  /* 1244 */  "far_cmpI_branch_bit",
  /* 1245 */  "branchLoopEnd",
  /* 1246 */  "branchLoopEndU",
  /* 1247 */  "safePoint",
  /* 1248 */  "CallStaticJavaDirect",
  /* 1249 */  "CallDynamicJavaDirect",
  /* 1250 */  "CallRuntimeDirect",
  /* 1251 */  "CallLeafDirect",
  /* 1252 */  "CallLeafNoFPDirect",
  /* 1253 */  "CallNativeDirect",
  /* 1254 */  "TailCalljmpInd",
  /* 1255 */  "TailjmpInd",
  /* 1256 */  "CreateException",
  /* 1257 */  "RethrowException",
  /* 1258 */  "Ret",
  /* 1259 */  "ShouldNotReachHere",
  /* 1260 */  "partialSubtypeCheck",
  /* 1261 */  "string_compareU",
  /* 1262 */  "string_compareL",
  /* 1263 */  "string_compareUL",
  /* 1264 */  "string_compareLU",
  /* 1265 */  "string_indexofUU",
  /* 1266 */  "string_indexofLL",
  /* 1267 */  "string_indexofUL",
  /* 1268 */  "string_indexof_conUU",
  /* 1269 */  "string_indexof_conLL",
  /* 1270 */  "string_indexof_conUL",
  /* 1271 */  "string_indexof_char",
  /* 1272 */  "stringL_indexof_char",
  /* 1273 */  "string_equalsL",
  /* 1274 */  "string_equalsU",
  /* 1275 */  "array_equalsB",
  /* 1276 */  "array_equalsC",
  /* 1277 */  "has_negatives",
  /* 1278 */  "string_compress",
  /* 1279 */  "string_inflate",
  /* 1280 */  "encode_iso_array",
  /* 1281 */  "loadV2",
  /* 1282 */  "loadV4",
  /* 1283 */  "loadV8",
  /* 1284 */  "loadV16",
  /* 1285 */  "storeV2",
  /* 1286 */  "storeV4",
  /* 1287 */  "storeV8",
  /* 1288 */  "storeV16",
  /* 1289 */  "vcvt2Dto2I",
  /* 1290 */  "reduce_add8B",
  /* 1291 */  "reduce_add16B",
  /* 1292 */  "reduce_add4S",
  /* 1293 */  "reduce_add8S",
  /* 1294 */  "reduce_add2L",
  /* 1295 */  "reduce_mul8B",
  /* 1296 */  "reduce_mul16B",
  /* 1297 */  "reduce_mul4S",
  /* 1298 */  "reduce_mul8S",
  /* 1299 */  "reduce_mul2L",
  /* 1300 */  "reduce_max8B",
  /* 1301 */  "reduce_max16B",
  /* 1302 */  "reduce_max4S",
  /* 1303 */  "reduce_max8S",
  /* 1304 */  "reduce_max4I",
  /* 1305 */  "reduce_min8B",
  /* 1306 */  "reduce_min16B",
  /* 1307 */  "reduce_min4S",
  /* 1308 */  "reduce_min8S",
  /* 1309 */  "reduce_min4I",
  /* 1310 */  "reduce_max2I",
  /* 1311 */  "reduce_min2I",
  /* 1312 */  "reduce_max2L",
  /* 1313 */  "reduce_min2L",
  /* 1314 */  "reduce_max2F",
  /* 1315 */  "reduce_max4F",
  /* 1316 */  "reduce_max2D",
  /* 1317 */  "reduce_min2F",
  /* 1318 */  "reduce_min4F",
  /* 1319 */  "reduce_min2D",
  /* 1320 */  "reduce_and8B",
  /* 1321 */  "reduce_orr8B",
  /* 1322 */  "reduce_eor8B",
  /* 1323 */  "reduce_and16B",
  /* 1324 */  "reduce_orr16B",
  /* 1325 */  "reduce_eor16B",
  /* 1326 */  "reduce_and4S",
  /* 1327 */  "reduce_orr4S",
  /* 1328 */  "reduce_eor4S",
  /* 1329 */  "reduce_and8S",
  /* 1330 */  "reduce_orr8S",
  /* 1331 */  "reduce_eor8S",
  /* 1332 */  "reduce_and2I",
  /* 1333 */  "reduce_orr2I",
  /* 1334 */  "reduce_eor2I",
  /* 1335 */  "reduce_and4I",
  /* 1336 */  "reduce_orr4I",
  /* 1337 */  "reduce_eor4I",
  /* 1338 */  "reduce_and2L",
  /* 1339 */  "reduce_orr2L",
  /* 1340 */  "reduce_eor2L",
  /* 1341 */  "insert8B",
  /* 1342 */  "insert16B",
  /* 1343 */  "insert4S",
  /* 1344 */  "insert8S",
  /* 1345 */  "insert2I",
  /* 1346 */  "insert4I",
  /* 1347 */  "insert2L",
  /* 1348 */  "insert2F",
  /* 1349 */  "insert4F",
  /* 1350 */  "insert2D",
  /* 1351 */  "extract8B",
  /* 1352 */  "extract16B",
  /* 1353 */  "extract4S",
  /* 1354 */  "extract8S",
  /* 1355 */  "extract2I",
  /* 1356 */  "extract4I",
  /* 1357 */  "extract2L",
  /* 1358 */  "extract2F",
  /* 1359 */  "extract4F",
  /* 1360 */  "extract2D",
  /* 1361 */  "vcmpD",
  /* 1362 */  "vcmpX",
  /* 1363 */  "vmul2L",
  /* 1364 */  "vnot2I",
  /* 1365 */  "vnot2I_0",
  /* 1366 */  "vnot2I_1",
  /* 1367 */  "vnot2I_2",
  /* 1368 */  "vnot2I_3",
  /* 1369 */  "vnot2I_4",
  /* 1370 */  "vnot4I",
  /* 1371 */  "vnot4I_0",
  /* 1372 */  "vnot4I_1",
  /* 1373 */  "vnot4I_2",
  /* 1374 */  "vnot4I_3",
  /* 1375 */  "vnot4I_4",
  /* 1376 */  "vnot2L",
  /* 1377 */  "vnot2L_0",
  /* 1378 */  "vand_not2I",
  /* 1379 */  "vand_not2I_1",
  /* 1380 */  "vand_not2I_0",
  /* 1381 */  "vand_not2I_2",
  /* 1382 */  "vand_not2I_3",
  /* 1383 */  "vand_not2I_5",
  /* 1384 */  "vand_not2I_4",
  /* 1385 */  "vand_not2I_6",
  /* 1386 */  "vand_not2I_7",
  /* 1387 */  "vand_not2I_9",
  /* 1388 */  "vand_not2I_8",
  /* 1389 */  "vand_not2I_10",
  /* 1390 */  "vand_not4I",
  /* 1391 */  "vand_not4I_1",
  /* 1392 */  "vand_not4I_0",
  /* 1393 */  "vand_not4I_2",
  /* 1394 */  "vand_not4I_3",
  /* 1395 */  "vand_not4I_5",
  /* 1396 */  "vand_not4I_4",
  /* 1397 */  "vand_not4I_6",
  /* 1398 */  "vand_not4I_7",
  /* 1399 */  "vand_not4I_9",
  /* 1400 */  "vand_not4I_8",
  /* 1401 */  "vand_not4I_10",
  /* 1402 */  "vand_not2L",
  /* 1403 */  "vand_not2L_1",
  /* 1404 */  "vand_not2L_0",
  /* 1405 */  "vand_not2L_2",
  /* 1406 */  "vmax8B",
  /* 1407 */  "vmax16B",
  /* 1408 */  "vmax4S",
  /* 1409 */  "vmax8S",
  /* 1410 */  "vmax2I",
  /* 1411 */  "vmax4I",
  /* 1412 */  "vmin8B",
  /* 1413 */  "vmin16B",
  /* 1414 */  "vmin4S",
  /* 1415 */  "vmin8S",
  /* 1416 */  "vmin2I",
  /* 1417 */  "vmin4I",
  /* 1418 */  "vmax2L",
  /* 1419 */  "vmin2L",
  /* 1420 */  "vbsl8B",
  /* 1421 */  "vbsl16B",
  /* 1422 */  "storemask8B",
  /* 1423 */  "storemask16B",
  /* 1424 */  "storemask4S",
  /* 1425 */  "storemask8S",
  /* 1426 */  "storemask2I",
  /* 1427 */  "storemask4I",
  /* 1428 */  "storemask2L",
  /* 1429 */  "rearrange8B",
  /* 1430 */  "rearrange16B",
  /* 1431 */  "rearrange4S",
  /* 1432 */  "rearrange8S",
  /* 1433 */  "rearrange4I",
  /* 1434 */  "anytrue_in_mask8B",
  /* 1435 */  "anytrue_in_mask16B",
  /* 1436 */  "alltrue_in_mask8B",
  /* 1437 */  "alltrue_in_mask16B",
  /* 1438 */  "vabd2F",
  /* 1439 */  "vabd4F",
  /* 1440 */  "vabd2D",
  /* 1441 */  "replicate8B",
  /* 1442 */  "replicate16B",
  /* 1443 */  "replicate8B_imm",
  /* 1444 */  "replicate16B_imm",
  /* 1445 */  "replicate4S",
  /* 1446 */  "replicate8S",
  /* 1447 */  "replicate4S_imm",
  /* 1448 */  "replicate8S_imm",
  /* 1449 */  "replicate2I",
  /* 1450 */  "replicate4I",
  /* 1451 */  "replicate2I_imm",
  /* 1452 */  "replicate4I_imm",
  /* 1453 */  "replicate2L",
  /* 1454 */  "replicate2L_zero",
  /* 1455 */  "replicate2F",
  /* 1456 */  "replicate4F",
  /* 1457 */  "replicate2D",
  /* 1458 */  "reduce_add2I",
  /* 1459 */  "reduce_add4I",
  /* 1460 */  "reduce_mul2I",
  /* 1461 */  "reduce_mul4I",
  /* 1462 */  "reduce_add2F",
  /* 1463 */  "reduce_add4F",
  /* 1464 */  "reduce_mul2F",
  /* 1465 */  "reduce_mul4F",
  /* 1466 */  "reduce_add2D",
  /* 1467 */  "reduce_mul2D",
  /* 1468 */  "vadd8B",
  /* 1469 */  "vadd16B",
  /* 1470 */  "vadd4S",
  /* 1471 */  "vadd8S",
  /* 1472 */  "vadd2I",
  /* 1473 */  "vadd4I",
  /* 1474 */  "vadd2L",
  /* 1475 */  "vadd2F",
  /* 1476 */  "vadd4F",
  /* 1477 */  "vadd2D",
  /* 1478 */  "vsub8B",
  /* 1479 */  "vsub16B",
  /* 1480 */  "vsub4S",
  /* 1481 */  "vsub8S",
  /* 1482 */  "vsub2I",
  /* 1483 */  "vsub4I",
  /* 1484 */  "vsub2L",
  /* 1485 */  "vsub2F",
  /* 1486 */  "vsub4F",
  /* 1487 */  "vsub2D",
  /* 1488 */  "vmul8B",
  /* 1489 */  "vmul16B",
  /* 1490 */  "vmul4S",
  /* 1491 */  "vmul8S",
  /* 1492 */  "vmul2I",
  /* 1493 */  "vmul4I",
  /* 1494 */  "vmul2F",
  /* 1495 */  "vmul4F",
  /* 1496 */  "vmul2D",
  /* 1497 */  "vmla4S",
  /* 1498 */  "vmla4S_0",
  /* 1499 */  "vmla8S",
  /* 1500 */  "vmla8S_0",
  /* 1501 */  "vmla2I",
  /* 1502 */  "vmla2I_0",
  /* 1503 */  "vmla4I",
  /* 1504 */  "vmla4I_0",
  /* 1505 */  "vmla2F",
  /* 1506 */  "vmla4F",
  /* 1507 */  "vmla2D",
  /* 1508 */  "vmls4S",
  /* 1509 */  "vmls8S",
  /* 1510 */  "vmls2I",
  /* 1511 */  "vmls4I",
  /* 1512 */  "vmls2F",
  /* 1513 */  "vmls2F_0",
  /* 1514 */  "vmls4F",
  /* 1515 */  "vmls4F_0",
  /* 1516 */  "vmls2D",
  /* 1517 */  "vmls2D_0",
  /* 1518 */  "vmuladdS2I",
  /* 1519 */  "vdiv2F",
  /* 1520 */  "vdiv4F",
  /* 1521 */  "vdiv2D",
  /* 1522 */  "vand8B",
  /* 1523 */  "vand16B",
  /* 1524 */  "vor8B",
  /* 1525 */  "vor16B",
  /* 1526 */  "vxor8B",
  /* 1527 */  "vxor16B",
  /* 1528 */  "vsll8B",
  /* 1529 */  "vsll16B",
  /* 1530 */  "vsra8B",
  /* 1531 */  "vsra16B",
  /* 1532 */  "vsrl8B",
  /* 1533 */  "vsrl16B",
  /* 1534 */  "vsll8B_imm",
  /* 1535 */  "vsll16B_imm",
  /* 1536 */  "vsra8B_imm",
  /* 1537 */  "vsra16B_imm",
  /* 1538 */  "vsrl8B_imm",
  /* 1539 */  "vsrl16B_imm",
  /* 1540 */  "vsll4S",
  /* 1541 */  "vsll8S",
  /* 1542 */  "vsra4S",
  /* 1543 */  "vsra8S",
  /* 1544 */  "vsrl4S",
  /* 1545 */  "vsrl8S",
  /* 1546 */  "vsll4S_imm",
  /* 1547 */  "vsll8S_imm",
  /* 1548 */  "vsra4S_imm",
  /* 1549 */  "vsra8S_imm",
  /* 1550 */  "vsrl4S_imm",
  /* 1551 */  "vsrl8S_imm",
  /* 1552 */  "vsll2I",
  /* 1553 */  "vsll4I",
  /* 1554 */  "vsra2I",
  /* 1555 */  "vsra4I",
  /* 1556 */  "vsrl2I",
  /* 1557 */  "vsrl4I",
  /* 1558 */  "vsll2I_imm",
  /* 1559 */  "vsll4I_imm",
  /* 1560 */  "vsra2I_imm",
  /* 1561 */  "vsra4I_imm",
  /* 1562 */  "vsrl2I_imm",
  /* 1563 */  "vsrl4I_imm",
  /* 1564 */  "vsll2L",
  /* 1565 */  "vsra2L",
  /* 1566 */  "vsrl2L",
  /* 1567 */  "vsll2L_imm",
  /* 1568 */  "vsra2L_imm",
  /* 1569 */  "vsrl2L_imm",
  /* 1570 */  "vsraa8B_imm",
  /* 1571 */  "vsraa8B_imm_0",
  /* 1572 */  "vsraa16B_imm",
  /* 1573 */  "vsraa16B_imm_0",
  /* 1574 */  "vsraa4S_imm",
  /* 1575 */  "vsraa4S_imm_0",
  /* 1576 */  "vsraa8S_imm",
  /* 1577 */  "vsraa8S_imm_0",
  /* 1578 */  "vsraa2I_imm",
  /* 1579 */  "vsraa2I_imm_0",
  /* 1580 */  "vsraa4I_imm",
  /* 1581 */  "vsraa4I_imm_0",
  /* 1582 */  "vsraa2L_imm",
  /* 1583 */  "vsraa2L_imm_0",
  /* 1584 */  "vsrla8B_imm",
  /* 1585 */  "vsrla8B_imm_0",
  /* 1586 */  "vsrla16B_imm",
  /* 1587 */  "vsrla16B_imm_0",
  /* 1588 */  "vsrla4S_imm",
  /* 1589 */  "vsrla4S_imm_0",
  /* 1590 */  "vsrla8S_imm",
  /* 1591 */  "vsrla8S_imm_0",
  /* 1592 */  "vsrla2I_imm",
  /* 1593 */  "vsrla2I_imm_0",
  /* 1594 */  "vsrla4I_imm",
  /* 1595 */  "vsrla4I_imm_0",
  /* 1596 */  "vsrla2L_imm",
  /* 1597 */  "vsrla2L_imm_0",
  /* 1598 */  "vmax2F",
  /* 1599 */  "vmax4F",
  /* 1600 */  "vmax2D",
  /* 1601 */  "vmin2F",
  /* 1602 */  "vmin4F",
  /* 1603 */  "vmin2D",
  /* 1604 */  "vround2D_reg",
  /* 1605 */  "vmask_truecount8B",
  /* 1606 */  "vmask_truecount16B",
  /* 1607 */  "vmask_firsttrue_LT8B",
  /* 1608 */  "loadV",
  /* 1609 */  "storeV",
  /* 1610 */  "loadV2_vreg",
  /* 1611 */  "storeV2_vreg",
  /* 1612 */  "loadV4_vreg",
  /* 1613 */  "storeV4_vreg",
  /* 1614 */  "loadV8_vreg",
  /* 1615 */  "storeV8_vreg",
  /* 1616 */  "loadV16_vreg",
  /* 1617 */  "storeV16_vreg",
  /* 1618 */  "loadV_partial",
  /* 1619 */  "storeV_partial",
  /* 1620 */  "loadV_masked",
  /* 1621 */  "loadV_masked_partial",
  /* 1622 */  "storeV_masked",
  /* 1623 */  "storeV_masked_partial",
  /* 1624 */  "vmaskAll_immI",
  /* 1625 */  "vmaskAllI",
  /* 1626 */  "vmaskAll_immL",
  /* 1627 */  "vmaskAllL",
  /* 1628 */  "vmask_and",
  /* 1629 */  "vmask_or",
  /* 1630 */  "vmask_xor",
  /* 1631 */  "vmask_and_notI",
  /* 1632 */  "vmask_and_notL",
  /* 1633 */  "reinterpretResize",
  /* 1634 */  "vmask_reinterpret_diff_esize",
  /* 1635 */  "vabsB_masked",
  /* 1636 */  "vabsS_masked",
  /* 1637 */  "vabsI_masked",
  /* 1638 */  "vabsL_masked",
  /* 1639 */  "vabsF_masked",
  /* 1640 */  "vabsD_masked",
  /* 1641 */  "vaddB",
  /* 1642 */  "vaddS",
  /* 1643 */  "vaddI",
  /* 1644 */  "vaddL",
  /* 1645 */  "vaddF",
  /* 1646 */  "vaddD",
  /* 1647 */  "vaddB_masked",
  /* 1648 */  "vaddS_masked",
  /* 1649 */  "vaddI_masked",
  /* 1650 */  "vaddL_masked",
  /* 1651 */  "vaddF_masked",
  /* 1652 */  "vaddD_masked",
  /* 1653 */  "vaddImmB",
  /* 1654 */  "vaddImmB_0",
  /* 1655 */  "vaddImmS",
  /* 1656 */  "vaddImmS_0",
  /* 1657 */  "vaddImmI",
  /* 1658 */  "vaddImmI_0",
  /* 1659 */  "vaddImmL",
  /* 1660 */  "vaddImmL_0",
  /* 1661 */  "vandB",
  /* 1662 */  "vandB_0",
  /* 1663 */  "vandH",
  /* 1664 */  "vandH_0",
  /* 1665 */  "vandS",
  /* 1666 */  "vandS_0",
  /* 1667 */  "vandD",
  /* 1668 */  "vandD_0",
  /* 1669 */  "vorB",
  /* 1670 */  "vorB_0",
  /* 1671 */  "vorH",
  /* 1672 */  "vorH_0",
  /* 1673 */  "vorS",
  /* 1674 */  "vorS_0",
  /* 1675 */  "vorD",
  /* 1676 */  "vorD_0",
  /* 1677 */  "vxorB",
  /* 1678 */  "vxorB_0",
  /* 1679 */  "vxorH",
  /* 1680 */  "vxorH_0",
  /* 1681 */  "vxorS",
  /* 1682 */  "vxorS_0",
  /* 1683 */  "vxorD",
  /* 1684 */  "vxorD_0",
  /* 1685 */  "vand",
  /* 1686 */  "vor",
  /* 1687 */  "vxor",
  /* 1688 */  "vand_masked",
  /* 1689 */  "vor_masked",
  /* 1690 */  "vxor_masked",
  /* 1691 */  "vnotI",
  /* 1692 */  "vnotI_0",
  /* 1693 */  "vnotI_1",
  /* 1694 */  "vnotI_2",
  /* 1695 */  "vnotI_3",
  /* 1696 */  "vnotI_4",
  /* 1697 */  "vnotL",
  /* 1698 */  "vnotL_0",
  /* 1699 */  "vand_notI",
  /* 1700 */  "vand_notI_1",
  /* 1701 */  "vand_notI_0",
  /* 1702 */  "vand_notI_2",
  /* 1703 */  "vand_notI_3",
  /* 1704 */  "vand_notI_5",
  /* 1705 */  "vand_notI_4",
  /* 1706 */  "vand_notI_6",
  /* 1707 */  "vand_notI_7",
  /* 1708 */  "vand_notI_9",
  /* 1709 */  "vand_notI_8",
  /* 1710 */  "vand_notI_10",
  /* 1711 */  "vand_notL",
  /* 1712 */  "vand_notL_1",
  /* 1713 */  "vand_notL_0",
  /* 1714 */  "vand_notL_2",
  /* 1715 */  "vdivF",
  /* 1716 */  "vdivD",
  /* 1717 */  "vfdivF_masked",
  /* 1718 */  "vfdivD_masked",
  /* 1719 */  "vmin",
  /* 1720 */  "vmax",
  /* 1721 */  "vmin_masked",
  /* 1722 */  "vmax_masked",
  /* 1723 */  "vfmlaF",
  /* 1724 */  "vfmlaD",
  /* 1725 */  "vfmlaF_masked",
  /* 1726 */  "vfmlaD_masked",
  /* 1727 */  "vfmlsF",
  /* 1728 */  "vfmlsF_0",
  /* 1729 */  "vfmlsD",
  /* 1730 */  "vfmlsD_0",
  /* 1731 */  "vfnmlaF",
  /* 1732 */  "vfnmlaF_0",
  /* 1733 */  "vfnmlaD",
  /* 1734 */  "vfnmlaD_0",
  /* 1735 */  "vfnmlsF",
  /* 1736 */  "vfnmlsD",
  /* 1737 */  "vmlaB",
  /* 1738 */  "vmlaB_0",
  /* 1739 */  "vmlaS",
  /* 1740 */  "vmlaS_0",
  /* 1741 */  "vmlaI",
  /* 1742 */  "vmlaI_0",
  /* 1743 */  "vmlaL",
  /* 1744 */  "vmlaL_0",
  /* 1745 */  "vmlsB",
  /* 1746 */  "vmlsS",
  /* 1747 */  "vmlsI",
  /* 1748 */  "vmlsL",
  /* 1749 */  "vmulB",
  /* 1750 */  "vmulS",
  /* 1751 */  "vmulI",
  /* 1752 */  "vmulL",
  /* 1753 */  "vmulF",
  /* 1754 */  "vmulD",
  /* 1755 */  "vmulB_masked",
  /* 1756 */  "vmulS_masked",
  /* 1757 */  "vmulI_masked",
  /* 1758 */  "vmulL_masked",
  /* 1759 */  "vmulF_masked",
  /* 1760 */  "vmulD_masked",
  /* 1761 */  "vnegF_masked",
  /* 1762 */  "vnegD_masked",
  /* 1763 */  "vmaskcmp",
  /* 1764 */  "vmaskcmp_masked",
  /* 1765 */  "vblend",
  /* 1766 */  "vloadmaskB",
  /* 1767 */  "vloadmask_extend",
  /* 1768 */  "vstoremaskB",
  /* 1769 */  "vstoremask_narrow",
  /* 1770 */  "vloadmask_loadV",
  /* 1771 */  "vloadmask_loadV_partial",
  /* 1772 */  "storeV_vstoremask",
  /* 1773 */  "storeV_vstoremask_partial",
  /* 1774 */  "reduce_addI",
  /* 1775 */  "reduce_addL",
  /* 1776 */  "reduce_addF",
  /* 1777 */  "reduce_addD",
  /* 1778 */  "reduce_addI_partial",
  /* 1779 */  "reduce_addL_partial",
  /* 1780 */  "reduce_addF_partial",
  /* 1781 */  "reduce_addD_partial",
  /* 1782 */  "reduce_addI_masked",
  /* 1783 */  "reduce_addL_masked",
  /* 1784 */  "reduce_addF_masked",
  /* 1785 */  "reduce_addD_masked",
  /* 1786 */  "reduce_addI_masked_partial",
  /* 1787 */  "reduce_addL_masked_partial",
  /* 1788 */  "reduce_addF_masked_partial",
  /* 1789 */  "reduce_addD_masked_partial",
  /* 1790 */  "reduce_andI",
  /* 1791 */  "reduce_andL",
  /* 1792 */  "reduce_andI_partial",
  /* 1793 */  "reduce_andL_partial",
  /* 1794 */  "reduce_andI_masked",
  /* 1795 */  "reduce_andL_masked",
  /* 1796 */  "reduce_andI_masked_partial",
  /* 1797 */  "reduce_andL_masked_partial",
  /* 1798 */  "reduce_orI",
  /* 1799 */  "reduce_orL",
  /* 1800 */  "reduce_orI_partial",
  /* 1801 */  "reduce_orL_partial",
  /* 1802 */  "reduce_orI_masked",
  /* 1803 */  "reduce_orL_masked",
  /* 1804 */  "reduce_orI_masked_partial",
  /* 1805 */  "reduce_orL_masked_partial",
  /* 1806 */  "reduce_eorI",
  /* 1807 */  "reduce_eorL",
  /* 1808 */  "reduce_eorI_partial",
  /* 1809 */  "reduce_eorL_partial",
  /* 1810 */  "reduce_eorI_masked",
  /* 1811 */  "reduce_eorL_masked",
  /* 1812 */  "reduce_eorI_masked_partial",
  /* 1813 */  "reduce_eorL_masked_partial",
  /* 1814 */  "reduce_maxI",
  /* 1815 */  "reduce_maxL",
  /* 1816 */  "reduce_maxI_partial",
  /* 1817 */  "reduce_maxL_partial",
  /* 1818 */  "reduce_maxF",
  /* 1819 */  "reduce_maxF_partial",
  /* 1820 */  "reduce_maxD",
  /* 1821 */  "reduce_maxD_partial",
  /* 1822 */  "reduce_maxI_masked",
  /* 1823 */  "reduce_maxL_masked",
  /* 1824 */  "reduce_maxI_masked_partial",
  /* 1825 */  "reduce_maxL_masked_partial",
  /* 1826 */  "reduce_maxF_masked",
  /* 1827 */  "reduce_maxD_masked",
  /* 1828 */  "reduce_maxF_masked_partial",
  /* 1829 */  "reduce_maxD_masked_partial",
  /* 1830 */  "reduce_minI",
  /* 1831 */  "reduce_minL",
  /* 1832 */  "reduce_minI_partial",
  /* 1833 */  "reduce_minL_partial",
  /* 1834 */  "reduce_minF",
  /* 1835 */  "reduce_minF_partial",
  /* 1836 */  "reduce_minD",
  /* 1837 */  "reduce_minD_partial",
  /* 1838 */  "reduce_minI_masked",
  /* 1839 */  "reduce_minL_masked",
  /* 1840 */  "reduce_minI_masked_partial",
  /* 1841 */  "reduce_minL_masked_partial",
  /* 1842 */  "reduce_minF_masked",
  /* 1843 */  "reduce_minD_masked",
  /* 1844 */  "reduce_minF_masked_partial",
  /* 1845 */  "reduce_minD_masked_partial",
  /* 1846 */  "vroundD",
  /* 1847 */  "replicateB",
  /* 1848 */  "replicateS",
  /* 1849 */  "replicateI",
  /* 1850 */  "replicateL",
  /* 1851 */  "replicateB_imm8",
  /* 1852 */  "replicateS_imm8",
  /* 1853 */  "replicateI_imm8",
  /* 1854 */  "replicateL_imm8",
  /* 1855 */  "replicateF",
  /* 1856 */  "replicateD",
  /* 1857 */  "vasrB",
  /* 1858 */  "vasrS",
  /* 1859 */  "vasrI",
  /* 1860 */  "vasrL",
  /* 1861 */  "vlslB",
  /* 1862 */  "vlslS",
  /* 1863 */  "vlslI",
  /* 1864 */  "vlslL",
  /* 1865 */  "vlsrB",
  /* 1866 */  "vlsrS",
  /* 1867 */  "vlsrI",
  /* 1868 */  "vlsrL",
  /* 1869 */  "vasrB_imm",
  /* 1870 */  "vasrS_imm",
  /* 1871 */  "vasrI_imm",
  /* 1872 */  "vasrL_imm",
  /* 1873 */  "vlsrB_imm",
  /* 1874 */  "vlsrS_imm",
  /* 1875 */  "vlsrI_imm",
  /* 1876 */  "vlsrL_imm",
  /* 1877 */  "vlslB_imm",
  /* 1878 */  "vlslS_imm",
  /* 1879 */  "vlslI_imm",
  /* 1880 */  "vlslL_imm",
  /* 1881 */  "vasrB_masked",
  /* 1882 */  "vasrS_masked",
  /* 1883 */  "vasrI_masked",
  /* 1884 */  "vasrL_masked",
  /* 1885 */  "vlslB_masked",
  /* 1886 */  "vlslS_masked",
  /* 1887 */  "vlslI_masked",
  /* 1888 */  "vlslL_masked",
  /* 1889 */  "vlsrB_masked",
  /* 1890 */  "vlsrS_masked",
  /* 1891 */  "vlsrI_masked",
  /* 1892 */  "vlsrL_masked",
  /* 1893 */  "vasrB_imm_masked",
  /* 1894 */  "vasrS_imm_masked",
  /* 1895 */  "vasrI_imm_masked",
  /* 1896 */  "vasrL_imm_masked",
  /* 1897 */  "vlsrB_imm_masked",
  /* 1898 */  "vlsrS_imm_masked",
  /* 1899 */  "vlsrI_imm_masked",
  /* 1900 */  "vlsrL_imm_masked",
  /* 1901 */  "vlslB_imm_masked",
  /* 1902 */  "vlslS_imm_masked",
  /* 1903 */  "vlslI_imm_masked",
  /* 1904 */  "vlslL_imm_masked",
  /* 1905 */  "vsqrtF_masked",
  /* 1906 */  "vsqrtD_masked",
  /* 1907 */  "vsubB",
  /* 1908 */  "vsubS",
  /* 1909 */  "vsubI",
  /* 1910 */  "vsubL",
  /* 1911 */  "vsubF",
  /* 1912 */  "vsubD",
  /* 1913 */  "vsubB_masked",
  /* 1914 */  "vsubS_masked",
  /* 1915 */  "vsubI_masked",
  /* 1916 */  "vsubL_masked",
  /* 1917 */  "vsubF_masked",
  /* 1918 */  "vsubD_masked",
  /* 1919 */  "vcvtStoB",
  /* 1920 */  "vcvtItoB",
  /* 1921 */  "vcvtItoS",
  /* 1922 */  "vcvtLtoX_narrow",
  /* 1923 */  "vcvtLtoF",
  /* 1924 */  "vcvtFtoX_narrow",
  /* 1925 */  "vcvtDtoX_narrow",
  /* 1926 */  "vcvtDtoF",
  /* 1927 */  "extractB",
  /* 1928 */  "extractS",
  /* 1929 */  "extractI",
  /* 1930 */  "extractL",
  /* 1931 */  "extractF",
  /* 1932 */  "extractD",
  /* 1933 */  "vtest_alltrue",
  /* 1934 */  "vtest_anytrue",
  /* 1935 */  "vtest_alltrue_partial",
  /* 1936 */  "vtest_anytrue_partial",
  /* 1937 */  "insertI_small",
  /* 1938 */  "insertF_small",
  /* 1939 */  "insertI",
  /* 1940 */  "insertL",
  /* 1941 */  "insertD",
  /* 1942 */  "insertF",
  /* 1943 */  "rearrange",
  /* 1944 */  "gatherI",
  /* 1945 */  "gatherL",
  /* 1946 */  "gatherI_partial",
  /* 1947 */  "gatherL_partial",
  /* 1948 */  "gatherI_masked",
  /* 1949 */  "gatherL_masked",
  /* 1950 */  "gatherI_masked_partial",
  /* 1951 */  "gatherL_masked_partial",
  /* 1952 */  "scatterI",
  /* 1953 */  "scatterL",
  /* 1954 */  "scatterI_partial",
  /* 1955 */  "scatterL_partial",
  /* 1956 */  "scatterI_masked",
  /* 1957 */  "scatterL_masked",
  /* 1958 */  "scatterI_masked_partial",
  /* 1959 */  "scatterL_masked_partial",
  /* 1960 */  "stringL_indexof_char_sve",
  /* 1961 */  "stringU_indexof_char_sve",
  /* 1962 */  "vmask_firsttrue",
  /* 1963 */  "vmask_lasttrue",
  /* 1964 */  "vmask_truecount_partial",
  /* 1965 */  "vmask_firsttrue_partial",
  /* 1966 */  "vmask_lasttrue_partial",
  /* 1967 */  "vmask_tolong",
  /* 1968 */  "vmask_gen",
  /* 1969 */  "compareAndSwapP_shenandoah",
  /* 1970 */  "compareAndSwapN_shenandoah",
  /* 1971 */  "compareAndSwapPAcq_shenandoah",
  /* 1972 */  "compareAndSwapNAcq_shenandoah",
  /* 1973 */  "compareAndExchangeN_shenandoah",
  /* 1974 */  "compareAndExchangeP_shenandoah",
  /* 1975 */  "compareAndExchangeNAcq_shenandoah",
  /* 1976 */  "compareAndExchangePAcq_shenandoah",
  /* 1977 */  "weakCompareAndSwapN_shenandoah",
  /* 1978 */  "weakCompareAndSwapP_shenandoah",
  /* 1979 */  "weakCompareAndSwapNAcq_shenandoah",
  /* 1980 */  "weakCompareAndSwapPAcq_shenandoah",
  /* 1981 */  "zLoadP",
  /* 1982 */  "zLoadPVolatile",
  /* 1983 */  "zCompareAndSwapP",
  /* 1984 */  "zCompareAndSwapP_0",
  /* 1985 */  "zCompareAndSwapPAcq",
  /* 1986 */  "zCompareAndSwapPAcq_0",
  /* 1987 */  "zCompareAndExchangeP",
  /* 1988 */  "zCompareAndExchangePAcq",
  /* 1989 */  "zGetAndSetP",
  /* 1990 */  "zGetAndSetPAcq",
  // last instruction
  "invalid rule name" // no trailing comma
};

const        bool  swallowed[] = {
  /*    0 */  false,
  /*    1 */  false,
  /*    2 */  false,
  /*    3 */  false,
  /*    4 */  false,
  /*    5 */  false,
  /*    6 */  false,
  /*    7 */  false,
  /*    8 */  true,
  /*    9 */  true,
  /*   10 */  true,
  /*   11 */  true,
  /*   12 */  true,
  /*   13 */  true,
  /*   14 */  true,
  /*   15 */  true,
  /*   16 */  true,
  /*   17 */  true,
  /*   18 */  true,
  /*   19 */  true,
  /*   20 */  true,
  /*   21 */  true,
  /*   22 */  true,
  /*   23 */  true,
  /*   24 */  true,
  /*   25 */  true,
  /*   26 */  true,
  /*   27 */  true,
  /*   28 */  true,
  /*   29 */  true,
  /*   30 */  true,
  /*   31 */  true,
  /*   32 */  true,
  /*   33 */  true,
  /*   34 */  true,
  /*   35 */  true,
  /*   36 */  true,
  /*   37 */  true,
  /*   38 */  true,
  /*   39 */  true,
  /*   40 */  true,
  /*   41 */  true,
  /*   42 */  true,
  /*   43 */  true,
  /*   44 */  true,
  /*   45 */  true,
  /*   46 */  true,
  /*   47 */  true,
  /*   48 */  true,
  /*   49 */  true,
  /*   50 */  true,
  /*   51 */  true,
  /*   52 */  true,
  /*   53 */  true,
  /*   54 */  true,
  /*   55 */  true,
  /*   56 */  true,
  /*   57 */  true,
  /*   58 */  true,
  /*   59 */  true,
  /*   60 */  true,
  /*   61 */  true,
  /*   62 */  true,
  /*   63 */  true,
  /*   64 */  true,
  /*   65 */  true,
  /*   66 */  true,
  /*   67 */  true,
  /*   68 */  true,
  /*   69 */  true,
  /*   70 */  true,
  /*   71 */  true,
  /*   72 */  true,
  /*   73 */  true,
  /*   74 */  true,
  /*   75 */  true,
  /*   76 */  true,
  /*   77 */  true,
  /*   78 */  true,
  /*   79 */  true,
  /*   80 */  true,
  /*   81 */  true,
  /*   82 */  true,
  /*   83 */  true,
  /*   84 */  false,
  /*   85 */  false,
  /*   86 */  false,
  /*   87 */  false,
  /*   88 */  false,
  /*   89 */  false,
  /*   90 */  false,
  /*   91 */  false,
  /*   92 */  false,
  /*   93 */  false,
  /*   94 */  false,
  /*   95 */  false,
  /*   96 */  false,
  /*   97 */  false,
  /*   98 */  false,
  /*   99 */  false,
  /*  100 */  false,
  /*  101 */  false,
  /*  102 */  false,
  /*  103 */  false,
  /*  104 */  false,
  /*  105 */  false,
  /*  106 */  false,
  /*  107 */  false,
  /*  108 */  false,
  /*  109 */  false,
  /*  110 */  false,
  /*  111 */  false,
  /*  112 */  false,
  /*  113 */  false,
  /*  114 */  false,
  /*  115 */  false,
  /*  116 */  false,
  /*  117 */  false,
  /*  118 */  false,
  /*  119 */  false,
  /*  120 */  false,
  /*  121 */  false,
  /*  122 */  false,
  /*  123 */  false,
  /*  124 */  false,
  /*  125 */  false,
  /*  126 */  false,
  /*  127 */  false,
  /*  128 */  false,
  /*  129 */  false,
  /*  130 */  false,
  /*  131 */  false,
  /*  132 */  false,
  /*  133 */  false,
  /*  134 */  false,
  /*  135 */  false,
  /*  136 */  false,
  /*  137 */  false,
  /*  138 */  false,
  /*  139 */  false,
  /*  140 */  false,
  /*  141 */  false,
  /*  142 */  false,
  /*  143 */  false,
  /*  144 */  false,
  /*  145 */  false,
  /*  146 */  false,
  /*  147 */  false,
  /*  148 */  false,
  /*  149 */  false,
  /*  150 */  false,
  /*  151 */  false,
  /*  152 */  false,
  /*  153 */  false,
  /*  154 */  false,
  /*  155 */  false,
  /*  156 */  false,
  /*  157 */  false,
  /*  158 */  false,
  /*  159 */  false,
  /*  160 */  false,
  /*  161 */  false,
  /*  162 */  false,
  /*  163 */  false,
  /*  164 */  false,
  /*  165 */  false,
  /*  166 */  false,
  /*  167 */  false,
  /*  168 */  false,
  /*  169 */  false,
  /*  170 */  false,
  /*  171 */  false,
  /*  172 */  false,
  /*  173 */  false,
  /*  174 */  false,
  /*  175 */  false,
  /*  176 */  false,
  /*  177 */  false,
  /*  178 */  false,
  /*  179 */  false,
  /*  180 */  false,
  /*  181 */  false,
  /*  182 */  false,
  /*  183 */  false,
  /*  184 */  false,
  /*  185 */  false,
  /*  186 */  true,
  /*  187 */  true,
  /*  188 */  true,
  /*  189 */  true,
  /*  190 */  true,
  /*  191 */  false,
  /*  192 */  true,
  /*  193 */  true,
  /*  194 */  false,
  /*  195 */  false,
  // last operand
  /*  196 */  false,
  /*  197 */  false,
  /*  198 */  false,
  /*  199 */  false,
  /*  200 */  false,
  /*  201 */  false,
  /*  202 */  false,
  /*  203 */  false,
  /*  204 */  false,
  /*  205 */  false,
  /*  206 */  false,
  // last operand class
  /*  207 */  false,
  /*  208 */  false,
  /*  209 */  false,
  /*  210 */  false,
  /*  211 */  false,
  /*  212 */  false,
  /*  213 */  false,
  /*  214 */  false,
  /*  215 */  false,
  /*  216 */  false,
  /*  217 */  false,
  /*  218 */  false,
  /*  219 */  false,
  /*  220 */  false,
  /*  221 */  false,
  /*  222 */  false,
  /*  223 */  false,
  /*  224 */  false,
  /*  225 */  false,
  /*  226 */  false,
  /*  227 */  false,
  /*  228 */  false,
  /*  229 */  false,
  /*  230 */  false,
  /*  231 */  false,
  /*  232 */  false,
  /*  233 */  false,
  /*  234 */  false,
  /*  235 */  false,
  /*  236 */  false,
  /*  237 */  false,
  /*  238 */  false,
  /*  239 */  false,
  /*  240 */  false,
  /*  241 */  false,
  /*  242 */  false,
  /*  243 */  false,
  /*  244 */  false,
  /*  245 */  false,
  /*  246 */  false,
  /*  247 */  false,
  /*  248 */  false,
  /*  249 */  false,
  /*  250 */  false,
  /*  251 */  false,
  /*  252 */  false,
  /*  253 */  false,
  /*  254 */  false,
  /*  255 */  false,
  /*  256 */  false,
  /*  257 */  false,
  /*  258 */  false,
  /*  259 */  false,
  /*  260 */  false,
  /*  261 */  false,
  /*  262 */  false,
  /*  263 */  false,
  /*  264 */  false,
  /*  265 */  false,
  /*  266 */  false,
  /*  267 */  false,
  /*  268 */  false,
  /*  269 */  false,
  /*  270 */  false,
  /*  271 */  false,
  /*  272 */  false,
  /*  273 */  false,
  /*  274 */  false,
  /*  275 */  false,
  /*  276 */  false,
  /*  277 */  false,
  /*  278 */  false,
  /*  279 */  false,
  /*  280 */  false,
  /*  281 */  false,
  /*  282 */  false,
  /*  283 */  false,
  /*  284 */  false,
  /*  285 */  false,
  /*  286 */  false,
  /*  287 */  false,
  /*  288 */  false,
  /*  289 */  false,
  /*  290 */  false,
  /*  291 */  false,
  /*  292 */  false,
  /*  293 */  false,
  /*  294 */  false,
  /*  295 */  false,
  /*  296 */  false,
  /*  297 */  false,
  /*  298 */  false,
  /*  299 */  false,
  /*  300 */  false,
  /*  301 */  false,
  /*  302 */  false,
  /*  303 */  false,
  /*  304 */  false,
  /*  305 */  false,
  /*  306 */  false,
  /*  307 */  false,
  /*  308 */  false,
  /*  309 */  false,
  /*  310 */  false,
  /*  311 */  false,
  /*  312 */  false,
  /*  313 */  false,
  /*  314 */  false,
  /*  315 */  false,
  /*  316 */  false,
  /*  317 */  false,
  /*  318 */  false,
  /*  319 */  false,
  /*  320 */  false,
  /*  321 */  false,
  /*  322 */  false,
  /*  323 */  false,
  /*  324 */  false,
  /*  325 */  false,
  /*  326 */  false,
  /*  327 */  false,
  /*  328 */  false,
  /*  329 */  false,
  /*  330 */  false,
  /*  331 */  false,
  /*  332 */  false,
  /*  333 */  false,
  /*  334 */  false,
  /*  335 */  false,
  /*  336 */  false,
  /*  337 */  false,
  /*  338 */  false,
  /*  339 */  false,
  /*  340 */  false,
  /*  341 */  false,
  /*  342 */  false,
  /*  343 */  false,
  /*  344 */  false,
  /*  345 */  false,
  /*  346 */  false,
  /*  347 */  false,
  /*  348 */  false,
  /*  349 */  false,
  /*  350 */  false,
  /*  351 */  false,
  /*  352 */  false,
  /*  353 */  false,
  /*  354 */  false,
  /*  355 */  false,
  /*  356 */  false,
  /*  357 */  false,
  /*  358 */  false,
  /*  359 */  false,
  /*  360 */  false,
  /*  361 */  false,
  /*  362 */  false,
  /*  363 */  false,
  /*  364 */  false,
  /*  365 */  false,
  /*  366 */  false,
  /*  367 */  false,
  /*  368 */  false,
  /*  369 */  false,
  /*  370 */  false,
  /*  371 */  false,
  /*  372 */  false,
  /*  373 */  false,
  /*  374 */  false,
  /*  375 */  false,
  /*  376 */  false,
  /*  377 */  false,
  /*  378 */  false,
  /*  379 */  false,
  /*  380 */  false,
  /*  381 */  false,
  /*  382 */  false,
  /*  383 */  false,
  /*  384 */  false,
  /*  385 */  false,
  /*  386 */  false,
  /*  387 */  false,
  /*  388 */  false,
  /*  389 */  false,
  /*  390 */  false,
  /*  391 */  false,
  /*  392 */  false,
  /*  393 */  false,
  /*  394 */  false,
  /*  395 */  false,
  /*  396 */  false,
  /*  397 */  false,
  /*  398 */  false,
  /*  399 */  false,
  /*  400 */  false,
  /*  401 */  false,
  /*  402 */  false,
  /*  403 */  false,
  /*  404 */  false,
  /*  405 */  false,
  /*  406 */  false,
  /*  407 */  false,
  /*  408 */  false,
  /*  409 */  false,
  /*  410 */  false,
  /*  411 */  false,
  /*  412 */  false,
  /*  413 */  false,
  /*  414 */  false,
  /*  415 */  false,
  /*  416 */  false,
  /*  417 */  false,
  /*  418 */  false,
  /*  419 */  false,
  /*  420 */  false,
  /*  421 */  false,
  /*  422 */  false,
  /*  423 */  false,
  /*  424 */  false,
  /*  425 */  false,
  /*  426 */  false,
  /*  427 */  false,
  /*  428 */  false,
  /*  429 */  false,
  /*  430 */  false,
  /*  431 */  false,
  /*  432 */  false,
  /*  433 */  false,
  /*  434 */  false,
  /*  435 */  false,
  /*  436 */  false,
  /*  437 */  false,
  /*  438 */  false,
  /*  439 */  false,
  /*  440 */  false,
  /*  441 */  false,
  /*  442 */  false,
  /*  443 */  false,
  /*  444 */  false,
  /*  445 */  false,
  /*  446 */  false,
  /*  447 */  false,
  /*  448 */  false,
  /*  449 */  false,
  /*  450 */  false,
  /*  451 */  false,
  /*  452 */  false,
  /*  453 */  false,
  /*  454 */  false,
  /*  455 */  false,
  /*  456 */  false,
  /*  457 */  false,
  /*  458 */  false,
  /*  459 */  false,
  /*  460 */  false,
  /*  461 */  false,
  /*  462 */  false,
  /*  463 */  false,
  /*  464 */  false,
  // last internally defined operand
  /*  465 */  false,
  /*  466 */  false,
  /*  467 */  false,
  /*  468 */  false,
  /*  469 */  false,
  /*  470 */  false,
  /*  471 */  false,
  /*  472 */  false,
  /*  473 */  false,
  /*  474 */  false,
  /*  475 */  false,
  /*  476 */  false,
  /*  477 */  false,
  /*  478 */  false,
  /*  479 */  false,
  /*  480 */  false,
  /*  481 */  false,
  /*  482 */  false,
  /*  483 */  false,
  /*  484 */  false,
  /*  485 */  false,
  /*  486 */  false,
  /*  487 */  false,
  /*  488 */  false,
  /*  489 */  false,
  /*  490 */  false,
  /*  491 */  false,
  /*  492 */  false,
  /*  493 */  false,
  /*  494 */  false,
  /*  495 */  false,
  /*  496 */  false,
  /*  497 */  false,
  /*  498 */  false,
  /*  499 */  false,
  /*  500 */  false,
  /*  501 */  false,
  /*  502 */  false,
  /*  503 */  false,
  /*  504 */  false,
  /*  505 */  false,
  /*  506 */  false,
  /*  507 */  false,
  /*  508 */  false,
  /*  509 */  false,
  /*  510 */  false,
  /*  511 */  false,
  /*  512 */  false,
  /*  513 */  false,
  /*  514 */  false,
  /*  515 */  false,
  /*  516 */  false,
  /*  517 */  false,
  /*  518 */  false,
  /*  519 */  false,
  /*  520 */  false,
  /*  521 */  false,
  /*  522 */  false,
  /*  523 */  false,
  /*  524 */  false,
  /*  525 */  false,
  /*  526 */  false,
  /*  527 */  false,
  /*  528 */  false,
  /*  529 */  false,
  /*  530 */  false,
  /*  531 */  false,
  /*  532 */  false,
  /*  533 */  false,
  /*  534 */  false,
  /*  535 */  false,
  /*  536 */  false,
  /*  537 */  false,
  /*  538 */  false,
  /*  539 */  false,
  /*  540 */  false,
  /*  541 */  false,
  /*  542 */  false,
  /*  543 */  false,
  /*  544 */  false,
  /*  545 */  false,
  /*  546 */  false,
  /*  547 */  false,
  /*  548 */  false,
  /*  549 */  false,
  /*  550 */  false,
  /*  551 */  false,
  /*  552 */  false,
  /*  553 */  false,
  /*  554 */  false,
  /*  555 */  false,
  /*  556 */  false,
  /*  557 */  false,
  /*  558 */  false,
  /*  559 */  false,
  /*  560 */  false,
  /*  561 */  false,
  /*  562 */  false,
  /*  563 */  false,
  /*  564 */  false,
  /*  565 */  false,
  /*  566 */  false,
  /*  567 */  false,
  /*  568 */  false,
  /*  569 */  false,
  /*  570 */  false,
  /*  571 */  false,
  /*  572 */  false,
  /*  573 */  false,
  /*  574 */  false,
  /*  575 */  false,
  /*  576 */  false,
  /*  577 */  false,
  /*  578 */  false,
  /*  579 */  false,
  /*  580 */  false,
  /*  581 */  false,
  /*  582 */  false,
  /*  583 */  false,
  /*  584 */  false,
  /*  585 */  false,
  /*  586 */  false,
  /*  587 */  false,
  /*  588 */  false,
  /*  589 */  false,
  /*  590 */  false,
  /*  591 */  false,
  /*  592 */  false,
  /*  593 */  false,
  /*  594 */  false,
  /*  595 */  false,
  /*  596 */  false,
  /*  597 */  false,
  /*  598 */  false,
  /*  599 */  false,
  /*  600 */  false,
  /*  601 */  false,
  /*  602 */  false,
  /*  603 */  false,
  /*  604 */  false,
  /*  605 */  false,
  /*  606 */  false,
  /*  607 */  false,
  /*  608 */  false,
  /*  609 */  false,
  /*  610 */  false,
  /*  611 */  false,
  /*  612 */  false,
  /*  613 */  false,
  /*  614 */  false,
  /*  615 */  false,
  /*  616 */  false,
  /*  617 */  false,
  /*  618 */  false,
  /*  619 */  false,
  /*  620 */  false,
  /*  621 */  false,
  /*  622 */  false,
  /*  623 */  false,
  /*  624 */  false,
  /*  625 */  false,
  /*  626 */  false,
  /*  627 */  false,
  /*  628 */  false,
  /*  629 */  false,
  /*  630 */  false,
  /*  631 */  false,
  /*  632 */  false,
  /*  633 */  false,
  /*  634 */  false,
  /*  635 */  false,
  /*  636 */  false,
  /*  637 */  false,
  /*  638 */  false,
  /*  639 */  false,
  /*  640 */  false,
  /*  641 */  false,
  /*  642 */  false,
  /*  643 */  false,
  /*  644 */  false,
  /*  645 */  false,
  /*  646 */  false,
  /*  647 */  false,
  /*  648 */  false,
  /*  649 */  false,
  /*  650 */  false,
  /*  651 */  false,
  /*  652 */  false,
  /*  653 */  false,
  /*  654 */  false,
  /*  655 */  false,
  /*  656 */  false,
  /*  657 */  false,
  /*  658 */  false,
  /*  659 */  false,
  /*  660 */  false,
  /*  661 */  false,
  /*  662 */  false,
  /*  663 */  false,
  /*  664 */  false,
  /*  665 */  false,
  /*  666 */  false,
  /*  667 */  false,
  /*  668 */  false,
  /*  669 */  false,
  /*  670 */  false,
  /*  671 */  false,
  /*  672 */  false,
  /*  673 */  false,
  /*  674 */  false,
  /*  675 */  false,
  /*  676 */  false,
  /*  677 */  false,
  /*  678 */  false,
  /*  679 */  false,
  /*  680 */  false,
  /*  681 */  false,
  /*  682 */  false,
  /*  683 */  false,
  /*  684 */  false,
  /*  685 */  false,
  /*  686 */  false,
  /*  687 */  false,
  /*  688 */  false,
  /*  689 */  false,
  /*  690 */  false,
  /*  691 */  false,
  /*  692 */  false,
  /*  693 */  false,
  /*  694 */  false,
  /*  695 */  false,
  /*  696 */  false,
  /*  697 */  false,
  /*  698 */  false,
  /*  699 */  false,
  /*  700 */  false,
  /*  701 */  false,
  /*  702 */  false,
  /*  703 */  false,
  /*  704 */  false,
  /*  705 */  false,
  /*  706 */  false,
  /*  707 */  false,
  /*  708 */  false,
  /*  709 */  false,
  /*  710 */  false,
  /*  711 */  false,
  /*  712 */  false,
  /*  713 */  false,
  /*  714 */  false,
  /*  715 */  false,
  /*  716 */  false,
  /*  717 */  false,
  /*  718 */  false,
  /*  719 */  false,
  /*  720 */  false,
  /*  721 */  false,
  /*  722 */  false,
  /*  723 */  false,
  /*  724 */  false,
  /*  725 */  false,
  /*  726 */  false,
  /*  727 */  false,
  /*  728 */  false,
  /*  729 */  false,
  /*  730 */  false,
  /*  731 */  false,
  /*  732 */  false,
  /*  733 */  false,
  /*  734 */  false,
  /*  735 */  false,
  /*  736 */  false,
  /*  737 */  false,
  /*  738 */  false,
  /*  739 */  false,
  /*  740 */  false,
  /*  741 */  false,
  /*  742 */  false,
  /*  743 */  false,
  /*  744 */  false,
  /*  745 */  false,
  /*  746 */  false,
  /*  747 */  false,
  /*  748 */  false,
  /*  749 */  false,
  /*  750 */  false,
  /*  751 */  false,
  /*  752 */  false,
  /*  753 */  false,
  /*  754 */  false,
  /*  755 */  false,
  /*  756 */  false,
  /*  757 */  false,
  /*  758 */  false,
  /*  759 */  false,
  /*  760 */  false,
  /*  761 */  false,
  /*  762 */  false,
  /*  763 */  false,
  /*  764 */  false,
  /*  765 */  false,
  /*  766 */  false,
  /*  767 */  false,
  /*  768 */  false,
  /*  769 */  false,
  /*  770 */  false,
  /*  771 */  false,
  /*  772 */  false,
  /*  773 */  false,
  /*  774 */  false,
  /*  775 */  false,
  /*  776 */  false,
  /*  777 */  false,
  /*  778 */  false,
  /*  779 */  false,
  /*  780 */  false,
  /*  781 */  false,
  /*  782 */  false,
  /*  783 */  false,
  /*  784 */  false,
  /*  785 */  false,
  /*  786 */  false,
  /*  787 */  false,
  /*  788 */  false,
  /*  789 */  false,
  /*  790 */  false,
  /*  791 */  false,
  /*  792 */  false,
  /*  793 */  false,
  /*  794 */  false,
  /*  795 */  false,
  /*  796 */  false,
  /*  797 */  false,
  /*  798 */  false,
  /*  799 */  false,
  /*  800 */  false,
  /*  801 */  false,
  /*  802 */  false,
  /*  803 */  false,
  /*  804 */  false,
  /*  805 */  false,
  /*  806 */  false,
  /*  807 */  false,
  /*  808 */  false,
  /*  809 */  false,
  /*  810 */  false,
  /*  811 */  false,
  /*  812 */  false,
  /*  813 */  false,
  /*  814 */  false,
  /*  815 */  false,
  /*  816 */  false,
  /*  817 */  false,
  /*  818 */  false,
  /*  819 */  false,
  /*  820 */  false,
  /*  821 */  false,
  /*  822 */  false,
  /*  823 */  false,
  /*  824 */  false,
  /*  825 */  false,
  /*  826 */  false,
  /*  827 */  false,
  /*  828 */  false,
  /*  829 */  false,
  /*  830 */  false,
  /*  831 */  false,
  /*  832 */  false,
  /*  833 */  false,
  /*  834 */  false,
  /*  835 */  false,
  /*  836 */  false,
  /*  837 */  false,
  /*  838 */  false,
  /*  839 */  false,
  /*  840 */  false,
  /*  841 */  false,
  /*  842 */  false,
  /*  843 */  false,
  /*  844 */  false,
  /*  845 */  false,
  /*  846 */  false,
  /*  847 */  false,
  /*  848 */  false,
  /*  849 */  false,
  /*  850 */  false,
  /*  851 */  false,
  /*  852 */  false,
  /*  853 */  false,
  /*  854 */  false,
  /*  855 */  false,
  /*  856 */  false,
  /*  857 */  false,
  /*  858 */  false,
  /*  859 */  false,
  /*  860 */  false,
  /*  861 */  false,
  /*  862 */  false,
  /*  863 */  false,
  /*  864 */  false,
  /*  865 */  false,
  /*  866 */  false,
  /*  867 */  false,
  /*  868 */  false,
  /*  869 */  false,
  /*  870 */  false,
  /*  871 */  false,
  /*  872 */  false,
  /*  873 */  false,
  /*  874 */  false,
  /*  875 */  false,
  /*  876 */  false,
  /*  877 */  false,
  /*  878 */  false,
  /*  879 */  false,
  /*  880 */  false,
  /*  881 */  false,
  /*  882 */  false,
  /*  883 */  false,
  /*  884 */  false,
  /*  885 */  false,
  /*  886 */  false,
  /*  887 */  false,
  /*  888 */  false,
  /*  889 */  false,
  /*  890 */  false,
  /*  891 */  false,
  /*  892 */  false,
  /*  893 */  false,
  /*  894 */  false,
  /*  895 */  false,
  /*  896 */  false,
  /*  897 */  false,
  /*  898 */  false,
  /*  899 */  false,
  /*  900 */  false,
  /*  901 */  false,
  /*  902 */  false,
  /*  903 */  false,
  /*  904 */  false,
  /*  905 */  false,
  /*  906 */  false,
  /*  907 */  false,
  /*  908 */  false,
  /*  909 */  false,
  /*  910 */  false,
  /*  911 */  false,
  /*  912 */  false,
  /*  913 */  false,
  /*  914 */  false,
  /*  915 */  false,
  /*  916 */  false,
  /*  917 */  false,
  /*  918 */  false,
  /*  919 */  false,
  /*  920 */  false,
  /*  921 */  false,
  /*  922 */  false,
  /*  923 */  false,
  /*  924 */  false,
  /*  925 */  false,
  /*  926 */  false,
  /*  927 */  false,
  /*  928 */  false,
  /*  929 */  false,
  /*  930 */  false,
  /*  931 */  false,
  /*  932 */  false,
  /*  933 */  false,
  /*  934 */  false,
  /*  935 */  false,
  /*  936 */  false,
  /*  937 */  false,
  /*  938 */  false,
  /*  939 */  false,
  /*  940 */  false,
  /*  941 */  false,
  /*  942 */  false,
  /*  943 */  false,
  /*  944 */  false,
  /*  945 */  false,
  /*  946 */  false,
  /*  947 */  false,
  /*  948 */  false,
  /*  949 */  false,
  /*  950 */  false,
  /*  951 */  false,
  /*  952 */  false,
  /*  953 */  false,
  /*  954 */  false,
  /*  955 */  false,
  /*  956 */  false,
  /*  957 */  false,
  /*  958 */  false,
  /*  959 */  false,
  /*  960 */  false,
  /*  961 */  false,
  /*  962 */  false,
  /*  963 */  false,
  /*  964 */  false,
  /*  965 */  false,
  /*  966 */  false,
  /*  967 */  false,
  /*  968 */  false,
  /*  969 */  false,
  /*  970 */  false,
  /*  971 */  false,
  /*  972 */  false,
  /*  973 */  false,
  /*  974 */  false,
  /*  975 */  false,
  /*  976 */  false,
  /*  977 */  false,
  /*  978 */  false,
  /*  979 */  false,
  /*  980 */  false,
  /*  981 */  false,
  /*  982 */  false,
  /*  983 */  false,
  /*  984 */  false,
  /*  985 */  false,
  /*  986 */  false,
  /*  987 */  false,
  /*  988 */  false,
  /*  989 */  false,
  /*  990 */  false,
  /*  991 */  false,
  /*  992 */  false,
  /*  993 */  false,
  /*  994 */  false,
  /*  995 */  false,
  /*  996 */  false,
  /*  997 */  false,
  /*  998 */  false,
  /*  999 */  false,
  /* 1000 */  false,
  /* 1001 */  false,
  /* 1002 */  false,
  /* 1003 */  false,
  /* 1004 */  false,
  /* 1005 */  false,
  /* 1006 */  false,
  /* 1007 */  false,
  /* 1008 */  false,
  /* 1009 */  false,
  /* 1010 */  false,
  /* 1011 */  false,
  /* 1012 */  false,
  /* 1013 */  false,
  /* 1014 */  false,
  /* 1015 */  false,
  /* 1016 */  false,
  /* 1017 */  false,
  /* 1018 */  false,
  /* 1019 */  false,
  /* 1020 */  false,
  /* 1021 */  false,
  /* 1022 */  false,
  /* 1023 */  false,
  /* 1024 */  false,
  /* 1025 */  false,
  /* 1026 */  false,
  /* 1027 */  false,
  /* 1028 */  false,
  /* 1029 */  false,
  /* 1030 */  false,
  /* 1031 */  false,
  /* 1032 */  false,
  /* 1033 */  false,
  /* 1034 */  false,
  /* 1035 */  false,
  /* 1036 */  false,
  /* 1037 */  false,
  /* 1038 */  false,
  /* 1039 */  false,
  /* 1040 */  false,
  /* 1041 */  false,
  /* 1042 */  false,
  /* 1043 */  false,
  /* 1044 */  false,
  /* 1045 */  false,
  /* 1046 */  false,
  /* 1047 */  false,
  /* 1048 */  false,
  /* 1049 */  false,
  /* 1050 */  false,
  /* 1051 */  false,
  /* 1052 */  false,
  /* 1053 */  false,
  /* 1054 */  false,
  /* 1055 */  false,
  /* 1056 */  false,
  /* 1057 */  false,
  /* 1058 */  false,
  /* 1059 */  false,
  /* 1060 */  false,
  /* 1061 */  false,
  /* 1062 */  false,
  /* 1063 */  false,
  /* 1064 */  false,
  /* 1065 */  false,
  /* 1066 */  false,
  /* 1067 */  false,
  /* 1068 */  false,
  /* 1069 */  false,
  /* 1070 */  false,
  /* 1071 */  false,
  /* 1072 */  false,
  /* 1073 */  false,
  /* 1074 */  false,
  /* 1075 */  false,
  /* 1076 */  false,
  /* 1077 */  false,
  /* 1078 */  false,
  /* 1079 */  false,
  /* 1080 */  false,
  /* 1081 */  false,
  /* 1082 */  false,
  /* 1083 */  false,
  /* 1084 */  false,
  /* 1085 */  false,
  /* 1086 */  false,
  /* 1087 */  false,
  /* 1088 */  false,
  /* 1089 */  false,
  /* 1090 */  false,
  /* 1091 */  false,
  /* 1092 */  false,
  /* 1093 */  false,
  /* 1094 */  false,
  /* 1095 */  false,
  /* 1096 */  false,
  /* 1097 */  false,
  /* 1098 */  false,
  /* 1099 */  false,
  /* 1100 */  false,
  /* 1101 */  false,
  /* 1102 */  false,
  /* 1103 */  false,
  /* 1104 */  false,
  /* 1105 */  false,
  /* 1106 */  false,
  /* 1107 */  false,
  /* 1108 */  false,
  /* 1109 */  false,
  /* 1110 */  false,
  /* 1111 */  false,
  /* 1112 */  false,
  /* 1113 */  false,
  /* 1114 */  false,
  /* 1115 */  false,
  /* 1116 */  false,
  /* 1117 */  false,
  /* 1118 */  false,
  /* 1119 */  false,
  /* 1120 */  false,
  /* 1121 */  false,
  /* 1122 */  false,
  /* 1123 */  false,
  /* 1124 */  false,
  /* 1125 */  false,
  /* 1126 */  false,
  /* 1127 */  false,
  /* 1128 */  false,
  /* 1129 */  false,
  /* 1130 */  false,
  /* 1131 */  false,
  /* 1132 */  false,
  /* 1133 */  false,
  /* 1134 */  false,
  /* 1135 */  false,
  /* 1136 */  false,
  /* 1137 */  false,
  /* 1138 */  false,
  /* 1139 */  false,
  /* 1140 */  false,
  /* 1141 */  false,
  /* 1142 */  false,
  /* 1143 */  false,
  /* 1144 */  false,
  /* 1145 */  false,
  /* 1146 */  false,
  /* 1147 */  false,
  /* 1148 */  false,
  /* 1149 */  false,
  /* 1150 */  false,
  /* 1151 */  false,
  /* 1152 */  false,
  /* 1153 */  false,
  /* 1154 */  false,
  /* 1155 */  false,
  /* 1156 */  false,
  /* 1157 */  false,
  /* 1158 */  false,
  /* 1159 */  false,
  /* 1160 */  false,
  /* 1161 */  false,
  /* 1162 */  false,
  /* 1163 */  false,
  /* 1164 */  false,
  /* 1165 */  false,
  /* 1166 */  false,
  /* 1167 */  false,
  /* 1168 */  false,
  /* 1169 */  false,
  /* 1170 */  false,
  /* 1171 */  false,
  /* 1172 */  false,
  /* 1173 */  false,
  /* 1174 */  false,
  /* 1175 */  false,
  /* 1176 */  false,
  /* 1177 */  false,
  /* 1178 */  false,
  /* 1179 */  false,
  /* 1180 */  false,
  /* 1181 */  false,
  /* 1182 */  false,
  /* 1183 */  false,
  /* 1184 */  false,
  /* 1185 */  false,
  /* 1186 */  false,
  /* 1187 */  false,
  /* 1188 */  false,
  /* 1189 */  false,
  /* 1190 */  false,
  /* 1191 */  false,
  /* 1192 */  false,
  /* 1193 */  false,
  /* 1194 */  false,
  /* 1195 */  false,
  /* 1196 */  false,
  /* 1197 */  false,
  /* 1198 */  false,
  /* 1199 */  false,
  /* 1200 */  false,
  /* 1201 */  false,
  /* 1202 */  false,
  /* 1203 */  false,
  /* 1204 */  false,
  /* 1205 */  false,
  /* 1206 */  false,
  /* 1207 */  false,
  /* 1208 */  false,
  /* 1209 */  false,
  /* 1210 */  false,
  /* 1211 */  false,
  /* 1212 */  false,
  /* 1213 */  false,
  /* 1214 */  false,
  /* 1215 */  false,
  /* 1216 */  false,
  /* 1217 */  false,
  /* 1218 */  false,
  /* 1219 */  false,
  /* 1220 */  false,
  /* 1221 */  false,
  /* 1222 */  false,
  /* 1223 */  false,
  /* 1224 */  false,
  /* 1225 */  false,
  /* 1226 */  false,
  /* 1227 */  false,
  /* 1228 */  false,
  /* 1229 */  false,
  /* 1230 */  false,
  /* 1231 */  false,
  /* 1232 */  false,
  /* 1233 */  false,
  /* 1234 */  false,
  /* 1235 */  false,
  /* 1236 */  false,
  /* 1237 */  false,
  /* 1238 */  false,
  /* 1239 */  false,
  /* 1240 */  false,
  /* 1241 */  false,
  /* 1242 */  false,
  /* 1243 */  false,
  /* 1244 */  false,
  /* 1245 */  false,
  /* 1246 */  false,
  /* 1247 */  false,
  /* 1248 */  false,
  /* 1249 */  false,
  /* 1250 */  false,
  /* 1251 */  false,
  /* 1252 */  false,
  /* 1253 */  false,
  /* 1254 */  false,
  /* 1255 */  false,
  /* 1256 */  false,
  /* 1257 */  false,
  /* 1258 */  false,
  /* 1259 */  false,
  /* 1260 */  false,
  /* 1261 */  false,
  /* 1262 */  false,
  /* 1263 */  false,
  /* 1264 */  false,
  /* 1265 */  false,
  /* 1266 */  false,
  /* 1267 */  false,
  /* 1268 */  false,
  /* 1269 */  false,
  /* 1270 */  false,
  /* 1271 */  false,
  /* 1272 */  false,
  /* 1273 */  false,
  /* 1274 */  false,
  /* 1275 */  false,
  /* 1276 */  false,
  /* 1277 */  false,
  /* 1278 */  false,
  /* 1279 */  false,
  /* 1280 */  false,
  /* 1281 */  false,
  /* 1282 */  false,
  /* 1283 */  false,
  /* 1284 */  false,
  /* 1285 */  false,
  /* 1286 */  false,
  /* 1287 */  false,
  /* 1288 */  false,
  /* 1289 */  false,
  /* 1290 */  false,
  /* 1291 */  false,
  /* 1292 */  false,
  /* 1293 */  false,
  /* 1294 */  false,
  /* 1295 */  false,
  /* 1296 */  false,
  /* 1297 */  false,
  /* 1298 */  false,
  /* 1299 */  false,
  /* 1300 */  false,
  /* 1301 */  false,
  /* 1302 */  false,
  /* 1303 */  false,
  /* 1304 */  false,
  /* 1305 */  false,
  /* 1306 */  false,
  /* 1307 */  false,
  /* 1308 */  false,
  /* 1309 */  false,
  /* 1310 */  false,
  /* 1311 */  false,
  /* 1312 */  false,
  /* 1313 */  false,
  /* 1314 */  false,
  /* 1315 */  false,
  /* 1316 */  false,
  /* 1317 */  false,
  /* 1318 */  false,
  /* 1319 */  false,
  /* 1320 */  false,
  /* 1321 */  false,
  /* 1322 */  false,
  /* 1323 */  false,
  /* 1324 */  false,
  /* 1325 */  false,
  /* 1326 */  false,
  /* 1327 */  false,
  /* 1328 */  false,
  /* 1329 */  false,
  /* 1330 */  false,
  /* 1331 */  false,
  /* 1332 */  false,
  /* 1333 */  false,
  /* 1334 */  false,
  /* 1335 */  false,
  /* 1336 */  false,
  /* 1337 */  false,
  /* 1338 */  false,
  /* 1339 */  false,
  /* 1340 */  false,
  /* 1341 */  false,
  /* 1342 */  false,
  /* 1343 */  false,
  /* 1344 */  false,
  /* 1345 */  false,
  /* 1346 */  false,
  /* 1347 */  false,
  /* 1348 */  false,
  /* 1349 */  false,
  /* 1350 */  false,
  /* 1351 */  false,
  /* 1352 */  false,
  /* 1353 */  false,
  /* 1354 */  false,
  /* 1355 */  false,
  /* 1356 */  false,
  /* 1357 */  false,
  /* 1358 */  false,
  /* 1359 */  false,
  /* 1360 */  false,
  /* 1361 */  false,
  /* 1362 */  false,
  /* 1363 */  false,
  /* 1364 */  false,
  /* 1365 */  false,
  /* 1366 */  false,
  /* 1367 */  false,
  /* 1368 */  false,
  /* 1369 */  false,
  /* 1370 */  false,
  /* 1371 */  false,
  /* 1372 */  false,
  /* 1373 */  false,
  /* 1374 */  false,
  /* 1375 */  false,
  /* 1376 */  false,
  /* 1377 */  false,
  /* 1378 */  false,
  /* 1379 */  false,
  /* 1380 */  false,
  /* 1381 */  false,
  /* 1382 */  false,
  /* 1383 */  false,
  /* 1384 */  false,
  /* 1385 */  false,
  /* 1386 */  false,
  /* 1387 */  false,
  /* 1388 */  false,
  /* 1389 */  false,
  /* 1390 */  false,
  /* 1391 */  false,
  /* 1392 */  false,
  /* 1393 */  false,
  /* 1394 */  false,
  /* 1395 */  false,
  /* 1396 */  false,
  /* 1397 */  false,
  /* 1398 */  false,
  /* 1399 */  false,
  /* 1400 */  false,
  /* 1401 */  false,
  /* 1402 */  false,
  /* 1403 */  false,
  /* 1404 */  false,
  /* 1405 */  false,
  /* 1406 */  false,
  /* 1407 */  false,
  /* 1408 */  false,
  /* 1409 */  false,
  /* 1410 */  false,
  /* 1411 */  false,
  /* 1412 */  false,
  /* 1413 */  false,
  /* 1414 */  false,
  /* 1415 */  false,
  /* 1416 */  false,
  /* 1417 */  false,
  /* 1418 */  false,
  /* 1419 */  false,
  /* 1420 */  false,
  /* 1421 */  false,
  /* 1422 */  false,
  /* 1423 */  false,
  /* 1424 */  false,
  /* 1425 */  false,
  /* 1426 */  false,
  /* 1427 */  false,
  /* 1428 */  false,
  /* 1429 */  false,
  /* 1430 */  false,
  /* 1431 */  false,
  /* 1432 */  false,
  /* 1433 */  false,
  /* 1434 */  false,
  /* 1435 */  false,
  /* 1436 */  false,
  /* 1437 */  false,
  /* 1438 */  false,
  /* 1439 */  false,
  /* 1440 */  false,
  /* 1441 */  false,
  /* 1442 */  false,
  /* 1443 */  false,
  /* 1444 */  false,
  /* 1445 */  false,
  /* 1446 */  false,
  /* 1447 */  false,
  /* 1448 */  false,
  /* 1449 */  false,
  /* 1450 */  false,
  /* 1451 */  false,
  /* 1452 */  false,
  /* 1453 */  false,
  /* 1454 */  false,
  /* 1455 */  false,
  /* 1456 */  false,
  /* 1457 */  false,
  /* 1458 */  false,
  /* 1459 */  false,
  /* 1460 */  false,
  /* 1461 */  false,
  /* 1462 */  false,
  /* 1463 */  false,
  /* 1464 */  false,
  /* 1465 */  false,
  /* 1466 */  false,
  /* 1467 */  false,
  /* 1468 */  false,
  /* 1469 */  false,
  /* 1470 */  false,
  /* 1471 */  false,
  /* 1472 */  false,
  /* 1473 */  false,
  /* 1474 */  false,
  /* 1475 */  false,
  /* 1476 */  false,
  /* 1477 */  false,
  /* 1478 */  false,
  /* 1479 */  false,
  /* 1480 */  false,
  /* 1481 */  false,
  /* 1482 */  false,
  /* 1483 */  false,
  /* 1484 */  false,
  /* 1485 */  false,
  /* 1486 */  false,
  /* 1487 */  false,
  /* 1488 */  false,
  /* 1489 */  false,
  /* 1490 */  false,
  /* 1491 */  false,
  /* 1492 */  false,
  /* 1493 */  false,
  /* 1494 */  false,
  /* 1495 */  false,
  /* 1496 */  false,
  /* 1497 */  false,
  /* 1498 */  false,
  /* 1499 */  false,
  /* 1500 */  false,
  /* 1501 */  false,
  /* 1502 */  false,
  /* 1503 */  false,
  /* 1504 */  false,
  /* 1505 */  false,
  /* 1506 */  false,
  /* 1507 */  false,
  /* 1508 */  false,
  /* 1509 */  false,
  /* 1510 */  false,
  /* 1511 */  false,
  /* 1512 */  false,
  /* 1513 */  false,
  /* 1514 */  false,
  /* 1515 */  false,
  /* 1516 */  false,
  /* 1517 */  false,
  /* 1518 */  false,
  /* 1519 */  false,
  /* 1520 */  false,
  /* 1521 */  false,
  /* 1522 */  false,
  /* 1523 */  false,
  /* 1524 */  false,
  /* 1525 */  false,
  /* 1526 */  false,
  /* 1527 */  false,
  /* 1528 */  false,
  /* 1529 */  false,
  /* 1530 */  false,
  /* 1531 */  false,
  /* 1532 */  false,
  /* 1533 */  false,
  /* 1534 */  false,
  /* 1535 */  false,
  /* 1536 */  false,
  /* 1537 */  false,
  /* 1538 */  false,
  /* 1539 */  false,
  /* 1540 */  false,
  /* 1541 */  false,
  /* 1542 */  false,
  /* 1543 */  false,
  /* 1544 */  false,
  /* 1545 */  false,
  /* 1546 */  false,
  /* 1547 */  false,
  /* 1548 */  false,
  /* 1549 */  false,
  /* 1550 */  false,
  /* 1551 */  false,
  /* 1552 */  false,
  /* 1553 */  false,
  /* 1554 */  false,
  /* 1555 */  false,
  /* 1556 */  false,
  /* 1557 */  false,
  /* 1558 */  false,
  /* 1559 */  false,
  /* 1560 */  false,
  /* 1561 */  false,
  /* 1562 */  false,
  /* 1563 */  false,
  /* 1564 */  false,
  /* 1565 */  false,
  /* 1566 */  false,
  /* 1567 */  false,
  /* 1568 */  false,
  /* 1569 */  false,
  /* 1570 */  false,
  /* 1571 */  false,
  /* 1572 */  false,
  /* 1573 */  false,
  /* 1574 */  false,
  /* 1575 */  false,
  /* 1576 */  false,
  /* 1577 */  false,
  /* 1578 */  false,
  /* 1579 */  false,
  /* 1580 */  false,
  /* 1581 */  false,
  /* 1582 */  false,
  /* 1583 */  false,
  /* 1584 */  false,
  /* 1585 */  false,
  /* 1586 */  false,
  /* 1587 */  false,
  /* 1588 */  false,
  /* 1589 */  false,
  /* 1590 */  false,
  /* 1591 */  false,
  /* 1592 */  false,
  /* 1593 */  false,
  /* 1594 */  false,
  /* 1595 */  false,
  /* 1596 */  false,
  /* 1597 */  false,
  /* 1598 */  false,
  /* 1599 */  false,
  /* 1600 */  false,
  /* 1601 */  false,
  /* 1602 */  false,
  /* 1603 */  false,
  /* 1604 */  false,
  /* 1605 */  false,
  /* 1606 */  false,
  /* 1607 */  false,
  /* 1608 */  false,
  /* 1609 */  false,
  /* 1610 */  false,
  /* 1611 */  false,
  /* 1612 */  false,
  /* 1613 */  false,
  /* 1614 */  false,
  /* 1615 */  false,
  /* 1616 */  false,
  /* 1617 */  false,
  /* 1618 */  false,
  /* 1619 */  false,
  /* 1620 */  false,
  /* 1621 */  false,
  /* 1622 */  false,
  /* 1623 */  false,
  /* 1624 */  false,
  /* 1625 */  false,
  /* 1626 */  false,
  /* 1627 */  false,
  /* 1628 */  false,
  /* 1629 */  false,
  /* 1630 */  false,
  /* 1631 */  false,
  /* 1632 */  false,
  /* 1633 */  false,
  /* 1634 */  false,
  /* 1635 */  false,
  /* 1636 */  false,
  /* 1637 */  false,
  /* 1638 */  false,
  /* 1639 */  false,
  /* 1640 */  false,
  /* 1641 */  false,
  /* 1642 */  false,
  /* 1643 */  false,
  /* 1644 */  false,
  /* 1645 */  false,
  /* 1646 */  false,
  /* 1647 */  false,
  /* 1648 */  false,
  /* 1649 */  false,
  /* 1650 */  false,
  /* 1651 */  false,
  /* 1652 */  false,
  /* 1653 */  false,
  /* 1654 */  false,
  /* 1655 */  false,
  /* 1656 */  false,
  /* 1657 */  false,
  /* 1658 */  false,
  /* 1659 */  false,
  /* 1660 */  false,
  /* 1661 */  false,
  /* 1662 */  false,
  /* 1663 */  false,
  /* 1664 */  false,
  /* 1665 */  false,
  /* 1666 */  false,
  /* 1667 */  false,
  /* 1668 */  false,
  /* 1669 */  false,
  /* 1670 */  false,
  /* 1671 */  false,
  /* 1672 */  false,
  /* 1673 */  false,
  /* 1674 */  false,
  /* 1675 */  false,
  /* 1676 */  false,
  /* 1677 */  false,
  /* 1678 */  false,
  /* 1679 */  false,
  /* 1680 */  false,
  /* 1681 */  false,
  /* 1682 */  false,
  /* 1683 */  false,
  /* 1684 */  false,
  /* 1685 */  false,
  /* 1686 */  false,
  /* 1687 */  false,
  /* 1688 */  false,
  /* 1689 */  false,
  /* 1690 */  false,
  /* 1691 */  false,
  /* 1692 */  false,
  /* 1693 */  false,
  /* 1694 */  false,
  /* 1695 */  false,
  /* 1696 */  false,
  /* 1697 */  false,
  /* 1698 */  false,
  /* 1699 */  false,
  /* 1700 */  false,
  /* 1701 */  false,
  /* 1702 */  false,
  /* 1703 */  false,
  /* 1704 */  false,
  /* 1705 */  false,
  /* 1706 */  false,
  /* 1707 */  false,
  /* 1708 */  false,
  /* 1709 */  false,
  /* 1710 */  false,
  /* 1711 */  false,
  /* 1712 */  false,
  /* 1713 */  false,
  /* 1714 */  false,
  /* 1715 */  false,
  /* 1716 */  false,
  /* 1717 */  false,
  /* 1718 */  false,
  /* 1719 */  false,
  /* 1720 */  false,
  /* 1721 */  false,
  /* 1722 */  false,
  /* 1723 */  false,
  /* 1724 */  false,
  /* 1725 */  false,
  /* 1726 */  false,
  /* 1727 */  false,
  /* 1728 */  false,
  /* 1729 */  false,
  /* 1730 */  false,
  /* 1731 */  false,
  /* 1732 */  false,
  /* 1733 */  false,
  /* 1734 */  false,
  /* 1735 */  false,
  /* 1736 */  false,
  /* 1737 */  false,
  /* 1738 */  false,
  /* 1739 */  false,
  /* 1740 */  false,
  /* 1741 */  false,
  /* 1742 */  false,
  /* 1743 */  false,
  /* 1744 */  false,
  /* 1745 */  false,
  /* 1746 */  false,
  /* 1747 */  false,
  /* 1748 */  false,
  /* 1749 */  false,
  /* 1750 */  false,
  /* 1751 */  false,
  /* 1752 */  false,
  /* 1753 */  false,
  /* 1754 */  false,
  /* 1755 */  false,
  /* 1756 */  false,
  /* 1757 */  false,
  /* 1758 */  false,
  /* 1759 */  false,
  /* 1760 */  false,
  /* 1761 */  false,
  /* 1762 */  false,
  /* 1763 */  false,
  /* 1764 */  false,
  /* 1765 */  false,
  /* 1766 */  false,
  /* 1767 */  false,
  /* 1768 */  false,
  /* 1769 */  false,
  /* 1770 */  false,
  /* 1771 */  false,
  /* 1772 */  false,
  /* 1773 */  false,
  /* 1774 */  false,
  /* 1775 */  false,
  /* 1776 */  false,
  /* 1777 */  false,
  /* 1778 */  false,
  /* 1779 */  false,
  /* 1780 */  false,
  /* 1781 */  false,
  /* 1782 */  false,
  /* 1783 */  false,
  /* 1784 */  false,
  /* 1785 */  false,
  /* 1786 */  false,
  /* 1787 */  false,
  /* 1788 */  false,
  /* 1789 */  false,
  /* 1790 */  false,
  /* 1791 */  false,
  /* 1792 */  false,
  /* 1793 */  false,
  /* 1794 */  false,
  /* 1795 */  false,
  /* 1796 */  false,
  /* 1797 */  false,
  /* 1798 */  false,
  /* 1799 */  false,
  /* 1800 */  false,
  /* 1801 */  false,
  /* 1802 */  false,
  /* 1803 */  false,
  /* 1804 */  false,
  /* 1805 */  false,
  /* 1806 */  false,
  /* 1807 */  false,
  /* 1808 */  false,
  /* 1809 */  false,
  /* 1810 */  false,
  /* 1811 */  false,
  /* 1812 */  false,
  /* 1813 */  false,
  /* 1814 */  false,
  /* 1815 */  false,
  /* 1816 */  false,
  /* 1817 */  false,
  /* 1818 */  false,
  /* 1819 */  false,
  /* 1820 */  false,
  /* 1821 */  false,
  /* 1822 */  false,
  /* 1823 */  false,
  /* 1824 */  false,
  /* 1825 */  false,
  /* 1826 */  false,
  /* 1827 */  false,
  /* 1828 */  false,
  /* 1829 */  false,
  /* 1830 */  false,
  /* 1831 */  false,
  /* 1832 */  false,
  /* 1833 */  false,
  /* 1834 */  false,
  /* 1835 */  false,
  /* 1836 */  false,
  /* 1837 */  false,
  /* 1838 */  false,
  /* 1839 */  false,
  /* 1840 */  false,
  /* 1841 */  false,
  /* 1842 */  false,
  /* 1843 */  false,
  /* 1844 */  false,
  /* 1845 */  false,
  /* 1846 */  false,
  /* 1847 */  false,
  /* 1848 */  false,
  /* 1849 */  false,
  /* 1850 */  false,
  /* 1851 */  false,
  /* 1852 */  false,
  /* 1853 */  false,
  /* 1854 */  false,
  /* 1855 */  false,
  /* 1856 */  false,
  /* 1857 */  false,
  /* 1858 */  false,
  /* 1859 */  false,
  /* 1860 */  false,
  /* 1861 */  false,
  /* 1862 */  false,
  /* 1863 */  false,
  /* 1864 */  false,
  /* 1865 */  false,
  /* 1866 */  false,
  /* 1867 */  false,
  /* 1868 */  false,
  /* 1869 */  false,
  /* 1870 */  false,
  /* 1871 */  false,
  /* 1872 */  false,
  /* 1873 */  false,
  /* 1874 */  false,
  /* 1875 */  false,
  /* 1876 */  false,
  /* 1877 */  false,
  /* 1878 */  false,
  /* 1879 */  false,
  /* 1880 */  false,
  /* 1881 */  false,
  /* 1882 */  false,
  /* 1883 */  false,
  /* 1884 */  false,
  /* 1885 */  false,
  /* 1886 */  false,
  /* 1887 */  false,
  /* 1888 */  false,
  /* 1889 */  false,
  /* 1890 */  false,
  /* 1891 */  false,
  /* 1892 */  false,
  /* 1893 */  false,
  /* 1894 */  false,
  /* 1895 */  false,
  /* 1896 */  false,
  /* 1897 */  false,
  /* 1898 */  false,
  /* 1899 */  false,
  /* 1900 */  false,
  /* 1901 */  false,
  /* 1902 */  false,
  /* 1903 */  false,
  /* 1904 */  false,
  /* 1905 */  false,
  /* 1906 */  false,
  /* 1907 */  false,
  /* 1908 */  false,
  /* 1909 */  false,
  /* 1910 */  false,
  /* 1911 */  false,
  /* 1912 */  false,
  /* 1913 */  false,
  /* 1914 */  false,
  /* 1915 */  false,
  /* 1916 */  false,
  /* 1917 */  false,
  /* 1918 */  false,
  /* 1919 */  false,
  /* 1920 */  false,
  /* 1921 */  false,
  /* 1922 */  false,
  /* 1923 */  false,
  /* 1924 */  false,
  /* 1925 */  false,
  /* 1926 */  false,
  /* 1927 */  false,
  /* 1928 */  false,
  /* 1929 */  false,
  /* 1930 */  false,
  /* 1931 */  false,
  /* 1932 */  false,
  /* 1933 */  false,
  /* 1934 */  false,
  /* 1935 */  false,
  /* 1936 */  false,
  /* 1937 */  false,
  /* 1938 */  false,
  /* 1939 */  false,
  /* 1940 */  false,
  /* 1941 */  false,
  /* 1942 */  false,
  /* 1943 */  false,
  /* 1944 */  false,
  /* 1945 */  false,
  /* 1946 */  false,
  /* 1947 */  false,
  /* 1948 */  false,
  /* 1949 */  false,
  /* 1950 */  false,
  /* 1951 */  false,
  /* 1952 */  false,
  /* 1953 */  false,
  /* 1954 */  false,
  /* 1955 */  false,
  /* 1956 */  false,
  /* 1957 */  false,
  /* 1958 */  false,
  /* 1959 */  false,
  /* 1960 */  false,
  /* 1961 */  false,
  /* 1962 */  false,
  /* 1963 */  false,
  /* 1964 */  false,
  /* 1965 */  false,
  /* 1966 */  false,
  /* 1967 */  false,
  /* 1968 */  false,
  /* 1969 */  false,
  /* 1970 */  false,
  /* 1971 */  false,
  /* 1972 */  false,
  /* 1973 */  false,
  /* 1974 */  false,
  /* 1975 */  false,
  /* 1976 */  false,
  /* 1977 */  false,
  /* 1978 */  false,
  /* 1979 */  false,
  /* 1980 */  false,
  /* 1981 */  false,
  /* 1982 */  false,
  /* 1983 */  false,
  /* 1984 */  false,
  /* 1985 */  false,
  /* 1986 */  false,
  /* 1987 */  false,
  /* 1988 */  false,
  /* 1989 */  false,
  /* 1990 */  false,
  // last instruction
  false // no trailing comma
};

// Mapping from machine-independent opcode to boolean
const        char must_clone[] = {
  0, // Node: 0
  0, // Set: 1
  0, // RegN: 2
  0, // RegI: 3
  0, // RegP: 4
  0, // RegF: 5
  0, // RegD: 6
  0, // RegL: 7
  0, // VecA: 8
  0, // VecS: 9
  0, // VecD: 10
  0, // VecX: 11
  0, // VecY: 12
  0, // VecZ: 13
  0, // RegVectMask: 14
  0, // RegFlags: 15
  0, // _last_machine_leaf: 16
  0, // AbsD: 17
  0, // AbsF: 18
  0, // AbsI: 19
  0, // AbsL: 20
  0, // AddD: 21
  0, // AddF: 22
  0, // AddI: 23
  0, // AddL: 24
  0, // AddP: 25
  0, // Allocate: 26
  0, // AllocateArray: 27
  0, // AndI: 28
  0, // AndL: 29
  0, // ArrayCopy: 30
  0, // AryEq: 31
  0, // AtanD: 32
  1, // Binary: 33
  0, // Blackhole: 34
  1, // Bool: 35
  0, // BoxLock: 36
  0, // ReverseBytesI: 37
  0, // ReverseBytesL: 38
  0, // ReverseBytesUS: 39
  0, // ReverseBytesS: 40
  0, // CProj: 41
  0, // CacheWB: 42
  0, // CacheWBPreSync: 43
  0, // CacheWBPostSync: 44
  0, // CallDynamicJava: 45
  0, // CallJava: 46
  0, // CallLeaf: 47
  0, // CallLeafNoFP: 48
  0, // CallLeafVector: 49
  0, // CallRuntime: 50
  0, // CallNative: 51
  0, // CallStaticJava: 52
  0, // CastDD: 53
  0, // CastFF: 54
  0, // CastII: 55
  0, // CastLL: 56
  0, // CastVV: 57
  0, // CastX2P: 58
  0, // CastP2X: 59
  0, // CastPP: 60
  0, // Catch: 61
  0, // CatchProj: 62
  0, // CheckCastPP: 63
  0, // ClearArray: 64
  0, // ConstraintCast: 65
  0, // CMoveD: 66
  0, // CMoveVD: 67
  0, // CMoveF: 68
  0, // CMoveVF: 69
  0, // CMoveI: 70
  0, // CMoveL: 71
  0, // CMoveP: 72
  0, // CMoveN: 73
  1, // CmpN: 74
  1, // CmpD: 75
  0, // CmpD3: 76
  1, // CmpF: 77
  0, // CmpF3: 78
  1, // CmpI: 79
  1, // CmpL: 80
  0, // CmpL3: 81
  0, // CmpLTMask: 82
  1, // CmpP: 83
  1, // CmpU: 84
  1, // CmpUL: 85
  0, // CompareAndSwapB: 86
  0, // CompareAndSwapS: 87
  0, // CompareAndSwapI: 88
  0, // CompareAndSwapL: 89
  0, // CompareAndSwapP: 90
  0, // CompareAndSwapN: 91
  0, // WeakCompareAndSwapB: 92
  0, // WeakCompareAndSwapS: 93
  0, // WeakCompareAndSwapI: 94
  0, // WeakCompareAndSwapL: 95
  0, // WeakCompareAndSwapP: 96
  0, // WeakCompareAndSwapN: 97
  0, // CompareAndExchangeB: 98
  0, // CompareAndExchangeS: 99
  0, // CompareAndExchangeI: 100
  0, // CompareAndExchangeL: 101
  0, // CompareAndExchangeP: 102
  0, // CompareAndExchangeN: 103
  0, // GetAndAddB: 104
  0, // GetAndAddS: 105
  0, // GetAndAddI: 106
  0, // GetAndAddL: 107
  0, // GetAndSetB: 108
  0, // GetAndSetS: 109
  0, // GetAndSetI: 110
  0, // GetAndSetL: 111
  0, // GetAndSetP: 112
  0, // GetAndSetN: 113
  0, // Con: 114
  0, // ConN: 115
  0, // ConNKlass: 116
  0, // ConD: 117
  0, // ConF: 118
  0, // ConI: 119
  0, // ConL: 120
  0, // ConP: 121
  0, // Conv2B: 122
  0, // ConvD2F: 123
  0, // ConvD2I: 124
  0, // ConvD2L: 125
  0, // ConvF2D: 126
  0, // ConvF2I: 127
  0, // ConvF2L: 128
  0, // ConvI2D: 129
  0, // ConvI2F: 130
  0, // ConvI2L: 131
  0, // ConvL2D: 132
  0, // ConvL2F: 133
  0, // ConvL2I: 134
  0, // CountedLoop: 135
  0, // CountedLoopEnd: 136
  0, // OuterStripMinedLoop: 137
  0, // OuterStripMinedLoopEnd: 138
  0, // LongCountedLoop: 139
  0, // LongCountedLoopEnd: 140
  0, // CountLeadingZerosI: 141
  0, // CountLeadingZerosL: 142
  0, // CountTrailingZerosI: 143
  0, // CountTrailingZerosL: 144
  0, // CreateEx: 145
  0, // DecodeN: 146
  0, // DecodeNKlass: 147
  0, // DivD: 148
  0, // DivF: 149
  0, // DivI: 150
  0, // DivL: 151
  0, // DivMod: 152
  0, // DivModI: 153
  0, // DivModL: 154
  0, // EncodeISOArray: 155
  0, // EncodeP: 156
  0, // EncodePKlass: 157
  1, // FastLock: 158
  1, // FastUnlock: 159
  0, // FmaD: 160
  0, // FmaF: 161
  0, // Goto: 162
  0, // Halt: 163
  0, // HasNegatives: 164
  0, // If: 165
  0, // RangeCheck: 166
  0, // IfFalse: 167
  0, // IfTrue: 168
  0, // Initialize: 169
  0, // JProj: 170
  0, // Jump: 171
  0, // JumpProj: 172
  0, // LShiftI: 173
  0, // LShiftL: 174
  0, // LoadB: 175
  0, // LoadUB: 176
  0, // LoadUS: 177
  0, // LoadD: 178
  0, // LoadD_unaligned: 179
  0, // LoadF: 180
  0, // LoadI: 181
  0, // LoadKlass: 182
  0, // LoadNKlass: 183
  0, // LoadL: 184
  0, // LoadL_unaligned: 185
  0, // LoadPLocked: 186
  0, // LoadP: 187
  0, // LoadN: 188
  0, // LoadRange: 189
  0, // LoadS: 190
  0, // Lock: 191
  0, // Loop: 192
  0, // LoopLimit: 193
  0, // Mach: 194
  0, // MachNullCheck: 195
  0, // MachProj: 196
  0, // MulAddS2I: 197
  0, // MaxI: 198
  0, // MaxL: 199
  0, // MaxD: 200
  0, // MaxF: 201
  0, // MemBarAcquire: 202
  0, // LoadFence: 203
  0, // SetVectMaskI: 204
  0, // MemBarAcquireLock: 205
  0, // MemBarCPUOrder: 206
  0, // MemBarRelease: 207
  0, // StoreFence: 208
  0, // StoreStoreFence: 209
  0, // MemBarReleaseLock: 210
  0, // MemBarVolatile: 211
  0, // MemBarStoreStore: 212
  0, // MergeMem: 213
  0, // MinI: 214
  0, // MinL: 215
  0, // MinF: 216
  0, // MinD: 217
  0, // ModD: 218
  0, // ModF: 219
  0, // ModI: 220
  0, // ModL: 221
  0, // MoveI2F: 222
  0, // MoveF2I: 223
  0, // MoveL2D: 224
  0, // MoveD2L: 225
  0, // MulD: 226
  0, // MulF: 227
  0, // MulHiL: 228
  0, // UMulHiL: 229
  0, // MulI: 230
  0, // MulL: 231
  0, // Multi: 232
  0, // NegI: 233
  0, // NegL: 234
  0, // NegD: 235
  0, // NegF: 236
  0, // NeverBranch: 237
  0, // OnSpinWait: 238
  0, // Opaque1: 239
  0, // OpaqueLoopInit: 240
  0, // OpaqueLoopStride: 241
  0, // Opaque2: 242
  0, // Opaque3: 243
  0, // Opaque4: 244
  0, // ProfileBoolean: 245
  0, // OrI: 246
  0, // OrL: 247
  1, // OverflowAddI: 248
  1, // OverflowSubI: 249
  1, // OverflowMulI: 250
  1, // OverflowAddL: 251
  1, // OverflowSubL: 252
  1, // OverflowMulL: 253
  0, // PCTable: 254
  0, // Parm: 255
  0, // PartialSubtypeCheck: 256
  0, // SubTypeCheck: 257
  0, // Phi: 258
  0, // PopCountI: 259
  0, // PopCountL: 260
  0, // PopCountVI: 261
  0, // PrefetchAllocation: 262
  0, // Proj: 263
  0, // RShiftI: 264
  0, // RShiftL: 265
  0, // Region: 266
  0, // Rethrow: 267
  0, // Return: 268
  0, // Root: 269
  0, // RoundDouble: 270
  0, // RoundDoubleMode: 271
  0, // RoundDoubleModeV: 272
  0, // RoundFloat: 273
  0, // RotateLeft: 274
  0, // RotateLeftV: 275
  0, // RotateRight: 276
  0, // RotateRightV: 277
  0, // SafePoint: 278
  0, // SafePointScalarObject: 279
  0, // ShenandoahCompareAndExchangeP: 280
  0, // ShenandoahCompareAndExchangeN: 281
  0, // ShenandoahCompareAndSwapN: 282
  0, // ShenandoahCompareAndSwapP: 283
  0, // ShenandoahWeakCompareAndSwapN: 284
  0, // ShenandoahWeakCompareAndSwapP: 285
  0, // ShenandoahIUBarrier: 286
  0, // ShenandoahLoadReferenceBarrier: 287
  0, // SCMemProj: 288
  0, // CopySignD: 289
  0, // CopySignF: 290
  0, // SignumD: 291
  0, // SignumF: 292
  0, // SqrtD: 293
  0, // SqrtF: 294
  0, // Start: 295
  0, // StartOSR: 296
  0, // StoreB: 297
  0, // StoreC: 298
  0, // StoreCM: 299
  0, // StorePConditional: 300
  0, // StoreIConditional: 301
  0, // StoreLConditional: 302
  0, // StoreD: 303
  0, // StoreF: 304
  0, // StoreI: 305
  0, // StoreL: 306
  0, // StoreP: 307
  0, // StoreN: 308
  0, // StoreNKlass: 309
  0, // StrComp: 310
  0, // StrCompressedCopy: 311
  0, // StrEquals: 312
  0, // StrIndexOf: 313
  0, // StrIndexOfChar: 314
  0, // StrInflatedCopy: 315
  0, // SubD: 316
  0, // SubF: 317
  0, // SubI: 318
  0, // SubL: 319
  0, // TailCall: 320
  0, // TailJump: 321
  0, // MacroLogicV: 322
  0, // ThreadLocal: 323
  0, // Unlock: 324
  0, // URShiftB: 325
  0, // URShiftS: 326
  0, // URShiftI: 327
  0, // URShiftL: 328
  0, // XorI: 329
  0, // XorL: 330
  0, // Vector: 331
  0, // AddVB: 332
  0, // AddVS: 333
  0, // AddVI: 334
  0, // AddReductionVI: 335
  0, // AddVL: 336
  0, // AddReductionVL: 337
  0, // AddVF: 338
  0, // AddReductionVF: 339
  0, // AddVD: 340
  0, // AddReductionVD: 341
  0, // SubVB: 342
  0, // SubVS: 343
  0, // SubVI: 344
  0, // SubVL: 345
  0, // SubVF: 346
  0, // SubVD: 347
  0, // MulVB: 348
  0, // MulVS: 349
  0, // MulVI: 350
  0, // MulReductionVI: 351
  0, // MulVL: 352
  0, // MulReductionVL: 353
  0, // MulVF: 354
  0, // MulReductionVF: 355
  0, // MulVD: 356
  0, // MulReductionVD: 357
  0, // MulAddVS2VI: 358
  0, // FmaVD: 359
  0, // FmaVF: 360
  0, // DivVF: 361
  0, // DivVD: 362
  0, // AbsVB: 363
  0, // AbsVS: 364
  0, // AbsVI: 365
  0, // AbsVL: 366
  0, // AbsVF: 367
  0, // AbsVD: 368
  0, // NegVI: 369
  0, // NegVF: 370
  0, // NegVD: 371
  0, // SqrtVD: 372
  0, // SqrtVF: 373
  0, // LShiftCntV: 374
  0, // RShiftCntV: 375
  0, // LShiftVB: 376
  0, // LShiftVS: 377
  0, // LShiftVI: 378
  0, // LShiftVL: 379
  0, // RShiftVB: 380
  0, // RShiftVS: 381
  0, // RShiftVI: 382
  0, // RShiftVL: 383
  0, // URShiftVB: 384
  0, // URShiftVS: 385
  0, // URShiftVI: 386
  0, // URShiftVL: 387
  0, // AndV: 388
  0, // AndReductionV: 389
  0, // OrV: 390
  0, // OrReductionV: 391
  0, // XorV: 392
  0, // XorReductionV: 393
  0, // MinV: 394
  0, // MaxV: 395
  0, // MinReductionV: 396
  0, // MaxReductionV: 397
  0, // LoadVector: 398
  0, // LoadVectorGather: 399
  0, // LoadVectorGatherMasked: 400
  0, // StoreVector: 401
  0, // StoreVectorScatter: 402
  0, // StoreVectorScatterMasked: 403
  0, // LoadVectorMasked: 404
  0, // StoreVectorMasked: 405
  0, // VectorCmpMasked: 406
  0, // VectorMaskGen: 407
  0, // VectorMaskOp: 408
  0, // VectorMaskTrueCount: 409
  0, // VectorMaskFirstTrue: 410
  0, // VectorMaskLastTrue: 411
  0, // VectorMaskToLong: 412
  0, // Pack: 413
  0, // PackB: 414
  0, // PackS: 415
  0, // PackI: 416
  0, // PackL: 417
  0, // PackF: 418
  0, // PackD: 419
  0, // Pack2L: 420
  0, // Pack2D: 421
  0, // ReplicateB: 422
  0, // ReplicateS: 423
  0, // ReplicateI: 424
  0, // ReplicateL: 425
  0, // ReplicateF: 426
  0, // ReplicateD: 427
  0, // Extract: 428
  0, // ExtractB: 429
  0, // ExtractUB: 430
  0, // ExtractC: 431
  0, // ExtractS: 432
  0, // ExtractI: 433
  0, // ExtractL: 434
  0, // ExtractF: 435
  0, // ExtractD: 436
  0, // Digit: 437
  0, // LowerCase: 438
  0, // UpperCase: 439
  0, // Whitespace: 440
  0, // VectorBox: 441
  0, // VectorBoxAllocate: 442
  0, // VectorUnbox: 443
  0, // VectorMaskWrapper: 444
  0, // VectorMaskCmp: 445
  0, // VectorMaskCast: 446
  0, // VectorTest: 447
  0, // VectorBlend: 448
  0, // VectorRearrange: 449
  0, // VectorLoadMask: 450
  0, // VectorLoadShuffle: 451
  0, // VectorLoadConst: 452
  0, // VectorStoreMask: 453
  0, // VectorReinterpret: 454
  0, // VectorCast: 455
  0, // VectorCastB2X: 456
  0, // VectorCastS2X: 457
  0, // VectorCastI2X: 458
  0, // VectorCastL2X: 459
  0, // VectorCastF2X: 460
  0, // VectorCastD2X: 461
  0, // VectorInsert: 462
  0, // MaskAll: 463
  0, // AndVMask: 464
  0, // OrVMask: 465
  0 // no trailing comma // XorVMask: 466
};
//  The following instructions can cisc-spill



// An array of character pointers to machine register names.
const char *Matcher::regName[REG_COUNT] = {
  "R10",
  "R10_H",
  "R11",
  "R11_H",
  "R12",
  "R12_H",
  "R13",
  "R13_H",
  "R14",
  "R14_H",
  "R15",
  "R15_H",
  "R16",
  "R16_H",
  "R17",
  "R17_H",
  "R18",
  "R18_H",
  "R0",
  "R0_H",
  "R1",
  "R1_H",
  "R2",
  "R2_H",
  "R3",
  "R3_H",
  "R4",
  "R4_H",
  "R5",
  "R5_H",
  "R6",
  "R6_H",
  "R7",
  "R7_H",
  "R19",
  "R19_H",
  "R20",
  "R20_H",
  "R21",
  "R21_H",
  "R22",
  "R22_H",
  "R23",
  "R23_H",
  "R24",
  "R24_H",
  "R25",
  "R25_H",
  "R26",
  "R26_H",
  "R27",
  "R27_H",
  "R28",
  "R28_H",
  "R29",
  "R29_H",
  "R30",
  "R30_H",
  "R31",
  "R31_H",
  "R8",
  "R8_H",
  "R9",
  "R9_H",
  "V16",
  "V16_H",
  "V16_J",
  "V16_K",
  "V16_L",
  "V16_M",
  "V16_N",
  "V16_O",
  "V17",
  "V17_H",
  "V17_J",
  "V17_K",
  "V17_L",
  "V17_M",
  "V17_N",
  "V17_O",
  "V18",
  "V18_H",
  "V18_J",
  "V18_K",
  "V18_L",
  "V18_M",
  "V18_N",
  "V18_O",
  "V19",
  "V19_H",
  "V19_J",
  "V19_K",
  "V19_L",
  "V19_M",
  "V19_N",
  "V19_O",
  "V20",
  "V20_H",
  "V20_J",
  "V20_K",
  "V20_L",
  "V20_M",
  "V20_N",
  "V20_O",
  "V21",
  "V21_H",
  "V21_J",
  "V21_K",
  "V21_L",
  "V21_M",
  "V21_N",
  "V21_O",
  "V22",
  "V22_H",
  "V22_J",
  "V22_K",
  "V22_L",
  "V22_M",
  "V22_N",
  "V22_O",
  "V23",
  "V23_H",
  "V23_J",
  "V23_K",
  "V23_L",
  "V23_M",
  "V23_N",
  "V23_O",
  "V24",
  "V24_H",
  "V24_J",
  "V24_K",
  "V24_L",
  "V24_M",
  "V24_N",
  "V24_O",
  "V25",
  "V25_H",
  "V25_J",
  "V25_K",
  "V25_L",
  "V25_M",
  "V25_N",
  "V25_O",
  "V26",
  "V26_H",
  "V26_J",
  "V26_K",
  "V26_L",
  "V26_M",
  "V26_N",
  "V26_O",
  "V27",
  "V27_H",
  "V27_J",
  "V27_K",
  "V27_L",
  "V27_M",
  "V27_N",
  "V27_O",
  "V28",
  "V28_H",
  "V28_J",
  "V28_K",
  "V28_L",
  "V28_M",
  "V28_N",
  "V28_O",
  "V29",
  "V29_H",
  "V29_J",
  "V29_K",
  "V29_L",
  "V29_M",
  "V29_N",
  "V29_O",
  "V30",
  "V30_H",
  "V30_J",
  "V30_K",
  "V30_L",
  "V30_M",
  "V30_N",
  "V30_O",
  "V31",
  "V31_H",
  "V31_J",
  "V31_K",
  "V31_L",
  "V31_M",
  "V31_N",
  "V31_O",
  "V0",
  "V0_H",
  "V0_J",
  "V0_K",
  "V0_L",
  "V0_M",
  "V0_N",
  "V0_O",
  "V1",
  "V1_H",
  "V1_J",
  "V1_K",
  "V1_L",
  "V1_M",
  "V1_N",
  "V1_O",
  "V2",
  "V2_H",
  "V2_J",
  "V2_K",
  "V2_L",
  "V2_M",
  "V2_N",
  "V2_O",
  "V3",
  "V3_H",
  "V3_J",
  "V3_K",
  "V3_L",
  "V3_M",
  "V3_N",
  "V3_O",
  "V4",
  "V4_H",
  "V4_J",
  "V4_K",
  "V4_L",
  "V4_M",
  "V4_N",
  "V4_O",
  "V5",
  "V5_H",
  "V5_J",
  "V5_K",
  "V5_L",
  "V5_M",
  "V5_N",
  "V5_O",
  "V6",
  "V6_H",
  "V6_J",
  "V6_K",
  "V6_L",
  "V6_M",
  "V6_N",
  "V6_O",
  "V7",
  "V7_H",
  "V7_J",
  "V7_K",
  "V7_L",
  "V7_M",
  "V7_N",
  "V7_O",
  "V8",
  "V8_H",
  "V8_J",
  "V8_K",
  "V8_L",
  "V8_M",
  "V8_N",
  "V8_O",
  "V9",
  "V9_H",
  "V9_J",
  "V9_K",
  "V9_L",
  "V9_M",
  "V9_N",
  "V9_O",
  "V10",
  "V10_H",
  "V10_J",
  "V10_K",
  "V10_L",
  "V10_M",
  "V10_N",
  "V10_O",
  "V11",
  "V11_H",
  "V11_J",
  "V11_K",
  "V11_L",
  "V11_M",
  "V11_N",
  "V11_O",
  "V12",
  "V12_H",
  "V12_J",
  "V12_K",
  "V12_L",
  "V12_M",
  "V12_N",
  "V12_O",
  "V13",
  "V13_H",
  "V13_J",
  "V13_K",
  "V13_L",
  "V13_M",
  "V13_N",
  "V13_O",
  "V14",
  "V14_H",
  "V14_J",
  "V14_K",
  "V14_L",
  "V14_M",
  "V14_N",
  "V14_O",
  "V15",
  "V15_H",
  "V15_J",
  "V15_K",
  "V15_L",
  "V15_M",
  "V15_N",
  "V15_O",
  "P0",
  "P1",
  "P2",
  "P3",
  "P4",
  "P5",
  "P6",
  "P7",
  "P8",
  "P9",
  "P10",
  "P11",
  "P12",
  "P13",
  "P14",
  "P15",
  "RFLAGS" // no trailing comma
};

// An array of character pointers to machine register names.
const VMReg OptoReg::opto2vm[REG_COUNT] = {
	r10->as_VMReg()        ,
	r10->as_VMReg()->next(),
	r11->as_VMReg()        ,
	r11->as_VMReg()->next(),
	r12->as_VMReg()        ,
	r12->as_VMReg()->next(),
	r13->as_VMReg()        ,
	r13->as_VMReg()->next(),
	r14->as_VMReg()        ,
	r14->as_VMReg()->next(),
	r15->as_VMReg()        ,
	r15->as_VMReg()->next(),
	r16->as_VMReg()        ,
	r16->as_VMReg()->next(),
	r17->as_VMReg()        ,
	r17->as_VMReg()->next(),
	r18_tls->as_VMReg()        ,
	r18_tls->as_VMReg()->next(),
	r0->as_VMReg()         ,
	r0->as_VMReg()->next() ,
	r1->as_VMReg()         ,
	r1->as_VMReg()->next() ,
	r2->as_VMReg()         ,
	r2->as_VMReg()->next() ,
	r3->as_VMReg()         ,
	r3->as_VMReg()->next() ,
	r4->as_VMReg()         ,
	r4->as_VMReg()->next() ,
	r5->as_VMReg()         ,
	r5->as_VMReg()->next() ,
	r6->as_VMReg()         ,
	r6->as_VMReg()->next() ,
	r7->as_VMReg()         ,
	r7->as_VMReg()->next() ,
	r19->as_VMReg()        ,
	r19->as_VMReg()->next(),
	r20->as_VMReg()        ,
	r20->as_VMReg()->next(),
	r21->as_VMReg()        ,
	r21->as_VMReg()->next(),
	r22->as_VMReg()        ,
	r22->as_VMReg()->next(),
	r23->as_VMReg()        ,
	r23->as_VMReg()->next(),
	r24->as_VMReg()        ,
	r24->as_VMReg()->next(),
	r25->as_VMReg()        ,
	r25->as_VMReg()->next(),
	r26->as_VMReg()        ,
	r26->as_VMReg()->next(),
	r27->as_VMReg()        ,
	r27->as_VMReg()->next(),
	r28->as_VMReg()        ,
	r28->as_VMReg()->next(),
	r29->as_VMReg()        ,
	r29->as_VMReg()->next(),
	r30->as_VMReg()        ,
	r30->as_VMReg()->next(),
	r31_sp->as_VMReg()     ,
	r31_sp->as_VMReg()->next(),
	r8->as_VMReg()         ,
	r8->as_VMReg()->next() ,
	r9->as_VMReg()         ,
	r9->as_VMReg()->next() ,
	v16->as_VMReg()          ,
	v16->as_VMReg()->next()  ,
	v16->as_VMReg()->next(2) ,
	v16->as_VMReg()->next(3) ,
	v16->as_VMReg()->next(4) ,
	v16->as_VMReg()->next(5) ,
	v16->as_VMReg()->next(6) ,
	v16->as_VMReg()->next(7) ,
	v17->as_VMReg()          ,
	v17->as_VMReg()->next()  ,
	v17->as_VMReg()->next(2) ,
	v17->as_VMReg()->next(3) ,
	v17->as_VMReg()->next(4) ,
	v17->as_VMReg()->next(5) ,
	v17->as_VMReg()->next(6) ,
	v17->as_VMReg()->next(7) ,
	v18->as_VMReg()          ,
	v18->as_VMReg()->next()  ,
	v18->as_VMReg()->next(2) ,
	v18->as_VMReg()->next(3) ,
	v18->as_VMReg()->next(4) ,
	v18->as_VMReg()->next(5) ,
	v18->as_VMReg()->next(6) ,
	v18->as_VMReg()->next(7) ,
	v19->as_VMReg()          ,
	v19->as_VMReg()->next()  ,
	v19->as_VMReg()->next(2) ,
	v19->as_VMReg()->next(3) ,
	v19->as_VMReg()->next(4) ,
	v19->as_VMReg()->next(5) ,
	v19->as_VMReg()->next(6) ,
	v19->as_VMReg()->next(7) ,
	v20->as_VMReg()          ,
	v20->as_VMReg()->next()  ,
	v20->as_VMReg()->next(2) ,
	v20->as_VMReg()->next(3) ,
	v20->as_VMReg()->next(4) ,
	v20->as_VMReg()->next(5) ,
	v20->as_VMReg()->next(6) ,
	v20->as_VMReg()->next(7) ,
	v21->as_VMReg()          ,
	v21->as_VMReg()->next()  ,
	v21->as_VMReg()->next(2) ,
	v21->as_VMReg()->next(3) ,
	v21->as_VMReg()->next(4) ,
	v21->as_VMReg()->next(5) ,
	v21->as_VMReg()->next(6) ,
	v21->as_VMReg()->next(7) ,
	v22->as_VMReg()          ,
	v22->as_VMReg()->next()  ,
	v22->as_VMReg()->next(2) ,
	v22->as_VMReg()->next(3) ,
	v22->as_VMReg()->next(4) ,
	v22->as_VMReg()->next(5) ,
	v22->as_VMReg()->next(6) ,
	v22->as_VMReg()->next(7) ,
	v23->as_VMReg()          ,
	v23->as_VMReg()->next()  ,
	v23->as_VMReg()->next(2) ,
	v23->as_VMReg()->next(3) ,
	v23->as_VMReg()->next(4) ,
	v23->as_VMReg()->next(5) ,
	v23->as_VMReg()->next(6) ,
	v23->as_VMReg()->next(7) ,
	v24->as_VMReg()          ,
	v24->as_VMReg()->next()  ,
	v24->as_VMReg()->next(2) ,
	v24->as_VMReg()->next(3) ,
	v24->as_VMReg()->next(4) ,
	v24->as_VMReg()->next(5) ,
	v24->as_VMReg()->next(6) ,
	v24->as_VMReg()->next(7) ,
	v25->as_VMReg()          ,
	v25->as_VMReg()->next()  ,
	v25->as_VMReg()->next(2) ,
	v25->as_VMReg()->next(3) ,
	v25->as_VMReg()->next(4) ,
	v25->as_VMReg()->next(5) ,
	v25->as_VMReg()->next(6) ,
	v25->as_VMReg()->next(7) ,
	v26->as_VMReg()          ,
	v26->as_VMReg()->next()  ,
	v26->as_VMReg()->next(2) ,
	v26->as_VMReg()->next(3) ,
	v26->as_VMReg()->next(4) ,
	v26->as_VMReg()->next(5) ,
	v26->as_VMReg()->next(6) ,
	v26->as_VMReg()->next(7) ,
	v27->as_VMReg()          ,
	v27->as_VMReg()->next()  ,
	v27->as_VMReg()->next(2) ,
	v27->as_VMReg()->next(3) ,
	v27->as_VMReg()->next(4) ,
	v27->as_VMReg()->next(5) ,
	v27->as_VMReg()->next(6) ,
	v27->as_VMReg()->next(7) ,
	v28->as_VMReg()          ,
	v28->as_VMReg()->next()  ,
	v28->as_VMReg()->next(2) ,
	v28->as_VMReg()->next(3) ,
	v28->as_VMReg()->next(4) ,
	v28->as_VMReg()->next(5) ,
	v28->as_VMReg()->next(6) ,
	v28->as_VMReg()->next(7) ,
	v29->as_VMReg()          ,
	v29->as_VMReg()->next()  ,
	v29->as_VMReg()->next(2) ,
	v29->as_VMReg()->next(3) ,
	v29->as_VMReg()->next(4) ,
	v29->as_VMReg()->next(5) ,
	v29->as_VMReg()->next(6) ,
	v29->as_VMReg()->next(7) ,
	v30->as_VMReg()          ,
	v30->as_VMReg()->next()  ,
	v30->as_VMReg()->next(2) ,
	v30->as_VMReg()->next(3) ,
	v30->as_VMReg()->next(4) ,
	v30->as_VMReg()->next(5) ,
	v30->as_VMReg()->next(6) ,
	v30->as_VMReg()->next(7) ,
	v31->as_VMReg()          ,
	v31->as_VMReg()->next()  ,
	v31->as_VMReg()->next(2) ,
	v31->as_VMReg()->next(3) ,
	v31->as_VMReg()->next(4) ,
	v31->as_VMReg()->next(5) ,
	v31->as_VMReg()->next(6) ,
	v31->as_VMReg()->next(7) ,
	v0->as_VMReg()          ,
	v0->as_VMReg()->next()  ,
	v0->as_VMReg()->next(2) ,
	v0->as_VMReg()->next(3) ,
	v0->as_VMReg()->next(4) ,
	v0->as_VMReg()->next(5) ,
	v0->as_VMReg()->next(6) ,
	v0->as_VMReg()->next(7) ,
	v1->as_VMReg()          ,
	v1->as_VMReg()->next()  ,
	v1->as_VMReg()->next(2) ,
	v1->as_VMReg()->next(3) ,
	v1->as_VMReg()->next(4) ,
	v1->as_VMReg()->next(5) ,
	v1->as_VMReg()->next(6) ,
	v1->as_VMReg()->next(7) ,
	v2->as_VMReg()          ,
	v2->as_VMReg()->next()  ,
	v2->as_VMReg()->next(2) ,
	v2->as_VMReg()->next(3) ,
	v2->as_VMReg()->next(4) ,
	v2->as_VMReg()->next(5) ,
	v2->as_VMReg()->next(6) ,
	v2->as_VMReg()->next(7) ,
	v3->as_VMReg()          ,
	v3->as_VMReg()->next()  ,
	v3->as_VMReg()->next(2) ,
	v3->as_VMReg()->next(3) ,
	v3->as_VMReg()->next(4) ,
	v3->as_VMReg()->next(5) ,
	v3->as_VMReg()->next(6) ,
	v3->as_VMReg()->next(7) ,
	v4->as_VMReg()          ,
	v4->as_VMReg()->next()  ,
	v4->as_VMReg()->next(2) ,
	v4->as_VMReg()->next(3) ,
	v4->as_VMReg()->next(4) ,
	v4->as_VMReg()->next(5) ,
	v4->as_VMReg()->next(6) ,
	v4->as_VMReg()->next(7) ,
	v5->as_VMReg()          ,
	v5->as_VMReg()->next()  ,
	v5->as_VMReg()->next(2) ,
	v5->as_VMReg()->next(3) ,
	v5->as_VMReg()->next(4) ,
	v5->as_VMReg()->next(5) ,
	v5->as_VMReg()->next(6) ,
	v5->as_VMReg()->next(7) ,
	v6->as_VMReg()          ,
	v6->as_VMReg()->next()  ,
	v6->as_VMReg()->next(2) ,
	v6->as_VMReg()->next(3) ,
	v6->as_VMReg()->next(4) ,
	v6->as_VMReg()->next(5) ,
	v6->as_VMReg()->next(6) ,
	v6->as_VMReg()->next(7) ,
	v7->as_VMReg()          ,
	v7->as_VMReg()->next()  ,
	v7->as_VMReg()->next(2) ,
	v7->as_VMReg()->next(3) ,
	v7->as_VMReg()->next(4) ,
	v7->as_VMReg()->next(5) ,
	v7->as_VMReg()->next(6) ,
	v7->as_VMReg()->next(7) ,
	v8->as_VMReg()          ,
	v8->as_VMReg()->next()  ,
	v8->as_VMReg()->next(2) ,
	v8->as_VMReg()->next(3) ,
	v8->as_VMReg()->next(4) ,
	v8->as_VMReg()->next(5) ,
	v8->as_VMReg()->next(6) ,
	v8->as_VMReg()->next(7) ,
	v9->as_VMReg()          ,
	v9->as_VMReg()->next()  ,
	v9->as_VMReg()->next(2) ,
	v9->as_VMReg()->next(3) ,
	v9->as_VMReg()->next(4) ,
	v9->as_VMReg()->next(5) ,
	v9->as_VMReg()->next(6) ,
	v9->as_VMReg()->next(7) ,
	v10->as_VMReg()          ,
	v10->as_VMReg()->next()  ,
	v10->as_VMReg()->next(2) ,
	v10->as_VMReg()->next(3) ,
	v10->as_VMReg()->next(4) ,
	v10->as_VMReg()->next(5) ,
	v10->as_VMReg()->next(6) ,
	v10->as_VMReg()->next(7) ,
	v11->as_VMReg()          ,
	v11->as_VMReg()->next()  ,
	v11->as_VMReg()->next(2) ,
	v11->as_VMReg()->next(3) ,
	v11->as_VMReg()->next(4) ,
	v11->as_VMReg()->next(5) ,
	v11->as_VMReg()->next(6) ,
	v11->as_VMReg()->next(7) ,
	v12->as_VMReg()          ,
	v12->as_VMReg()->next()  ,
	v12->as_VMReg()->next(2) ,
	v12->as_VMReg()->next(3) ,
	v12->as_VMReg()->next(4) ,
	v12->as_VMReg()->next(5) ,
	v12->as_VMReg()->next(6) ,
	v12->as_VMReg()->next(7) ,
	v13->as_VMReg()          ,
	v13->as_VMReg()->next()  ,
	v13->as_VMReg()->next(2) ,
	v13->as_VMReg()->next(3) ,
	v13->as_VMReg()->next(4) ,
	v13->as_VMReg()->next(5) ,
	v13->as_VMReg()->next(6) ,
	v13->as_VMReg()->next(7) ,
	v14->as_VMReg()          ,
	v14->as_VMReg()->next()  ,
	v14->as_VMReg()->next(2) ,
	v14->as_VMReg()->next(3) ,
	v14->as_VMReg()->next(4) ,
	v14->as_VMReg()->next(5) ,
	v14->as_VMReg()->next(6) ,
	v14->as_VMReg()->next(7) ,
	v15->as_VMReg()          ,
	v15->as_VMReg()->next()  ,
	v15->as_VMReg()->next(2) ,
	v15->as_VMReg()->next(3) ,
	v15->as_VMReg()->next(4) ,
	v15->as_VMReg()->next(5) ,
	v15->as_VMReg()->next(6) ,
	v15->as_VMReg()->next(7) ,
	p0->as_VMReg(),
	p1->as_VMReg(),
	p2->as_VMReg(),
	p3->as_VMReg(),
	p4->as_VMReg(),
	p5->as_VMReg(),
	p6->as_VMReg(),
	p7->as_VMReg(),
	p8->as_VMReg(),
	p9->as_VMReg(),
	p10->as_VMReg(),
	p11->as_VMReg(),
	p12->as_VMReg(),
	p13->as_VMReg(),
	p14->as_VMReg(),
	p15->as_VMReg(),
	VMRegImpl::Bad() // no trailing comma
	};

 OptoReg::Name OptoReg::vm2opto[ConcreteRegisterImpl::number_of_registers];

// An array of the machine register encode values
const unsigned char Matcher::_regEncode[REG_COUNT] = {
  (unsigned char)'\xA',  // R10
  (unsigned char)'\xA',  // R10_H
  (unsigned char)'\xB',  // R11
  (unsigned char)'\xB',  // R11_H
  (unsigned char)'\xC',  // R12
  (unsigned char)'\xC',  // R12_H
  (unsigned char)'\xD',  // R13
  (unsigned char)'\xD',  // R13_H
  (unsigned char)'\xE',  // R14
  (unsigned char)'\xE',  // R14_H
  (unsigned char)'\xF',  // R15
  (unsigned char)'\xF',  // R15_H
  (unsigned char)'\x10',  // R16
  (unsigned char)'\x10',  // R16_H
  (unsigned char)'\x11',  // R17
  (unsigned char)'\x11',  // R17_H
  (unsigned char)'\x12',  // R18
  (unsigned char)'\x12',  // R18_H
  (unsigned char)'\x0',  // R0
  (unsigned char)'\x0',  // R0_H
  (unsigned char)'\x1',  // R1
  (unsigned char)'\x1',  // R1_H
  (unsigned char)'\x2',  // R2
  (unsigned char)'\x2',  // R2_H
  (unsigned char)'\x3',  // R3
  (unsigned char)'\x3',  // R3_H
  (unsigned char)'\x4',  // R4
  (unsigned char)'\x4',  // R4_H
  (unsigned char)'\x5',  // R5
  (unsigned char)'\x5',  // R5_H
  (unsigned char)'\x6',  // R6
  (unsigned char)'\x6',  // R6_H
  (unsigned char)'\x7',  // R7
  (unsigned char)'\x7',  // R7_H
  (unsigned char)'\x13',  // R19
  (unsigned char)'\x13',  // R19_H
  (unsigned char)'\x14',  // R20
  (unsigned char)'\x14',  // R20_H
  (unsigned char)'\x15',  // R21
  (unsigned char)'\x15',  // R21_H
  (unsigned char)'\x16',  // R22
  (unsigned char)'\x16',  // R22_H
  (unsigned char)'\x17',  // R23
  (unsigned char)'\x17',  // R23_H
  (unsigned char)'\x18',  // R24
  (unsigned char)'\x18',  // R24_H
  (unsigned char)'\x19',  // R25
  (unsigned char)'\x19',  // R25_H
  (unsigned char)'\x1A',  // R26
  (unsigned char)'\x1A',  // R26_H
  (unsigned char)'\x1B',  // R27
  (unsigned char)'\x1B',  // R27_H
  (unsigned char)'\x1C',  // R28
  (unsigned char)'\x1C',  // R28_H
  (unsigned char)'\x1D',  // R29
  (unsigned char)'\x1D',  // R29_H
  (unsigned char)'\x1E',  // R30
  (unsigned char)'\x1E',  // R30_H
  (unsigned char)'\x1F',  // R31
  (unsigned char)'\x1F',  // R31_H
  (unsigned char)'\x8',  // R8
  (unsigned char)'\x8',  // R8_H
  (unsigned char)'\x9',  // R9
  (unsigned char)'\x9',  // R9_H
  (unsigned char)'\x10',  // V16
  (unsigned char)'\x10',  // V16_H
  (unsigned char)'\x10',  // V16_J
  (unsigned char)'\x10',  // V16_K
  (unsigned char)'\x10',  // V16_L
  (unsigned char)'\x10',  // V16_M
  (unsigned char)'\x10',  // V16_N
  (unsigned char)'\x10',  // V16_O
  (unsigned char)'\x11',  // V17
  (unsigned char)'\x11',  // V17_H
  (unsigned char)'\x11',  // V17_J
  (unsigned char)'\x11',  // V17_K
  (unsigned char)'\x11',  // V17_L
  (unsigned char)'\x11',  // V17_M
  (unsigned char)'\x11',  // V17_N
  (unsigned char)'\x11',  // V17_O
  (unsigned char)'\x12',  // V18
  (unsigned char)'\x12',  // V18_H
  (unsigned char)'\x12',  // V18_J
  (unsigned char)'\x12',  // V18_K
  (unsigned char)'\x12',  // V18_L
  (unsigned char)'\x12',  // V18_M
  (unsigned char)'\x12',  // V18_N
  (unsigned char)'\x12',  // V18_O
  (unsigned char)'\x13',  // V19
  (unsigned char)'\x13',  // V19_H
  (unsigned char)'\x13',  // V19_J
  (unsigned char)'\x13',  // V19_K
  (unsigned char)'\x13',  // V19_L
  (unsigned char)'\x13',  // V19_M
  (unsigned char)'\x13',  // V19_N
  (unsigned char)'\x13',  // V19_O
  (unsigned char)'\x14',  // V20
  (unsigned char)'\x14',  // V20_H
  (unsigned char)'\x14',  // V20_J
  (unsigned char)'\x14',  // V20_K
  (unsigned char)'\x14',  // V20_L
  (unsigned char)'\x14',  // V20_M
  (unsigned char)'\x14',  // V20_N
  (unsigned char)'\x14',  // V20_O
  (unsigned char)'\x15',  // V21
  (unsigned char)'\x15',  // V21_H
  (unsigned char)'\x15',  // V21_J
  (unsigned char)'\x15',  // V21_K
  (unsigned char)'\x15',  // V21_L
  (unsigned char)'\x15',  // V21_M
  (unsigned char)'\x15',  // V21_N
  (unsigned char)'\x15',  // V21_O
  (unsigned char)'\x16',  // V22
  (unsigned char)'\x16',  // V22_H
  (unsigned char)'\x16',  // V22_J
  (unsigned char)'\x16',  // V22_K
  (unsigned char)'\x16',  // V22_L
  (unsigned char)'\x16',  // V22_M
  (unsigned char)'\x16',  // V22_N
  (unsigned char)'\x16',  // V22_O
  (unsigned char)'\x17',  // V23
  (unsigned char)'\x17',  // V23_H
  (unsigned char)'\x17',  // V23_J
  (unsigned char)'\x17',  // V23_K
  (unsigned char)'\x17',  // V23_L
  (unsigned char)'\x17',  // V23_M
  (unsigned char)'\x17',  // V23_N
  (unsigned char)'\x17',  // V23_O
  (unsigned char)'\x18',  // V24
  (unsigned char)'\x18',  // V24_H
  (unsigned char)'\x18',  // V24_J
  (unsigned char)'\x18',  // V24_K
  (unsigned char)'\x18',  // V24_L
  (unsigned char)'\x18',  // V24_M
  (unsigned char)'\x18',  // V24_N
  (unsigned char)'\x18',  // V24_O
  (unsigned char)'\x19',  // V25
  (unsigned char)'\x19',  // V25_H
  (unsigned char)'\x19',  // V25_J
  (unsigned char)'\x19',  // V25_K
  (unsigned char)'\x19',  // V25_L
  (unsigned char)'\x19',  // V25_M
  (unsigned char)'\x19',  // V25_N
  (unsigned char)'\x19',  // V25_O
  (unsigned char)'\x1A',  // V26
  (unsigned char)'\x1A',  // V26_H
  (unsigned char)'\x1A',  // V26_J
  (unsigned char)'\x1A',  // V26_K
  (unsigned char)'\x1A',  // V26_L
  (unsigned char)'\x1A',  // V26_M
  (unsigned char)'\x1A',  // V26_N
  (unsigned char)'\x1A',  // V26_O
  (unsigned char)'\x1B',  // V27
  (unsigned char)'\x1B',  // V27_H
  (unsigned char)'\x1B',  // V27_J
  (unsigned char)'\x1B',  // V27_K
  (unsigned char)'\x1B',  // V27_L
  (unsigned char)'\x1B',  // V27_M
  (unsigned char)'\x1B',  // V27_N
  (unsigned char)'\x1B',  // V27_O
  (unsigned char)'\x1C',  // V28
  (unsigned char)'\x1C',  // V28_H
  (unsigned char)'\x1C',  // V28_J
  (unsigned char)'\x1C',  // V28_K
  (unsigned char)'\x1C',  // V28_L
  (unsigned char)'\x1C',  // V28_M
  (unsigned char)'\x1C',  // V28_N
  (unsigned char)'\x1C',  // V28_O
  (unsigned char)'\x1D',  // V29
  (unsigned char)'\x1D',  // V29_H
  (unsigned char)'\x1D',  // V29_J
  (unsigned char)'\x1D',  // V29_K
  (unsigned char)'\x1D',  // V29_L
  (unsigned char)'\x1D',  // V29_M
  (unsigned char)'\x1D',  // V29_N
  (unsigned char)'\x1D',  // V29_O
  (unsigned char)'\x1E',  // V30
  (unsigned char)'\x1E',  // V30_H
  (unsigned char)'\x1E',  // V30_J
  (unsigned char)'\x1E',  // V30_K
  (unsigned char)'\x1E',  // V30_L
  (unsigned char)'\x1E',  // V30_M
  (unsigned char)'\x1E',  // V30_N
  (unsigned char)'\x1E',  // V30_O
  (unsigned char)'\x1F',  // V31
  (unsigned char)'\x1F',  // V31_H
  (unsigned char)'\x1F',  // V31_J
  (unsigned char)'\x1F',  // V31_K
  (unsigned char)'\x1F',  // V31_L
  (unsigned char)'\x1F',  // V31_M
  (unsigned char)'\x1F',  // V31_N
  (unsigned char)'\x1F',  // V31_O
  (unsigned char)'\x0',  // V0
  (unsigned char)'\x0',  // V0_H
  (unsigned char)'\x0',  // V0_J
  (unsigned char)'\x0',  // V0_K
  (unsigned char)'\x0',  // V0_L
  (unsigned char)'\x0',  // V0_M
  (unsigned char)'\x0',  // V0_N
  (unsigned char)'\x0',  // V0_O
  (unsigned char)'\x1',  // V1
  (unsigned char)'\x1',  // V1_H
  (unsigned char)'\x1',  // V1_J
  (unsigned char)'\x1',  // V1_K
  (unsigned char)'\x1',  // V1_L
  (unsigned char)'\x1',  // V1_M
  (unsigned char)'\x1',  // V1_N
  (unsigned char)'\x1',  // V1_O
  (unsigned char)'\x2',  // V2
  (unsigned char)'\x2',  // V2_H
  (unsigned char)'\x2',  // V2_J
  (unsigned char)'\x2',  // V2_K
  (unsigned char)'\x2',  // V2_L
  (unsigned char)'\x2',  // V2_M
  (unsigned char)'\x2',  // V2_N
  (unsigned char)'\x2',  // V2_O
  (unsigned char)'\x3',  // V3
  (unsigned char)'\x3',  // V3_H
  (unsigned char)'\x3',  // V3_J
  (unsigned char)'\x3',  // V3_K
  (unsigned char)'\x3',  // V3_L
  (unsigned char)'\x3',  // V3_M
  (unsigned char)'\x3',  // V3_N
  (unsigned char)'\x3',  // V3_O
  (unsigned char)'\x4',  // V4
  (unsigned char)'\x4',  // V4_H
  (unsigned char)'\x4',  // V4_J
  (unsigned char)'\x4',  // V4_K
  (unsigned char)'\x4',  // V4_L
  (unsigned char)'\x4',  // V4_M
  (unsigned char)'\x4',  // V4_N
  (unsigned char)'\x4',  // V4_O
  (unsigned char)'\x5',  // V5
  (unsigned char)'\x5',  // V5_H
  (unsigned char)'\x5',  // V5_J
  (unsigned char)'\x5',  // V5_K
  (unsigned char)'\x5',  // V5_L
  (unsigned char)'\x5',  // V5_M
  (unsigned char)'\x5',  // V5_N
  (unsigned char)'\x5',  // V5_O
  (unsigned char)'\x6',  // V6
  (unsigned char)'\x6',  // V6_H
  (unsigned char)'\x6',  // V6_J
  (unsigned char)'\x6',  // V6_K
  (unsigned char)'\x6',  // V6_L
  (unsigned char)'\x6',  // V6_M
  (unsigned char)'\x6',  // V6_N
  (unsigned char)'\x6',  // V6_O
  (unsigned char)'\x7',  // V7
  (unsigned char)'\x7',  // V7_H
  (unsigned char)'\x7',  // V7_J
  (unsigned char)'\x7',  // V7_K
  (unsigned char)'\x7',  // V7_L
  (unsigned char)'\x7',  // V7_M
  (unsigned char)'\x7',  // V7_N
  (unsigned char)'\x7',  // V7_O
  (unsigned char)'\x8',  // V8
  (unsigned char)'\x8',  // V8_H
  (unsigned char)'\x8',  // V8_J
  (unsigned char)'\x8',  // V8_K
  (unsigned char)'\x8',  // V8_L
  (unsigned char)'\x8',  // V8_M
  (unsigned char)'\x8',  // V8_N
  (unsigned char)'\x8',  // V8_O
  (unsigned char)'\x9',  // V9
  (unsigned char)'\x9',  // V9_H
  (unsigned char)'\x9',  // V9_J
  (unsigned char)'\x9',  // V9_K
  (unsigned char)'\x9',  // V9_L
  (unsigned char)'\x9',  // V9_M
  (unsigned char)'\x9',  // V9_N
  (unsigned char)'\x9',  // V9_O
  (unsigned char)'\xA',  // V10
  (unsigned char)'\xA',  // V10_H
  (unsigned char)'\xA',  // V10_J
  (unsigned char)'\xA',  // V10_K
  (unsigned char)'\xA',  // V10_L
  (unsigned char)'\xA',  // V10_M
  (unsigned char)'\xA',  // V10_N
  (unsigned char)'\xA',  // V10_O
  (unsigned char)'\xB',  // V11
  (unsigned char)'\xB',  // V11_H
  (unsigned char)'\xB',  // V11_J
  (unsigned char)'\xB',  // V11_K
  (unsigned char)'\xB',  // V11_L
  (unsigned char)'\xB',  // V11_M
  (unsigned char)'\xB',  // V11_N
  (unsigned char)'\xB',  // V11_O
  (unsigned char)'\xC',  // V12
  (unsigned char)'\xC',  // V12_H
  (unsigned char)'\xC',  // V12_J
  (unsigned char)'\xC',  // V12_K
  (unsigned char)'\xC',  // V12_L
  (unsigned char)'\xC',  // V12_M
  (unsigned char)'\xC',  // V12_N
  (unsigned char)'\xC',  // V12_O
  (unsigned char)'\xD',  // V13
  (unsigned char)'\xD',  // V13_H
  (unsigned char)'\xD',  // V13_J
  (unsigned char)'\xD',  // V13_K
  (unsigned char)'\xD',  // V13_L
  (unsigned char)'\xD',  // V13_M
  (unsigned char)'\xD',  // V13_N
  (unsigned char)'\xD',  // V13_O
  (unsigned char)'\xE',  // V14
  (unsigned char)'\xE',  // V14_H
  (unsigned char)'\xE',  // V14_J
  (unsigned char)'\xE',  // V14_K
  (unsigned char)'\xE',  // V14_L
  (unsigned char)'\xE',  // V14_M
  (unsigned char)'\xE',  // V14_N
  (unsigned char)'\xE',  // V14_O
  (unsigned char)'\xF',  // V15
  (unsigned char)'\xF',  // V15_H
  (unsigned char)'\xF',  // V15_J
  (unsigned char)'\xF',  // V15_K
  (unsigned char)'\xF',  // V15_L
  (unsigned char)'\xF',  // V15_M
  (unsigned char)'\xF',  // V15_N
  (unsigned char)'\xF',  // V15_O
  (unsigned char)'\x0',  // P0
  (unsigned char)'\x1',  // P1
  (unsigned char)'\x2',  // P2
  (unsigned char)'\x3',  // P3
  (unsigned char)'\x4',  // P4
  (unsigned char)'\x5',  // P5
  (unsigned char)'\x6',  // P6
  (unsigned char)'\x7',  // P7
  (unsigned char)'\x8',  // P8
  (unsigned char)'\x9',  // P9
  (unsigned char)'\xA',  // P10
  (unsigned char)'\xB',  // P11
  (unsigned char)'\xC',  // P12
  (unsigned char)'\xD',  // P13
  (unsigned char)'\xE',  // P14
  (unsigned char)'\xF',  // P15
  (unsigned char)'\x20' // no trailing comma  // RFLAGS
};


//------------------Define classes derived from MachOper---------------------
MachOper  *labelOper::clone() const {
  return  new labelOper(_label, _block_num);
}
uint labelOper::opcode() const { return LABEL; }

const RegMask *sRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

MachOper  *methodOper::clone() const {
  return  new methodOper(_method);
}
uint methodOper::opcode() const { return METHOD; }

const RegMask *iRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *iRegINoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_REG32_mask();
}

const RegMask *iRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG_mask();
}

const RegMask *iRegLNoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_REG_mask();
}

const RegMask *iRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *iRegPNoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_PTR_REG_mask();
}

const RegMask *iRegP_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0_REG_mask();
}

const RegMask *iRegP_R1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R1_REG_mask();
}

const RegMask *iRegP_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2_REG_mask();
}

const RegMask *iRegP_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R3_REG_mask();
}

const RegMask *iRegP_R4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R4_REG_mask();
}

const RegMask *iRegP_R5Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R5_REG_mask();
}

const RegMask *iRegP_R10Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R10_REG_mask();
}

const RegMask *iRegL_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0_REG_mask();
}

const RegMask *iRegL_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2_REG_mask();
}

const RegMask *iRegL_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R3_REG_mask();
}

const RegMask *iRegL_R11Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R11_REG_mask();
}

const RegMask *iRegP_FPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FP_REG_mask();
}

const RegMask *iRegI_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R0_REG_mask();
}

const RegMask *iRegI_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R2_REG_mask();
}

const RegMask *iRegI_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R3_REG_mask();
}

const RegMask *iRegI_R4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R4_REG_mask();
}

const RegMask *iRegNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *iRegN_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0_REG_mask();
}

const RegMask *iRegN_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2_REG_mask();
}

const RegMask *iRegN_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R3_REG_mask();
}

const RegMask *iRegNNoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_REG32_mask();
}

const RegMask *iRegIHeapbaseOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &HEAPBASE_REG_mask();
}

const RegMask *vRegFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FLOAT_REG_mask();
}

const RegMask *vRegDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &DOUBLE_REG_mask();
}

const RegMask *vRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORA_REG_mask();
}

const RegMask *vecDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORD_REG_mask();
}

const RegMask *vecXOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORX_REG_mask();
}

const RegMask *vRegD_V0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V0_REG_mask();
}

const RegMask *vRegD_V1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V1_REG_mask();
}

const RegMask *vRegD_V2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V2_REG_mask();
}

const RegMask *vRegD_V3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V3_REG_mask();
}

const RegMask *vRegD_V4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V4_REG_mask();
}

const RegMask *vRegD_V5Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V5_REG_mask();
}

const RegMask *vRegD_V6Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V6_REG_mask();
}

const RegMask *vRegD_V7Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V7_REG_mask();
}

const RegMask *vRegD_V8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V8_REG_mask();
}

const RegMask *vRegD_V9Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V9_REG_mask();
}

const RegMask *vRegD_V10Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V10_REG_mask();
}

const RegMask *vRegD_V11Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V11_REG_mask();
}

const RegMask *vRegD_V12Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V12_REG_mask();
}

const RegMask *vRegD_V13Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V13_REG_mask();
}

const RegMask *vRegD_V14Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V14_REG_mask();
}

const RegMask *vRegD_V15Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V15_REG_mask();
}

const RegMask *vRegD_V16Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V16_REG_mask();
}

const RegMask *vRegD_V17Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V17_REG_mask();
}

const RegMask *vRegD_V18Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V18_REG_mask();
}

const RegMask *vRegD_V19Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V19_REG_mask();
}

const RegMask *vRegD_V20Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V20_REG_mask();
}

const RegMask *vRegD_V21Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V21_REG_mask();
}

const RegMask *vRegD_V22Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V22_REG_mask();
}

const RegMask *vRegD_V23Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V23_REG_mask();
}

const RegMask *vRegD_V24Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V24_REG_mask();
}

const RegMask *vRegD_V25Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V25_REG_mask();
}

const RegMask *vRegD_V26Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V26_REG_mask();
}

const RegMask *vRegD_V27Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V27_REG_mask();
}

const RegMask *vRegD_V28Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V28_REG_mask();
}

const RegMask *vRegD_V29Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V29_REG_mask();
}

const RegMask *vRegD_V30Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V30_REG_mask();
}

const RegMask *vRegD_V31Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V31_REG_mask();
}

const RegMask *pRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PR_REG_mask();
}

const RegMask *pRegGovOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &GOV_PR_mask();
}

const RegMask *rFlagsRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *rFlagsRegUOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *inline_cache_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &METHOD_REG_mask();
}

const RegMask *thread_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &THREAD_REG_mask();
}

const RegMask *lr_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &LR_REG_mask();
}

const RegMask *indirectOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indIndexScaledI2LOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG32_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexScaledOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexI2LOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG32_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indOffIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI16Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL16Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indirectNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexScaledI2LNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexScaledNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG32_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexI2LNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG32_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indOffINOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indOffLNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *thread_anchor_pcOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *stackSlotPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *iRegL2IOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG_mask();
}

const RegMask *vmemA_indOffI4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *vmemA_indOffL4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

//------------------Define members for classes derived from MachNode----------
// Build short branch version of this instruction
MachNode *far_cmpL_branch_signNode::short_branch_version() {
  cmpL_branch_signNode *node = new cmpL_branch_signNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}

// Build short branch version of this instruction
MachNode *far_cmpI_branch_signNode::short_branch_version() {
  cmpI_branch_signNode *node = new cmpI_branch_signNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}

// Build short branch version of this instruction
MachNode *far_cmpL_branch_bitNode::short_branch_version() {
  cmpL_branch_bitNode *node = new cmpL_branch_bitNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}

// Build short branch version of this instruction
MachNode *far_cmpI_branch_bitNode::short_branch_version() {
  cmpI_branch_bitNode *node = new cmpI_branch_bitNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}


// Copy _idx, inputs and operands to new node
void MachNode::fill_new_machnode(MachNode* node) const {
  // New node must use same node index
  node->set_idx( _idx );
  // Copy machine-independent inputs
  for( uint j = 0; j < req(); j++ ) {
    node->add_req(in(j));
  }
  // Copy my operands, except for cisc position
  int nopnds = num_opnds();
  assert( node->num_opnds() == (uint)nopnds, "Must have same number of operands");
  MachOper **to = node->_opnds;
  for( int i = 0; i < nopnds; i++ ) {
    if( i != cisc_operand() ) 
      to[i] = _opnds[i]->clone();
  }
}

void overflowMulI_reg_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void overflowMulI_reg_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void overflowMulL_reg_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void overflowMulL_reg_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpI_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpI_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpP_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpP_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpN_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpN_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpP_narrowOop_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpP_narrowOop_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpUI_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpUI_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpUL_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpUL_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpI_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpI_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpI_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpI_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpL_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpL_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpI_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpI_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpL_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpL_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpI_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpI_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchLoopEndNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchLoopEndNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchLoopEndUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchLoopEndUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void CallStaticJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallDynamicJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallRuntimeDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafNoFPDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallNativeDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

int loadBNode::reloc() const {
  return 1;
}

int loadB2LNode::reloc() const {
  return 1;
}

int loadUBNode::reloc() const {
  return 1;
}

int loadUB2LNode::reloc() const {
  return 1;
}

int loadSNode::reloc() const {
  return 1;
}

int loadS2LNode::reloc() const {
  return 1;
}

int loadUSNode::reloc() const {
  return 1;
}

int loadUS2LNode::reloc() const {
  return 1;
}

int loadINode::reloc() const {
  return 1;
}

int loadI2LNode::reloc() const {
  return 1;
}

int loadUI2LNode::reloc() const {
  return 1;
}

int loadLNode::reloc() const {
  return 1;
}

int loadRangeNode::reloc() const {
  return 1;
}

int loadPNode::reloc() const {
  return 1;
}

int loadNNode::reloc() const {
  return 1;
}

int loadKlassNode::reloc() const {
  return 1;
}

int loadNKlassNode::reloc() const {
  return 1;
}

int loadFNode::reloc() const {
  return 1;
}

int loadDNode::reloc() const {
  return 1;
}

int loadConPNode::reloc() const {
  return 1;
}

int loadConP0Node::reloc() const {
  return 1;
}

int loadConP1Node::reloc() const {
  return 1;
}

int loadByteMapBaseNode::reloc() const {
  return 1;
}

int loadConF_packedNode::reloc() const {
  return 2;
}

int loadConFNode::reloc() const {
  return 2;
}

int loadConD_packedNode::reloc() const {
  return 2;
}

int loadConDNode::reloc() const {
  return 2;
}

int storeimmCM0Node::reloc() const {
  return 2;
}

int storeimmCM0_orderedNode::reloc() const {
  return 2;
}

int storeBNode::reloc() const {
  return 3;
}

int storeimmB0Node::reloc() const {
  return 2;
}

int storeCNode::reloc() const {
  return 3;
}

int storeimmC0Node::reloc() const {
  return 2;
}

int storeINode::reloc() const {
  return 3;
}

int storeimmI0Node::reloc() const {
  return 2;
}

int storeLNode::reloc() const {
  return 2;
}

int storeimmL0Node::reloc() const {
  return 2;
}

int storePNode::reloc() const {
  return 2;
}

int storeimmP0Node::reloc() const {
  return 3;
}

int storeNNode::reloc() const {
  return 2;
}

int storeImmN0Node::reloc() const {
  return 2;
}

int storeFNode::reloc() const {
  return 2;
}

int storeDNode::reloc() const {
  return 2;
}

int storeNKlassNode::reloc() const {
  return 2;
}

int prefetchallocNode::reloc() const {
  return 1;
}

int storeB_volatileNode::reloc() const {
  return 1;
}

int storeC_volatileNode::reloc() const {
  return 1;
}

int storeI_volatileNode::reloc() const {
  return 1;
}

int bytes_reverse_intNode::reloc() const {
  return 1;
}

int bytes_reverse_unsigned_shortNode::reloc() const {
  return 1;
}

int bytes_reverse_shortNode::reloc() const {
  return 1;
}

int countLeadingZerosINode::reloc() const {
  return 1;
}

int countTrailingZerosINode::reloc() const {
  return 1;
}

int popCountINode::reloc() const {
  return 1;
}

int popCountI_memNode::reloc() const {
  return 1;
}

int popCountL_memNode::reloc() const {
  return 1;
}

int storePConditionalNode::reloc() const {
  return 1;
}

int get_and_addINode::reloc() const {
  return 1;
}

int get_and_addI_no_resNode::reloc() const {
  return 1;
}

int get_and_addIAcqNode::reloc() const {
  return 1;
}

int get_and_addI_no_resAcqNode::reloc() const {
  return 1;
}

int cmovI_reg_regNode::reloc() const {
  return 2;
}

int cmovUI_reg_regNode::reloc() const {
  return 2;
}

int cmovI_zero_regNode::reloc() const {
  return 1;
}

int cmovUI_zero_regNode::reloc() const {
  return 1;
}

int cmovI_reg_zeroNode::reloc() const {
  return 1;
}

int cmovUI_reg_zeroNode::reloc() const {
  return 1;
}

int cmovP_reg_zeroNode::reloc() const {
  return 1;
}

int cmovUP_reg_zeroNode::reloc() const {
  return 1;
}

int cmovP_zero_regNode::reloc() const {
  return 1;
}

int cmovUP_zero_regNode::reloc() const {
  return 1;
}

int addI_reg_regNode::reloc() const {
  return 2;
}

int addI_reg_immNode::reloc() const {
  return 1;
}

int addP_reg_reg_extNode::reloc() const {
  return 1;
}

int addP_reg_reg_ext_shiftNode::reloc() const {
  return 1;
}

int lshift_extNode::reloc() const {
  return 1;
}

int subI_reg_regNode::reloc() const {
  return 2;
}

int subI_reg_immNode::reloc() const {
  return 1;
}

int negI_regNode::reloc() const {
  return 1;
}

int mulINode::reloc() const {
  return 2;
}

int smulINode::reloc() const {
  return 2;
}

int smulI_0Node::reloc() const {
  return 2;
}

int maddINode::reloc() const {
  return 3;
}

int maddI_0Node::reloc() const {
  return 3;
}

int msubINode::reloc() const {
  return 3;
}

int mnegINode::reloc() const {
  return 2;
}

int mnegI_0Node::reloc() const {
  return 2;
}

int smaddLNode::reloc() const {
  return 2;
}

int smaddL_1Node::reloc() const {
  return 2;
}

int smaddL_0Node::reloc() const {
  return 2;
}

int smaddL_2Node::reloc() const {
  return 2;
}

int smsubLNode::reloc() const {
  return 2;
}

int smsubL_0Node::reloc() const {
  return 2;
}

int smnegLNode::reloc() const {
  return 2;
}

int smnegL_0Node::reloc() const {
  return 2;
}

int muladdS2INode::reloc() const {
  return 4;
}

int divINode::reloc() const {
  return 2;
}

int modINode::reloc() const {
  return 2;
}

int lShiftI_reg_regNode::reloc() const {
  return 2;
}

int lShiftI_reg_immNode::reloc() const {
  return 1;
}

int urShiftI_reg_regNode::reloc() const {
  return 2;
}

int urShiftI_reg_immNode::reloc() const {
  return 1;
}

int rShiftI_reg_regNode::reloc() const {
  return 2;
}

int rShiftI_reg_immNode::reloc() const {
  return 1;
}

int lShiftL_reg_regNode::reloc() const {
  return 1;
}

int urShiftL_reg_regNode::reloc() const {
  return 1;
}

int rShiftL_reg_regNode::reloc() const {
  return 1;
}

int regI_not_regNode::reloc() const {
  return 1;
}

int AndI_reg_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_URShift_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_URShift_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RShift_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_RShift_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RotateRight_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_RotateRight_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_LShift_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_LShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_reg_2Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_reg_2Node::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_not_reg_2Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_reg_2Node::reloc() const {
  return 2;
}

int OrI_reg_URShift_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_URShift_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RShift_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_RShift_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RotateRight_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_RotateRight_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_LShift_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_LShift_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_URShift_regNode::reloc() const {
  return 2;
}

int AndI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RShift_regNode::reloc() const {
  return 2;
}

int AndI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_LShift_regNode::reloc() const {
  return 2;
}

int AndI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RotateRight_regNode::reloc() const {
  return 2;
}

int AndI_reg_RotateRight_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_regNode::reloc() const {
  return 2;
}

int XorI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_regNode::reloc() const {
  return 2;
}

int XorI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_regNode::reloc() const {
  return 2;
}

int XorI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_regNode::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_URShift_regNode::reloc() const {
  return 2;
}

int OrI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RShift_regNode::reloc() const {
  return 2;
}

int OrI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_LShift_regNode::reloc() const {
  return 2;
}

int OrI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RotateRight_regNode::reloc() const {
  return 2;
}

int OrI_reg_RotateRight_reg_0Node::reloc() const {
  return 2;
}

int AddI_reg_URShift_regNode::reloc() const {
  return 2;
}

int AddI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int AddI_reg_RShift_regNode::reloc() const {
  return 2;
}

int AddI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int AddI_reg_LShift_regNode::reloc() const {
  return 2;
}

int AddI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int SubI_reg_URShift_regNode::reloc() const {
  return 2;
}

int SubI_reg_RShift_regNode::reloc() const {
  return 2;
}

int SubI_reg_LShift_regNode::reloc() const {
  return 2;
}

int sbfmwINode::reloc() const {
  return 1;
}

int ubfmwINode::reloc() const {
  return 1;
}

int ubfxwINode::reloc() const {
  return 1;
}

int ubfxIConvI2LNode::reloc() const {
  return 1;
}

int ubfizwINode::reloc() const {
  return 1;
}

int ubfizwIConvI2LNode::reloc() const {
  return 1;
}

int ubfizIConvI2LNode::reloc() const {
  return 1;
}

int extrOrINode::reloc() const {
  return 2;
}

int extrOrI_0Node::reloc() const {
  return 2;
}

int extrAddINode::reloc() const {
  return 2;
}

int extrAddI_0Node::reloc() const {
  return 2;
}

int AddExtINode::reloc() const {
  return 1;
}

int AddExtI_0Node::reloc() const {
  return 1;
}

int SubExtINode::reloc() const {
  return 1;
}

int AddExtI_sxthNode::reloc() const {
  return 2;
}

int AddExtI_sxth_0Node::reloc() const {
  return 2;
}

int AddExtI_sxtbNode::reloc() const {
  return 2;
}

int AddExtI_sxtb_0Node::reloc() const {
  return 2;
}

int AddExtI_uxtbNode::reloc() const {
  return 2;
}

int AddExtI_uxtb_0Node::reloc() const {
  return 2;
}

int AddExtI_uxtb_andNode::reloc() const {
  return 2;
}

int AddExtI_uxtb_and_0Node::reloc() const {
  return 2;
}

int AddExtI_uxth_andNode::reloc() const {
  return 2;
}

int AddExtI_uxth_and_0Node::reloc() const {
  return 2;
}

int SubExtI_uxtb_andNode::reloc() const {
  return 2;
}

int SubExtI_uxth_andNode::reloc() const {
  return 2;
}

int AddExtI_sxtb_shiftNode::reloc() const {
  return 2;
}

int AddExtI_sxtb_shift_0Node::reloc() const {
  return 2;
}

int AddExtI_sxth_shiftNode::reloc() const {
  return 2;
}

int AddExtI_sxth_shift_0Node::reloc() const {
  return 2;
}

int SubExtI_sxtb_shiftNode::reloc() const {
  return 2;
}

int SubExtI_sxth_shiftNode::reloc() const {
  return 2;
}

int AddExtI_shiftNode::reloc() const {
  return 1;
}

int AddExtI_shift_0Node::reloc() const {
  return 1;
}

int SubExtI_shiftNode::reloc() const {
  return 1;
}

int AddExtI_uxtb_and_shiftNode::reloc() const {
  return 2;
}

int AddExtI_uxtb_and_shift_0Node::reloc() const {
  return 2;
}

int AddExtI_uxth_and_shiftNode::reloc() const {
  return 2;
}

int AddExtI_uxth_and_shift_0Node::reloc() const {
  return 2;
}

int SubExtI_uxtb_and_shiftNode::reloc() const {
  return 2;
}

int SubExtI_uxth_and_shiftNode::reloc() const {
  return 2;
}

int mnsubF_reg_regNode::reloc() const {
  return 1;
}

int mnsubD_reg_regNode::reloc() const {
  return 1;
}

int absI_regNode::reloc() const {
  return 1;
}

int andI_reg_regNode::reloc() const {
  return 2;
}

int andI_reg_immNode::reloc() const {
  return 1;
}

int orI_reg_regNode::reloc() const {
  return 2;
}

int orI_reg_immNode::reloc() const {
  return 1;
}

int xorI_reg_regNode::reloc() const {
  return 2;
}

int xorI_reg_immNode::reloc() const {
  return 1;
}

int convI2L_reg_regNode::reloc() const {
  return 1;
}

int convUI2L_reg_regNode::reloc() const {
  return 1;
}

int convI2BNode::reloc() const {
  return 1;
}

int convI2F_reg_regNode::reloc() const {
  return 1;
}

int convI2D_reg_regNode::reloc() const {
  return 1;
}

int overflowAddI_reg_regNode::reloc() const {
  return 2;
}

int overflowAddI_reg_immNode::reloc() const {
  return 1;
}

int overflowSubI_reg_regNode::reloc() const {
  return 2;
}

int overflowSubI_reg_immNode::reloc() const {
  return 1;
}

int overflowNegI_regNode::reloc() const {
  return 1;
}

int overflowMulI_regNode::reloc() const {
  return 2;
}

int overflowMulI_reg_branchNode::reloc() const {
  return 2;
}

int testP_regNode::reloc() const {
  return 1;
}

int compF_reg_zeroNode::reloc() const {
  return 1;
}

int compD_reg_zeroNode::reloc() const {
  return 1;
}

int compF3_reg_immF0Node::reloc() const {
  return 1;
}

int compD3_reg_immD0Node::reloc() const {
  return 1;
}

int cmpLTMask_reg_regNode::reloc() const {
  return 2;
}

int cmpLTMask_reg_zeroNode::reloc() const {
  return 1;
}

int cmpI_imm0_branchNode::reloc() const {
  return 1;
}

int cmpP_imm0_branchNode::reloc() const {
  return 1;
}

int cmpP_narrowOop_imm0_branchNode::reloc() const {
  return 1;
}

int cmpUI_imm0_branchNode::reloc() const {
  return 1;
}

int cmpI_branch_signNode::reloc() const {
  return 1;
}

int cmpI_branch_bitNode::reloc() const {
  return 1;
}

int far_cmpI_branch_signNode::reloc() const {
  return 1;
}

int far_cmpI_branch_bitNode::reloc() const {
  return 1;
}

int cmpI_andNode::reloc() const {
  return 1;
}

int cmpI_and_regNode::reloc() const {
  return 2;
}

int safePointNode::reloc() const {
  return 1;
}

int CallStaticJavaDirectNode::reloc() const {
  return 1;
}

int CallDynamicJavaDirectNode::reloc() const {
  return 1;
}

int CallRuntimeDirectNode::reloc() const {
  return 1;
}

int CallLeafDirectNode::reloc() const {
  return 1;
}

int CallLeafNoFPDirectNode::reloc() const {
  return 1;
}

int CallNativeDirectNode::reloc() const {
  return 1;
}

int TailCalljmpIndNode::reloc() const {
  return 1;
}

int TailjmpIndNode::reloc() const {
  return 1;
}

int RethrowExceptionNode::reloc() const {
  return 1;
}

int RetNode::reloc() const {
  return 1;
}

int partialSubtypeCheckVsZeroNode::reloc() const {
  return 1;
}

int loadV2Node::reloc() const {
  return 1;
}

int loadV4Node::reloc() const {
  return 1;
}

int loadV8Node::reloc() const {
  return 1;
}

int loadV16Node::reloc() const {
  return 1;
}

int storeV2Node::reloc() const {
  return 2;
}

int storeV4Node::reloc() const {
  return 2;
}

int storeV8Node::reloc() const {
  return 2;
}

int storeV16Node::reloc() const {
  return 2;
}

int reduce_add8BNode::reloc() const {
  return 1;
}

int reduce_add16BNode::reloc() const {
  return 1;
}

int reduce_add4SNode::reloc() const {
  return 1;
}

int reduce_add8SNode::reloc() const {
  return 1;
}

int reduce_mul8BNode::reloc() const {
  return 1;
}

int reduce_mul16BNode::reloc() const {
  return 1;
}

int reduce_mul4SNode::reloc() const {
  return 1;
}

int reduce_mul8SNode::reloc() const {
  return 1;
}

int reduce_max8BNode::reloc() const {
  return 1;
}

int reduce_max16BNode::reloc() const {
  return 1;
}

int reduce_max4SNode::reloc() const {
  return 1;
}

int reduce_max8SNode::reloc() const {
  return 1;
}

int reduce_max4INode::reloc() const {
  return 1;
}

int reduce_min8BNode::reloc() const {
  return 1;
}

int reduce_min16BNode::reloc() const {
  return 1;
}

int reduce_min4SNode::reloc() const {
  return 1;
}

int reduce_min8SNode::reloc() const {
  return 1;
}

int reduce_min4INode::reloc() const {
  return 1;
}

int reduce_max2INode::reloc() const {
  return 1;
}

int reduce_min2INode::reloc() const {
  return 1;
}

int reduce_and8BNode::reloc() const {
  return 1;
}

int reduce_orr8BNode::reloc() const {
  return 1;
}

int reduce_eor8BNode::reloc() const {
  return 1;
}

int reduce_and16BNode::reloc() const {
  return 1;
}

int reduce_orr16BNode::reloc() const {
  return 1;
}

int reduce_eor16BNode::reloc() const {
  return 1;
}

int reduce_and4SNode::reloc() const {
  return 1;
}

int reduce_orr4SNode::reloc() const {
  return 1;
}

int reduce_eor4SNode::reloc() const {
  return 1;
}

int reduce_and8SNode::reloc() const {
  return 1;
}

int reduce_orr8SNode::reloc() const {
  return 1;
}

int reduce_eor8SNode::reloc() const {
  return 1;
}

int reduce_and2INode::reloc() const {
  return 1;
}

int reduce_orr2INode::reloc() const {
  return 1;
}

int reduce_eor2INode::reloc() const {
  return 1;
}

int reduce_and4INode::reloc() const {
  return 1;
}

int reduce_orr4INode::reloc() const {
  return 1;
}

int reduce_eor4INode::reloc() const {
  return 1;
}

int insert8BNode::reloc() const {
  return 1;
}

int insert16BNode::reloc() const {
  return 1;
}

int insert4SNode::reloc() const {
  return 1;
}

int insert8SNode::reloc() const {
  return 1;
}

int insert2INode::reloc() const {
  return 1;
}

int insert4INode::reloc() const {
  return 1;
}

int replicate8BNode::reloc() const {
  return 1;
}

int replicate16BNode::reloc() const {
  return 1;
}

int replicate4SNode::reloc() const {
  return 1;
}

int replicate8SNode::reloc() const {
  return 1;
}

int replicate2INode::reloc() const {
  return 1;
}

int replicate4INode::reloc() const {
  return 1;
}

int reduce_add2INode::reloc() const {
  return 1;
}

int reduce_add4INode::reloc() const {
  return 1;
}

int reduce_mul2INode::reloc() const {
  return 1;
}

int reduce_mul4INode::reloc() const {
  return 1;
}

int vshiftcnt8BNode::reloc() const {
  return 1;
}

int vshiftcnt8B_0Node::reloc() const {
  return 1;
}

int vshiftcnt16BNode::reloc() const {
  return 1;
}

int vshiftcnt16B_0Node::reloc() const {
  return 1;
}

int loadVNode::reloc() const {
  return 1;
}

int storeVNode::reloc() const {
  return 2;
}

int loadV2_vregNode::reloc() const {
  return 1;
}

int storeV2_vregNode::reloc() const {
  return 2;
}

int loadV4_vregNode::reloc() const {
  return 1;
}

int storeV4_vregNode::reloc() const {
  return 2;
}

int loadV8_vregNode::reloc() const {
  return 1;
}

int storeV8_vregNode::reloc() const {
  return 2;
}

int loadV16_vregNode::reloc() const {
  return 1;
}

int storeV16_vregNode::reloc() const {
  return 2;
}

int loadV_partialNode::reloc() const {
  return 1;
}

int storeV_partialNode::reloc() const {
  return 2;
}

int loadV_maskedNode::reloc() const {
  return 1;
}

int loadV_masked_partialNode::reloc() const {
  return 1;
}

int storeV_maskedNode::reloc() const {
  return 2;
}

int storeV_masked_partialNode::reloc() const {
  return 2;
}

int vmaskAllINode::reloc() const {
  return 1;
}

int reduce_addINode::reloc() const {
  return 1;
}

int reduce_addI_partialNode::reloc() const {
  return 1;
}

int reduce_addI_maskedNode::reloc() const {
  return 1;
}

int reduce_addI_masked_partialNode::reloc() const {
  return 1;
}

int reduce_andINode::reloc() const {
  return 1;
}

int reduce_andI_partialNode::reloc() const {
  return 1;
}

int reduce_andI_maskedNode::reloc() const {
  return 1;
}

int reduce_andI_masked_partialNode::reloc() const {
  return 1;
}

int reduce_orINode::reloc() const {
  return 1;
}

int reduce_orI_partialNode::reloc() const {
  return 1;
}

int reduce_orI_maskedNode::reloc() const {
  return 1;
}

int reduce_orI_masked_partialNode::reloc() const {
  return 1;
}

int reduce_eorINode::reloc() const {
  return 1;
}

int reduce_eorI_partialNode::reloc() const {
  return 1;
}

int reduce_eorI_maskedNode::reloc() const {
  return 1;
}

int reduce_eorI_masked_partialNode::reloc() const {
  return 1;
}

int reduce_maxINode::reloc() const {
  return 1;
}

int reduce_maxI_partialNode::reloc() const {
  return 1;
}

int reduce_maxI_maskedNode::reloc() const {
  return 1;
}

int reduce_maxI_masked_partialNode::reloc() const {
  return 1;
}

int reduce_minINode::reloc() const {
  return 1;
}

int reduce_minI_partialNode::reloc() const {
  return 1;
}

int reduce_minI_maskedNode::reloc() const {
  return 1;
}

int reduce_minI_masked_partialNode::reloc() const {
  return 1;
}

int replicateBNode::reloc() const {
  return 1;
}

int replicateSNode::reloc() const {
  return 1;
}

int replicateINode::reloc() const {
  return 1;
}

int vshiftcntBNode::reloc() const {
  return 1;
}

int vshiftcntB_0Node::reloc() const {
  return 1;
}

int vshiftcntSNode::reloc() const {
  return 1;
}

int vshiftcntS_0Node::reloc() const {
  return 1;
}

int vshiftcntINode::reloc() const {
  return 1;
}

int vshiftcntI_0Node::reloc() const {
  return 1;
}

int vshiftcntLNode::reloc() const {
  return 1;
}

int vshiftcntL_0Node::reloc() const {
  return 1;
}

int insertI_smallNode::reloc() const {
  return 1;
}

int insertINode::reloc() const {
  return 1;
}

int zLoadPNode::reloc() const {
  return 1;
}


void loadBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2939 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrsbw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 16749 "ad_aarch64.cpp"
  }
}

void loadB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2947 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrsb, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 16766 "ad_aarch64.cpp"
  }
}

void loadUBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2963 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrb, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 16783 "ad_aarch64.cpp"
  }
}

void loadUB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2963 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrb, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 16800 "ad_aarch64.cpp"
  }
}

void loadSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2971 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrshw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 16817 "ad_aarch64.cpp"
  }
}

void loadS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2979 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrsh, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 16834 "ad_aarch64.cpp"
  }
}

void loadUSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2995 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrh, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 16851 "ad_aarch64.cpp"
  }
}

void loadUS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2995 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrh, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 16868 "ad_aarch64.cpp"
  }
}

void loadINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3011 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 16885 "ad_aarch64.cpp"
  }
}

void loadI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3019 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrsw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 16902 "ad_aarch64.cpp"
  }
}

void loadUI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {

#line 3011 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 16920 "ad_aarch64.cpp"
  }
}

void loadLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3027 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 16937 "ad_aarch64.cpp"
  }
}

void loadRangeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3011 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 16954 "ad_aarch64.cpp"
  }
}

void loadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3027 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 16971 "ad_aarch64.cpp"
  }
}

void loadNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3011 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 16988 "ad_aarch64.cpp"
  }
}

void loadKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3027 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 17005 "ad_aarch64.cpp"
  }
}

void loadNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3011 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 17022 "ad_aarch64.cpp"
  }
}

void loadFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3035 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrs, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 17039 "ad_aarch64.cpp"
  }
}

void loadDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3043 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrd, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 17056 "ad_aarch64.cpp"
  }
}

void loadConINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 3484 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    uint32_t con = (uint32_t)opnd_array(1)->constant();
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    if (con == 0) {
      __ movw(dst_reg, zr);
    } else {
      __ movw(dst_reg, con);
    }
  
#line 17078 "ad_aarch64.cpp"
  }
}

void loadConLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 3495 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    uint64_t con = (uint64_t)opnd_array(1)->constantL();
    if (con == 0) {
      __ mov(dst_reg, zr);
    } else {
      __ mov(dst_reg, con);
    }
  
#line 17100 "ad_aarch64.cpp"
  }
}

void loadConPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3506 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    address con = (address)opnd_array(1)->constant();
    if (con == NULL || con == (address)1) {
      ShouldNotReachHere();
    } else {
      relocInfo::relocType rtype = opnd_array(1)->constant_reloc();
      if (rtype == relocInfo::oop_type) {
        __ movoop(dst_reg, (jobject)con, /*immediate*/true);
      } else if (rtype == relocInfo::metadata_type) {
        __ mov_metadata(dst_reg, (Metadata*)con);
      } else {
        assert(rtype == relocInfo::none, "unexpected reloc type");
        if (con < (address)(uintptr_t)os::vm_page_size()) {
          __ mov(dst_reg, con);
        } else {
          uint64_t offset;
          __ adrp(dst_reg, con, offset);
          __ add(dst_reg, dst_reg, offset);
        }
      }
    }
  
#line 17136 "ad_aarch64.cpp"
  }
}

void loadConP0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3531 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ mov(dst_reg, zr);
  
#line 17153 "ad_aarch64.cpp"
  }
}

void loadConP1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3537 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ mov(dst_reg, (uint64_t)1);
  
#line 17170 "ad_aarch64.cpp"
  }
}

void loadByteMapBaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3543 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    __ load_byte_map_base(opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 17186 "ad_aarch64.cpp"
  }
}

void loadConNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3548 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    address con = (address)opnd_array(1)->constant();
    if (con == NULL) {
      ShouldNotReachHere();
    } else {
      relocInfo::relocType rtype = opnd_array(1)->constant_reloc();
      assert(rtype == relocInfo::oop_type, "unexpected reloc type");
      __ set_narrow_oop(dst_reg, (jobject)con);
    }
  
#line 17210 "ad_aarch64.cpp"
  }
}

void loadConN0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3561 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ mov(dst_reg, zr);
  
#line 17227 "ad_aarch64.cpp"
  }
}

void loadConNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3567 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    address con = (address)opnd_array(1)->constant();
    if (con == NULL) {
      ShouldNotReachHere();
    } else {
      relocInfo::relocType rtype = opnd_array(1)->constant_reloc();
      assert(rtype == relocInfo::metadata_type, "unexpected reloc type");
      __ set_narrow_klass(dst_reg, (Klass *)con);
    }
  
#line 17251 "ad_aarch64.cpp"
  }
}

void loadConF_packedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7753 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), (double)opnd_array(1)->constantF());
  
#line 17267 "ad_aarch64.cpp"
  }
}

void loadConFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7771 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 17283 "ad_aarch64.cpp"
  }
}

void loadConFNode::eval_constant(Compile* C) {
  {

#line 7772 "src/hotspot/cpu/aarch64/aarch64.ad"
    _constant = C->output()->constant_table().add(this, opnd_array(1));
#line 17292 "ad_aarch64.cpp"
  }
}
void loadConD_packedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7784 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->constantD());
  
#line 17307 "ad_aarch64.cpp"
  }
}

void loadConDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7801 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 17323 "ad_aarch64.cpp"
  }
}

void loadConDNode::eval_constant(Compile* C) {
  {

#line 7802 "src/hotspot/cpu/aarch64/aarch64.ad"
    _constant = C->output()->constant_table().add(this, opnd_array(1));
#line 17332 "ad_aarch64.cpp"
  }
}
void storeimmCM0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3059 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strb, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 17349 "ad_aarch64.cpp"
  }
}

void storeimmCM0_orderedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3139 "src/hotspot/cpu/aarch64/aarch64.ad"

      C2_MacroAssembler _masm(&cbuf);
      __ membar(Assembler::StoreStore);
      loadStore(_masm, &MacroAssembler::strb, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 17368 "ad_aarch64.cpp"
  }
}

void storeBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3051 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strb, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 17386 "ad_aarch64.cpp"
  }
}

void storeimmB0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3059 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strb, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 17404 "ad_aarch64.cpp"
  }
}

void storeCNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3067 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strh, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 17422 "ad_aarch64.cpp"
  }
}

void storeimmC0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3075 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strh, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 17440 "ad_aarch64.cpp"
  }
}

void storeINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3083 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 17458 "ad_aarch64.cpp"
  }
}

void storeimmI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3091 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strw, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 17476 "ad_aarch64.cpp"
  }
}

void storeLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3099 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      C2_MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 17502 "ad_aarch64.cpp"
  }
}

void storeimmL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3115 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::str, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 17520 "ad_aarch64.cpp"
  }
}

void storePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3099 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      C2_MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 17546 "ad_aarch64.cpp"
  }
}

void storeimmP0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3115 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::str, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 17564 "ad_aarch64.cpp"
  }
}

void storeNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3083 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 17582 "ad_aarch64.cpp"
  }
}

void storeImmN0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3091 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strw, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 17600 "ad_aarch64.cpp"
  }
}

void storeFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3123 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strs, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 17618 "ad_aarch64.cpp"
  }
}

void storeDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3131 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strd, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 17636 "ad_aarch64.cpp"
  }
}

void storeNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3083 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 17654 "ad_aarch64.cpp"
  }
}

void prefetchallocNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {

#line 3463 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    if (index == -1) {
      __ prfm(Address(base, disp), PSTL1KEEP);
    } else {
      Register index_reg = as_Register(index);
      if (disp == 0) {
        __ prfm(Address(base, index_reg, Address::lsl(scale)), PSTL1KEEP);
      } else {
        __ lea(rscratch1, Address(base, disp));
	__ prfm(Address(rscratch1, index_reg, Address::lsl(scale)), PSTL1KEEP);
      }
    }
  
#line 17684 "ad_aarch64.cpp"
  }
}

void loadB_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3222 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
    __ sxtb(dst_reg, dst_reg);
  
#line 17702 "ad_aarch64.cpp"
  }
}

void loadB2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3222 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
    __ sxtb(dst_reg, dst_reg);
  
#line 17720 "ad_aarch64.cpp"
  }
}

void loadUB_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3234 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
  
#line 17736 "ad_aarch64.cpp"
  }
}

void loadUB2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3234 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
  
#line 17752 "ad_aarch64.cpp"
  }
}

void loadS_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3239 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
    __ sxthw(dst_reg, dst_reg);
  
#line 17770 "ad_aarch64.cpp"
  }
}

void loadUS_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3253 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
  
#line 17786 "ad_aarch64.cpp"
  }
}

void loadUS2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3258 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
  
#line 17802 "ad_aarch64.cpp"
  }
}

void loadS2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3246 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
    __ sxth(dst_reg, dst_reg);
  
#line 17820 "ad_aarch64.cpp"
  }
}

void loadI_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3268 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
  
#line 17836 "ad_aarch64.cpp"
  }
}

void loadUI2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {

#line 3268 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
  
#line 17853 "ad_aarch64.cpp"
  }
}

void loadL_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3273 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldar);
  
#line 17869 "ad_aarch64.cpp"
  }
}

void loadP_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3273 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldar);
  
#line 17885 "ad_aarch64.cpp"
  }
}

void loadN_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3268 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
  
#line 17901 "ad_aarch64.cpp"
  }
}

void loadF_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3278 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(rscratch1, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
    __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), rscratch1);
  
#line 17918 "ad_aarch64.cpp"
  }
}

void loadD_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3284 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(rscratch1, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldar);
    __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), rscratch1);
  
#line 17935 "ad_aarch64.cpp"
  }
}

void storeB_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3199 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrb);
  
#line 17952 "ad_aarch64.cpp"
  }
}

void storeC_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3204 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrh);
  
#line 17969 "ad_aarch64.cpp"
  }
}

void storeI_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3209 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 17986 "ad_aarch64.cpp"
  }
}

void storeL_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3290 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      C2_MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    MOV_VOLATILE(src_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 18012 "ad_aarch64.cpp"
  }
}

void storeP_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3290 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      C2_MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    MOV_VOLATILE(src_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 18038 "ad_aarch64.cpp"
  }
}

void storeN_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3209 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 18055 "ad_aarch64.cpp"
  }
}

void storeF_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3304 "src/hotspot/cpu/aarch64/aarch64.ad"

    {
      C2_MacroAssembler _masm(&cbuf);
      FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
      __ fmovs(rscratch2, src_reg);
    }
    MOV_VOLATILE(rscratch2, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 18077 "ad_aarch64.cpp"
  }
}

void storeD_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3314 "src/hotspot/cpu/aarch64/aarch64.ad"

    {
      C2_MacroAssembler _masm(&cbuf);
      FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
      __ fmovd(rscratch2, src_reg);
    }
    MOV_VOLATILE(rscratch2, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 18099 "ad_aarch64.cpp"
  }
}

void cacheWBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8382 "src/hotspot/cpu/aarch64/aarch64.ad"

    assert(opnd_array(1)->index_position() < 0, "should be");
    assert(opnd_array(1)->disp(ra_,this,idx1)== 0, "should be");
    __ cache_wb(Address(as_Register(opnd_array(1)->base(ra_,this,idx1)), 0));
  
#line 18117 "ad_aarch64.cpp"
  }
}

void cacheWBPreSyncNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8397 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cache_wbsync(true);
  
#line 18133 "ad_aarch64.cpp"
  }
}

void cacheWBPostSyncNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8410 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cache_wbsync(false);
  
#line 18149 "ad_aarch64.cpp"
  }
}

void bytes_reverse_intNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8425 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ revw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18165 "ad_aarch64.cpp"
  }
}

void bytes_reverse_longNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8438 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rev(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18181 "ad_aarch64.cpp"
  }
}

void bytes_reverse_unsigned_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8451 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rev16w(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18197 "ad_aarch64.cpp"
  }
}

void bytes_reverse_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8465 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rev16w(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sbfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */), 0U, 15U);
  
#line 18214 "ad_aarch64.cpp"
  }
}

void countLeadingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8481 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ clzw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18230 "ad_aarch64.cpp"
  }
}

void countLeadingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8493 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ clz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18246 "ad_aarch64.cpp"
  }
}

void countTrailingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8506 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rbitw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ clzw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 18263 "ad_aarch64.cpp"
  }
}

void countTrailingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8520 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rbit(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ clz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 18280 "ad_aarch64.cpp"
  }
}

void popCountINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8542 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */); // ensure top 32 bits 0
    __ mov(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0);
  
#line 18301 "ad_aarch64.cpp"
  }
}

void popCountI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8563 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister tmp_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrs, tmp_reg, opnd_array(1)->opcode(),
              as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0);
  
#line 18323 "ad_aarch64.cpp"
  }
}

void popCountLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8586 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mov(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0);
  
#line 18343 "ad_aarch64.cpp"
  }
}

void popCountL_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8606 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister tmp_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrd, tmp_reg, opnd_array(1)->opcode(),
              as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0);
  
#line 18365 "ad_aarch64.cpp"
  }
}

void load_fenceNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8627 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ membar(Assembler::LoadLoad|Assembler::LoadStore);
  
#line 18381 "ad_aarch64.cpp"
  }
}

void unnecessary_membar_acquireNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8640 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_acquire (elided)");
  
#line 18397 "ad_aarch64.cpp"
  }
}

void membar_acquireNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8654 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_acquire");
    __ membar(Assembler::LoadLoad|Assembler::LoadStore);
  
#line 18414 "ad_aarch64.cpp"
  }
}

void membar_acquire_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8669 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_acquire_lock (elided)");
  
#line 18430 "ad_aarch64.cpp"
  }
}

void store_fenceNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8682 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ membar(Assembler::LoadStore|Assembler::StoreStore);
  
#line 18446 "ad_aarch64.cpp"
  }
}

void unnecessary_membar_releaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8695 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_release (elided)");
  
#line 18462 "ad_aarch64.cpp"
  }
}

void membar_releaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8708 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_release");
    __ membar(Assembler::LoadStore|Assembler::StoreStore);
  
#line 18479 "ad_aarch64.cpp"
  }
}

void membar_storestoreNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8722 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ membar(Assembler::StoreStore);
  
#line 18495 "ad_aarch64.cpp"
  }
}

void membar_storestore_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8722 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ membar(Assembler::StoreStore);
  
#line 18511 "ad_aarch64.cpp"
  }
}

void membar_release_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8734 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_release_lock (elided)");
  
#line 18527 "ad_aarch64.cpp"
  }
}

void unnecessary_membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8748 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_volatile (elided)");
  
#line 18543 "ad_aarch64.cpp"
  }
}

void membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8762 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_volatile");
    __ membar(Assembler::StoreLoad);
  
#line 18560 "ad_aarch64.cpp"
  }
}

void castX2PNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8779 "src/hotspot/cpu/aarch64/aarch64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */!= opnd_array(1)->reg(ra_,this,idx1)/* src */) {
      __ mov(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
  
#line 18578 "ad_aarch64.cpp"
  }
}

void castP2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8794 "src/hotspot/cpu/aarch64/aarch64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */!= opnd_array(1)->reg(ra_,this,idx1)/* src */) {
      __ mov(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
  
#line 18596 "ad_aarch64.cpp"
  }
}

void convP2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8809 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 18612 "ad_aarch64.cpp"
  }
}

void convN2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8825 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 18628 "ad_aarch64.cpp"
  }
}

void encodeHeapOopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8840 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ encode_heap_oop(d, s);
  
#line 18646 "ad_aarch64.cpp"
  }
}

void encodeHeapOop_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8853 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ encode_heap_oop_not_null(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 18662 "ad_aarch64.cpp"
  }
}

void decodeHeapOopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8865 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ decode_heap_oop(d, s);
  
#line 18680 "ad_aarch64.cpp"
  }
}

void decodeHeapOop_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8879 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ decode_heap_oop_not_null(d, s);
  
#line 18698 "ad_aarch64.cpp"
  }
}

void encodeKlass_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8897 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ encode_klass_not_null(dst_reg, src_reg);
  
#line 18716 "ad_aarch64.cpp"
  }
}

void decodeKlass_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8912 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    if (dst_reg != src_reg) {
      __ decode_klass_not_null(dst_reg, src_reg);
    } else {
      __ decode_klass_not_null(dst_reg);
    }
  
#line 18738 "ad_aarch64.cpp"
  }
}

void checkCastPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint checkCastPPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castPPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castIINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castIINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castLLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castLLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castFFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castFFNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castDDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castDDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castVVDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castVVDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castVVXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castVVXNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castVVNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castVVNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castVVMaskNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castVVMaskNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void loadPLockedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3326 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    if (index == -1) {
       if (disp != 0) {
        __ lea(rscratch1, Address(base, disp));
        __ ldaxr(dst_reg, rscratch1);
      } else {
        // TODO
        // should we ever get anything other than this case?
        __ ldaxr(dst_reg, base);
      }
    } else {
      Register index_reg = as_Register(index);
      if (disp == 0) {
        __ lea(rscratch1, Address(base, index_reg, Address::lsl(scale)));
        __ ldaxr(dst_reg, rscratch1);
      } else {
        __ lea(rscratch1, Address(base, disp));
        __ lea(rscratch1, Address(rscratch1, index_reg, Address::lsl(scale)));
        __ ldaxr(dst_reg, rscratch1);
      }
    }
  
#line 18908 "ad_aarch64.cpp"
  }
}

void storePConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// heap_top_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3355 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register src_reg = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* newval */);
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    if (index == -1) {
       if (disp != 0) {
        __ lea(rscratch2, Address(base, disp));
        __ stlxr(rscratch1, src_reg, rscratch2);
      } else {
        // TODO
        // should we ever get anything other than this case?
        __ stlxr(rscratch1, src_reg, base);
      }
    } else {
      Register index_reg = as_Register(index);
      if (disp == 0) {
        __ lea(rscratch2, Address(base, index_reg, Address::lsl(scale)));
        __ stlxr(rscratch1, src_reg, rscratch2);
      } else {
        __ lea(rscratch2, Address(base, disp));
        __ lea(rscratch2, Address(rscratch2, index_reg, Address::lsl(scale)));
        __ stlxr(rscratch1, src_reg, rscratch2);
      }
    }
    __ cmpw(rscratch1, zr);
  
#line 18951 "ad_aarch64.cpp"
  }
}

void storeLConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3422 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 18972 "ad_aarch64.cpp"
  }
}

void storeIConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3430 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 18993 "ad_aarch64.cpp"
  }
}

void compareAndSwapBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3409 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19014 "ad_aarch64.cpp"
  }
  {

#line 3455 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19024 "ad_aarch64.cpp"
  }
}

void compareAndSwapSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3401 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19045 "ad_aarch64.cpp"
  }
  {

#line 3455 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19055 "ad_aarch64.cpp"
  }
}

void compareAndSwapINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3393 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19076 "ad_aarch64.cpp"
  }
  {

#line 3455 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19086 "ad_aarch64.cpp"
  }
}

void compareAndSwapLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3385 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19107 "ad_aarch64.cpp"
  }
  {

#line 3455 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19117 "ad_aarch64.cpp"
  }
}

void compareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3385 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19138 "ad_aarch64.cpp"
  }
  {

#line 3455 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19148 "ad_aarch64.cpp"
  }
}

void compareAndSwapNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3393 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19169 "ad_aarch64.cpp"
  }
  {

#line 3455 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19179 "ad_aarch64.cpp"
  }
}

void compareAndSwapBAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3446 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19200 "ad_aarch64.cpp"
  }
  {

#line 3455 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19210 "ad_aarch64.cpp"
  }
}

void compareAndSwapSAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3438 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19231 "ad_aarch64.cpp"
  }
  {

#line 3455 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19241 "ad_aarch64.cpp"
  }
}

void compareAndSwapIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3430 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19262 "ad_aarch64.cpp"
  }
  {

#line 3455 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19272 "ad_aarch64.cpp"
  }
}

void compareAndSwapLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3422 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19293 "ad_aarch64.cpp"
  }
  {

#line 3455 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19303 "ad_aarch64.cpp"
  }
}

void compareAndSwapPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3422 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19324 "ad_aarch64.cpp"
  }
  {

#line 3455 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19334 "ad_aarch64.cpp"
  }
}

void compareAndSwapNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3430 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19355 "ad_aarch64.cpp"
  }
  {

#line 3455 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19365 "ad_aarch64.cpp"
  }
}

void compareAndExchangeBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9391 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxtbw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 19387 "ad_aarch64.cpp"
  }
}

void compareAndExchangeSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9410 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxthw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 19409 "ad_aarch64.cpp"
  }
}

void compareAndExchangeINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9429 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 19430 "ad_aarch64.cpp"
  }
}

void compareAndExchangeLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9447 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 19451 "ad_aarch64.cpp"
  }
}

void compareAndExchangeNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9465 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 19472 "ad_aarch64.cpp"
  }
}

void compareAndExchangePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9483 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 19493 "ad_aarch64.cpp"
  }
}

void compareAndExchangeBAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9501 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxtbw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 19515 "ad_aarch64.cpp"
  }
}

void compareAndExchangeSAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9520 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxthw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 19537 "ad_aarch64.cpp"
  }
}

void compareAndExchangeIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9539 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 19558 "ad_aarch64.cpp"
  }
}

void compareAndExchangeLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9557 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 19579 "ad_aarch64.cpp"
  }
}

void compareAndExchangeNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9575 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 19600 "ad_aarch64.cpp"
  }
}

void compareAndExchangePAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9593 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 19621 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9612 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 19642 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9632 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 19663 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9652 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 19684 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9672 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 19705 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9692 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 19726 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9712 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 19747 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapBAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9732 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 19768 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapSAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9752 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 19789 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9772 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 19810 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9792 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 19831 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9812 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 19852 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9832 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 19873 "ad_aarch64.cpp"
  }
}

void get_and_setINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9848 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 19890 "ad_aarch64.cpp"
  }
}

void get_and_setLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9858 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchg(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 19907 "ad_aarch64.cpp"
  }
}

void get_and_setNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9868 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 19924 "ad_aarch64.cpp"
  }
}

void get_and_setPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9879 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchg(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 19941 "ad_aarch64.cpp"
  }
}

void get_and_setIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9890 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgalw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 19958 "ad_aarch64.cpp"
  }
}

void get_and_setLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9901 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgal(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 19975 "ad_aarch64.cpp"
  }
}

void get_and_setNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9912 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgalw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 19992 "ad_aarch64.cpp"
  }
}

void get_and_setPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9923 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgal(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20009 "ad_aarch64.cpp"
  }
}

void get_and_addLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9934 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20026 "ad_aarch64.cpp"
  }
}

void get_and_addL_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9945 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20043 "ad_aarch64.cpp"
  }
}

void get_and_addLiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9955 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20060 "ad_aarch64.cpp"
  }
}

void get_and_addLi_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9966 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(noreg, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20077 "ad_aarch64.cpp"
  }
}

void get_and_addINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9976 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20094 "ad_aarch64.cpp"
  }
}

void get_and_addI_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9987 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20111 "ad_aarch64.cpp"
  }
}

void get_and_addIiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9997 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20128 "ad_aarch64.cpp"
  }
}

void get_and_addIi_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10008 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(noreg, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20145 "ad_aarch64.cpp"
  }
}

void get_and_addLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10019 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20162 "ad_aarch64.cpp"
  }
}

void get_and_addL_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10030 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20179 "ad_aarch64.cpp"
  }
}

void get_and_addLiAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10041 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20196 "ad_aarch64.cpp"
  }
}

void get_and_addLi_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10052 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(noreg, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20213 "ad_aarch64.cpp"
  }
}

void get_and_addIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10063 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20230 "ad_aarch64.cpp"
  }
}

void get_and_addI_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10074 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20247 "ad_aarch64.cpp"
  }
}

void get_and_addIiAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10085 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20264 "ad_aarch64.cpp"
  }
}

void get_and_addIi_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10096 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(noreg, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20281 "ad_aarch64.cpp"
  }
}

void cmpL3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10116 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
    __ cnegw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LT);
  
#line 20300 "ad_aarch64.cpp"
  }
}

void cmpL3_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10136 "src/hotspot/cpu/aarch64/aarch64.ad"

    int32_t con = (int32_t)opnd_array(2)->constantL();
     if (con < 0) {
      __ adds(zr, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, -con);
    } else {
      __ subs(zr, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, con);
    }
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
    __ cnegw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LT);
  
#line 20324 "ad_aarch64.cpp"
  }
}

void cmovI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10169 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20346 "ad_aarch64.cpp"
  }
}

void cmovUI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10185 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20368 "ad_aarch64.cpp"
  }
}

void cmovI_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10210 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20390 "ad_aarch64.cpp"
  }
}

void cmovUI_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10226 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20412 "ad_aarch64.cpp"
  }
}

void cmovI_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10242 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20434 "ad_aarch64.cpp"
  }
}

void cmovUI_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10258 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20456 "ad_aarch64.cpp"
  }
}

void cmovI_reg_zero_oneNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10279 "src/hotspot/cpu/aarch64/aarch64.ad"

    // equivalently
    // cset(as_Register($dst$$reg),
    //      negate_condition((Assembler::Condition)$cmp$$cmpcode));
    __ csincw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20481 "ad_aarch64.cpp"
  }
}

void cmovUI_reg_zero_oneNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10298 "src/hotspot/cpu/aarch64/aarch64.ad"

    // equivalently
    // cset(as_Register($dst$$reg),
    //      negate_condition((Assembler::Condition)$cmp$$cmpcode));
    __ csincw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20506 "ad_aarch64.cpp"
  }
}

void cmovL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10317 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20528 "ad_aarch64.cpp"
  }
}

void cmovUL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10333 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20550 "ad_aarch64.cpp"
  }
}

void cmovL_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10351 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20572 "ad_aarch64.cpp"
  }
}

void cmovUL_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10367 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20594 "ad_aarch64.cpp"
  }
}

void cmovL_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10383 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20616 "ad_aarch64.cpp"
  }
}

void cmovUL_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10399 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20638 "ad_aarch64.cpp"
  }
}

void cmovP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10415 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20660 "ad_aarch64.cpp"
  }
}

void cmovUP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10431 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20682 "ad_aarch64.cpp"
  }
}

void cmovP_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10449 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20704 "ad_aarch64.cpp"
  }
}

void cmovUP_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10465 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20726 "ad_aarch64.cpp"
  }
}

void cmovP_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10481 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20748 "ad_aarch64.cpp"
  }
}

void cmovUP_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10497 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20770 "ad_aarch64.cpp"
  }
}

void cmovN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10513 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20792 "ad_aarch64.cpp"
  }
}

void cmovUN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10529 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20814 "ad_aarch64.cpp"
  }
}

void cmovN_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10547 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20836 "ad_aarch64.cpp"
  }
}

void cmovUN_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10563 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20858 "ad_aarch64.cpp"
  }
}

void cmovN_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10579 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20880 "ad_aarch64.cpp"
  }
}

void cmovUN_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10595 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20902 "ad_aarch64.cpp"
  }
}

void cmovF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10612 "src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcsels(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 20925 "ad_aarch64.cpp"
  }
}

void cmovUF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10630 "src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcsels(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 20948 "ad_aarch64.cpp"
  }
}

void cmovD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10648 "src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcseld(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 20971 "ad_aarch64.cpp"
  }
}

void cmovUD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10666 "src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcseld(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 20994 "ad_aarch64.cpp"
  }
}

void addI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10695 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21013 "ad_aarch64.cpp"
  }
}

void addI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3582 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constant();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ subw(dst_reg, src_reg, -con);
    } else {
      __ addw(dst_reg, src_reg, con);
    }
  
#line 21039 "ad_aarch64.cpp"
  }
}

void addI_reg_imm_i2lNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3582 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constant();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ subw(dst_reg, src_reg, -con);
    } else {
      __ addw(dst_reg, src_reg, con);
    }
  
#line 21065 "ad_aarch64.cpp"
  }
}

void addP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10739 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21084 "ad_aarch64.cpp"
  }
}

void addP_reg_reg_extNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10754 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
  
#line 21103 "ad_aarch64.cpp"
  }
}

void addP_reg_reg_lslNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// scale
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10769 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lea(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           Address(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                   Address::lsl(opnd_array(3)->constant())));
  
#line 21123 "ad_aarch64.cpp"
  }
}

void addP_reg_reg_ext_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// scale
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10784 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lea(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           Address(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                   Address::sxtw(opnd_array(3)->constant())));
  
#line 21143 "ad_aarch64.cpp"
  }
}

void lshift_extNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// scale
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10799 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sbfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
          opnd_array(2)->constant()& 63, MIN2(32, (int)((-opnd_array(2)->constant()) & 63)));
  
#line 21162 "ad_aarch64.cpp"
  }
}

void addP_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3596 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constantL();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ sub(dst_reg, src_reg, -con);
    } else {
      __ add(dst_reg, src_reg, con);
    }
  
#line 21188 "ad_aarch64.cpp"
  }
}

void addL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10833 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21207 "ad_aarch64.cpp"
  }
}

void addL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3596 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constantL();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ sub(dst_reg, src_reg, -con);
    } else {
      __ add(dst_reg, src_reg, con);
    }
  
#line 21233 "ad_aarch64.cpp"
  }
}

void subI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10864 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21252 "ad_aarch64.cpp"
  }
}

void subI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3582 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constant();
    // add has primary == 0, subtract has primary == 1
    if ((0x1 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ subw(dst_reg, src_reg, -con);
    } else {
      __ addw(dst_reg, src_reg, con);
    }
  
#line 21278 "ad_aarch64.cpp"
  }
}

void subL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10896 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21297 "ad_aarch64.cpp"
  }
}

void subL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3596 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constantL();
    // add has primary == 0, subtract has primary == 1
    if ((0x1 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ sub(dst_reg, src_reg, -con);
    } else {
      __ add(dst_reg, src_reg, con);
    }
  
#line 21323 "ad_aarch64.cpp"
  }
}

void negI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10928 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 21341 "ad_aarch64.cpp"
  }
}

void negL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10944 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ neg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 21359 "ad_aarch64.cpp"
  }
}

void mulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10960 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mulw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21378 "ad_aarch64.cpp"
  }
}

void smulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10975 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smull(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21397 "ad_aarch64.cpp"
  }
}

void smulI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10975 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smull(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 21416 "ad_aarch64.cpp"
  }
}

void mulLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10992 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mul(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21435 "ad_aarch64.cpp"
  }
}

void mulHiL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11008 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smulh(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21454 "ad_aarch64.cpp"
  }
}

void maddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11025 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ maddw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 21475 "ad_aarch64.cpp"
  }
}

void maddI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11025 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ maddw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 21496 "ad_aarch64.cpp"
  }
}

void msubINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11041 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ msubw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 21517 "ad_aarch64.cpp"
  }
}

void mnegINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11059 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mnegw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 21537 "ad_aarch64.cpp"
  }
}

void mnegI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11059 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mnegw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 21557 "ad_aarch64.cpp"
  }
}

void maddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11076 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ madd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 21578 "ad_aarch64.cpp"
  }
}

void maddL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11076 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ madd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 21599 "ad_aarch64.cpp"
  }
}

void msubLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11092 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ msub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 21620 "ad_aarch64.cpp"
  }
}

void mnegLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11110 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mneg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 21640 "ad_aarch64.cpp"
  }
}

void mnegL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11110 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mneg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 21660 "ad_aarch64.cpp"
  }
}

void smaddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11127 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 21681 "ad_aarch64.cpp"
  }
}

void smaddL_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11127 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 21702 "ad_aarch64.cpp"
  }
}

void smaddL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11127 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 21723 "ad_aarch64.cpp"
  }
}

void smaddL_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11127 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 21744 "ad_aarch64.cpp"
  }
}

void smsubLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11143 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smsubl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 21765 "ad_aarch64.cpp"
  }
}

void smsubL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11143 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smsubl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 21786 "ad_aarch64.cpp"
  }
}

void smnegLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11159 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smnegl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 21806 "ad_aarch64.cpp"
  }
}

void smnegL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11159 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smnegl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 21826 "ad_aarch64.cpp"
  }
}

void muladdS2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11177 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mulw(rscratch1, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ maddw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src4 */), rscratch1); 
#line 21845 "ad_aarch64.cpp"
  }
}

void divINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3610 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivl(dst_reg, src1_reg, src2_reg, false, rscratch1);
  
#line 21865 "ad_aarch64.cpp"
  }
}

void divLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3618 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivq(dst_reg, src1_reg, src2_reg, false, rscratch1);
  
#line 21885 "ad_aarch64.cpp"
  }
}

void modINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3626 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivl(dst_reg, src1_reg, src2_reg, true, rscratch1);
  
#line 21905 "ad_aarch64.cpp"
  }
}

void modLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3634 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivq(dst_reg, src1_reg, src2_reg, true, rscratch1);
  
#line 21925 "ad_aarch64.cpp"
  }
}

void lShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11243 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lslvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21944 "ad_aarch64.cpp"
  }
}

void lShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11259 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lslw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x1f);
  
#line 21963 "ad_aarch64.cpp"
  }
}

void urShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11275 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsrvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21982 "ad_aarch64.cpp"
  }
}

void urShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11291 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x1f);
  
#line 22001 "ad_aarch64.cpp"
  }
}

void rShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11307 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22020 "ad_aarch64.cpp"
  }
}

void rShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11323 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x1f);
  
#line 22039 "ad_aarch64.cpp"
  }
}

void lShiftL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11344 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lslv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22058 "ad_aarch64.cpp"
  }
}

void lShiftL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11360 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x3f);
  
#line 22077 "ad_aarch64.cpp"
  }
}

void urShiftL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11376 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsrv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22096 "ad_aarch64.cpp"
  }
}

void urShiftL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11392 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           opnd_array(2)->constant()& 0x3f);
  
#line 22115 "ad_aarch64.cpp"
  }
}

void urShiftP_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11408 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           opnd_array(2)->constant()& 0x3f);
  
#line 22134 "ad_aarch64.cpp"
  }
}

void rShiftL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11424 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22153 "ad_aarch64.cpp"
  }
}

void rShiftL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11440 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           opnd_array(2)->constant()& 0x3f);
  
#line 22172 "ad_aarch64.cpp"
  }
}

void regL_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11462 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              zr,
              Assembler::LSL, 0);
  
#line 22192 "ad_aarch64.cpp"
  }
}

void regI_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11481 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              zr,
              Assembler::LSL, 0);
  
#line 22212 "ad_aarch64.cpp"
  }
}

void AndI_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11499 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 22233 "ad_aarch64.cpp"
  }
}

void AndI_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11499 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 22254 "ad_aarch64.cpp"
  }
}

void AndL_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11517 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 22275 "ad_aarch64.cpp"
  }
}

void AndL_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11517 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 22296 "ad_aarch64.cpp"
  }
}

void OrI_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11535 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 22317 "ad_aarch64.cpp"
  }
}

void OrI_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11535 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 22338 "ad_aarch64.cpp"
  }
}

void OrL_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11553 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 22359 "ad_aarch64.cpp"
  }
}

void OrL_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11553 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 22380 "ad_aarch64.cpp"
  }
}

void XorI_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11571 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 22401 "ad_aarch64.cpp"
  }
}

void XorI_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11571 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 22422 "ad_aarch64.cpp"
  }
}

void XorL_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11589 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 22443 "ad_aarch64.cpp"
  }
}

void XorL_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11589 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 22464 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11609 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22487 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11609 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22510 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11630 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22533 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11630 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22556 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11651 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22579 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11651 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22602 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11672 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22625 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11672 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22648 "ad_aarch64.cpp"
  }
}

void AndI_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11693 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22671 "ad_aarch64.cpp"
  }
}

void AndI_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11693 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22694 "ad_aarch64.cpp"
  }
}

void AndL_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11714 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22717 "ad_aarch64.cpp"
  }
}

void AndL_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11714 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22740 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11735 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 22763 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11735 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 22786 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11756 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 22809 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11756 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 22832 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11777 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22855 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11777 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22878 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11777 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSR,
              opnd_array(4)->constant()& 0x1f);
  
#line 22901 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11777 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22924 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11798 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22947 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11798 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22970 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11798 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSR,
              opnd_array(4)->constant()& 0x3f);
  
#line 22993 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11798 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23016 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11819 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23039 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11819 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 23062 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11819 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ASR,
              opnd_array(4)->constant()& 0x1f);
  
#line 23085 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11819 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23108 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11840 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23131 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11840 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 23154 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11840 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ASR,
              opnd_array(4)->constant()& 0x3f);
  
#line 23177 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11840 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23200 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11861 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23223 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11861 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 23246 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11861 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ROR,
              opnd_array(4)->constant()& 0x1f);
  
#line 23269 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11861 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23292 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11882 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23315 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11882 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 23338 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11882 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ROR,
              opnd_array(4)->constant()& 0x3f);
  
#line 23361 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11882 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23384 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11903 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 23407 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11903 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 23430 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11903 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSL,
              opnd_array(4)->constant()& 0x1f);
  
#line 23453 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11903 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 23476 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11924 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 23499 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11924 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 23522 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11924 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSL,
              opnd_array(4)->constant()& 0x3f);
  
#line 23545 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11924 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 23568 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11945 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23591 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11945 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 23614 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11966 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23637 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11966 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 23660 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11987 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23683 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11987 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 23706 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12008 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23729 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12008 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 23752 "ad_aarch64.cpp"
  }
}

void OrI_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12029 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23775 "ad_aarch64.cpp"
  }
}

void OrI_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12029 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 23798 "ad_aarch64.cpp"
  }
}

void OrL_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12050 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23821 "ad_aarch64.cpp"
  }
}

void OrL_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12050 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 23844 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12071 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 23867 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12071 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 23890 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12092 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 23913 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12092 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 23936 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12113 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23958 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12113 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 23980 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12134 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 24002 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12134 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 24024 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12155 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 24046 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12155 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 24068 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12176 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 24090 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12176 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 24112 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12197 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 24134 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12197 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 24156 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12218 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 24178 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12218 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 24200 "ad_aarch64.cpp"
  }
}

void AndI_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12239 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 24222 "ad_aarch64.cpp"
  }
}

void AndI_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12239 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 24244 "ad_aarch64.cpp"
  }
}

void AndL_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12260 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 24266 "ad_aarch64.cpp"
  }
}

void AndL_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12260 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 24288 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12281 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 24310 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12281 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 24332 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12302 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 24354 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12302 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 24376 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12323 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 24398 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12323 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 24420 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12344 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 24442 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12344 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 24464 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12365 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 24486 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12365 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 24508 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12386 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 24530 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12386 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 24552 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12407 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 24574 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12407 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 24596 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12428 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 24618 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12428 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 24640 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12449 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 24662 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12449 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 24684 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12470 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 24706 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12470 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 24728 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12491 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 24750 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12491 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 24772 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12512 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 24794 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12512 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 24816 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12533 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 24838 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12533 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 24860 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12554 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 24882 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12554 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 24904 "ad_aarch64.cpp"
  }
}

void OrI_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12575 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 24926 "ad_aarch64.cpp"
  }
}

void OrI_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12575 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 24948 "ad_aarch64.cpp"
  }
}

void OrL_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12596 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 24970 "ad_aarch64.cpp"
  }
}

void OrL_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12596 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 24992 "ad_aarch64.cpp"
  }
}

void AddI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12617 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 25014 "ad_aarch64.cpp"
  }
}

void AddI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12617 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 25036 "ad_aarch64.cpp"
  }
}

void AddL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12638 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 25058 "ad_aarch64.cpp"
  }
}

void AddL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12638 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 25080 "ad_aarch64.cpp"
  }
}

void AddI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12659 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 25102 "ad_aarch64.cpp"
  }
}

void AddI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12659 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 25124 "ad_aarch64.cpp"
  }
}

void AddL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12680 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 25146 "ad_aarch64.cpp"
  }
}

void AddL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12680 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 25168 "ad_aarch64.cpp"
  }
}

void AddI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12701 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 25190 "ad_aarch64.cpp"
  }
}

void AddI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12701 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 25212 "ad_aarch64.cpp"
  }
}

void AddL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12722 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 25234 "ad_aarch64.cpp"
  }
}

void AddL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12722 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 25256 "ad_aarch64.cpp"
  }
}

void SubI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12743 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 25278 "ad_aarch64.cpp"
  }
}

void SubL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12764 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 25300 "ad_aarch64.cpp"
  }
}

void SubI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12785 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 25322 "ad_aarch64.cpp"
  }
}

void SubL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12806 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 25344 "ad_aarch64.cpp"
  }
}

void SubI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12827 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 25366 "ad_aarch64.cpp"
  }
}

void SubL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12848 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 25388 "ad_aarch64.cpp"
  }
}

void sbfmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12869 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 63;
    int rshift = opnd_array(3)->constant()& 63;
    int s = 63 - lshift;
    int r = (rshift - lshift) & 63;
    __ sbfm(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 25412 "ad_aarch64.cpp"
  }
}

void sbfmwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12892 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 31;
    int rshift = opnd_array(3)->constant()& 31;
    int s = 31 - lshift;
    int r = (rshift - lshift) & 31;
    __ sbfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 25436 "ad_aarch64.cpp"
  }
}

void ubfmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12915 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 63;
    int rshift = opnd_array(3)->constant()& 63;
    int s = 63 - lshift;
    int r = (rshift - lshift) & 63;
    __ ubfm(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 25460 "ad_aarch64.cpp"
  }
}

void ubfmwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12938 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 31;
    int rshift = opnd_array(3)->constant()& 31;
    int s = 31 - lshift;
    int r = (rshift - lshift) & 31;
    __ ubfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 25484 "ad_aarch64.cpp"
  }
}

void ubfxwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12963 "src/hotspot/cpu/aarch64/aarch64.ad"

    int rshift = opnd_array(2)->constant()& 31;
    intptr_t mask = opnd_array(3)->constant();
    int width = exact_log2(mask+1);
    __ ubfxw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rshift, width);
  
#line 25506 "ad_aarch64.cpp"
  }
}

void ubfxLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12983 "src/hotspot/cpu/aarch64/aarch64.ad"

    int rshift = opnd_array(2)->constant()& 63;
    intptr_t mask = opnd_array(3)->constantL();
    int width = exact_log2_long(mask+1);
    __ ubfx(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rshift, width);
  
#line 25528 "ad_aarch64.cpp"
  }
}

void ubfxIConvI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13007 "src/hotspot/cpu/aarch64/aarch64.ad"

    int rshift = opnd_array(2)->constant()& 31;
    intptr_t mask = opnd_array(3)->constant();
    int width = exact_log2(mask+1);
    __ ubfx(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rshift, width);
  
#line 25550 "ad_aarch64.cpp"
  }
}

void ubfizwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13030 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 31;
    intptr_t mask = opnd_array(2)->constant();
    int width = exact_log2(mask+1);
    __ ubfizw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 25572 "ad_aarch64.cpp"
  }
}

void ubfizLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13052 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 63;
    intptr_t mask = opnd_array(2)->constantL();
    int width = exact_log2_long(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 25594 "ad_aarch64.cpp"
  }
}

void ubfizwIConvI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13074 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 31;
    intptr_t mask = opnd_array(2)->constant();
    int width = exact_log2(mask+1);
    __ ubfizw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 25616 "ad_aarch64.cpp"
  }
}

void ubfizLConvL2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13096 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 63;
    intptr_t mask = opnd_array(2)->constantL();
    int width = exact_log2_long(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 25638 "ad_aarch64.cpp"
  }
}

void ubfizIConvI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13118 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 63;
    intptr_t mask = opnd_array(2)->constant();
    int width = exact_log2(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 25660 "ad_aarch64.cpp"
  }
}

void ubfizLConvL2IxNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13139 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 31;
    intptr_t mask = opnd_array(2)->constantL();
    int width = exact_log2(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 25682 "ad_aarch64.cpp"
  }
}

void ubfizIConvI2LAndINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// msk
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13158 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0, exact_log2(opnd_array(2)->constant()+ 1));
  
#line 25699 "ad_aarch64.cpp"
  }
}

void extrOrLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13176 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 63);
  
#line 25719 "ad_aarch64.cpp"
  }
}

void extrOrL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13176 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 63);
  
#line 25739 "ad_aarch64.cpp"
  }
}

void extrOrINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13194 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 31);
  
#line 25759 "ad_aarch64.cpp"
  }
}

void extrOrI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13194 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 31);
  
#line 25779 "ad_aarch64.cpp"
  }
}

void extrAddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13212 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 63);
  
#line 25799 "ad_aarch64.cpp"
  }
}

void extrAddL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13212 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 63);
  
#line 25819 "ad_aarch64.cpp"
  }
}

void extrAddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13230 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 31);
  
#line 25839 "ad_aarch64.cpp"
  }
}

void extrAddI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13230 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 31);
  
#line 25859 "ad_aarch64.cpp"
  }
}

void rorI_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13247 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
               opnd_array(2)->constant()& 0x1f);
  
#line 25877 "ad_aarch64.cpp"
  }
}

void rorL_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13263 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
               opnd_array(2)->constant()& 0x3f);
  
#line 25895 "ad_aarch64.cpp"
  }
}

void rorI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13279 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ rorvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 25912 "ad_aarch64.cpp"
  }
}

void rorL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13294 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ rorv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 25929 "ad_aarch64.cpp"
  }
}

void rolI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13309 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(rscratch1, zr, as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
     __ rorvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rscratch1);
  
#line 25947 "ad_aarch64.cpp"
  }
}

void rolL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13325 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(rscratch1, zr, as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
     __ rorv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rscratch1);
  
#line 25965 "ad_aarch64.cpp"
  }
}

void AddExtINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13343 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
   
#line 25983 "ad_aarch64.cpp"
  }
}

void AddExtI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13343 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw);
   
#line 26001 "ad_aarch64.cpp"
  }
}

void SubExtINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13358 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
   
#line 26019 "ad_aarch64.cpp"
  }
}

void AddExtI_sxthNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13373 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth);
   
#line 26039 "ad_aarch64.cpp"
  }
}

void AddExtI_sxth_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13373 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth);
   
#line 26059 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13388 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb);
   
#line 26079 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13388 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb);
   
#line 26099 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13403 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 26119 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13403 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 26139 "ad_aarch64.cpp"
  }
}

void AddExtL_sxthNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13418 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth);
   
#line 26159 "ad_aarch64.cpp"
  }
}

void AddExtL_sxth_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13418 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth);
   
#line 26179 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtwNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13433 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
   
#line 26199 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtw_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13433 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw);
   
#line 26219 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13448 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb);
   
#line 26239 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13448 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb);
   
#line 26259 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13463 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 26279 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13463 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 26299 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13478 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 26318 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13478 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 26337 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13493 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 26356 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13493 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth);
   
#line 26375 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13508 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 26394 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13508 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 26413 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13523 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 26432 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13523 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth);
   
#line 26451 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13538 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw);
   
#line 26470 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13538 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtw);
   
#line 26489 "ad_aarch64.cpp"
  }
}

void SubExtI_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13553 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 26508 "ad_aarch64.cpp"
  }
}

void SubExtI_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13568 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 26527 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13583 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 26546 "ad_aarch64.cpp"
  }
}

void SubExtL_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13598 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 26565 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtw_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13613 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw);
   
#line 26584 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13629 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 26605 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtb_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13629 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb, (opnd_array(4)->constant()));
   
#line 26626 "ad_aarch64.cpp"
  }
}

void AddExtL_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13644 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 26647 "ad_aarch64.cpp"
  }
}

void AddExtL_sxth_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13644 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth, (opnd_array(4)->constant()));
   
#line 26668 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtw_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13659 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(5)->constant()));
   
#line 26689 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtw_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13659 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw, (opnd_array(4)->constant()));
   
#line 26710 "ad_aarch64.cpp"
  }
}

void SubExtL_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13674 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 26731 "ad_aarch64.cpp"
  }
}

void SubExtL_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13689 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 26752 "ad_aarch64.cpp"
  }
}

void SubExtL_sxtw_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13704 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(5)->constant()));
   
#line 26773 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13719 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 26794 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtb_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13719 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb, (opnd_array(4)->constant()));
   
#line 26815 "ad_aarch64.cpp"
  }
}

void AddExtI_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13734 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 26836 "ad_aarch64.cpp"
  }
}

void AddExtI_sxth_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13734 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth, (opnd_array(4)->constant()));
   
#line 26857 "ad_aarch64.cpp"
  }
}

void SubExtI_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13749 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 26878 "ad_aarch64.cpp"
  }
}

void SubExtI_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13764 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 26899 "ad_aarch64.cpp"
  }
}

void AddExtI_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13779 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(3)->constant()));
   
#line 26918 "ad_aarch64.cpp"
  }
}

void AddExtI_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13779 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw, (opnd_array(2)->constant()));
   
#line 26937 "ad_aarch64.cpp"
  }
}

void SubExtI_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13794 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(3)->constant()));
   
#line 26956 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13809 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 26976 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13809 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb, (opnd_array(3)->constant()));
   
#line 26996 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13824 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 27016 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13824 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth, (opnd_array(3)->constant()));
   
#line 27036 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13839 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw, (opnd_array(4)->constant()));
   
#line 27056 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13839 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtw, (opnd_array(3)->constant()));
   
#line 27076 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13854 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 27096 "ad_aarch64.cpp"
  }
}

void SubExtL_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13869 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 27116 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtw_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13884 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw, (opnd_array(4)->constant()));
   
#line 27136 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13899 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 27156 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13899 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb, (opnd_array(3)->constant()));
   
#line 27176 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13914 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 27196 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13914 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth, (opnd_array(3)->constant()));
   
#line 27216 "ad_aarch64.cpp"
  }
}

void SubExtI_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13929 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 27236 "ad_aarch64.cpp"
  }
}

void SubExtI_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13944 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 27256 "ad_aarch64.cpp"
  }
}

void addF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13965 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27275 "ad_aarch64.cpp"
  }
}

void addD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13980 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ faddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27294 "ad_aarch64.cpp"
  }
}

void subF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13995 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27313 "ad_aarch64.cpp"
  }
}

void subD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14010 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsubd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27332 "ad_aarch64.cpp"
  }
}

void mulF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14025 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmuls(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27351 "ad_aarch64.cpp"
  }
}

void mulD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14040 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmuld(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27370 "ad_aarch64.cpp"
  }
}

void maddF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14056 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 27391 "ad_aarch64.cpp"
  }
}

void maddD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14073 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmaddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 27412 "ad_aarch64.cpp"
  }
}

void msubF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14091 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 27433 "ad_aarch64.cpp"
  }
}

void msubF_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14091 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 27454 "ad_aarch64.cpp"
  }
}

void msubD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14109 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 27475 "ad_aarch64.cpp"
  }
}

void msubD_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14109 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 27496 "ad_aarch64.cpp"
  }
}

void mnaddF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14127 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 27517 "ad_aarch64.cpp"
  }
}

void mnaddF_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14127 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 27538 "ad_aarch64.cpp"
  }
}

void mnaddD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14145 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmaddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 27559 "ad_aarch64.cpp"
  }
}

void mnaddD_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14145 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmaddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 27580 "ad_aarch64.cpp"
  }
}

void mnsubF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14162 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 27601 "ad_aarch64.cpp"
  }
}

void mnsubD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14179 "src/hotspot/cpu/aarch64/aarch64.ad"

  // n.b. insn name should be fnmsubd
    __ fnmsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 27623 "ad_aarch64.cpp"
  }
}

void maxF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14196 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmaxs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27642 "ad_aarch64.cpp"
  }
}

void minF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14210 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmins(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27661 "ad_aarch64.cpp"
  }
}

void maxD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14224 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmaxd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27680 "ad_aarch64.cpp"
  }
}

void minD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14238 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmind(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27699 "ad_aarch64.cpp"
  }
}

void divF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14254 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fdivs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27718 "ad_aarch64.cpp"
  }
}

void divD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14269 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fdivd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27737 "ad_aarch64.cpp"
  }
}

void negF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14284 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnegs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 27754 "ad_aarch64.cpp"
  }
}

void negD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14298 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnegd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 27771 "ad_aarch64.cpp"
  }
}

void absI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14316 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cnegw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), Assembler::LT);
  
#line 27788 "ad_aarch64.cpp"
  }
}

void absL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14333 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cneg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), Assembler::LT);
  
#line 27805 "ad_aarch64.cpp"
  }
}

void absF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14345 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabss(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 27822 "ad_aarch64.cpp"
  }
}

void absD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14358 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabsd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 27839 "ad_aarch64.cpp"
  }
}

void absdF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14371 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27858 "ad_aarch64.cpp"
  }
}

void absdD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14385 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabdd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27877 "ad_aarch64.cpp"
  }
}

void sqrtD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14399 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsqrtd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 27894 "ad_aarch64.cpp"
  }
}

void sqrtF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14412 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsqrts(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 27911 "ad_aarch64.cpp"
  }
}

void roundD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rmode
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14424 "src/hotspot/cpu/aarch64/aarch64.ad"

    switch (opnd_array(2)->constant()) {
      case RoundDoubleModeNode::rmode_rint:
        __ frintnd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_floor:
        __ frintmd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_ceil:
        __ frintpd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
    }
  
#line 27941 "ad_aarch64.cpp"
  }
}

void copySignD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14447 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst = as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */),
                  src1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                  src2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                  zero = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* zero */);
    __ fnegd(dst, zero);
    __ bsl(dst, __ T8B, src2, src1);
  
#line 27965 "ad_aarch64.cpp"
  }
}

void copySignF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14462 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
                  src1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                  src2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ movi(dst, __ T2S, 0x80, 24);
    __ bsl(dst, __ T8B, src2, src1);
  
#line 27987 "ad_aarch64.cpp"
  }
}

void signumD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14476 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                  dst = as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */),
                  zero = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* zero */),
                  one = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* one */);
    __ facgtd(dst, src, zero); // dst=0 for +-0.0 and NaN. 0xFFF..F otherwise
    __ ushrd(dst, dst, 1);     // dst=0 for +-0.0 and NaN. 0x7FF..F otherwise
    // Bit selection instruction gets bit from "one" for each enabled bit in
    // "dst", otherwise gets a bit from "src". For "src" that contains +-0.0 or
    // NaN the whole "src" will be copied because "dst" is zero. For all other
    // "src" values dst is 0x7FF..F, which means only the sign bit is copied
    // from "src", and all other bits are copied from 1.0.
    __ bsl(dst, __ T8B, one, src);
  
#line 28017 "ad_aarch64.cpp"
  }
}

void signumF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14497 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                  dst = as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */),
                  zero = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* zero */),
                  one = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* one */);
    __ facgts(dst, src, zero);    // dst=0 for +-0.0 and NaN. 0xFFF..F otherwise
    __ ushr(dst, __ T2S, dst, 1); // dst=0 for +-0.0 and NaN. 0x7FF..F otherwise
    // Bit selection instruction gets bit from "one" for each enabled bit in
    // "dst", otherwise gets a bit from "src". For "src" that contains +-0.0 or
    // NaN the whole "src" will be copied because "dst" is zero. For all other
    // "src" values dst is 0x7FF..F, which means only the sign bit is copied
    // from "src", and all other bits are copied from 1.0.
    __ bsl(dst, __ T8B, one, src);
  
#line 28047 "ad_aarch64.cpp"
  }
}

void onspinwaitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14520 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ spin_wait();
  
#line 28063 "ad_aarch64.cpp"
  }
}

void andI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14540 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28082 "ad_aarch64.cpp"
  }
}

void andI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14555 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constant()));
  
#line 28101 "ad_aarch64.cpp"
  }
}

void orI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14572 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28120 "ad_aarch64.cpp"
  }
}

void orI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14587 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constant()));
  
#line 28139 "ad_aarch64.cpp"
  }
}

void xorI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14604 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28158 "ad_aarch64.cpp"
  }
}

void xorI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14619 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constant()));
  
#line 28177 "ad_aarch64.cpp"
  }
}

void andL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14637 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28196 "ad_aarch64.cpp"
  }
}

void andL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14652 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constantL()));
  
#line 28215 "ad_aarch64.cpp"
  }
}

void orL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14669 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28234 "ad_aarch64.cpp"
  }
}

void orL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14684 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           (uint64_t)(opnd_array(2)->constantL()));
  
#line 28253 "ad_aarch64.cpp"
  }
}

void xorL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14701 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28272 "ad_aarch64.cpp"
  }
}

void xorL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14716 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           (uint64_t)(opnd_array(2)->constantL()));
  
#line 28291 "ad_aarch64.cpp"
  }
}

void convI2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14731 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sbfm(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0, 31);
  
#line 28307 "ad_aarch64.cpp"
  }
}

void convUI2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14744 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ubfm(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0, 31);
  
#line 28324 "ad_aarch64.cpp"
  }
}

void convL2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14757 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28340 "ad_aarch64.cpp"
  }
}

void convI2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14774 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cset(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::NE);
  
#line 28357 "ad_aarch64.cpp"
  }
}

void convP2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14792 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cset(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::NE);
  
#line 28374 "ad_aarch64.cpp"
  }
}

void convD2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14806 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28390 "ad_aarch64.cpp"
  }
}

void convF2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14819 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvts(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28406 "ad_aarch64.cpp"
  }
}

void convF2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14832 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzsw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28422 "ad_aarch64.cpp"
  }
}

void convF2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14845 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzs(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28438 "ad_aarch64.cpp"
  }
}

void convI2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14858 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfws(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28454 "ad_aarch64.cpp"
  }
}

void convL2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14871 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28470 "ad_aarch64.cpp"
  }
}

void convD2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14884 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzdw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28486 "ad_aarch64.cpp"
  }
}

void convD2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14897 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28502 "ad_aarch64.cpp"
  }
}

void convI2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14910 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfwd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28518 "ad_aarch64.cpp"
  }
}

void convL2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14923 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28534 "ad_aarch64.cpp"
  }
}

void MoveF2I_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14942 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrw(opnd_array(0)->as_Register(ra_,this)/* dst */, Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 28550 "ad_aarch64.cpp"
  }
}

void MoveI2F_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14960 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 28566 "ad_aarch64.cpp"
  }
}

void MoveD2L_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14978 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */, Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 28582 "ad_aarch64.cpp"
  }
}

void MoveL2D_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14996 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 28598 "ad_aarch64.cpp"
  }
}

void MoveF2I_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15014 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ strs(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 28614 "ad_aarch64.cpp"
  }
}

void MoveI2F_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15032 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ strw(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 28630 "ad_aarch64.cpp"
  }
}

void MoveD2L_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15050 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ strd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 28646 "ad_aarch64.cpp"
  }
}

void MoveL2D_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15068 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ str(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 28662 "ad_aarch64.cpp"
  }
}

void MoveF2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15086 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovs(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28678 "ad_aarch64.cpp"
  }
}

void MoveI2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15104 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 28694 "ad_aarch64.cpp"
  }
}

void MoveD2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15122 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28710 "ad_aarch64.cpp"
  }
}

void MoveL2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15140 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 28726 "ad_aarch64.cpp"
  }
}

void clearArray_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cnt
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15159 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ zero_words(opnd_array(2)->as_Register(ra_,this,idx2)/* base */, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 28747 "ad_aarch64.cpp"
  }
}

void clearArray_imm_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cnt
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// temp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15180 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ zero_words(opnd_array(2)->as_Register(ra_,this,idx2)/* base */, (uint64_t)opnd_array(1)->constantL());
  
#line 28765 "ad_aarch64.cpp"
  }
}

void overflowAddI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15196 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmnw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 28782 "ad_aarch64.cpp"
  }
}

void overflowAddI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15209 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmnw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 28799 "ad_aarch64.cpp"
  }
}

void overflowAddL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15222 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmn(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 28816 "ad_aarch64.cpp"
  }
}

void overflowAddL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15235 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmn(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 28833 "ad_aarch64.cpp"
  }
}

void overflowSubI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15248 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 28850 "ad_aarch64.cpp"
  }
}

void overflowSubI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15261 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 28867 "ad_aarch64.cpp"
  }
}

void overflowSubL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15274 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 28884 "ad_aarch64.cpp"
  }
}

void overflowSubL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15287 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subs(zr, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 28901 "ad_aarch64.cpp"
  }
}

void overflowNegI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15300 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(zr, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */);
  
#line 28918 "ad_aarch64.cpp"
  }
}

void overflowNegL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15313 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(zr, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */);
  
#line 28935 "ad_aarch64.cpp"
  }
}

void overflowMulI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15330 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smull(rscratch1, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
    __ subs(zr, rscratch1, rscratch1, ext::sxtw);      // NE => overflow
    __ movw(rscratch1, 0x80000000);                    // Develop 0 (EQ),
    __ cselw(rscratch1, rscratch1, zr, Assembler::NE); // or 0x80000000 (NE)
    __ cmpw(rscratch1, 1);                             // 0x80000000 - 1 => VS
  
#line 28956 "ad_aarch64.cpp"
  }
}

void overflowMulI_reg_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15352 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ smull(rscratch1, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* op2 */);
    __ subs(zr, rscratch1, rscratch1, ext::sxtw);      // NE => overflow
    __ br(cond == Assembler::VS ? Assembler::NE : Assembler::EQ, *L);
  
#line 28979 "ad_aarch64.cpp"
  }
}

void overflowMulL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15374 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mul(rscratch1, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);   // Result bits 0..63
    __ smulh(rscratch2, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */); // Result bits 64..127
    __ cmp(rscratch2, rscratch1, Assembler::ASR, 63);    // Top is pure sign ext
    __ movw(rscratch1, 0x80000000);                    // Develop 0 (EQ),
    __ cselw(rscratch1, rscratch1, zr, Assembler::NE); // or 0x80000000 (NE)
    __ cmpw(rscratch1, 1);                             // 0x80000000 - 1 => VS
  
#line 29001 "ad_aarch64.cpp"
  }
}

void overflowMulL_reg_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15398 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ mul(rscratch1, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* op2 */);   // Result bits 0..63
    __ smulh(rscratch2, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* op2 */); // Result bits 64..127
    __ cmp(rscratch2, rscratch1, Assembler::ASR, 63);    // Top is pure sign ext
    __ br(cond == Assembler::VS ? Assembler::NE : Assembler::EQ, *L);
  
#line 29025 "ad_aarch64.cpp"
  }
}

void compI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3644 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmpw(reg1, reg2);
  
#line 29044 "ad_aarch64.cpp"
  }
}

void compI_reg_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3651 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 29067 "ad_aarch64.cpp"
  }
}

void compI_reg_immIAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3651 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 29090 "ad_aarch64.cpp"
  }
}

void compI_reg_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3662 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint32_t val = (uint32_t)opnd_array(2)->constant();
    __ movw(rscratch1, val);
    __ cmpw(reg1, rscratch1);
  
#line 29110 "ad_aarch64.cpp"
  }
}

void compU_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3644 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmpw(reg1, reg2);
  
#line 29129 "ad_aarch64.cpp"
  }
}

void compU_reg_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3651 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 29152 "ad_aarch64.cpp"
  }
}

void compU_reg_immIAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3651 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 29175 "ad_aarch64.cpp"
  }
}

void compU_reg_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3662 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint32_t val = (uint32_t)opnd_array(2)->constant();
    __ movw(rscratch1, val);
    __ cmpw(reg1, rscratch1);
  
#line 29195 "ad_aarch64.cpp"
  }
}

void compL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3670 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmp(reg1, reg2);
  
#line 29214 "ad_aarch64.cpp"
  }
}

void compL_reg_immL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3677 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 29241 "ad_aarch64.cpp"
  }
}

void compL_reg_immLAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3677 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 29268 "ad_aarch64.cpp"
  }
}

void compL_reg_immLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3692 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint64_t val = (uint64_t)opnd_array(2)->constantL();
    __ mov(rscratch1, val);
    __ cmp(reg1, rscratch1);
  
#line 29288 "ad_aarch64.cpp"
  }
}

void compUL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3670 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmp(reg1, reg2);
  
#line 29307 "ad_aarch64.cpp"
  }
}

void compUL_reg_immL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3677 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 29334 "ad_aarch64.cpp"
  }
}

void compUL_reg_immLAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3677 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 29361 "ad_aarch64.cpp"
  }
}

void compUL_reg_immLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3692 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint64_t val = (uint64_t)opnd_array(2)->constantL();
    __ mov(rscratch1, val);
    __ cmp(reg1, rscratch1);
  
#line 29381 "ad_aarch64.cpp"
  }
}

void compP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3700 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmp(reg1, reg2);
  
#line 29400 "ad_aarch64.cpp"
  }
}

void compN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3707 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmpw(reg1, reg2);
  
#line 29419 "ad_aarch64.cpp"
  }
}

void testP_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3714 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    __ cmp(reg, zr);
  
#line 29437 "ad_aarch64.cpp"
  }
}

void testN_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3720 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    __ cmpw(reg, zr);
  
#line 29455 "ad_aarch64.cpp"
  }
}

void compF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15709 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmps(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 29472 "ad_aarch64.cpp"
  }
}

void compF_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15723 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmps(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), 0.0);
  
#line 29489 "ad_aarch64.cpp"
  }
}

void compD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15738 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmpd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 29506 "ad_aarch64.cpp"
  }
}

void compD_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15752 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmpd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), 0.0);
  
#line 29523 "ad_aarch64.cpp"
  }
}

void compF3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15770 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    FloatRegister s2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmps(s1, s2);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 29549 "ad_aarch64.cpp"
  }
}

void compD3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15798 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    FloatRegister s2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmpd(s1, s2);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 29575 "ad_aarch64.cpp"
  }
}

void compF3_reg_immF0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15825 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmps(s1, 0.0);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 29600 "ad_aarch64.cpp"
  }
}

void compD3_reg_immD0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15852 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmpd(s1, 0.0);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 29625 "ad_aarch64.cpp"
  }
}

void cmpLTMask_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15879 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* p */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* q */));
    __ csetw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::LT);
    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), zr, as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 29644 "ad_aarch64.cpp"
  }
}

void cmpLTMask_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15897 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), 31);
  
#line 29661 "ad_aarch64.cpp"
  }
}

void cmovI_reg_reg_ltNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15914 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
             Assembler::LT);
  
#line 29682 "ad_aarch64.cpp"
  }
}

void cmovI_reg_reg_gtNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15945 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
             Assembler::GT);
  
#line 29703 "ad_aarch64.cpp"
  }
}

void branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3726 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(1)->label();
    __ b(*L);
  
#line 29720 "ad_aarch64.cpp"
  }
}

void branchConNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3732 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 29739 "ad_aarch64.cpp"
  }
}

void branchConUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3738 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 29758 "ad_aarch64.cpp"
  }
}

void cmpI_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16036 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 29782 "ad_aarch64.cpp"
  }
}

void cmpL_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16053 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 29806 "ad_aarch64.cpp"
  }
}

void cmpP_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16070 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 29830 "ad_aarch64.cpp"
  }
}

void cmpN_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16087 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 29854 "ad_aarch64.cpp"
  }
}

void cmpP_narrowOop_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16104 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* oop */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* oop */, *L);
  
#line 29878 "ad_aarch64.cpp"
  }
}

void cmpUI_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16121 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ || cond == Assembler::LS)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 29902 "ad_aarch64.cpp"
  }
}

void cmpUL_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16138 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ || cond == Assembler::LS)
      __ cbz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 29926 "ad_aarch64.cpp"
  }
}

void cmpL_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16158 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 63, *L);
  
#line 29948 "ad_aarch64.cpp"
  }
}

void cmpI_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16174 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 31, *L);
  
#line 29970 "ad_aarch64.cpp"
  }
}

void cmpL_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16191 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2_long(opnd_array(3)->constantL());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L);
  
#line 29993 "ad_aarch64.cpp"
  }
}

void cmpI_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16208 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2((juint)opnd_array(3)->constant());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L);
  
#line 30016 "ad_aarch64.cpp"
  }
}

void far_cmpL_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16225 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 63, *L, /*far*/true);
  
#line 30038 "ad_aarch64.cpp"
  }
}

void far_cmpI_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16240 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 31, *L, /*far*/true);
  
#line 30060 "ad_aarch64.cpp"
  }
}

void far_cmpL_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16256 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2_long(opnd_array(3)->constantL());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L, /*far*/true);
  
#line 30083 "ad_aarch64.cpp"
  }
}

void far_cmpI_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16272 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2((juint)opnd_array(3)->constant());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L, /*far*/true);
  
#line 30106 "ad_aarch64.cpp"
  }
}

void cmpL_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16290 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ tst(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 30124 "ad_aarch64.cpp"
  }
}

void cmpI_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16303 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ tstw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 30142 "ad_aarch64.cpp"
  }
}

void cmpL_and_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16314 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ tst(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 30160 "ad_aarch64.cpp"
  }
}

void cmpI_and_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16325 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ tstw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 30178 "ad_aarch64.cpp"
  }
}

void branchLoopEndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3732 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 30197 "ad_aarch64.cpp"
  }
}

void branchLoopEndUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3738 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 30216 "ad_aarch64.cpp"
  }
}

void cmpFastLockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {

#line 3878 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register oop = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* object */);
    Register box = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* box */);
    Register disp_hdr = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp */);
    Register tmp = as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */);
    Label cont;
    Label object_has_monitor;
    Label cas_failed;

    assert_different_registers(oop, box, tmp, disp_hdr);

    // Load markWord from object into displaced_header.
    __ ldr(disp_hdr, Address(oop, oopDesc::mark_offset_in_bytes()));

    if (DiagnoseSyncOnValueBasedClasses != 0) {
      __ load_klass(tmp, oop);
      __ ldrw(tmp, Address(tmp, Klass::access_flags_offset()));
      __ tstw(tmp, JVM_ACC_IS_VALUE_BASED_CLASS);
      __ br(Assembler::NE, cont);
    }

    // Check for existing monitor
    __ tbnz(disp_hdr, exact_log2(markWord::monitor_value), object_has_monitor);

    if (!UseHeavyMonitors) {
      // Set tmp to be (markWord of object | UNLOCK_VALUE).
      __ orr(tmp, disp_hdr, markWord::unlocked_value);

      // Initialize the box. (Must happen before we update the object mark!)
      __ str(tmp, Address(box, BasicLock::displaced_header_offset_in_bytes()));

      // Compare object markWord with an unlocked value (tmp) and if
      // equal exchange the stack address of our box with object markWord.
      // On failure disp_hdr contains the possibly locked markWord.
      __ cmpxchg(oop, tmp, box, Assembler::xword, /*acquire*/ true,
                 /*release*/ true, /*weak*/ false, disp_hdr);
      __ br(Assembler::EQ, cont);

      assert(oopDesc::mark_offset_in_bytes() == 0, "offset of _mark is not 0");

      // If the compare-and-exchange succeeded, then we found an unlocked
      // object, will have now locked it will continue at label cont

      __ bind(cas_failed);
      // We did not see an unlocked object so try the fast recursive case.

      // Check if the owner is self by comparing the value in the
      // markWord of object (disp_hdr) with the stack pointer.
      __ mov(rscratch1, sp);
      __ sub(disp_hdr, disp_hdr, rscratch1);
      __ mov(tmp, (address) (~(os::vm_page_size()-1) | markWord::lock_mask_in_place));
      // If condition is true we are cont and hence we can store 0 as the
      // displaced header in the box, which indicates that it is a recursive lock.
      __ ands(tmp/*==0?*/, disp_hdr, tmp);   // Sets flags for result
      __ str(tmp/*==0, perhaps*/, Address(box, BasicLock::displaced_header_offset_in_bytes()));
    } else {
      __ tst(oop, oop); // Set NE to indicate 'failure' -> take slow-path. We know that oop != 0.
    }
    __ b(cont);

    // Handle existing monitor.
    __ bind(object_has_monitor);

    // The object's monitor m is unlocked iff m->owner == NULL,
    // otherwise m->owner may contain a thread or a stack address.
    //
    // Try to CAS m->owner from NULL to current thread.
    __ add(tmp, disp_hdr, (ObjectMonitor::owner_offset_in_bytes()-markWord::monitor_value));
    __ cmpxchg(tmp, zr, rthread, Assembler::xword, /*acquire*/ true,
               /*release*/ true, /*weak*/ false, rscratch1); // Sets flags for result

    // Store a non-null value into the box to avoid looking like a re-entrant
    // lock. The fast-path monitor unlock code checks for
    // markWord::monitor_value so use markWord::unused_mark which has the
    // relevant bit set, and also matches ObjectSynchronizer::enter.
    __ mov(tmp, (address)markWord::unused_mark().value());
    __ str(tmp, Address(box, BasicLock::displaced_header_offset_in_bytes()));

    __ br(Assembler::EQ, cont); // CAS success means locking succeeded

    __ cmp(rscratch1, rthread);
    __ br(Assembler::NE, cont); // Check for recursive locking

    // Recursive lock case
    __ increment(Address(disp_hdr, ObjectMonitor::recursions_offset_in_bytes() - markWord::monitor_value), 1);
    // flag == EQ still from the cmp above, checking if this is a reentrant lock

    __ bind(cont);
    // flag == EQ indicates success
    // flag == NE indicates failure
  
#line 30323 "ad_aarch64.cpp"
  }
}

void cmpFastUnlockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {

#line 3971 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register oop = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* object */);
    Register box = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* box */);
    Register disp_hdr = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp */);
    Register tmp = as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */);
    Label cont;
    Label object_has_monitor;

    assert_different_registers(oop, box, tmp, disp_hdr);

    if (!UseHeavyMonitors) {
      // Find the lock address and load the displaced header from the stack.
      __ ldr(disp_hdr, Address(box, BasicLock::displaced_header_offset_in_bytes()));

      // If the displaced header is 0, we have a recursive unlock.
      __ cmp(disp_hdr, zr);
      __ br(Assembler::EQ, cont);
    }

    // Handle existing monitor.
    __ ldr(tmp, Address(oop, oopDesc::mark_offset_in_bytes()));
    __ tbnz(disp_hdr, exact_log2(markWord::monitor_value), object_has_monitor);

    if (!UseHeavyMonitors) {
      // Check if it is still a light weight lock, this is is true if we
      // see the stack address of the basicLock in the markWord of the
      // object.

      __ cmpxchg(oop, box, disp_hdr, Assembler::xword, /*acquire*/ false,
                 /*release*/ true, /*weak*/ false, tmp);
    } else {
      __ tst(oop, oop); // Set NE to indicate 'failure' -> take slow-path. We know that oop != 0.
    }
    __ b(cont);

    assert(oopDesc::mark_offset_in_bytes() == 0, "offset of _mark is not 0");

    // Handle existing monitor.
    __ bind(object_has_monitor);
    STATIC_ASSERT(markWord::monitor_value <= INT_MAX);
    __ add(tmp, tmp, -(int)markWord::monitor_value); // monitor
    __ ldr(disp_hdr, Address(tmp, ObjectMonitor::recursions_offset_in_bytes()));

    Label notRecursive;
    __ cbz(disp_hdr, notRecursive);

    // Recursive lock
    __ sub(disp_hdr, disp_hdr, 1u);
    __ str(disp_hdr, Address(tmp, ObjectMonitor::recursions_offset_in_bytes()));
    __ cmp(disp_hdr, disp_hdr); // Sets flags for result
    __ b(cont);

    __ bind(notRecursive);
    __ ldr(rscratch1, Address(tmp, ObjectMonitor::EntryList_offset_in_bytes()));
    __ ldr(disp_hdr, Address(tmp, ObjectMonitor::cxq_offset_in_bytes()));
    __ orr(rscratch1, rscratch1, disp_hdr); // Will be 0 if both are 0.
    __ cmp(rscratch1, zr); // Sets flags for result
    __ cbnz(rscratch1, cont);
    // need a release store here
    __ lea(tmp, Address(tmp, ObjectMonitor::owner_offset_in_bytes()));
    __ stlr(zr, tmp); // set unowned

    __ bind(cont);
    // flag == EQ indicates success
    // flag == NE indicates failure
  
#line 30405 "ad_aarch64.cpp"
  }
}

void safePointNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16420 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ read_polling_page(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* poll */), relocInfo::poll_type);
  
#line 30421 "ad_aarch64.cpp"
  }
}

void CallStaticJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3762 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);

    address addr = (address)opnd_array(1)->method();
    address call;
    if (!_method) {
      // A call to a runtime wrapper, e.g. new, new_typeArray_Java, uncommon_trap.
      call = __ trampoline_call(Address(addr, relocInfo::runtime_call_type), &cbuf);
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    } else {
      int method_index = resolved_method_index(cbuf);
      RelocationHolder rspec = _optimized_virtual ? opt_virtual_call_Relocation::spec(method_index)
                                                  : static_call_Relocation::spec(method_index);
      call = __ trampoline_call(Address(addr, rspec), &cbuf);
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
      // Emit stub for static call
      address stub = CompiledStaticCall::emit_to_interp_stub(cbuf);
      if (stub == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    }

    // Only non uncommon_trap calls need to reinitialize ptrue.
    if (Compile::current()->max_vector_size() > 0 && uncommon_trap_request() == 0) {
      __ reinitialize_ptrue();
    }
  
#line 30467 "ad_aarch64.cpp"
  }
  {

#line 3809 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      __ call_Unimplemented();
    }
  
#line 30479 "ad_aarch64.cpp"
  }
}

void CallDynamicJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3797 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    int method_index = resolved_method_index(cbuf);
    address call = __ ic_call((address)opnd_array(1)->method(), method_index);
    if (call == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    } else if (Compile::current()->max_vector_size() > 0) {
      __ reinitialize_ptrue();
    }
  
#line 30502 "ad_aarch64.cpp"
  }
  {

#line 3809 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      __ call_Unimplemented();
    }
  
#line 30514 "ad_aarch64.cpp"
  }
}

void CallRuntimeDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3817 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ add(sp, sp, 2 * wordSize);
    }
    if (Compile::current()->max_vector_size() > 0) {
      __ reinitialize_ptrue();
    }
  
#line 30555 "ad_aarch64.cpp"
  }
}

void CallLeafDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3817 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ add(sp, sp, 2 * wordSize);
    }
    if (Compile::current()->max_vector_size() > 0) {
      __ reinitialize_ptrue();
    }
  
#line 30596 "ad_aarch64.cpp"
  }
}

void CallLeafNoFPDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3817 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ add(sp, sp, 2 * wordSize);
    }
    if (Compile::current()->max_vector_size() > 0) {
      __ reinitialize_ptrue();
    }
  
#line 30637 "ad_aarch64.cpp"
  }
}

void CallNativeDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3817 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ add(sp, sp, 2 * wordSize);
    }
    if (Compile::current()->max_vector_size() > 0) {
      __ reinitialize_ptrue();
    }
  
#line 30678 "ad_aarch64.cpp"
  }
}

void TailCalljmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// method_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {

#line 3862 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register target_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* jump_target */);
    __ br(target_reg);
  
#line 30696 "ad_aarch64.cpp"
  }
}

void TailjmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// ex_oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {

#line 3868 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register target_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* jump_target */);
    // exception oop should be in r0
    // ret addr has been popped into lr
    // callee expects it in r3
    __ mov(r3, lr);
    __ br(target_reg);
  
#line 30718 "ad_aarch64.cpp"
  }
}

void CreateExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint CreateExceptionNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void RethrowExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 3847 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    __ far_jump(RuntimeAddress(OptoRuntime::rethrow_stub()));
  
#line 30747 "ad_aarch64.cpp"
  }
}

void RetNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 3852 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
#ifdef ASSERT
    if (Compile::current()->max_vector_size() > 0) {
      __ verify_ptrue();
    }
#endif
    __ ret(lr);
  
#line 30768 "ad_aarch64.cpp"
  }
}

void ShouldNotReachHereNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16615 "src/hotspot/cpu/aarch64/aarch64.ad"

    if (is_reachable()) {
      __ stop(_halt_reason);
    }
  
#line 30786 "ad_aarch64.cpp"
  }
}

void partialSubtypeCheckNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// sub
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// super
  {

#line 3745 "src/hotspot/cpu/aarch64/aarch64.ad"

     Register sub_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* sub */);
     Register super_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* super */);
     Register temp_reg = as_Register(R2_enc);
     Register result_reg = as_Register(opnd_array(0)->reg(ra_,this)/* result */);

     Label miss;
     C2_MacroAssembler _masm(&cbuf);
     __ check_klass_subtype_slow_path(sub_reg, super_reg, temp_reg, result_reg,
                                     NULL, &miss,
                                     /*set_cond_codes:*/ true);
     if ((0x1 /*primary()*/)) {
       __ mov(result_reg, zr);
     }
     __ bind(miss);
  
#line 30815 "ad_aarch64.cpp"
  }
}

void partialSubtypeCheckVsZeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// sub
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// super
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {

#line 3745 "src/hotspot/cpu/aarch64/aarch64.ad"

     Register sub_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* sub */);
     Register super_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* super */);
     Register temp_reg = as_Register(R2_enc);
     Register result_reg = as_Register(R5_enc);

     Label miss;
     C2_MacroAssembler _masm(&cbuf);
     __ check_klass_subtype_slow_path(sub_reg, super_reg, temp_reg, result_reg,
                                     NULL, &miss,
                                     /*set_cond_codes:*/ true);
     if ((0x0 /*primary()*/)) {
       __ mov(result_reg, zr);
     }
     __ bind(miss);
  
#line 30845 "ad_aarch64.cpp"
  }
}

void string_compareUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16670 "src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      fnoreg, fnoreg, fnoreg, StrIntrinsicNode::UU);
  
#line 30868 "ad_aarch64.cpp"
  }
}

void string_compareLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16688 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      fnoreg, fnoreg, fnoreg, StrIntrinsicNode::LL);
  
#line 30890 "ad_aarch64.cpp"
  }
}

void string_compareULNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16707 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      as_FloatRegister(V0_enc), as_FloatRegister(V1_enc),
                      as_FloatRegister(V2_enc), StrIntrinsicNode::UL);
  
#line 30913 "ad_aarch64.cpp"
  }
}

void string_compareLUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16727 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      as_FloatRegister(V0_enc), as_FloatRegister(V1_enc),
                      as_FloatRegister(V2_enc),StrIntrinsicNode::LU);
  
#line 30936 "ad_aarch64.cpp"
  }
}

void string_indexofUUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// tmp5
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// tmp6
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16747 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */,
                      opnd_array(9)->as_Register(ra_,this,idx9)/* tmp5 */, opnd_array(10)->as_Register(ra_,this,idx10)/* tmp6 */,
                      -1, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UU);
  
#line 30966 "ad_aarch64.cpp"
  }
}

void string_indexofLLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// tmp5
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// tmp6
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16768 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */,
                      opnd_array(9)->as_Register(ra_,this,idx9)/* tmp5 */, opnd_array(10)->as_Register(ra_,this,idx10)/* tmp6 */,
                      -1, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::LL);
  
#line 30996 "ad_aarch64.cpp"
  }
}

void string_indexofULNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// tmp5
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// tmp6
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16789 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */,
                      opnd_array(9)->as_Register(ra_,this,idx9)/* tmp5 */, opnd_array(10)->as_Register(ra_,this,idx10)/* tmp6 */,
                      -1, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UL);
  
#line 31026 "ad_aarch64.cpp"
  }
}

void string_indexof_conUUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// int_cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16810 "src/hotspot/cpu/aarch64/aarch64.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, zr,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */, zr, zr,
                      icnt2, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UU);
  
#line 31054 "ad_aarch64.cpp"
  }
}

void string_indexof_conLLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// int_cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16831 "src/hotspot/cpu/aarch64/aarch64.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, zr,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */, zr, zr,
                      icnt2, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::LL);
  
#line 31082 "ad_aarch64.cpp"
  }
}

void string_indexof_conULNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// int_cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16852 "src/hotspot/cpu/aarch64/aarch64.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, zr,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */, zr, zr,
                      icnt2, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UL);
  
#line 31110 "ad_aarch64.cpp"
  }
}

void string_indexof_charNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ch
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16874 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof_char(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* ch */,
                           opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */,
                           opnd_array(6)->as_Register(ra_,this,idx6)/* tmp3 */);
  
#line 31133 "ad_aarch64.cpp"
  }
}

void stringL_indexof_charNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ch
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16893 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ stringL_indexof_char(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* ch */,
                            opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */,
                            opnd_array(6)->as_Register(ra_,this,idx6)/* tmp3 */);
  
#line 31156 "ad_aarch64.cpp"
  }
}

void string_equalsLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// str2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16909 "src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* str2 */,
                     opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(3)->as_Register(ra_,this,idx3)/* cnt */, 1);
  
#line 31176 "ad_aarch64.cpp"
  }
}

void string_equalsUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// str2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16925 "src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* str2 */,
                     opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(3)->as_Register(ra_,this,idx3)/* cnt */, 2);
  
#line 31196 "ad_aarch64.cpp"
  }
}

void array_equalsBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// ary1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ary2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16942 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ arrays_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* ary1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* ary2 */,
                                   opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp3 */,
                                   opnd_array(0)->as_Register(ra_,this)/* result */, as_Register(R10_enc), 1);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 31222 "ad_aarch64.cpp"
  }
}

void array_equalsCNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// ary1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ary2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16963 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ arrays_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* ary1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* ary2 */,
                                   opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp3 */,
                                   opnd_array(0)->as_Register(ra_,this)/* result */, as_Register(R10_enc), 2);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 31248 "ad_aarch64.cpp"
  }
}

void has_negativesNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// ary1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// len
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16980 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ has_negatives(opnd_array(1)->as_Register(ra_,this,idx1)/* ary1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* len */, opnd_array(0)->as_Register(ra_,this)/* result */);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 31269 "ad_aarch64.cpp"
  }
}

void string_compressNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17000 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ char_array_compress(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
                           opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp2 */,
                           opnd_array(6)->as_FloatRegister(ra_,this,idx6)/* tmp3 */, opnd_array(7)->as_FloatRegister(ra_,this,idx7)/* tmp4 */,
                           opnd_array(0)->as_Register(ra_,this)/* result */);
  
#line 31294 "ad_aarch64.cpp"
  }
}

void string_inflateNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17017 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ byte_array_inflate(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
                                        opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp2 */,
                                        opnd_array(6)->as_FloatRegister(ra_,this,idx6)/* tmp3 */, opnd_array(7)->as_Register(ra_,this,idx7)/* tmp4 */);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 31322 "ad_aarch64.cpp"
  }
}

void encode_iso_arrayNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17041 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ encode_iso_array(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
         opnd_array(0)->as_Register(ra_,this)/* result */, as_FloatRegister(V0_enc),  as_FloatRegister(V1_enc),
         as_FloatRegister(V2_enc),  as_FloatRegister(V3_enc));
  
#line 31342 "ad_aarch64.cpp"
  }
}

void tlsLoadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint tlsLoadPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void loadV2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3149 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::H,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 31372 "ad_aarch64.cpp"
  }
}

void loadV4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3155 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::S,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 31389 "ad_aarch64.cpp"
  }
}

void loadV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3161 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::D,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 31406 "ad_aarch64.cpp"
  }
}

void loadV16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3167 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::Q,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 31423 "ad_aarch64.cpp"
  }
}

void storeV2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3173 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::H,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 31441 "ad_aarch64.cpp"
  }
}

void storeV4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3179 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::S,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 31459 "ad_aarch64.cpp"
  }
}

void storeV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3185 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::D,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 31477 "ad_aarch64.cpp"
  }
}

void storeV16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3191 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::Q,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 31495 "ad_aarch64.cpp"
  }
}

void reinterpretDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 128 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // empty
  
#line 31511 "ad_aarch64.cpp"
  }
}

void reinterpretXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 141 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // empty
  
#line 31527 "ad_aarch64.cpp"
  }
}

void reinterpretD2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 154 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // The higher 64-bits of the "dst" register must be cleared to zero.
    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 31546 "ad_aarch64.cpp"
  }
}

void reinterpretX2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 170 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // The higher 64-bits of the "dst" register must be cleared to zero.
    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 31565 "ad_aarch64.cpp"
  }
}

void reinterpretS2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 186 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // The higher bits of the "dst" register must be cleared to zero.
    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 31582 "ad_aarch64.cpp"
  }
}

void reinterpretX2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 200 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // The higher bits of the "dst" register must be cleared to zero.
    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 31599 "ad_aarch64.cpp"
  }
}

void reinterpretS2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 214 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // The higher bits of the "dst" register must be cleared to zero.
    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 31616 "ad_aarch64.cpp"
  }
}

void reinterpretD2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 228 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // The higher bits of the "dst" register must be cleared to zero.
    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 31633 "ad_aarch64.cpp"
  }
}

void vcvt8Bto8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 242 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
  
#line 31649 "ad_aarch64.cpp"
  }
}

void vcvt4Bto4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 253 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
  
#line 31665 "ad_aarch64.cpp"
  }
}

void vcvt8Sto8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 264 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8H);
  
#line 31681 "ad_aarch64.cpp"
  }
}

void vcvt4Sto4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 275 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8H);
  
#line 31697 "ad_aarch64.cpp"
  }
}

void vcvt4Sto4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 286 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T4H);
  
#line 31713 "ad_aarch64.cpp"
  }
}

void vcvt4Ito4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 297 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T4S);
  
#line 31729 "ad_aarch64.cpp"
  }
}

void vcvt2Ito2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 308 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2S);
  
#line 31745 "ad_aarch64.cpp"
  }
}

void vcvt2Lto2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 319 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2D);
  
#line 31761 "ad_aarch64.cpp"
  }
}

void vcvt4Ito4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 332 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T4S);
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H);
  
#line 31778 "ad_aarch64.cpp"
  }
}

void vcvt4Bto4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 346 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H);
  
#line 31795 "ad_aarch64.cpp"
  }
}

void vcvt2Lto2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 360 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ scvtfv(__ T2D, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ fcvtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D);
  
#line 31812 "ad_aarch64.cpp"
  }
}

void vcvt2Ito2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 372 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ scvtfv(__ T2S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 31828 "ad_aarch64.cpp"
  }
}

void vcvt4Ito4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 383 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ scvtfv(__ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 31844 "ad_aarch64.cpp"
  }
}

void vcvt2Lto2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 394 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ scvtfv(__ T2D, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 31860 "ad_aarch64.cpp"
  }
}

void vcvt4Sto4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 407 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T4H);
    __ scvtfv(__ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 31877 "ad_aarch64.cpp"
  }
}

void vcvt2Ito2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 421 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2S);
    __ scvtfv(__ T2D, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 31894 "ad_aarch64.cpp"
  }
}

void vcvt4Bto4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 436 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H);
    __ scvtfv(__ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 31912 "ad_aarch64.cpp"
  }
}

void vcvt2Fto2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 451 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fcvtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2S);
    __ fcvtzs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 31929 "ad_aarch64.cpp"
  }
}

void vcvt2Fto2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 463 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fcvtzs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 31945 "ad_aarch64.cpp"
  }
}

void vcvt4Fto4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 474 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fcvtzs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 31961 "ad_aarch64.cpp"
  }
}

void vcvt2Dto2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 485 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fcvtzs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 31977 "ad_aarch64.cpp"
  }
}

void vcvt4Fto4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 498 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fcvtzs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S);
  
#line 31994 "ad_aarch64.cpp"
  }
}

void vcvt2Dto2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 516 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0, 1);
    // We can't use fcvtzs(vector, integer) instruction here because we need
    // saturation arithmetic. See JDK-8276151.
    __ fcvtzdw(rscratch1, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ fcvtzdw(rscratch2, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */));
    __ fmovs(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), rscratch1);
    __ mov(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ T2S, 1, rscratch2);
  
#line 32017 "ad_aarch64.cpp"
  }
}

void vcvt4Fto4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 536 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fcvtzs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S);
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H);
  
#line 32035 "ad_aarch64.cpp"
  }
}

void vcvt2Fto2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 549 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fcvtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2S);
  
#line 32051 "ad_aarch64.cpp"
  }
}

void vcvt2Dto2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 560 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fcvtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2D);
  
#line 32067 "ad_aarch64.cpp"
  }
}

void reduce_add8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 579 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T8B, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ addw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32089 "ad_aarch64.cpp"
  }
}

void reduce_add16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 599 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T16B, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ addw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32111 "ad_aarch64.cpp"
  }
}

void reduce_add4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 619 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T4H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ addw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32133 "ad_aarch64.cpp"
  }
}

void reduce_add8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 639 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T8H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ addw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32155 "ad_aarch64.cpp"
  }
}

void reduce_add2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 657 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addpd(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D, 0);
    __ add(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32176 "ad_aarch64.cpp"
  }
}

void reduce_mul8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 682 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ T8B,
            as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ H,
           as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ T8B,
            as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */));
    __ umov(opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ B, 0);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ umov(opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ B, 1);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32210 "ad_aarch64.cpp"
  }
}

void reduce_mul16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 720 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ T8B,
            as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ S,
           as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ T8B,
            as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */));
    __ ins(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ H,
           as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ T8B,
            as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */));
    __ umov(opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ B, 0);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ umov(opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ B, 1);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32248 "ad_aarch64.cpp"
  }
}

void reduce_mul4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 758 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ T4H,
            as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ H, 0);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ umov(opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ H, 1);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32277 "ad_aarch64.cpp"
  }
}

void reduce_mul8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 790 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ T4H,
            as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ S,
           as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ T4H,
            as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */));
    __ umov(opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ H, 0);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ umov(opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ H, 1);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32311 "ad_aarch64.cpp"
  }
}

void reduce_mul2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 819 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
  
#line 32333 "ad_aarch64.cpp"
  }
}

void reduce_max8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 839 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T8B, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::GT);
  
#line 32355 "ad_aarch64.cpp"
  }
}

void reduce_max16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 859 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T16B, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::GT);
  
#line 32377 "ad_aarch64.cpp"
  }
}

void reduce_max4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 879 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T4H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::GT);
  
#line 32399 "ad_aarch64.cpp"
  }
}

void reduce_max8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 899 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T8H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::GT);
  
#line 32421 "ad_aarch64.cpp"
  }
}

void reduce_max4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 919 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T4S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::GT);
  
#line 32443 "ad_aarch64.cpp"
  }
}

void reduce_min8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 939 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T8B, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::LT);
  
#line 32465 "ad_aarch64.cpp"
  }
}

void reduce_min16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 959 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T16B, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::LT);
  
#line 32487 "ad_aarch64.cpp"
  }
}

void reduce_min4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 979 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T4H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::LT);
  
#line 32509 "ad_aarch64.cpp"
  }
}

void reduce_min8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 999 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T8H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::LT);
  
#line 32531 "ad_aarch64.cpp"
  }
}

void reduce_min4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1019 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T4S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::LT);
  
#line 32553 "ad_aarch64.cpp"
  }
}

void reduce_max2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1039 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smaxp(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T2S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::GT);
  
#line 32575 "ad_aarch64.cpp"
  }
}

void reduce_min2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1059 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sminp(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T2S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::LT);
  
#line 32597 "ad_aarch64.cpp"
  }
}

void reduce_max2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1081 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ cmp(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ csel(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), Assembler::GT);
    __ umov(as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ cmp(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ csel(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), Assembler::GT);
  
#line 32621 "ad_aarch64.cpp"
  }
}

void reduce_min2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1105 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ cmp(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ csel(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), Assembler::LT);
    __ umov(as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ cmp(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ csel(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), Assembler::LT);
  
#line 32645 "ad_aarch64.cpp"
  }
}

void reduce_max2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1123 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmaxp(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S);
    __ fmaxs(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */));
  
#line 32664 "ad_aarch64.cpp"
  }
}

void reduce_max4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1137 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmaxv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ fmaxs(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */));
  
#line 32683 "ad_aarch64.cpp"
  }
}

void reduce_max2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1151 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmaxp(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D);
    __ fmaxd(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dsrc */));
  
#line 32702 "ad_aarch64.cpp"
  }
}

void reduce_min2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1165 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fminp(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S);
    __ fmins(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */));
  
#line 32721 "ad_aarch64.cpp"
  }
}

void reduce_min4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1179 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ fmins(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */));
  
#line 32740 "ad_aarch64.cpp"
  }
}

void reduce_min2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1193 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fminp(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D);
    __ fmind(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dsrc */));
  
#line 32759 "ad_aarch64.cpp"
  }
}

void reduce_and8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1214 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 8);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32784 "ad_aarch64.cpp"
  }
}

void reduce_orr8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1240 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 8);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32809 "ad_aarch64.cpp"
  }
}

void reduce_eor8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1266 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 8);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32834 "ad_aarch64.cpp"
  }
}

void reduce_and16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1293 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 8);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32860 "ad_aarch64.cpp"
  }
}

void reduce_orr16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1321 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 8);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32886 "ad_aarch64.cpp"
  }
}

void reduce_eor16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1349 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 8);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32912 "ad_aarch64.cpp"
  }
}

void reduce_and4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1375 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32936 "ad_aarch64.cpp"
  }
}

void reduce_orr4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1399 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32960 "ad_aarch64.cpp"
  }
}

void reduce_eor4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1423 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32984 "ad_aarch64.cpp"
  }
}

void reduce_and8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1448 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33009 "ad_aarch64.cpp"
  }
}

void reduce_orr8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1474 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33034 "ad_aarch64.cpp"
  }
}

void reduce_eor8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1500 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33059 "ad_aarch64.cpp"
  }
}

void reduce_and2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1523 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33081 "ad_aarch64.cpp"
  }
}

void reduce_orr2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1543 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33103 "ad_aarch64.cpp"
  }
}

void reduce_eor2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1563 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33125 "ad_aarch64.cpp"
  }
}

void reduce_and4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1584 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33148 "ad_aarch64.cpp"
  }
}

void reduce_orr4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1606 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33171 "ad_aarch64.cpp"
  }
}

void reduce_eor4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1628 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33194 "ad_aarch64.cpp"
  }
}

void reduce_and2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1649 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
  
#line 33216 "ad_aarch64.cpp"
  }
}

void reduce_orr2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1669 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
  
#line 33238 "ad_aarch64.cpp"
  }
}

void reduce_eor2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1689 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
  
#line 33260 "ad_aarch64.cpp"
  }
}

void insert8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1707 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 33282 "ad_aarch64.cpp"
  }
}

void insert16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1724 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 33304 "ad_aarch64.cpp"
  }
}

void insert4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1741 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 33326 "ad_aarch64.cpp"
  }
}

void insert8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1758 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 33348 "ad_aarch64.cpp"
  }
}

void insert2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1775 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 33370 "ad_aarch64.cpp"
  }
}

void insert4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1792 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 33392 "ad_aarch64.cpp"
  }
}

void insert2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1809 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 33414 "ad_aarch64.cpp"
  }
}

void insert2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1827 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* val */), opnd_array(3)->constant(), 0);
  
#line 33436 "ad_aarch64.cpp"
  }
}

void insert4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1844 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* val */), opnd_array(3)->constant(), 0);
  
#line 33458 "ad_aarch64.cpp"
  }
}

void insert2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1861 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* val */), opnd_array(3)->constant(), 0);
  
#line 33480 "ad_aarch64.cpp"
  }
}

void extract8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1878 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ B, opnd_array(2)->constant());
  
#line 33497 "ad_aarch64.cpp"
  }
}

void extract16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1890 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ B, opnd_array(2)->constant());
  
#line 33514 "ad_aarch64.cpp"
  }
}

void extract4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1902 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ H, opnd_array(2)->constant());
  
#line 33531 "ad_aarch64.cpp"
  }
}

void extract8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1914 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ H, opnd_array(2)->constant());
  
#line 33548 "ad_aarch64.cpp"
  }
}

void extract2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1926 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S, opnd_array(2)->constant());
  
#line 33565 "ad_aarch64.cpp"
  }
}

void extract4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1938 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S, opnd_array(2)->constant());
  
#line 33582 "ad_aarch64.cpp"
  }
}

void extract2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1950 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D, opnd_array(2)->constant());
  
#line 33599 "ad_aarch64.cpp"
  }
}

void extract2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1962 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0, opnd_array(2)->constant());
  
#line 33617 "ad_aarch64.cpp"
  }
}

void extract4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1975 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0, opnd_array(2)->constant());
  
#line 33635 "ad_aarch64.cpp"
  }
}

void extract2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1988 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0, opnd_array(2)->constant());
  
#line 33653 "ad_aarch64.cpp"
  }
}

void vcmpDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cond
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2003 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    assert(type2aelembytes(bt) != 8, "not supported");
    __ neon_compare(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), bt, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                    as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), (int)opnd_array(3)->constant(), /*isQ*/ false);
  
#line 33674 "ad_aarch64.cpp"
  }
}

void vcmpXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cond
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2018 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ neon_compare(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), bt, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                    as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), (int)opnd_array(3)->constant(), /*isQ*/ true);
  
#line 33694 "ad_aarch64.cpp"
  }
}

void vmul2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2043 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), __ D, 0);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), __ D, 0);
    __ mul(as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp1 */));
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, 0, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), __ D, 1);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), __ D, 1);
    __ mul(as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp1 */));
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, 1, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */);
  
#line 33720 "ad_aarch64.cpp"
  }
}

void vnot2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2066 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33738 "ad_aarch64.cpp"
  }
}

void vnot2I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2066 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 33756 "ad_aarch64.cpp"
  }
}

void vnot2I_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2066 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33774 "ad_aarch64.cpp"
  }
}

void vnot2I_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2066 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 33792 "ad_aarch64.cpp"
  }
}

void vnot2I_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2066 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33810 "ad_aarch64.cpp"
  }
}

void vnot2I_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2066 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 33828 "ad_aarch64.cpp"
  }
}

void vnot4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2081 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33846 "ad_aarch64.cpp"
  }
}

void vnot4I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2081 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 33864 "ad_aarch64.cpp"
  }
}

void vnot4I_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2081 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33882 "ad_aarch64.cpp"
  }
}

void vnot4I_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2081 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 33900 "ad_aarch64.cpp"
  }
}

void vnot4I_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2081 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33918 "ad_aarch64.cpp"
  }
}

void vnot4I_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2081 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 33936 "ad_aarch64.cpp"
  }
}

void vnot2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2094 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33954 "ad_aarch64.cpp"
  }
}

void vnot2L_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2094 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 33972 "ad_aarch64.cpp"
  }
}

void vand_not2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2111 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 33991 "ad_aarch64.cpp"
  }
}

void vand_not2I_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2111 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 34010 "ad_aarch64.cpp"
  }
}

void vand_not2I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2111 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 34029 "ad_aarch64.cpp"
  }
}

void vand_not2I_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2111 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34048 "ad_aarch64.cpp"
  }
}

void vand_not2I_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2111 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34067 "ad_aarch64.cpp"
  }
}

void vand_not2I_5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2111 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 34086 "ad_aarch64.cpp"
  }
}

void vand_not2I_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2111 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 34105 "ad_aarch64.cpp"
  }
}

void vand_not2I_6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2111 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34124 "ad_aarch64.cpp"
  }
}

void vand_not2I_7Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2111 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34143 "ad_aarch64.cpp"
  }
}

void vand_not2I_9Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2111 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 34162 "ad_aarch64.cpp"
  }
}

void vand_not2I_8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2111 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 34181 "ad_aarch64.cpp"
  }
}

void vand_not2I_10Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2111 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34200 "ad_aarch64.cpp"
  }
}

void vand_not4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2126 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34219 "ad_aarch64.cpp"
  }
}

void vand_not4I_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2126 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 34238 "ad_aarch64.cpp"
  }
}

void vand_not4I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2126 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 34257 "ad_aarch64.cpp"
  }
}

void vand_not4I_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2126 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34276 "ad_aarch64.cpp"
  }
}

void vand_not4I_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2126 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34295 "ad_aarch64.cpp"
  }
}

void vand_not4I_5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2126 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 34314 "ad_aarch64.cpp"
  }
}

void vand_not4I_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2126 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 34333 "ad_aarch64.cpp"
  }
}

void vand_not4I_6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2126 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34352 "ad_aarch64.cpp"
  }
}

void vand_not4I_7Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2126 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34371 "ad_aarch64.cpp"
  }
}

void vand_not4I_9Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2126 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 34390 "ad_aarch64.cpp"
  }
}

void vand_not4I_8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2126 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 34409 "ad_aarch64.cpp"
  }
}

void vand_not4I_10Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2126 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34428 "ad_aarch64.cpp"
  }
}

void vand_not2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2139 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34447 "ad_aarch64.cpp"
  }
}

void vand_not2L_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2139 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 34466 "ad_aarch64.cpp"
  }
}

void vand_not2L_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2139 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 34485 "ad_aarch64.cpp"
  }
}

void vand_not2L_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2139 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34504 "ad_aarch64.cpp"
  }
}

void vmax8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2155 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ maxv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34523 "ad_aarch64.cpp"
  }
}

void vmax16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2169 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ maxv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34542 "ad_aarch64.cpp"
  }
}

void vmax4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2183 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ maxv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34561 "ad_aarch64.cpp"
  }
}

void vmax8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2197 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ maxv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34580 "ad_aarch64.cpp"
  }
}

void vmax2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2211 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ maxv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34599 "ad_aarch64.cpp"
  }
}

void vmax4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2225 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ maxv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34618 "ad_aarch64.cpp"
  }
}

void vmin8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2240 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ minv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34637 "ad_aarch64.cpp"
  }
}

void vmin16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2254 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ minv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34656 "ad_aarch64.cpp"
  }
}

void vmin4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2268 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ minv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34675 "ad_aarch64.cpp"
  }
}

void vmin8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2282 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ minv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34694 "ad_aarch64.cpp"
  }
}

void vmin2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2296 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ minv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34713 "ad_aarch64.cpp"
  }
}

void vmin4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2310 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ minv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34732 "ad_aarch64.cpp"
  }
}

void vmax2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2327 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ cmgt(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ bsl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34753 "ad_aarch64.cpp"
  }
}

void vmin2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2344 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ cmgt(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ bsl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 34774 "ad_aarch64.cpp"
  }
}

void vbsl8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2361 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bsl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 34793 "ad_aarch64.cpp"
  }
}

void vbsl16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2374 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bsl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 34812 "ad_aarch64.cpp"
  }
}

void loadmask8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2389 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 34828 "ad_aarch64.cpp"
  }
}

void loadmask16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2401 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 34844 "ad_aarch64.cpp"
  }
}

void storemask8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2413 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 34861 "ad_aarch64.cpp"
  }
}

void storemask16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2425 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 34878 "ad_aarch64.cpp"
  }
}

void loadmask4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2438 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 34895 "ad_aarch64.cpp"
  }
}

void loadmask8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2452 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 34912 "ad_aarch64.cpp"
  }
}

void storemask4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2466 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 34930 "ad_aarch64.cpp"
  }
}

void storemask8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2480 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 34948 "ad_aarch64.cpp"
  }
}

void loadmask2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2497 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 34966 "ad_aarch64.cpp"
  }
}

void loadmask4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2515 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 34984 "ad_aarch64.cpp"
  }
}

void storemask2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2531 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T4S);
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 35003 "ad_aarch64.cpp"
  }
}

void storemask4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2547 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T4S);
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 35022 "ad_aarch64.cpp"
  }
}

void loadmask2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2566 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H);
    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 35041 "ad_aarch64.cpp"
  }
}

void storemask2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2584 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2D);
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S);
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 35061 "ad_aarch64.cpp"
  }
}

void vmaskcastDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2603 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // empty
  
#line 35077 "ad_aarch64.cpp"
  }
}

void vmaskcastXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2617 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // empty
  
#line 35093 "ad_aarch64.cpp"
  }
}

void loadcon8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2634 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ lea(rscratch1, ExternalAddress(StubRoutines::aarch64::vector_iota_indices()));
    __ ldrd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), rscratch1);
  
#line 35110 "ad_aarch64.cpp"
  }
}

void loadcon16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2647 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ lea(rscratch1, ExternalAddress(StubRoutines::aarch64::vector_iota_indices()));
    __ ldrq(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), rscratch1);
  
#line 35127 "ad_aarch64.cpp"
  }
}

void loadshuffle8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2663 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35144 "ad_aarch64.cpp"
  }
}

void loadshuffle16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2677 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35161 "ad_aarch64.cpp"
  }
}

void loadshuffle4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2691 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
  
#line 35177 "ad_aarch64.cpp"
  }
}

void loadshuffle8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2704 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
  
#line 35193 "ad_aarch64.cpp"
  }
}

void loadshuffle4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2719 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H);
  
#line 35210 "ad_aarch64.cpp"
  }
}

void rearrange8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2755 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ tbl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shuffle */));
  
#line 35229 "ad_aarch64.cpp"
  }
}

void rearrange16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2770 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ tbl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shuffle */));
  
#line 35248 "ad_aarch64.cpp"
  }
}

void rearrange4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp0
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2789 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp0 */), __ T8B, 0x02);
    __ mov(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */), __ T4H, 0x0100);
    __ mulv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shuffle */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp0 */));
    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */));
    __ tbl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 35275 "ad_aarch64.cpp"
  }
}

void rearrange8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp0
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2814 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp0 */), __ T16B, 0x02);
    __ mov(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */), __ T8H, 0x0100);
    __ mulv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shuffle */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp0 */));
    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */));
    __ tbl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 35302 "ad_aarch64.cpp"
  }
}

void rearrange4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp0
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2840 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp0 */), __ T16B, 0x04);
    __ mov(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */), __ T4S, 0x03020100);
    __ mulv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shuffle */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp0 */));
    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */));
    __ tbl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 35329 "ad_aarch64.cpp"
  }
}

void anytrue_in_mask8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2865 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // No need to use src2.
    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ B, 0);
    __ cmpw(opnd_array(0)->as_Register(ra_,this)/* dst */, zr);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
  
#line 35351 "ad_aarch64.cpp"
  }
}

void anytrue_in_mask16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2885 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // No need to use src2.
    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ B, 0);
    __ cmpw(opnd_array(0)->as_Register(ra_,this)/* dst */, zr);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
  
#line 35373 "ad_aarch64.cpp"
  }
}

void alltrue_in_mask8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2905 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // No need to use src2.
    __ uminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ B, 0);
    __ cmpw(opnd_array(0)->as_Register(ra_,this)/* dst */, 0xff);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::EQ);
  
#line 35395 "ad_aarch64.cpp"
  }
}

void alltrue_in_mask16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2925 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // No need to use src2.
    __ uminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ B, 0);
    __ cmpw(opnd_array(0)->as_Register(ra_,this)/* dst */, 0xff);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::EQ);
  
#line 35417 "ad_aarch64.cpp"
  }
}

void vabs8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2943 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35433 "ad_aarch64.cpp"
  }
}

void vabs16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2955 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35449 "ad_aarch64.cpp"
  }
}

void vabs4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2967 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35465 "ad_aarch64.cpp"
  }
}

void vabs8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2979 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35481 "ad_aarch64.cpp"
  }
}

void vabs2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2991 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35497 "ad_aarch64.cpp"
  }
}

void vabs4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3003 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35513 "ad_aarch64.cpp"
  }
}

void vabs2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3015 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35529 "ad_aarch64.cpp"
  }
}

void vabs2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3027 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fabs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35545 "ad_aarch64.cpp"
  }
}

void vabs4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3039 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fabs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35561 "ad_aarch64.cpp"
  }
}

void vabs2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3051 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fabs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35577 "ad_aarch64.cpp"
  }
}

void vabd2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3065 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fabd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35595 "ad_aarch64.cpp"
  }
}

void vabd4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3078 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fabd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35613 "ad_aarch64.cpp"
  }
}

void vabd2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3091 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fabd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35631 "ad_aarch64.cpp"
  }
}

void replicate8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3105 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35647 "ad_aarch64.cpp"
  }
}

void replicate16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3117 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35663 "ad_aarch64.cpp"
  }
}

void replicate8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3130 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, opnd_array(1)->constant()& 0xff);
  
#line 35679 "ad_aarch64.cpp"
  }
}

void replicate16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3142 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, opnd_array(1)->constant()& 0xff);
  
#line 35695 "ad_aarch64.cpp"
  }
}

void replicate4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3155 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35711 "ad_aarch64.cpp"
  }
}

void replicate8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3167 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35727 "ad_aarch64.cpp"
  }
}

void replicate4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3180 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, opnd_array(1)->constant()& 0xffff);
  
#line 35743 "ad_aarch64.cpp"
  }
}

void replicate8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3192 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, opnd_array(1)->constant()& 0xffff);
  
#line 35759 "ad_aarch64.cpp"
  }
}

void replicate2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3204 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35775 "ad_aarch64.cpp"
  }
}

void replicate4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3216 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35791 "ad_aarch64.cpp"
  }
}

void replicate2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3228 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, opnd_array(1)->constant());
  
#line 35807 "ad_aarch64.cpp"
  }
}

void replicate4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3240 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, opnd_array(1)->constant());
  
#line 35823 "ad_aarch64.cpp"
  }
}

void replicate2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3252 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35839 "ad_aarch64.cpp"
  }
}

void replicate2L_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3264 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
           as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 35857 "ad_aarch64.cpp"
  }
}

void replicate2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3278 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35874 "ad_aarch64.cpp"
  }
}

void replicate4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3291 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35891 "ad_aarch64.cpp"
  }
}

void replicate2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3304 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35908 "ad_aarch64.cpp"
  }
}

void reduce_add2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// vtmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3323 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addpv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */), __ T2S,
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* itmp */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */), __ S, 0);
    __ addw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
  
#line 35930 "ad_aarch64.cpp"
  }
}

void reduce_add4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// vtmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3342 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* itmp */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */), __ S, 0);
    __ addw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
  
#line 35952 "ad_aarch64.cpp"
  }
}

void reduce_mul2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3362 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 35974 "ad_aarch64.cpp"
  }
}

void reduce_mul4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3384 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ T2S,
            as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ S, 0);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ umov(opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ S, 1);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 36001 "ad_aarch64.cpp"
  }
}

void reduce_add2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3406 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 36025 "ad_aarch64.cpp"
  }
}

void reduce_add4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3430 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 2);
    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 3);
    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 36057 "ad_aarch64.cpp"
  }
}

void reduce_mul2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3458 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 36081 "ad_aarch64.cpp"
  }
}

void reduce_mul4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3482 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 2);
    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 3);
    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 36113 "ad_aarch64.cpp"
  }
}

void reduce_add2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3510 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ faddd(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ faddd(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 36137 "ad_aarch64.cpp"
  }
}

void reduce_mul2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3530 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmuld(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ fmuld(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 36161 "ad_aarch64.cpp"
  }
}

void vadd8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3552 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36180 "ad_aarch64.cpp"
  }
}

void vadd16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3566 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36199 "ad_aarch64.cpp"
  }
}

void vadd4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3581 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36218 "ad_aarch64.cpp"
  }
}

void vadd8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3595 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36237 "ad_aarch64.cpp"
  }
}

void vadd2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3609 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36256 "ad_aarch64.cpp"
  }
}

void vadd4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3623 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36275 "ad_aarch64.cpp"
  }
}

void vadd2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3637 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36294 "ad_aarch64.cpp"
  }
}

void vadd2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3651 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36313 "ad_aarch64.cpp"
  }
}

void vadd4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3665 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36332 "ad_aarch64.cpp"
  }
}

void vadd2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3678 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36351 "ad_aarch64.cpp"
  }
}

void vsub8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3695 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36370 "ad_aarch64.cpp"
  }
}

void vsub16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3709 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36389 "ad_aarch64.cpp"
  }
}

void vsub4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3724 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36408 "ad_aarch64.cpp"
  }
}

void vsub8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3738 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36427 "ad_aarch64.cpp"
  }
}

void vsub2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3752 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36446 "ad_aarch64.cpp"
  }
}

void vsub4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3766 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36465 "ad_aarch64.cpp"
  }
}

void vsub2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3780 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36484 "ad_aarch64.cpp"
  }
}

void vsub2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3794 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36503 "ad_aarch64.cpp"
  }
}

void vsub4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3808 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36522 "ad_aarch64.cpp"
  }
}

void vsub2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3822 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36541 "ad_aarch64.cpp"
  }
}

void vmul8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3839 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36560 "ad_aarch64.cpp"
  }
}

void vmul16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3853 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36579 "ad_aarch64.cpp"
  }
}

void vmul4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3868 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36598 "ad_aarch64.cpp"
  }
}

void vmul8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3882 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36617 "ad_aarch64.cpp"
  }
}

void vmul2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3896 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36636 "ad_aarch64.cpp"
  }
}

void vmul4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3910 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36655 "ad_aarch64.cpp"
  }
}

void vmul2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3924 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36674 "ad_aarch64.cpp"
  }
}

void vmul4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3938 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36693 "ad_aarch64.cpp"
  }
}

void vmul2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3952 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36712 "ad_aarch64.cpp"
  }
}

void vmla4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3969 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 36732 "ad_aarch64.cpp"
  }
}

void vmla4S_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3969 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36752 "ad_aarch64.cpp"
  }
}

void vmla8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3983 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 36772 "ad_aarch64.cpp"
  }
}

void vmla8S_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3983 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36792 "ad_aarch64.cpp"
  }
}

void vmla2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3997 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 36812 "ad_aarch64.cpp"
  }
}

void vmla2I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3997 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36832 "ad_aarch64.cpp"
  }
}

void vmla4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4011 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 36852 "ad_aarch64.cpp"
  }
}

void vmla4I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4011 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36872 "ad_aarch64.cpp"
  }
}

void vmla2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4026 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 36892 "ad_aarch64.cpp"
  }
}

void vmla4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4041 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 36912 "ad_aarch64.cpp"
  }
}

void vmla2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4056 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 36932 "ad_aarch64.cpp"
  }
}

void vmls4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4072 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 36952 "ad_aarch64.cpp"
  }
}

void vmls8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4085 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 36972 "ad_aarch64.cpp"
  }
}

void vmls2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4098 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 36992 "ad_aarch64.cpp"
  }
}

void vmls4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4111 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37012 "ad_aarch64.cpp"
  }
}

void vmls2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4126 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37032 "ad_aarch64.cpp"
  }
}

void vmls2F_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4126 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37052 "ad_aarch64.cpp"
  }
}

void vmls4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4141 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37072 "ad_aarch64.cpp"
  }
}

void vmls4F_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4141 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37092 "ad_aarch64.cpp"
  }
}

void vmls2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4156 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37112 "ad_aarch64.cpp"
  }
}

void vmls2D_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4156 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37132 "ad_aarch64.cpp"
  }
}

void vmuladdS2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4174 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smullv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T4H,
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ smullv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8H,
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ addpv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S,
             as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 37159 "ad_aarch64.cpp"
  }
}

void vdiv2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4196 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fdiv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37178 "ad_aarch64.cpp"
  }
}

void vdiv4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4210 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fdiv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37197 "ad_aarch64.cpp"
  }
}

void vdiv2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4224 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fdiv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37216 "ad_aarch64.cpp"
  }
}

void vsqrt2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4239 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 37232 "ad_aarch64.cpp"
  }
}

void vsqrt4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4250 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 37248 "ad_aarch64.cpp"
  }
}

void vsqrt2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4261 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 37264 "ad_aarch64.cpp"
  }
}

void vneg2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4275 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 37281 "ad_aarch64.cpp"
  }
}

void vneg4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4288 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 37298 "ad_aarch64.cpp"
  }
}

void vneg2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4301 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 37315 "ad_aarch64.cpp"
  }
}

void vand8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4317 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ andr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37334 "ad_aarch64.cpp"
  }
}

void vand16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4331 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ andr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37353 "ad_aarch64.cpp"
  }
}

void vor8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4348 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37372 "ad_aarch64.cpp"
  }
}

void vor16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4362 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37391 "ad_aarch64.cpp"
  }
}

void vxor8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4379 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37410 "ad_aarch64.cpp"
  }
}

void vxor16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4393 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37429 "ad_aarch64.cpp"
  }
}

void vshiftcnt8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4409 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 37445 "ad_aarch64.cpp"
  }
}

void vshiftcnt8B_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4409 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 37461 "ad_aarch64.cpp"
  }
}

void vshiftcnt16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4420 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 37477 "ad_aarch64.cpp"
  }
}

void vshiftcnt16B_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4420 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 37493 "ad_aarch64.cpp"
  }
}

void vsll8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4432 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 37512 "ad_aarch64.cpp"
  }
}

void vsll16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4445 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 37531 "ad_aarch64.cpp"
  }
}

void vsra8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4482 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 37553 "ad_aarch64.cpp"
  }
}

void vsra16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4499 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 37575 "ad_aarch64.cpp"
  }
}

void vsrl8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4517 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 37597 "ad_aarch64.cpp"
  }
}

void vsrl16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4534 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 37619 "ad_aarch64.cpp"
  }
}

void vsll8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4550 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 37644 "ad_aarch64.cpp"
  }
}

void vsll16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4569 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 37669 "ad_aarch64.cpp"
  }
}

void vsra8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4589 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) sh = 7;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 37689 "ad_aarch64.cpp"
  }
}

void vsra16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4603 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) sh = 7;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 37709 "ad_aarch64.cpp"
  }
}

void vsrl8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4618 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 37734 "ad_aarch64.cpp"
  }
}

void vsrl16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4637 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 37759 "ad_aarch64.cpp"
  }
}

void vsll4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4657 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 37778 "ad_aarch64.cpp"
  }
}

void vsll8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4670 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 37797 "ad_aarch64.cpp"
  }
}

void vsra4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4686 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 37819 "ad_aarch64.cpp"
  }
}

void vsra8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4703 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 37841 "ad_aarch64.cpp"
  }
}

void vsrl4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4721 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 37863 "ad_aarch64.cpp"
  }
}

void vsrl8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4738 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 37885 "ad_aarch64.cpp"
  }
}

void vsll4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4754 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 37910 "ad_aarch64.cpp"
  }
}

void vsll8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4773 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 37935 "ad_aarch64.cpp"
  }
}

void vsra4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4793 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) sh = 15;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 37955 "ad_aarch64.cpp"
  }
}

void vsra8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4807 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) sh = 15;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 37975 "ad_aarch64.cpp"
  }
}

void vsrl4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4822 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 38000 "ad_aarch64.cpp"
  }
}

void vsrl8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4841 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 38025 "ad_aarch64.cpp"
  }
}

void vsll2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4860 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 38044 "ad_aarch64.cpp"
  }
}

void vsll4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4873 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 38063 "ad_aarch64.cpp"
  }
}

void vsra2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4888 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 38085 "ad_aarch64.cpp"
  }
}

void vsra4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4905 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 38107 "ad_aarch64.cpp"
  }
}

void vsrl2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4922 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 38129 "ad_aarch64.cpp"
  }
}

void vsrl4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4939 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 38151 "ad_aarch64.cpp"
  }
}

void vsll2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4954 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           (int)opnd_array(2)->constant());
  
#line 38170 "ad_aarch64.cpp"
  }
}

void vsll4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4967 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           (int)opnd_array(2)->constant());
  
#line 38189 "ad_aarch64.cpp"
  }
}

void vsra2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4980 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 38208 "ad_aarch64.cpp"
  }
}

void vsra4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4993 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 38227 "ad_aarch64.cpp"
  }
}

void vsrl2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5006 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 38246 "ad_aarch64.cpp"
  }
}

void vsrl4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5019 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 38265 "ad_aarch64.cpp"
  }
}

void vsll2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5032 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 38284 "ad_aarch64.cpp"
  }
}

void vsra2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5047 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 38306 "ad_aarch64.cpp"
  }
}

void vsrl2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5064 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 38328 "ad_aarch64.cpp"
  }
}

void vsll2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5079 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           (int)opnd_array(2)->constant());
  
#line 38347 "ad_aarch64.cpp"
  }
}

void vsra2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5092 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 38366 "ad_aarch64.cpp"
  }
}

void vsrl2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5105 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 38385 "ad_aarch64.cpp"
  }
}

void vsraa8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5118 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh >= 8) sh = 7;
    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
  
#line 38406 "ad_aarch64.cpp"
  }
}

void vsraa8B_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5118 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) sh = 7;
    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 38427 "ad_aarch64.cpp"
  }
}

void vsraa16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5132 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh >= 8) sh = 7;
    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
  
#line 38448 "ad_aarch64.cpp"
  }
}

void vsraa16B_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5132 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) sh = 7;
    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 38469 "ad_aarch64.cpp"
  }
}

void vsraa4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5146 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh >= 16) sh = 15;
    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4H,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
  
#line 38490 "ad_aarch64.cpp"
  }
}

void vsraa4S_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5146 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) sh = 15;
    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4H,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 38511 "ad_aarch64.cpp"
  }
}

void vsraa8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5160 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh >= 16) sh = 15;
    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8H,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
  
#line 38532 "ad_aarch64.cpp"
  }
}

void vsraa8S_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5160 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) sh = 15;
    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8H,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 38553 "ad_aarch64.cpp"
  }
}

void vsraa2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5174 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
            (int)opnd_array(3)->constant());
  
#line 38573 "ad_aarch64.cpp"
  }
}

void vsraa2I_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5174 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 38593 "ad_aarch64.cpp"
  }
}

void vsraa4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5187 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
            (int)opnd_array(3)->constant());
  
#line 38613 "ad_aarch64.cpp"
  }
}

void vsraa4I_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5187 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 38633 "ad_aarch64.cpp"
  }
}

void vsraa2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5200 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
            (int)opnd_array(3)->constant());
  
#line 38653 "ad_aarch64.cpp"
  }
}

void vsraa2L_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5200 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 38673 "ad_aarch64.cpp"
  }
}

void vsrla8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5213 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh < 8) {
      __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
    }
  
#line 38695 "ad_aarch64.cpp"
  }
}

void vsrla8B_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5213 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh < 8) {
      __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 38717 "ad_aarch64.cpp"
  }
}

void vsrla16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5228 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh < 8) {
      __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
    }
  
#line 38739 "ad_aarch64.cpp"
  }
}

void vsrla16B_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5228 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh < 8) {
      __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 38761 "ad_aarch64.cpp"
  }
}

void vsrla4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5243 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh < 16) {
      __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4H,
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
    }
  
#line 38783 "ad_aarch64.cpp"
  }
}

void vsrla4S_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5243 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh < 16) {
      __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 38805 "ad_aarch64.cpp"
  }
}

void vsrla8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5258 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh < 16) {
      __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8H,
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
    }
  
#line 38827 "ad_aarch64.cpp"
  }
}

void vsrla8S_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5258 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh < 16) {
      __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 38849 "ad_aarch64.cpp"
  }
}

void vsrla2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5273 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
            (int)opnd_array(3)->constant());
  
#line 38869 "ad_aarch64.cpp"
  }
}

void vsrla2I_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5273 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 38889 "ad_aarch64.cpp"
  }
}

void vsrla4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5286 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
            (int)opnd_array(3)->constant());
  
#line 38909 "ad_aarch64.cpp"
  }
}

void vsrla4I_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5286 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 38929 "ad_aarch64.cpp"
  }
}

void vsrla2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5299 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
            (int)opnd_array(3)->constant());
  
#line 38949 "ad_aarch64.cpp"
  }
}

void vsrla2L_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5299 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 38969 "ad_aarch64.cpp"
  }
}

void vmax2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5313 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmax(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38988 "ad_aarch64.cpp"
  }
}

void vmax4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5327 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmax(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 39007 "ad_aarch64.cpp"
  }
}

void vmax2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5341 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmax(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 39026 "ad_aarch64.cpp"
  }
}

void vmin2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5355 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmin(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 39045 "ad_aarch64.cpp"
  }
}

void vmin4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5369 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmin(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 39064 "ad_aarch64.cpp"
  }
}

void vmin2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5383 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmin(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 39083 "ad_aarch64.cpp"
  }
}

void vround2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rmode
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5395 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    switch (opnd_array(2)->constant()) {
      case RoundDoubleModeNode::rmode_rint:
        __ frintn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
                  as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_floor:
        __ frintm(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
                  as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_ceil:
        __ frintp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
                  as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
    }
  
#line 39113 "ad_aarch64.cpp"
  }
}

void vpopcount4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5422 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ cnt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
              as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
    __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
              as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 39134 "ad_aarch64.cpp"
  }
}

void vpopcount2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5441 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ cnt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
              as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
    __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
              as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 39155 "ad_aarch64.cpp"
  }
}

void vmask_truecount8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5461 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Input "src" is a vector of boolean represented as bytes with
    // 0x00/0x01 as element values.
    __ addv(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), __ B, 0);
  
#line 39175 "ad_aarch64.cpp"
  }
}

void vmask_truecount16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5477 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Input "src" is a vector of boolean represented as bytes with
    // 0x00/0x01 as element values.
    __ addv(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), __ T16B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), __ B, 0);
  
#line 39195 "ad_aarch64.cpp"
  }
}

void vmask_firsttrue_LT8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5493 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Returns the index of the first active lane of the
    // vector mask, or VLENGTH if no lane is active.
    //
    // Input "src" is a vector of boolean represented as
    // bytes with 0x00/0x01 as element values.
    //
    // Computed by reversing the bits and counting the leading
    // zero bytes.
    __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ rbit(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ clz(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ lsrw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, 3);
    __ movw(rscratch1, Matcher::vector_length(this, opnd_array(1)));
    __ cmpw(opnd_array(0)->as_Register(ra_,this)/* dst */, rscratch1);
    __ cselw(opnd_array(0)->as_Register(ra_,this)/* dst */, rscratch1, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::GE);
  
#line 39225 "ad_aarch64.cpp"
  }
}

void vmask_firsttrue8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5519 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Returns the index of the first active lane of the
    // vector mask, or VLENGTH if no lane is active.
    //
    // Input "src" is a vector of boolean represented as
    // bytes with 0x00/0x01 as element values.
    //
    // Computed by reversing the bits and counting the leading
    // zero bytes.
    __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ rbit(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ clz(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ lsrw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, 3);
  
#line 39252 "ad_aarch64.cpp"
  }
}

void vmask_firsttrue16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5541 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Returns the index of the first active lane of the
    // vector mask, or 16 (VLENGTH) if no lane is active.
    //
    // Input "src" is a vector of boolean represented as
    // bytes with 0x00/0x01 as element values.

    Label FIRST_TRUE_INDEX;

    // Try to compute the result from lower 64 bits.
    __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ movw(rscratch1, zr);
    __ cbnz(opnd_array(0)->as_Register(ra_,this)/* dst */, FIRST_TRUE_INDEX);

    // Compute the result from the higher 64 bits.
    __ fmovhid(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ movw(rscratch1, 8);

    // Reverse the bits and count the leading zero bytes.
    __ bind(FIRST_TRUE_INDEX);
    __ rbit(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ clz(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ addw(opnd_array(0)->as_Register(ra_,this)/* dst */, rscratch1, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LSR, 3);
  
#line 39289 "ad_aarch64.cpp"
  }
}

void vmask_lasttrue8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5573 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Returns the index of the last active lane of the
    // vector mask, or -1 if no lane is active.
    //
    // Input "src" is a vector of boolean represented as
    // bytes with 0x00/0x01 as element values.
    //
    // Computed by counting the leading zero bytes and
    // substracting it by 7 (VLENGTH - 1).
    __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ clz(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ movw(rscratch1, 7);
    __ subw(opnd_array(0)->as_Register(ra_,this)/* dst */, rscratch1, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LSR, 3);
  
#line 39316 "ad_aarch64.cpp"
  }
}

void vmask_lasttrue16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5595 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Returns the index of the last active lane of the
    // vector mask, or -1 if no lane is active.
    //
    // Input "src" is a vector of boolean represented as
    // bytes with 0x00/0x01 as element values.

    Label LAST_TRUE_INDEX;

    // Try to compute the result from higher 64 bits.
    __ fmovhid(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ movw(rscratch1, 16 - 1);
    __ cbnz(opnd_array(0)->as_Register(ra_,this)/* dst */, LAST_TRUE_INDEX);

    // Compute the result from the lower 64 bits.
    __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ movw(rscratch1, 8 - 1);

    // Count the leading zero bytes and substract it by 15 (VLENGTH - 1).
    __ bind(LAST_TRUE_INDEX);
    __ clz(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ subw(opnd_array(0)->as_Register(ra_,this)/* dst */, rscratch1, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LSR, 3);
  
#line 39352 "ad_aarch64.cpp"
  }
}

void vmask_tolong8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5625 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Input "src" is a vector of boolean represented as
    // bytes with 0x00/0x01 as element values.

    __ fmovd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ bytemask_compress(as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 39372 "ad_aarch64.cpp"
  }
}

void vmask_tolong16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5639 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Input "src" is a vector of boolean represented as
    // bytes with 0x00/0x01 as element values.

    __ umov(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D, 0);
    __ umov(rscratch1, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D, 1);
    __ bytemask_compress(as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
    __ bytemask_compress(rscratch1);
    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           rscratch1, Assembler::LSL, 8);
  
#line 39396 "ad_aarch64.cpp"
  }
}

void loadVNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 184 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    BasicType bt = Matcher::vector_element_basic_type(this);
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), false, dst_reg, ptrue,
                          bt, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 39416 "ad_aarch64.cpp"
  }
}

void storeVNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 200 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), true, src_reg, ptrue,
                          bt, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 39437 "ad_aarch64.cpp"
  }
}

void loadV2_vregNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3149 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::H,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 39454 "ad_aarch64.cpp"
  }
}

void storeV2_vregNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3173 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::H,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 39472 "ad_aarch64.cpp"
  }
}

void loadV4_vregNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3155 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::S,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 39489 "ad_aarch64.cpp"
  }
}

void storeV4_vregNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3179 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::S,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 39507 "ad_aarch64.cpp"
  }
}

void loadV8_vregNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3161 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::D,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 39524 "ad_aarch64.cpp"
  }
}

void storeV8_vregNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3185 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::D,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 39542 "ad_aarch64.cpp"
  }
}

void loadV16_vregNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3167 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::Q,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 39559 "ad_aarch64.cpp"
  }
}

void storeV16_vregNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3191 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::Q,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 39577 "ad_aarch64.cpp"
  }
}

void loadV_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 310 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pgtmp */), __ elemType_to_regVariant(bt),
                          Matcher::vector_length(this));
    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), false, dst_reg,
                          as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pgtmp */), bt, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 39600 "ad_aarch64.cpp"
  }
}

void storeV_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 330 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pgtmp */), __ elemType_to_regVariant(bt),
                          Matcher::vector_length(this, opnd_array(2)));
    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), true, src_reg,
                          as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pgtmp */), bt, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 39624 "ad_aarch64.cpp"
  }
}

void loadV_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 350 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), false, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
                          as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */), bt, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 39644 "ad_aarch64.cpp"
  }
}

void loadV_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 366 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pgtmp */), __ elemType_to_regVariant(bt),
                          Matcher::vector_length(this));
    __ sve_and(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pgtmp */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pgtmp */),
               as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */));
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), false, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
                          as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pgtmp */), bt, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 39669 "ad_aarch64.cpp"
  }
}

void storeV_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 385 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), true, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
                          as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), bt, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 39690 "ad_aarch64.cpp"
  }
}

void storeV_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 401 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pgtmp */), __ elemType_to_regVariant(bt),
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pgtmp */), as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pgtmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), true, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
                          as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pgtmp */), bt, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 39716 "ad_aarch64.cpp"
  }
}

void vmaskAll_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 421 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(1)->constant();
    if (con == 0) {
      __ sve_pfalse(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */));
    } else {
      assert(con == -1, "invalid constant value for mask");
      BasicType bt = Matcher::vector_element_basic_type(this);
      __ sve_ptrue_lanecnt(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ elemType_to_regVariant(bt),
                           Matcher::vector_length(this));
    }
  
#line 39740 "ad_aarch64.cpp"
  }
}

void vmaskAllINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 443 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    __ sve_dup(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), size, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    if (length_in_bytes < MaxVectorSize) {
      __ sve_ptrue_lanecnt(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, Matcher::vector_length(this));
      __ sve_cmp(Assembler::NE, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), size,
                 as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), 0);
    } else {
      __ sve_cmp(Assembler::NE, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), 0);
    }
  
#line 39767 "ad_aarch64.cpp"
  }
}

void vmaskAll_immLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 464 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    long con = (long)opnd_array(1)->constantL();
    if (con == 0) {
      __ sve_pfalse(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */));
    } else {
      assert(con == -1, "invalid constant value for mask");
      BasicType bt = Matcher::vector_element_basic_type(this);
      __ sve_ptrue_lanecnt(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ elemType_to_regVariant(bt),
                           Matcher::vector_length(this));
    }
  
#line 39791 "ad_aarch64.cpp"
  }
}

void vmaskAllLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 486 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    __ sve_dup(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), size, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    if (length_in_bytes < MaxVectorSize) {
      __ sve_ptrue_lanecnt(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, Matcher::vector_length(this));
      __ sve_cmp(Assembler::NE, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), size,
                 as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), 0);
    } else {
      __ sve_cmp(Assembler::NE, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), 0);
    }
  
#line 39818 "ad_aarch64.cpp"
  }
}

void vmask_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// pn
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pm
  {
    C2_MacroAssembler _masm(&cbuf);

#line 509 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_PRegister(opnd_array(0)->reg(ra_,this)/* pd */), ptrue,
               as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* pn */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pm */));
  
#line 39836 "ad_aarch64.cpp"
  }
}

void vmask_orNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// pn
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pm
  {
    C2_MacroAssembler _masm(&cbuf);

#line 521 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_PRegister(opnd_array(0)->reg(ra_,this)/* pd */), ptrue,
               as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* pn */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pm */));
  
#line 39854 "ad_aarch64.cpp"
  }
}

void vmask_xorNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// pn
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pm
  {
    C2_MacroAssembler _masm(&cbuf);

#line 533 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_PRegister(opnd_array(0)->reg(ra_,this)/* pd */), ptrue,
               as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* pn */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pm */));
  
#line 39872 "ad_aarch64.cpp"
  }
}

void vmask_and_notINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// pn
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pm
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 547 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_PRegister(opnd_array(0)->reg(ra_,this)/* pd */), ptrue,
               as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* pn */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pm */));
  
#line 39891 "ad_aarch64.cpp"
  }
}

void vmask_and_notLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// pn
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pm
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 559 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_PRegister(opnd_array(0)->reg(ra_,this)/* pd */), ptrue,
               as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* pn */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pm */));
  
#line 39910 "ad_aarch64.cpp"
  }
}

void reinterpretNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 574 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // empty
  
#line 39926 "ad_aarch64.cpp"
  }
}

void reinterpretResizeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 587 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    uint length_in_bytes_src = Matcher::vector_length_in_bytes(this, opnd_array(1));
    uint length_in_bytes_dst = Matcher::vector_length_in_bytes(this);
    uint length_in_bytes_resize = length_in_bytes_src < length_in_bytes_dst ?
                                  length_in_bytes_src : length_in_bytes_dst;
    assert(length_in_bytes_src <= MaxVectorSize && length_in_bytes_dst <= MaxVectorSize,
           "invalid vector length");
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pgtmp */), __ B, length_in_bytes_resize);
    __ sve_dup(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ B, 0);
    __ sve_sel(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ B, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pgtmp */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */));
  
#line 39953 "ad_aarch64.cpp"
  }
}

void vmask_reinterpret_same_esizeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 611 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // empty
  
#line 39969 "ad_aarch64.cpp"
  }
}

void vmask_reinterpret_diff_esizeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 625 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType from_bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant from_size = __ elemType_to_regVariant(from_bt);
    BasicType to_bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant to_size = __ elemType_to_regVariant(to_bt);
    __ sve_cpy(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), from_size, as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), -1, false);
    __ sve_cmp(Assembler::EQ, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), to_size, ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), -1);
  
#line 39991 "ad_aarch64.cpp"
  }
}

void vabsBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 644 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 40008 "ad_aarch64.cpp"
  }
}

void vabsSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 657 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 40025 "ad_aarch64.cpp"
  }
}

void vabsINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 670 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 40042 "ad_aarch64.cpp"
  }
}

void vabsLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 683 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 40059 "ad_aarch64.cpp"
  }
}

void vabsFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 696 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fabs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 40076 "ad_aarch64.cpp"
  }
}

void vabsDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 709 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fabs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 40093 "ad_aarch64.cpp"
  }
}

void vabsB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 723 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ B,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 40112 "ad_aarch64.cpp"
  }
}

void vabsS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 736 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ H,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 40131 "ad_aarch64.cpp"
  }
}

void vabsI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 749 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 40150 "ad_aarch64.cpp"
  }
}

void vabsL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 762 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 40169 "ad_aarch64.cpp"
  }
}

void vabsF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 775 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fabs(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 40188 "ad_aarch64.cpp"
  }
}

void vabsD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 788 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fabs(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 40207 "ad_aarch64.cpp"
  }
}

void vaddBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 803 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 40226 "ad_aarch64.cpp"
  }
}

void vaddSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 816 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 40245 "ad_aarch64.cpp"
  }
}

void vaddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 829 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 40264 "ad_aarch64.cpp"
  }
}

void vaddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 842 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 40283 "ad_aarch64.cpp"
  }
}

void vaddFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 855 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 40302 "ad_aarch64.cpp"
  }
}

void vaddDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 868 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 40321 "ad_aarch64.cpp"
  }
}

void vaddB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 883 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 40341 "ad_aarch64.cpp"
  }
}

void vaddS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 896 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 40361 "ad_aarch64.cpp"
  }
}

void vaddI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 909 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 40381 "ad_aarch64.cpp"
  }
}

void vaddL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 922 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 40401 "ad_aarch64.cpp"
  }
}

void vaddF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 935 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 40421 "ad_aarch64.cpp"
  }
}

void vaddD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 948 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 40441 "ad_aarch64.cpp"
  }
}

void vaddImmBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 963 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int32_t val = opnd_array(2)->constant();
    if (val > 0){
      __ sve_add(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ B, val);
    } else if (val < 0){
      __ sve_sub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ B, -val);
    }
  
#line 40463 "ad_aarch64.cpp"
  }
}

void vaddImmB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 963 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int32_t val = opnd_array(1)->constant();
    if (val > 0){
      __ sve_add(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ B, val);
    } else if (val < 0){
      __ sve_sub(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ B, -val);
    }
  
#line 40485 "ad_aarch64.cpp"
  }
}

void vaddImmSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 979 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int32_t val = opnd_array(2)->constant();
    if (val > 0){
      __ sve_add(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ H, val);
    } else if (val < 0){
      __ sve_sub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ H, -val);
    }
  
#line 40507 "ad_aarch64.cpp"
  }
}

void vaddImmS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 979 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int32_t val = opnd_array(1)->constant();
    if (val > 0){
      __ sve_add(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ H, val);
    } else if (val < 0){
      __ sve_sub(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ H, -val);
    }
  
#line 40529 "ad_aarch64.cpp"
  }
}

void vaddImmINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 995 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int32_t val = opnd_array(2)->constant();
    if (val > 0){
      __ sve_add(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S, val);
    } else if (val < 0){
      __ sve_sub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S, -val);
    }
  
#line 40551 "ad_aarch64.cpp"
  }
}

void vaddImmI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 995 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int32_t val = opnd_array(1)->constant();
    if (val > 0){
      __ sve_add(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ S, val);
    } else if (val < 0){
      __ sve_sub(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ S, -val);
    }
  
#line 40573 "ad_aarch64.cpp"
  }
}

void vaddImmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1011 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int32_t val = opnd_array(2)->constantL();
    if (val > 0){
      __ sve_add(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D, val);
    } else if (val < 0){
      __ sve_sub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D, -val);
    }
  
#line 40595 "ad_aarch64.cpp"
  }
}

void vaddImmL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1011 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int32_t val = opnd_array(1)->constantL();
    if (val > 0){
      __ sve_add(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ D, val);
    } else if (val < 0){
      __ sve_sub(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ D, -val);
    }
  
#line 40617 "ad_aarch64.cpp"
  }
}

void vandBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1029 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ B,
         (uint64_t)(opnd_array(2)->constant()));
  
#line 40635 "ad_aarch64.cpp"
  }
}

void vandB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1029 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ B,
         (uint64_t)(opnd_array(1)->constant()));
  
#line 40653 "ad_aarch64.cpp"
  }
}

void vandHNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1041 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ H,
         (uint64_t)(opnd_array(2)->constant()));
  
#line 40671 "ad_aarch64.cpp"
  }
}

void vandH_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1041 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ H,
         (uint64_t)(opnd_array(1)->constant()));
  
#line 40689 "ad_aarch64.cpp"
  }
}

void vandSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1053 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S,
         (uint64_t)(opnd_array(2)->constant()));
  
#line 40707 "ad_aarch64.cpp"
  }
}

void vandS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1053 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ S,
         (uint64_t)(opnd_array(1)->constant()));
  
#line 40725 "ad_aarch64.cpp"
  }
}

void vandDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1065 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D,
         (uint64_t)(opnd_array(2)->constantL()));
  
#line 40743 "ad_aarch64.cpp"
  }
}

void vandD_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1065 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ D,
         (uint64_t)(opnd_array(1)->constantL()));
  
#line 40761 "ad_aarch64.cpp"
  }
}

void vorBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1077 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ B,
         (uint64_t)(opnd_array(2)->constant()));
  
#line 40779 "ad_aarch64.cpp"
  }
}

void vorB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1077 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ B,
         (uint64_t)(opnd_array(1)->constant()));
  
#line 40797 "ad_aarch64.cpp"
  }
}

void vorHNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1089 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ H,
         (uint64_t)(opnd_array(2)->constant()));
  
#line 40815 "ad_aarch64.cpp"
  }
}

void vorH_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1089 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ H,
         (uint64_t)(opnd_array(1)->constant()));
  
#line 40833 "ad_aarch64.cpp"
  }
}

void vorSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1101 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S,
         (uint64_t)(opnd_array(2)->constant()));
  
#line 40851 "ad_aarch64.cpp"
  }
}

void vorS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1101 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ S,
         (uint64_t)(opnd_array(1)->constant()));
  
#line 40869 "ad_aarch64.cpp"
  }
}

void vorDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1113 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D,
         (uint64_t)(opnd_array(2)->constantL()));
  
#line 40887 "ad_aarch64.cpp"
  }
}

void vorD_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1113 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ D,
         (uint64_t)(opnd_array(1)->constantL()));
  
#line 40905 "ad_aarch64.cpp"
  }
}

void vxorBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1125 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ B,
         (uint64_t)(opnd_array(2)->constant()));
  
#line 40923 "ad_aarch64.cpp"
  }
}

void vxorB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1125 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ B,
         (uint64_t)(opnd_array(1)->constant()));
  
#line 40941 "ad_aarch64.cpp"
  }
}

void vxorHNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1137 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ H,
         (uint64_t)(opnd_array(2)->constant()));
  
#line 40959 "ad_aarch64.cpp"
  }
}

void vxorH_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1137 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ H,
         (uint64_t)(opnd_array(1)->constant()));
  
#line 40977 "ad_aarch64.cpp"
  }
}

void vxorSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1149 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S,
         (uint64_t)(opnd_array(2)->constant()));
  
#line 40995 "ad_aarch64.cpp"
  }
}

void vxorS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1149 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ S,
         (uint64_t)(opnd_array(1)->constant()));
  
#line 41013 "ad_aarch64.cpp"
  }
}

void vxorDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1161 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D,
         (uint64_t)(opnd_array(2)->constantL()));
  
#line 41031 "ad_aarch64.cpp"
  }
}

void vxorD_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1161 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ D,
         (uint64_t)(opnd_array(1)->constantL()));
  
#line 41049 "ad_aarch64.cpp"
  }
}

void vandNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1174 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41068 "ad_aarch64.cpp"
  }
}

void vorNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1189 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41087 "ad_aarch64.cpp"
  }
}

void vxorNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1204 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41106 "ad_aarch64.cpp"
  }
}

void vand_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1219 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_and(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
          as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
          as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41128 "ad_aarch64.cpp"
  }
}

void vor_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1236 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_orr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
          as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
          as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41150 "ad_aarch64.cpp"
  }
}

void vxor_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1253 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_eor(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
          as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
          as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41172 "ad_aarch64.cpp"
  }
}

void vnotINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1272 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 41190 "ad_aarch64.cpp"
  }
}

void vnotI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1272 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 41208 "ad_aarch64.cpp"
  }
}

void vnotI_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1272 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 41226 "ad_aarch64.cpp"
  }
}

void vnotI_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1272 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 41244 "ad_aarch64.cpp"
  }
}

void vnotI_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1272 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 41262 "ad_aarch64.cpp"
  }
}

void vnotI_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1272 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 41280 "ad_aarch64.cpp"
  }
}

void vnotLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1284 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 41298 "ad_aarch64.cpp"
  }
}

void vnotL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1284 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 41316 "ad_aarch64.cpp"
  }
}

void vand_notINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1300 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41336 "ad_aarch64.cpp"
  }
}

void vand_notI_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1300 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 41356 "ad_aarch64.cpp"
  }
}

void vand_notI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1300 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 41376 "ad_aarch64.cpp"
  }
}

void vand_notI_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1300 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41396 "ad_aarch64.cpp"
  }
}

void vand_notI_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1300 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41416 "ad_aarch64.cpp"
  }
}

void vand_notI_5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1300 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 41436 "ad_aarch64.cpp"
  }
}

void vand_notI_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1300 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 41456 "ad_aarch64.cpp"
  }
}

void vand_notI_6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1300 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41476 "ad_aarch64.cpp"
  }
}

void vand_notI_7Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1300 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41496 "ad_aarch64.cpp"
  }
}

void vand_notI_9Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1300 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 41516 "ad_aarch64.cpp"
  }
}

void vand_notI_8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1300 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 41536 "ad_aarch64.cpp"
  }
}

void vand_notI_10Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1300 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41556 "ad_aarch64.cpp"
  }
}

void vand_notLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1313 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41576 "ad_aarch64.cpp"
  }
}

void vand_notL_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1313 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 41596 "ad_aarch64.cpp"
  }
}

void vand_notL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1313 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 41616 "ad_aarch64.cpp"
  }
}

void vand_notL_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1313 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41636 "ad_aarch64.cpp"
  }
}

void vdivFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1328 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fdiv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41654 "ad_aarch64.cpp"
  }
}

void vdivDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1340 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fdiv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41672 "ad_aarch64.cpp"
  }
}

void vfdivF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1354 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fdiv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41692 "ad_aarch64.cpp"
  }
}

void vfdivD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1367 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fdiv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41712 "ad_aarch64.cpp"
  }
}

void vminNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1382 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    if (is_floating_point_type(bt)) {
      __ sve_fmin(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    } else {
      assert(is_integral_type(bt), "unsupported type");
      __ sve_smin(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    }
  
#line 41738 "ad_aarch64.cpp"
  }
}

void vmaxNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1402 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    if (is_floating_point_type(bt)) {
      __ sve_fmax(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    } else {
      assert(is_integral_type(bt), "unsupported type");
      __ sve_smax(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    }
  
#line 41764 "ad_aarch64.cpp"
  }
}

void vmin_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1424 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    if (is_floating_point_type(bt)) {
      __ sve_fmin(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    } else {
      assert(is_integral_type(bt), "unsupported type");
      __ sve_smin(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    }
  
#line 41791 "ad_aarch64.cpp"
  }
}

void vmax_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1444 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    if (is_floating_point_type(bt)) {
      __ sve_fmax(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    } else {
      assert(is_integral_type(bt), "unsupported type");
      __ sve_smax(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    }
  
#line 41818 "ad_aarch64.cpp"
  }
}

void vfmlaFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1467 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 41837 "ad_aarch64.cpp"
  }
}

void vfmlaDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1480 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 41856 "ad_aarch64.cpp"
  }
}

void vfmlaF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1495 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmad(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 41876 "ad_aarch64.cpp"
  }
}

void vfmlaD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1508 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmad(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 41896 "ad_aarch64.cpp"
  }
}

void vfmlsFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1525 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 41915 "ad_aarch64.cpp"
  }
}

void vfmlsF_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1525 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 41934 "ad_aarch64.cpp"
  }
}

void vfmlsDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1540 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 41953 "ad_aarch64.cpp"
  }
}

void vfmlsD_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1540 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 41972 "ad_aarch64.cpp"
  }
}

void vfnmlaFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1557 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 41991 "ad_aarch64.cpp"
  }
}

void vfnmlaF_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1557 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 42010 "ad_aarch64.cpp"
  }
}

void vfnmlaDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1572 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 42029 "ad_aarch64.cpp"
  }
}

void vfnmlaD_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1572 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 42048 "ad_aarch64.cpp"
  }
}

void vfnmlsFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1587 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 42067 "ad_aarch64.cpp"
  }
}

void vfnmlsDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1600 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 42086 "ad_aarch64.cpp"
  }
}

void vmlaBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1616 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 42105 "ad_aarch64.cpp"
  }
}

void vmlaB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1616 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst_src1 */), __ B,
      ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src3 */));
  
#line 42124 "ad_aarch64.cpp"
  }
}

void vmlaSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1630 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 42143 "ad_aarch64.cpp"
  }
}

void vmlaS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1630 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst_src1 */), __ H,
      ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src3 */));
  
#line 42162 "ad_aarch64.cpp"
  }
}

void vmlaINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1644 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 42181 "ad_aarch64.cpp"
  }
}

void vmlaI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1644 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst_src1 */), __ S,
      ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src3 */));
  
#line 42200 "ad_aarch64.cpp"
  }
}

void vmlaLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1658 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 42219 "ad_aarch64.cpp"
  }
}

void vmlaL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1658 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst_src1 */), __ D,
      ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src3 */));
  
#line 42238 "ad_aarch64.cpp"
  }
}

void vmlsBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1674 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 42257 "ad_aarch64.cpp"
  }
}

void vmlsSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1688 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 42276 "ad_aarch64.cpp"
  }
}

void vmlsINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1702 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 42295 "ad_aarch64.cpp"
  }
}

void vmlsLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1716 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 42314 "ad_aarch64.cpp"
  }
}

void vmulBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1730 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42332 "ad_aarch64.cpp"
  }
}

void vmulSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1742 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42350 "ad_aarch64.cpp"
  }
}

void vmulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1754 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42368 "ad_aarch64.cpp"
  }
}

void vmulLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1766 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42386 "ad_aarch64.cpp"
  }
}

void vmulFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1778 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42405 "ad_aarch64.cpp"
  }
}

void vmulDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1791 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42424 "ad_aarch64.cpp"
  }
}

void vmulB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1806 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42444 "ad_aarch64.cpp"
  }
}

void vmulS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1819 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42464 "ad_aarch64.cpp"
  }
}

void vmulI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1832 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42484 "ad_aarch64.cpp"
  }
}

void vmulL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1845 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42504 "ad_aarch64.cpp"
  }
}

void vmulF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1858 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42524 "ad_aarch64.cpp"
  }
}

void vmulD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1871 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42544 "ad_aarch64.cpp"
  }
}

void vnegFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1887 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 42561 "ad_aarch64.cpp"
  }
}

void vnegDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1900 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 42578 "ad_aarch64.cpp"
  }
}

void vnegF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1914 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fneg(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 42597 "ad_aarch64.cpp"
  }
}

void vnegD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1927 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fneg(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 42616 "ad_aarch64.cpp"
  }
}

void vpopcountINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1941 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

     __ sve_cnt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 42632 "ad_aarch64.cpp"
  }
}

void vmaskcmpNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cond
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1955 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_compare(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), bt, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                   as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), (int)opnd_array(3)->constant());
  
#line 42652 "ad_aarch64.cpp"
  }
}

void vmaskcmp_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cond
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1969 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_compare(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), bt, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                   as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), (int)opnd_array(3)->constant());
  
#line 42673 "ad_aarch64.cpp"
  }
}

void vblendNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1984 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    Assembler::SIMD_RegVariant size =
               __ elemType_to_regVariant(Matcher::vector_element_basic_type(this));
    __ sve_sel(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 42694 "ad_aarch64.cpp"
  }
}

void vloadmaskBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2002 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_cmp(Assembler::NE, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
               ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0);
  
#line 42711 "ad_aarch64.cpp"
  }
}

void vloadmask_extendNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2015 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_vector_extend(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), size, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ B);
    __ sve_cmp(Assembler::NE, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), 0);
  
#line 42731 "ad_aarch64.cpp"
  }
}

void vstoremaskBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2031 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_cpy(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, false);
  
#line 42748 "ad_aarch64.cpp"
  }
}

void vstoremask_narrowNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2043 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    Assembler::SIMD_RegVariant size = __ elemBytes_to_regVariant((int)opnd_array(2)->constant());
    __ sve_cpy(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), size, as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, false);
    __ sve_vector_narrow(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ B,
                         as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), size, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 42770 "ad_aarch64.cpp"
  }
}

void vloadmask_loadVNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2063 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // Load mask values which are boolean type, and extend them to the
    // expected vector element type. Convert the vector to predicate.
    BasicType to_vect_bt = Matcher::vector_element_basic_type(this);
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), false, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */),
                          ptrue, T_BOOLEAN, to_vect_bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
    __ sve_cmp(Assembler::NE, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ elemType_to_regVariant(to_vect_bt),
               ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), 0);
  
#line 42794 "ad_aarch64.cpp"
  }
}

void vloadmask_loadV_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vtmp
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2085 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // Load valid mask values which are boolean type, and extend them to the
    // expected vector element type. Convert the vector to predicate.
    BasicType to_vect_bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(to_vect_bt);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), size, Matcher::vector_length(this));
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), false, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vtmp */),
                          as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), T_BOOLEAN, to_vect_bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
    __ sve_cmp(Assembler::NE, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vtmp */), 0);
  
#line 42820 "ad_aarch64.cpp"
  }
}

void storeV_vstoremaskNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// esize
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2109 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType from_vect_bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    assert(type2aelembytes(from_vect_bt) == (int)opnd_array(3)->constant(), "unsupported type.");
    Assembler::SIMD_RegVariant size = __ elemBytes_to_regVariant(opnd_array(3)->constant());
    __ sve_cpy(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), size, as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), 1, false);
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), true, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */),
                          ptrue, T_BOOLEAN, from_vect_bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 42845 "ad_aarch64.cpp"
  }
}

void storeV_vstoremask_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// esize
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2131 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // Convert the valid src predicate to vector, and store the vector
    // elements as boolean values.
    BasicType from_vect_bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(from_vect_bt);
    __ sve_cpy(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), size, as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), 1, false);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), size, Matcher::vector_length(this, opnd_array(2)));
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), true, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */),
                          as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), T_BOOLEAN, from_vect_bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 42873 "ad_aarch64.cpp"
  }
}

void reduce_addINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2154 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 42895 "ad_aarch64.cpp"
  }
}

void reduce_addLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2170 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 42916 "ad_aarch64.cpp"
  }
}

void reduce_addFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1_dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2184 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadda(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1_dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42934 "ad_aarch64.cpp"
  }
}

void reduce_addDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1_dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2197 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadda(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1_dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42952 "ad_aarch64.cpp"
  }
}

void reduce_addI_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2212 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant variant = __ elemType_to_regVariant(bt);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), variant,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 42978 "ad_aarch64.cpp"
  }
}

void reduce_addL_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2232 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 43002 "ad_aarch64.cpp"
  }
}

void reduce_addF_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1_dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2249 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), __ S,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_fadda(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1_dst */), __ S,
                 as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 43023 "ad_aarch64.cpp"
  }
}

void reduce_addD_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1_dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2265 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_fadda(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1_dst */), __ D,
                 as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 43044 "ad_aarch64.cpp"
  }
}

void reduce_addI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2283 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 43067 "ad_aarch64.cpp"
  }
}

void reduce_addL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2299 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 43089 "ad_aarch64.cpp"
  }
}

void reduce_addF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1_dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2313 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadda(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1_dst */), __ S,
                 as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 43108 "ad_aarch64.cpp"
  }
}

void reduce_addD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1_dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2326 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadda(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1_dst */), __ D,
                 as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 43127 "ad_aarch64.cpp"
  }
}

void reduce_addI_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2341 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant variant = __ elemType_to_regVariant(bt);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), variant,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp */));
  
#line 43156 "ad_aarch64.cpp"
  }
}

void reduce_addL_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2363 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp */));
  
#line 43183 "ad_aarch64.cpp"
  }
}

void reduce_addF_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1_dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2382 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), __ S,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_fadda(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1_dst */), __ S,
                 as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 43207 "ad_aarch64.cpp"
  }
}

void reduce_addD_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1_dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2400 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_fadda(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1_dst */), __ D,
                 as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 43231 "ad_aarch64.cpp"
  }
}

void reduce_andINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2421 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 43253 "ad_aarch64.cpp"
  }
}

void reduce_andLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2438 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 43274 "ad_aarch64.cpp"
  }
}

void reduce_andI_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2455 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant variant = __ elemType_to_regVariant(bt);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), variant,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 43300 "ad_aarch64.cpp"
  }
}

void reduce_andL_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2476 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 43324 "ad_aarch64.cpp"
  }
}

void reduce_andI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2496 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 43347 "ad_aarch64.cpp"
  }
}

void reduce_andL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2513 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 43369 "ad_aarch64.cpp"
  }
}

void reduce_andI_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2530 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant variant = __ elemType_to_regVariant(bt);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), variant,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp */));
  
#line 43398 "ad_aarch64.cpp"
  }
}

void reduce_andL_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2553 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp */));
  
#line 43425 "ad_aarch64.cpp"
  }
}

void reduce_orINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2575 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 43447 "ad_aarch64.cpp"
  }
}

void reduce_orLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2592 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 43468 "ad_aarch64.cpp"
  }
}

void reduce_orI_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2609 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant variant = __ elemType_to_regVariant(bt);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), variant,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 43494 "ad_aarch64.cpp"
  }
}

void reduce_orL_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2630 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 43518 "ad_aarch64.cpp"
  }
}

void reduce_orI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2650 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 43541 "ad_aarch64.cpp"
  }
}

void reduce_orL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2667 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 43563 "ad_aarch64.cpp"
  }
}

void reduce_orI_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2684 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant variant = __ elemType_to_regVariant(bt);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), variant,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp */));
  
#line 43592 "ad_aarch64.cpp"
  }
}

void reduce_orL_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2707 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp */));
  
#line 43619 "ad_aarch64.cpp"
  }
}

void reduce_eorINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2729 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 43641 "ad_aarch64.cpp"
  }
}

void reduce_eorLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2746 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 43662 "ad_aarch64.cpp"
  }
}

void reduce_eorI_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2763 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant variant = __ elemType_to_regVariant(bt);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), variant,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 43688 "ad_aarch64.cpp"
  }
}

void reduce_eorL_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2784 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 43712 "ad_aarch64.cpp"
  }
}

void reduce_eorI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2804 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 43735 "ad_aarch64.cpp"
  }
}

void reduce_eorL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2821 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 43757 "ad_aarch64.cpp"
  }
}

void reduce_eorI_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2838 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant variant = __ elemType_to_regVariant(bt);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), variant,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp */));
  
#line 43786 "ad_aarch64.cpp"
  }
}

void reduce_eorL_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2861 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp */));
  
#line 43813 "ad_aarch64.cpp"
  }
}

void reduce_maxINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2884 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 43835 "ad_aarch64.cpp"
  }
}

void reduce_maxLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2901 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 43856 "ad_aarch64.cpp"
  }
}

void reduce_maxI_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2919 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant variant = __ elemType_to_regVariant(bt);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), variant,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 43882 "ad_aarch64.cpp"
  }
}

void reduce_maxL_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2940 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 43906 "ad_aarch64.cpp"
  }
}

void reduce_maxFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2958 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmaxv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmaxs(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 43925 "ad_aarch64.cpp"
  }
}

void reduce_maxF_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2974 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), __ S,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_fmaxv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ S, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmaxs(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 43947 "ad_aarch64.cpp"
  }
}

void reduce_maxDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2991 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmaxv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ D, ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmaxd(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 43966 "ad_aarch64.cpp"
  }
}

void reduce_maxD_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3007 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_fmaxv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ D, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmaxd(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 43988 "ad_aarch64.cpp"
  }
}

void reduce_maxI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3028 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 44011 "ad_aarch64.cpp"
  }
}

void reduce_maxL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3046 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 44033 "ad_aarch64.cpp"
  }
}

void reduce_maxI_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3064 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant variant = __ elemType_to_regVariant(bt);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), variant,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp */));
  
#line 44062 "ad_aarch64.cpp"
  }
}

void reduce_maxL_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3087 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp */));
  
#line 44089 "ad_aarch64.cpp"
  }
}

void reduce_maxF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3107 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmaxs(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 44109 "ad_aarch64.cpp"
  }
}

void reduce_maxD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3122 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ D, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmaxd(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 44129 "ad_aarch64.cpp"
  }
}

void reduce_maxF_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3138 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ S,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_fmaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S,
               as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmaxs(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 44155 "ad_aarch64.cpp"
  }
}

void reduce_maxD_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3159 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_fmaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ D,
               as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmaxd(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 44181 "ad_aarch64.cpp"
  }
}

void reduce_minINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3182 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 44203 "ad_aarch64.cpp"
  }
}

void reduce_minLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3199 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 44224 "ad_aarch64.cpp"
  }
}

void reduce_minI_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3217 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant variant = __ elemType_to_regVariant(bt);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), variant,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 44250 "ad_aarch64.cpp"
  }
}

void reduce_minL_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3238 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 44274 "ad_aarch64.cpp"
  }
}

void reduce_minFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3256 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmins(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 44293 "ad_aarch64.cpp"
  }
}

void reduce_minF_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3272 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), __ S,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_fminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ S, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmins(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 44315 "ad_aarch64.cpp"
  }
}

void reduce_minDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3289 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ D, ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmind(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 44334 "ad_aarch64.cpp"
  }
}

void reduce_minD_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3305 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_fminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ D, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmind(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 44356 "ad_aarch64.cpp"
  }
}

void reduce_minI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3326 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 44379 "ad_aarch64.cpp"
  }
}

void reduce_minL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3344 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 44401 "ad_aarch64.cpp"
  }
}

void reduce_minI_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3362 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant variant = __ elemType_to_regVariant(bt);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), variant,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp */));
  
#line 44430 "ad_aarch64.cpp"
  }
}

void reduce_minL_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3385 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp */));
  
#line 44457 "ad_aarch64.cpp"
  }
}

void reduce_minF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3405 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 44477 "ad_aarch64.cpp"
  }
}

void reduce_minD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3420 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ D, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmind(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 44497 "ad_aarch64.cpp"
  }
}

void reduce_minF_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3436 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ S,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_fminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S,
               as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 44523 "ad_aarch64.cpp"
  }
}

void reduce_minD_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3457 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_fminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ D,
               as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmind(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 44549 "ad_aarch64.cpp"
  }
}

void vroundDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rmode
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3476 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    switch (opnd_array(2)->constant()) {
      case RoundDoubleModeNode::rmode_rint:
        __ sve_frintn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
             ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_floor:
        __ sve_frintm(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
             ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_ceil:
        __ sve_frintp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
             ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
    }
  
#line 44579 "ad_aarch64.cpp"
  }
}

void replicateBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3502 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 44595 "ad_aarch64.cpp"
  }
}

void replicateSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3513 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 44611 "ad_aarch64.cpp"
  }
}

void replicateINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3524 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 44627 "ad_aarch64.cpp"
  }
}

void replicateLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3535 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 44643 "ad_aarch64.cpp"
  }
}

void replicateB_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3546 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, opnd_array(1)->constant());
  
#line 44659 "ad_aarch64.cpp"
  }
}

void replicateS_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3557 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H, opnd_array(1)->constant());
  
#line 44675 "ad_aarch64.cpp"
  }
}

void replicateI_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3568 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, opnd_array(1)->constant());
  
#line 44691 "ad_aarch64.cpp"
  }
}

void replicateL_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3579 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, opnd_array(1)->constantL());
  
#line 44707 "ad_aarch64.cpp"
  }
}

void replicateFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3590 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_cpy(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 44724 "ad_aarch64.cpp"
  }
}

void replicateDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3602 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_cpy(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 44741 "ad_aarch64.cpp"
  }
}

void vasrBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3616 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ B,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 44759 "ad_aarch64.cpp"
  }
}

void vasrSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3628 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ H,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 44777 "ad_aarch64.cpp"
  }
}

void vasrINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3640 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 44795 "ad_aarch64.cpp"
  }
}

void vasrLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3652 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 44813 "ad_aarch64.cpp"
  }
}

void vlslBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3664 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ B,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 44831 "ad_aarch64.cpp"
  }
}

void vlslSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3676 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ H,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 44849 "ad_aarch64.cpp"
  }
}

void vlslINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3688 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 44867 "ad_aarch64.cpp"
  }
}

void vlslLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3700 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 44885 "ad_aarch64.cpp"
  }
}

void vlsrBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3712 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ B,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 44903 "ad_aarch64.cpp"
  }
}

void vlsrSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3724 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ H,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 44921 "ad_aarch64.cpp"
  }
}

void vlsrINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3736 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 44939 "ad_aarch64.cpp"
  }
}

void vlsrLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3748 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 44957 "ad_aarch64.cpp"
  }
}

void vasrB_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3760 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    if (con >= 8) con = 7;
    __ sve_asr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 44982 "ad_aarch64.cpp"
  }
}

void vasrS_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3779 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    if (con >= 16) con = 15;
    __ sve_asr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 45007 "ad_aarch64.cpp"
  }
}

void vasrI_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3798 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_asr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 45031 "ad_aarch64.cpp"
  }
}

void vasrL_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3816 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_asr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 45055 "ad_aarch64.cpp"
  }
}

void vlsrB_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3834 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    if (con >= 8) {
      __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 45084 "ad_aarch64.cpp"
  }
}

void vlsrS_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3857 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    if (con >= 16) {
      __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 45113 "ad_aarch64.cpp"
  }
}

void vlsrI_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3880 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 45137 "ad_aarch64.cpp"
  }
}

void vlsrL_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3898 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 45161 "ad_aarch64.cpp"
  }
}

void vlslB_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3916 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con >= 8) {
      __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 45185 "ad_aarch64.cpp"
  }
}

void vlslS_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3934 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con >= 16) {
      __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 45209 "ad_aarch64.cpp"
  }
}

void vlslI_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3952 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    __ sve_lsl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 45228 "ad_aarch64.cpp"
  }
}

void vlslL_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3965 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    __ sve_lsl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 45247 "ad_aarch64.cpp"
  }
}

void vshiftcntBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3979 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 45263 "ad_aarch64.cpp"
  }
}

void vshiftcntB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3979 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 45279 "ad_aarch64.cpp"
  }
}

void vshiftcntSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3992 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 45295 "ad_aarch64.cpp"
  }
}

void vshiftcntS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3992 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 45311 "ad_aarch64.cpp"
  }
}

void vshiftcntINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4004 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 45327 "ad_aarch64.cpp"
  }
}

void vshiftcntI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4004 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 45343 "ad_aarch64.cpp"
  }
}

void vshiftcntLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4016 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 45359 "ad_aarch64.cpp"
  }
}

void vshiftcntL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4016 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 45375 "ad_aarch64.cpp"
  }
}

void vasrB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4029 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 45395 "ad_aarch64.cpp"
  }
}

void vasrS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4042 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 45415 "ad_aarch64.cpp"
  }
}

void vasrI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4055 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 45435 "ad_aarch64.cpp"
  }
}

void vasrL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4068 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 45455 "ad_aarch64.cpp"
  }
}

void vlslB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4081 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 45475 "ad_aarch64.cpp"
  }
}

void vlslS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4094 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 45495 "ad_aarch64.cpp"
  }
}

void vlslI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4107 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 45515 "ad_aarch64.cpp"
  }
}

void vlslL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4120 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 45535 "ad_aarch64.cpp"
  }
}

void vlsrB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4133 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 45555 "ad_aarch64.cpp"
  }
}

void vlsrS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4146 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 45575 "ad_aarch64.cpp"
  }
}

void vlsrI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4159 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 45595 "ad_aarch64.cpp"
  }
}

void vlsrL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4172 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 45615 "ad_aarch64.cpp"
  }
}

void vasrB_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4185 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < 8, "invalid shift immediate");
    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ B, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 45635 "ad_aarch64.cpp"
  }
}

void vasrS_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4198 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < 16, "invalid shift immediate");
    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ H, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 45655 "ad_aarch64.cpp"
  }
}

void vasrI_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4211 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < 32, "invalid shift immediate");
    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 45675 "ad_aarch64.cpp"
  }
}

void vasrL_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4224 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < 64, "invalid shift immediate");
    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 45695 "ad_aarch64.cpp"
  }
}

void vlsrB_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4237 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < 8, "invalid shift immediate");
    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ B, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 45715 "ad_aarch64.cpp"
  }
}

void vlsrS_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4250 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < 16, "invalid shift immediate");
    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ H, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 45735 "ad_aarch64.cpp"
  }
}

void vlsrI_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4263 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < 32, "invalid shift immediate");
    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 45755 "ad_aarch64.cpp"
  }
}

void vlsrL_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4276 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < 64, "invalid shift immediate");
    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 45775 "ad_aarch64.cpp"
  }
}

void vlslB_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4289 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con >= 0 && con < 8, "invalid shift immediate");
    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ B, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 45795 "ad_aarch64.cpp"
  }
}

void vlslS_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4302 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con >= 0 && con < 16, "invalid shift immediate");
    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ H, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 45815 "ad_aarch64.cpp"
  }
}

void vlslI_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4315 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con >= 0 && con < 32, "invalid shift immediate");
    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 45835 "ad_aarch64.cpp"
  }
}

void vlslL_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4328 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con >= 0 && con < 64, "invalid shift immediate");
    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 45855 "ad_aarch64.cpp"
  }
}

void vsqrtFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4344 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 45872 "ad_aarch64.cpp"
  }
}

void vsqrtDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4357 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 45889 "ad_aarch64.cpp"
  }
}

void vsqrtF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4371 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsqrt(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 45908 "ad_aarch64.cpp"
  }
}

void vsqrtD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4384 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsqrt(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 45927 "ad_aarch64.cpp"
  }
}

void vsubBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4399 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 45946 "ad_aarch64.cpp"
  }
}

void vsubSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4412 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 45965 "ad_aarch64.cpp"
  }
}

void vsubINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4425 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 45984 "ad_aarch64.cpp"
  }
}

void vsubLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4438 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46003 "ad_aarch64.cpp"
  }
}

void vsubFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4451 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46022 "ad_aarch64.cpp"
  }
}

void vsubDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4464 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46041 "ad_aarch64.cpp"
  }
}

void vsubB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4479 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46061 "ad_aarch64.cpp"
  }
}

void vsubS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4492 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46081 "ad_aarch64.cpp"
  }
}

void vsubI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4505 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46101 "ad_aarch64.cpp"
  }
}

void vsubL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4518 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46121 "ad_aarch64.cpp"
  }
}

void vsubF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4531 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46141 "ad_aarch64.cpp"
  }
}

void vsubD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4544 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46161 "ad_aarch64.cpp"
  }
}

void vmaskcastNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4561 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // empty
  
#line 46177 "ad_aarch64.cpp"
  }
}

void vmaskcast_extendNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4576 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_vmaskcast_extend(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                            Matcher::vector_length_in_bytes(this), Matcher::vector_length_in_bytes(this, opnd_array(1)));
  
#line 46194 "ad_aarch64.cpp"
  }
}

void vmaskcast_narrowNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4592 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_vmaskcast_narrow(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                            Matcher::vector_length_in_bytes(this), Matcher::vector_length_in_bytes(this, opnd_array(1)));
  
#line 46211 "ad_aarch64.cpp"
  }
}

void vcvtBtoX_extendNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4607 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType to_bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant to_size = __ elemType_to_regVariant(to_bt);
    __ sve_vector_extend(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), to_size, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ B);
    if (to_bt == T_FLOAT || to_bt == T_DOUBLE) {
      __ sve_scvtf(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), to_size, ptrue, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), to_size);
    }
  
#line 46232 "ad_aarch64.cpp"
  }
}

void vcvtStoBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4626 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_vector_narrow(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
                         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */));
  
#line 46250 "ad_aarch64.cpp"
  }
}

void vcvtStoX_extendNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4640 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType to_bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant to_size = __ elemType_to_regVariant(to_bt);
    __ sve_vector_extend(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), to_size, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ H);
    if (to_bt == T_FLOAT || to_bt == T_DOUBLE) {
      __ sve_scvtf(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), to_size, ptrue, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), to_size);
    }
  
#line 46271 "ad_aarch64.cpp"
  }
}

void vcvtItoBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4659 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_vector_narrow(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ B,
                         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 46290 "ad_aarch64.cpp"
  }
}

void vcvtItoSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4674 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_vector_narrow(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
                         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */));
  
#line 46308 "ad_aarch64.cpp"
  }
}

void vcvtItoLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4688 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_vector_extend(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S);
  
#line 46324 "ad_aarch64.cpp"
  }
}

void vcvtItoFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4701 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_scvtf(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S);
  
#line 46340 "ad_aarch64.cpp"
  }
}

void vcvtItoDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4714 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sunpklo(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sve_scvtf(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, ptrue, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D);
  
#line 46357 "ad_aarch64.cpp"
  }
}

void vcvtLtoX_narrowNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4728 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType to_bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant to_size = __ elemType_to_regVariant(to_bt);
    __ sve_vector_narrow(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), to_size,
                         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 46378 "ad_aarch64.cpp"
  }
}

void vcvtLtoFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4745 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_scvtf(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D);
    __ sve_vector_narrow(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ S,
                         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ D, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));

  
#line 46399 "ad_aarch64.cpp"
  }
}

void vcvtLtoDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4761 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_scvtf(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D);
  
#line 46415 "ad_aarch64.cpp"
  }
}

void vcvtFtoX_narrowNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4776 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType to_bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant to_size = __ elemType_to_regVariant(to_bt);
    __ sve_fcvtzs(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S);
    __ sve_vector_narrow(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), to_size,
                         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ S, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 46437 "ad_aarch64.cpp"
  }
}

void vcvtFtoINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4793 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fcvtzs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S);
  
#line 46453 "ad_aarch64.cpp"
  }
}

void vcvtFtoLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4806 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sunpklo(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sve_fcvtzs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, ptrue, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S);
  
#line 46470 "ad_aarch64.cpp"
  }
}

void vcvtFtoDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4820 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_vector_extend(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S);
    __ sve_fcvt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, ptrue, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S);
  
#line 46487 "ad_aarch64.cpp"
  }
}

void vcvtDtoX_narrowNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4837 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType to_bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant to_size = __ elemType_to_regVariant(to_bt);
    __ sve_fcvtzs(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D);
    __ sve_vector_narrow(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), to_size,
                         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ D, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 46509 "ad_aarch64.cpp"
  }
}

void vcvtDtoLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4854 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fcvtzs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D);
  
#line 46525 "ad_aarch64.cpp"
  }
}

void vcvtDtoFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4868 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fcvt(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D);
    __ sve_vector_narrow(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ S,
                         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ D, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 46545 "ad_aarch64.cpp"
  }
}

void extractBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4886 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_extract(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), __ B, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pgtmp */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), (int)(opnd_array(2)->constant()));
    __ sbfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */), 0U, 7U);
  
#line 46565 "ad_aarch64.cpp"
  }
}

void extractSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4902 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_extract(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), __ H, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pgtmp */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), (int)(opnd_array(2)->constant()));
    __ sbfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */), 0U, 15U);
  
#line 46585 "ad_aarch64.cpp"
  }
}

void extractINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4918 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_extract(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pgtmp */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), (int)(opnd_array(2)->constant()));
  
#line 46604 "ad_aarch64.cpp"
  }
}

void extractLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4932 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_extract(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pgtmp */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), (int)(opnd_array(2)->constant()));
  
#line 46623 "ad_aarch64.cpp"
  }
}

void extractFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4946 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_extract(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pgtmp */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), (int)(opnd_array(2)->constant()));
  
#line 46642 "ad_aarch64.cpp"
  }
}

void extractDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4960 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_extract(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pgtmp */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), (int)(opnd_array(2)->constant()));
  
#line 46661 "ad_aarch64.cpp"
  }
}

void vtest_alltrueNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4979 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eors(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), ptrue,
                as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ csetw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::EQ);
  
#line 46681 "ad_aarch64.cpp"
  }
}

void vtest_anytrueNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4997 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // "src2" is not used for sve.
    __ sve_ptest(ptrue, as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
    __ csetw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::NE);
  
#line 46700 "ad_aarch64.cpp"
  }
}

void vtest_alltrue_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5014 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), size,
                          Matcher::vector_length(this, opnd_array(1)));
    __ sve_eors(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */),
          as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ csetw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::EQ);
  
#line 46724 "ad_aarch64.cpp"
  }
}

void vtest_anytrue_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5035 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), size,
                          Matcher::vector_length(this, opnd_array(1)));
    __ sve_ands(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */),
          as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ csetw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::NE);
  
#line 46748 "ad_aarch64.cpp"
  }
}

void insertI_smallNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5062 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_index(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), size, -16, 1);
    __ sve_cmp(Assembler::EQ, as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* pgtmp */), size, ptrue,
               as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), (int)(opnd_array(3)->constant()) - 16);
    __ sve_orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sve_cpy(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), size, as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* pgtmp */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* val */));
  
#line 46774 "ad_aarch64.cpp"
  }
}

void insertF_smallNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5085 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_index(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S, -16, 1);
    __ sve_cmp(Assembler::EQ, as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* pgtmp */), __ S, ptrue,
               as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), (int)(opnd_array(3)->constant()) - 16);
    __ sve_orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sve_cpy(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S, as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* pgtmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* val */));
  
#line 46798 "ad_aarch64.cpp"
  }
}

void insertINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5109 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_index(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */), size, 0, 1);
    __ sve_dup(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), size, (int)(opnd_array(3)->constant()));
    __ sve_cmp(Assembler::EQ, as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* pgtmp */), size, ptrue,
               as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */));
    __ sve_orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sve_cpy(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), size, as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* pgtmp */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* val */));
  
#line 46826 "ad_aarch64.cpp"
  }
}

void insertLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5133 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_index(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ D, -16, 1);
    __ sve_cmp(Assembler::EQ, as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* pgtmp */), __ D, ptrue,
               as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), (int)(opnd_array(3)->constant()) - 16);
    __ sve_orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sve_cpy(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ D, as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* pgtmp */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* val */));
  
#line 46850 "ad_aarch64.cpp"
  }
}

void insertDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5154 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_index(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ D, -16, 1);
    __ sve_cmp(Assembler::EQ, as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* pgtmp */), __ D, ptrue,
               as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), (int)(opnd_array(3)->constant()) - 16);
    __ sve_orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sve_cpy(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ D, as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* pgtmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* val */));
  
#line 46874 "ad_aarch64.cpp"
  }
}

void insertFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5176 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_index(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */), __ S, 0, 1);
    __ sve_dup(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S, (int)(opnd_array(3)->constant()));
    __ sve_cmp(Assembler::EQ, as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* pgtmp */), __ S, ptrue,
               as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */));
    __ sve_orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sve_cpy(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S,
               as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* pgtmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* val */));
  
#line 46903 "ad_aarch64.cpp"
  }
}

void loadshuffleNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5197 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    if (bt == T_BYTE) {
      if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
        __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      }
    } else {
      __ sve_vector_extend(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),  __ elemType_to_regVariant(bt),
                           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ B);
    }
  
#line 46928 "ad_aarch64.cpp"
  }
}

void rearrangeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5220 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_tbl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), size,
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shuffle */));
  
#line 46948 "ad_aarch64.cpp"
  }
}

void gatherINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5239 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ld1w_gather(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), ptrue,
                       as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */));
  
#line 46966 "ad_aarch64.cpp"
  }
}

void gatherLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5254 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_uunpklo(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */), __ D, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */));
    __ sve_ld1d_gather(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), ptrue, as_Register(opnd_array(1)->base(ra_,this,idx1)),
                       as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */));
  
#line 46985 "ad_aarch64.cpp"
  }
}

void gatherI_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5273 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), __ S, Matcher::vector_length(this));
    __ sve_ld1w_gather(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */),
                       as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */));
  
#line 47005 "ad_aarch64.cpp"
  }
}

void gatherL_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5290 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), __ D,
                          Matcher::vector_length(this));
    __ sve_uunpklo(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */), __ D, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */));
    __ sve_ld1d_gather(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */),
                       as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */));
  
#line 47027 "ad_aarch64.cpp"
  }
}

void gatherI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5310 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ld1w_gather(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
                       as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */));
  
#line 47046 "ad_aarch64.cpp"
  }
}

void gatherL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5325 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_uunpklo(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */), __ D, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */));
    __ sve_ld1d_gather(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
                       as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */));
  
#line 47066 "ad_aarch64.cpp"
  }
}

void gatherI_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5344 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), __ S,
                          Matcher::vector_length(this));
    __ sve_and(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_ld1w_gather(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */),
                       as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */));
  
#line 47090 "ad_aarch64.cpp"
  }
}

void gatherL_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5364 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), __ D, Matcher::vector_length(this));
    __ sve_and(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */));
    __ sve_uunpklo(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */), __ D, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */));
    __ sve_ld1d_gather(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */),
                       as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */));
  
#line 47114 "ad_aarch64.cpp"
  }
}

void scatterINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5385 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_st1w_scatter(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), ptrue,
                        as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */));
  
#line 47133 "ad_aarch64.cpp"
  }
}

void scatterLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5400 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_uunpklo(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */), __ D, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */));
    __ sve_st1d_scatter(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), ptrue,
                        as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */));
  
#line 47153 "ad_aarch64.cpp"
  }
}

void scatterI_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5419 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), __ S,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_st1w_scatter(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */),
                        as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */));
  
#line 47175 "ad_aarch64.cpp"
  }
}

void scatterL_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5437 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_uunpklo(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */), __ D, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */));
    __ sve_st1d_scatter(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */),
                        as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */));
  
#line 47198 "ad_aarch64.cpp"
  }
}

void scatterI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5457 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_st1w_scatter(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
                        as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */));
  
#line 47218 "ad_aarch64.cpp"
  }
}

void scatterL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5472 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_uunpklo(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */), __ D, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */));
    __ sve_st1d_scatter(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
                        as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */));
  
#line 47239 "ad_aarch64.cpp"
  }
}

void scatterI_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5491 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ S,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */),
               as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */), as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */));
    __ sve_st1w_scatter(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */),
                        as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */));
  
#line 47264 "ad_aarch64.cpp"
  }
}

void scatterL_masked_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5511 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ D,
                          Matcher::vector_length(this, opnd_array(2)));
    __ sve_and(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */),
               as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */), as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */));
    __ sve_uunpklo(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */), __ D, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */));
    __ sve_st1d_scatter(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */),
                        as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */));
  
#line 47290 "ad_aarch64.cpp"
  }
}

void loadconBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5531 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_index(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, 0, 1);
  
#line 47306 "ad_aarch64.cpp"
  }
}

void stringL_indexof_char_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ch
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ztmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ztmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// pgtmp
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5550 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ string_indexof_char_sve(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* ch */, opnd_array(0)->as_Register(ra_,this)/* result */,
                               as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* ztmp1 */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* ztmp2 */),
                               as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* pgtmp */), as_PRegister(opnd_array(7)->reg(ra_,this,idx7)/* ptmp */), true /* isL */);
  
#line 47330 "ad_aarch64.cpp"
  }
}

void stringU_indexof_char_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ch
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ztmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ztmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// pgtmp
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5568 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ string_indexof_char_sve(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* ch */, opnd_array(0)->as_Register(ra_,this)/* result */,
                               as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* ztmp1 */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* ztmp2 */),
                               as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* pgtmp */), as_PRegister(opnd_array(7)->reg(ra_,this,idx7)/* ptmp */), false /* isL */);
  
#line 47354 "ad_aarch64.cpp"
  }
}

void vmask_truecountNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5583 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_cntp(opnd_array(0)->as_Register(ra_,this)/* dst */, size, ptrue, as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 47372 "ad_aarch64.cpp"
  }
}

void vmask_firsttrueNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5598 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_brkb(as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp */), ptrue, as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), false);
    __ sve_cntp(opnd_array(0)->as_Register(ra_,this)/* dst */, size, ptrue, as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp */));
  
#line 47392 "ad_aarch64.cpp"
  }
}

void vmask_lasttrueNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5614 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    __ sve_vmask_lasttrue(opnd_array(0)->as_Register(ra_,this)/* dst */, bt, as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp */));
  
#line 47410 "ad_aarch64.cpp"
  }
}

void vmask_truecount_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5628 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp */), size, Matcher::vector_length(this, opnd_array(1)));
    __ sve_cntp(opnd_array(0)->as_Register(ra_,this)/* dst */, size, as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp */), as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 47430 "ad_aarch64.cpp"
  }
}

void vmask_firsttrue_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ptmp1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ptmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5644 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp1 */), size,
                          Matcher::vector_length(this, opnd_array(1)));
    __ sve_brkb(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp2 */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp1 */), as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), false);
    __ sve_cntp(opnd_array(0)->as_Register(ra_,this)/* dst */, size, as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp1 */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp2 */));
  
#line 47453 "ad_aarch64.cpp"
  }
}

void vmask_lasttrue_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5662 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_whilelo_zr_imm(as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp */), size, Matcher::vector_length(this, opnd_array(1)));
    __ sve_and(as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp */), ptrue, as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp */), as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sve_vmask_lasttrue(opnd_array(0)->as_Register(ra_,this)/* dst */, bt, as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp */));
  
#line 47474 "ad_aarch64.cpp"
  }
}

void vmask_tolongNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vtmp1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// vtmp2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5679 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_vmask_tolong(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                        Matcher::vector_element_basic_type(this, opnd_array(1)),
                        Matcher::vector_length(this, opnd_array(1)),
                        as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vtmp1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp2 */),
                        as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pgtmp */));
  
#line 47497 "ad_aarch64.cpp"
  }
}

void vmask_genNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// len
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5695 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_whilelo(as_PRegister(opnd_array(0)->reg(ra_,this)/* pg */), size, zr, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* len */));
  
#line 47515 "ad_aarch64.cpp"
  }
}

void compareAndSwapP_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {

#line 31 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 47538 "ad_aarch64.cpp"
  }
}

void compareAndSwapN_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 77 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, /*acquire*/ false, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 47559 "ad_aarch64.cpp"
  }
}

void compareAndSwapPAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {

#line 40 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 47582 "ad_aarch64.cpp"
  }
}

void compareAndSwapNAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 115 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, /*acquire*/ true, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 47603 "ad_aarch64.cpp"
  }
}

void compareAndExchangeN_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 131 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ true, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 47626 "ad_aarch64.cpp"
  }
}

void compareAndExchangeP_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 147 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ true, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 47649 "ad_aarch64.cpp"
  }
}

void compareAndExchangeNAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 164 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ true, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 47672 "ad_aarch64.cpp"
  }
}

void compareAndExchangePAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 181 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ true, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 47695 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapN_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 198 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    // Weak is not currently supported by ShenandoahBarrierSet::cmpxchg_oop
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 47718 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapP_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 215 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    // Weak is not currently supported by ShenandoahBarrierSet::cmpxchg_oop
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 47741 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapNAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 234 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    // Weak is not currently supported by ShenandoahBarrierSet::cmpxchg_oop
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 47764 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapPAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 253 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    // Weak is not currently supported by ShenandoahBarrierSet::cmpxchg_oop
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 47787 "ad_aarch64.cpp"
  }
}

void zLoadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 64 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    const Address ref_addr = mem2address(opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
    __ ldr(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, ref_addr);
    z_load_barrier(_masm, this, ref_addr, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, rscratch2 /* tmp */, barrier_data());
  
#line 47806 "ad_aarch64.cpp"
  }
}

void zLoadPVolatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 84 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    __ ldar(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */);
    z_load_barrier(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, rscratch2 /* tmp */, barrier_data());
  
#line 47824 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 103 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               false /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 false /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 47857 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapP_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 103 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               false /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 false /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 47890 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 135 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               true /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */ );
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 true /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 47923 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapPAcq_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 135 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               true /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */ );
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 true /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 47956 "ad_aarch64.cpp"
  }
}

void zCompareAndExchangePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 165 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               false /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), opnd_array(4)->as_Register(ra_,this,idx4)/* res */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 false /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ bind(good);
    }
  
#line 47987 "ad_aarch64.cpp"
  }
}

void zCompareAndExchangePAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 193 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               true /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), opnd_array(4)->as_Register(ra_,this,idx4)/* res */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 true /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ bind(good);
    }
  
#line 48018 "ad_aarch64.cpp"
  }
}

void zGetAndSetPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// prev
  {
    C2_MacroAssembler _masm(&cbuf);

#line 221 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    __ atomic_xchg(opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */);
    z_load_barrier(_masm, this, Address(noreg, 0), opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, rscratch2 /* tmp */, barrier_data());
  
#line 48037 "ad_aarch64.cpp"
  }
}

void zGetAndSetPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// prev
  {
    C2_MacroAssembler _masm(&cbuf);

#line 238 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    __ atomic_xchgal(opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */);
    z_load_barrier(_masm, this, Address(noreg, 0), opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, rscratch2 /* tmp */, barrier_data());
  
#line 48056 "ad_aarch64.cpp"
  }
}

const MachOper* loadBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadINode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadLNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadRangeNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadNNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadNKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadFNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadDNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmCM0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmCM0_orderedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeBNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmB0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeCNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmC0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeINode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmI0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeLNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmL0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storePNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmP0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeNNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmN0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeFNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeDNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeNKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchallocNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUI2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadL_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadP_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadN_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadF_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadD_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeB_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeC_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeI_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeL_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeP_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeN_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeF_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeD_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* cacheWBNode::memory_operand() const { return _opnds[1]; }
const MachOper* popCountI_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* popCountL_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPLockedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storePConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeLConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeIConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapBNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapSNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapINode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapLNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapPNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapNNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapBAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapSAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeBNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeSNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeINode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeLNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeNNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangePNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeBAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeSAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangePAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapBNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapSNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapINode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapLNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapNNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapPNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapBAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapSAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setINode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setLNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setNNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setPNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addL_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLiNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLi_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addINode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addI_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIiNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIi_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addL_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLiAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLi_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addI_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIiAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIi_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV2Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV4Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV16Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV2Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV4Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV16Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadVNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeVNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV2_vregNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV2_vregNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV4_vregNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV4_vregNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV8_vregNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV8_vregNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV16_vregNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV16_vregNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV_masked_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV_masked_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* vloadmask_loadVNode::memory_operand() const { return _opnds[1]; }
const MachOper* vloadmask_loadV_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV_vstoremaskNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV_vstoremask_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* gatherINode::memory_operand() const { return _opnds[1]; }
const MachOper* gatherLNode::memory_operand() const { return _opnds[1]; }
const MachOper* gatherI_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* gatherL_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* gatherI_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* gatherL_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* gatherI_masked_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* gatherL_masked_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* scatterINode::memory_operand() const { return _opnds[1]; }
const MachOper* scatterLNode::memory_operand() const { return _opnds[1]; }
const MachOper* scatterI_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* scatterL_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* scatterI_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* scatterL_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* scatterI_masked_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* scatterL_masked_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapP_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapN_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapPAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapNAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeN_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeP_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeNAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangePAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapN_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapP_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapNAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapPAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* zLoadPNode::memory_operand() const { return _opnds[1]; }
const MachOper* zLoadPVolatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapPNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapP_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapPAcq_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndExchangePNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndExchangePAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* zGetAndSetPNode::memory_operand() const { return _opnds[1]; }
const MachOper* zGetAndSetPAcqNode::memory_operand() const { return _opnds[1]; }


const bool Matcher::has_match_rule(int opcode) {
  assert(_last_machine_leaf < opcode && opcode < _last_opcode, "opcode in range");
  return _hasMatchRule[opcode];
}

const bool Matcher::_hasMatchRule[_last_opcode] = {
    false,  // Node
    false,  // Set
    false,  // RegN
    false,  // RegI
    false,  // RegP
    false,  // RegF
    false,  // RegD
    false,  // RegL
    false,  // VecA
    false,  // VecS
    false,  // VecD
    false,  // VecX
    false,  // VecY
    false,  // VecZ
    false,  // RegVectMask
    false,  // RegFlags
    false,  // _last_machine_leaf
    true ,  // AbsD
    true ,  // AbsF
    true ,  // AbsI
    true ,  // AbsL
    true ,  // AddD
    true ,  // AddF
    true ,  // AddI
    true ,  // AddL
    true ,  // AddP
    false,  // Allocate
    false,  // AllocateArray
    true ,  // AndI
    true ,  // AndL
    false,  // ArrayCopy
    true ,  // AryEq
    false,  // AtanD
    true ,  // Binary
    false,  // Blackhole
    true ,  // Bool
    false,  // BoxLock
    true ,  // ReverseBytesI
    true ,  // ReverseBytesL
    true ,  // ReverseBytesUS
    true ,  // ReverseBytesS
    false,  // CProj
    true ,  // CacheWB
    true ,  // CacheWBPreSync
    true ,  // CacheWBPostSync
    true ,  // CallDynamicJava
    false,  // CallJava
    true ,  // CallLeaf
    true ,  // CallLeafNoFP
    false,  // CallLeafVector
    true ,  // CallRuntime
    true ,  // CallNative
    true ,  // CallStaticJava
    true ,  // CastDD
    true ,  // CastFF
    true ,  // CastII
    true ,  // CastLL
    true ,  // CastVV
    true ,  // CastX2P
    true ,  // CastP2X
    true ,  // CastPP
    false,  // Catch
    false,  // CatchProj
    true ,  // CheckCastPP
    true ,  // ClearArray
    false,  // ConstraintCast
    true ,  // CMoveD
    false,  // CMoveVD
    true ,  // CMoveF
    false,  // CMoveVF
    true ,  // CMoveI
    true ,  // CMoveL
    true ,  // CMoveP
    true ,  // CMoveN
    true ,  // CmpN
    true ,  // CmpD
    true ,  // CmpD3
    true ,  // CmpF
    true ,  // CmpF3
    true ,  // CmpI
    true ,  // CmpL
    true ,  // CmpL3
    true ,  // CmpLTMask
    true ,  // CmpP
    true ,  // CmpU
    true ,  // CmpUL
    true ,  // CompareAndSwapB
    true ,  // CompareAndSwapS
    true ,  // CompareAndSwapI
    true ,  // CompareAndSwapL
    true ,  // CompareAndSwapP
    true ,  // CompareAndSwapN
    true ,  // WeakCompareAndSwapB
    true ,  // WeakCompareAndSwapS
    true ,  // WeakCompareAndSwapI
    true ,  // WeakCompareAndSwapL
    true ,  // WeakCompareAndSwapP
    true ,  // WeakCompareAndSwapN
    true ,  // CompareAndExchangeB
    true ,  // CompareAndExchangeS
    true ,  // CompareAndExchangeI
    true ,  // CompareAndExchangeL
    true ,  // CompareAndExchangeP
    true ,  // CompareAndExchangeN
    false,  // GetAndAddB
    false,  // GetAndAddS
    true ,  // GetAndAddI
    true ,  // GetAndAddL
    false,  // GetAndSetB
    false,  // GetAndSetS
    true ,  // GetAndSetI
    true ,  // GetAndSetL
    true ,  // GetAndSetP
    true ,  // GetAndSetN
    false,  // Con
    true ,  // ConN
    true ,  // ConNKlass
    true ,  // ConD
    true ,  // ConF
    true ,  // ConI
    true ,  // ConL
    true ,  // ConP
    true ,  // Conv2B
    true ,  // ConvD2F
    true ,  // ConvD2I
    true ,  // ConvD2L
    true ,  // ConvF2D
    true ,  // ConvF2I
    true ,  // ConvF2L
    true ,  // ConvI2D
    true ,  // ConvI2F
    true ,  // ConvI2L
    true ,  // ConvL2D
    true ,  // ConvL2F
    true ,  // ConvL2I
    false,  // CountedLoop
    true ,  // CountedLoopEnd
    false,  // OuterStripMinedLoop
    false,  // OuterStripMinedLoopEnd
    false,  // LongCountedLoop
    false,  // LongCountedLoopEnd
    true ,  // CountLeadingZerosI
    true ,  // CountLeadingZerosL
    true ,  // CountTrailingZerosI
    true ,  // CountTrailingZerosL
    true ,  // CreateEx
    true ,  // DecodeN
    true ,  // DecodeNKlass
    true ,  // DivD
    true ,  // DivF
    true ,  // DivI
    true ,  // DivL
    false,  // DivMod
    false,  // DivModI
    false,  // DivModL
    true ,  // EncodeISOArray
    true ,  // EncodeP
    true ,  // EncodePKlass
    true ,  // FastLock
    true ,  // FastUnlock
    true ,  // FmaD
    true ,  // FmaF
    true ,  // Goto
    true ,  // Halt
    true ,  // HasNegatives
    true ,  // If
    false,  // RangeCheck
    false,  // IfFalse
    false,  // IfTrue
    false,  // Initialize
    false,  // JProj
    false,  // Jump
    false,  // JumpProj
    true ,  // LShiftI
    true ,  // LShiftL
    true ,  // LoadB
    true ,  // LoadUB
    true ,  // LoadUS
    true ,  // LoadD
    false,  // LoadD_unaligned
    true ,  // LoadF
    true ,  // LoadI
    true ,  // LoadKlass
    true ,  // LoadNKlass
    true ,  // LoadL
    false,  // LoadL_unaligned
    true ,  // LoadPLocked
    true ,  // LoadP
    true ,  // LoadN
    true ,  // LoadRange
    true ,  // LoadS
    false,  // Lock
    false,  // Loop
    false,  // LoopLimit
    false,  // Mach
    false,  // MachNullCheck
    false,  // MachProj
    true ,  // MulAddS2I
    true ,  // MaxI
    false,  // MaxL
    true ,  // MaxD
    true ,  // MaxF
    true ,  // MemBarAcquire
    true ,  // LoadFence
    false,  // SetVectMaskI
    true ,  // MemBarAcquireLock
    false,  // MemBarCPUOrder
    true ,  // MemBarRelease
    true ,  // StoreFence
    true ,  // StoreStoreFence
    true ,  // MemBarReleaseLock
    true ,  // MemBarVolatile
    true ,  // MemBarStoreStore
    false,  // MergeMem
    true ,  // MinI
    false,  // MinL
    true ,  // MinF
    true ,  // MinD
    false,  // ModD
    false,  // ModF
    true ,  // ModI
    true ,  // ModL
    true ,  // MoveI2F
    true ,  // MoveF2I
    true ,  // MoveL2D
    true ,  // MoveD2L
    true ,  // MulD
    true ,  // MulF
    true ,  // MulHiL
    false,  // UMulHiL
    true ,  // MulI
    true ,  // MulL
    false,  // Multi
    false,  // NegI
    false,  // NegL
    true ,  // NegD
    true ,  // NegF
    false,  // NeverBranch
    true ,  // OnSpinWait
    false,  // Opaque1
    false,  // OpaqueLoopInit
    false,  // OpaqueLoopStride
    false,  // Opaque2
    false,  // Opaque3
    false,  // Opaque4
    false,  // ProfileBoolean
    true ,  // OrI
    true ,  // OrL
    true ,  // OverflowAddI
    true ,  // OverflowSubI
    true ,  // OverflowMulI
    true ,  // OverflowAddL
    true ,  // OverflowSubL
    true ,  // OverflowMulL
    false,  // PCTable
    false,  // Parm
    true ,  // PartialSubtypeCheck
    false,  // SubTypeCheck
    false,  // Phi
    true ,  // PopCountI
    true ,  // PopCountL
    true ,  // PopCountVI
    true ,  // PrefetchAllocation
    false,  // Proj
    true ,  // RShiftI
    true ,  // RShiftL
    false,  // Region
    true ,  // Rethrow
    true ,  // Return
    false,  // Root
    false,  // RoundDouble
    true ,  // RoundDoubleMode
    true ,  // RoundDoubleModeV
    false,  // RoundFloat
    true ,  // RotateLeft
    false,  // RotateLeftV
    true ,  // RotateRight
    false,  // RotateRightV
    true ,  // SafePoint
    false,  // SafePointScalarObject
    true ,  // ShenandoahCompareAndExchangeP
    true ,  // ShenandoahCompareAndExchangeN
    true ,  // ShenandoahCompareAndSwapN
    true ,  // ShenandoahCompareAndSwapP
    true ,  // ShenandoahWeakCompareAndSwapN
    true ,  // ShenandoahWeakCompareAndSwapP
    false,  // ShenandoahIUBarrier
    false,  // ShenandoahLoadReferenceBarrier
    false,  // SCMemProj
    true ,  // CopySignD
    true ,  // CopySignF
    true ,  // SignumD
    true ,  // SignumF
    true ,  // SqrtD
    true ,  // SqrtF
    false,  // Start
    false,  // StartOSR
    true ,  // StoreB
    true ,  // StoreC
    true ,  // StoreCM
    true ,  // StorePConditional
    true ,  // StoreIConditional
    true ,  // StoreLConditional
    true ,  // StoreD
    true ,  // StoreF
    true ,  // StoreI
    true ,  // StoreL
    true ,  // StoreP
    true ,  // StoreN
    true ,  // StoreNKlass
    true ,  // StrComp
    true ,  // StrCompressedCopy
    true ,  // StrEquals
    true ,  // StrIndexOf
    true ,  // StrIndexOfChar
    true ,  // StrInflatedCopy
    true ,  // SubD
    true ,  // SubF
    true ,  // SubI
    true ,  // SubL
    true ,  // TailCall
    true ,  // TailJump
    false,  // MacroLogicV
    true ,  // ThreadLocal
    false,  // Unlock
    false,  // URShiftB
    false,  // URShiftS
    true ,  // URShiftI
    true ,  // URShiftL
    true ,  // XorI
    true ,  // XorL
    false,  // Vector
    true ,  // AddVB
    true ,  // AddVS
    true ,  // AddVI
    true ,  // AddReductionVI
    true ,  // AddVL
    true ,  // AddReductionVL
    true ,  // AddVF
    true ,  // AddReductionVF
    true ,  // AddVD
    true ,  // AddReductionVD
    true ,  // SubVB
    true ,  // SubVS
    true ,  // SubVI
    true ,  // SubVL
    true ,  // SubVF
    true ,  // SubVD
    true ,  // MulVB
    true ,  // MulVS
    true ,  // MulVI
    true ,  // MulReductionVI
    true ,  // MulVL
    true ,  // MulReductionVL
    true ,  // MulVF
    true ,  // MulReductionVF
    true ,  // MulVD
    true ,  // MulReductionVD
    true ,  // MulAddVS2VI
    true ,  // FmaVD
    true ,  // FmaVF
    true ,  // DivVF
    true ,  // DivVD
    true ,  // AbsVB
    true ,  // AbsVS
    true ,  // AbsVI
    true ,  // AbsVL
    true ,  // AbsVF
    true ,  // AbsVD
    false,  // NegVI
    true ,  // NegVF
    true ,  // NegVD
    true ,  // SqrtVD
    true ,  // SqrtVF
    true ,  // LShiftCntV
    true ,  // RShiftCntV
    true ,  // LShiftVB
    true ,  // LShiftVS
    true ,  // LShiftVI
    true ,  // LShiftVL
    true ,  // RShiftVB
    true ,  // RShiftVS
    true ,  // RShiftVI
    true ,  // RShiftVL
    true ,  // URShiftVB
    true ,  // URShiftVS
    true ,  // URShiftVI
    true ,  // URShiftVL
    true ,  // AndV
    true ,  // AndReductionV
    true ,  // OrV
    true ,  // OrReductionV
    true ,  // XorV
    true ,  // XorReductionV
    true ,  // MinV
    true ,  // MaxV
    true ,  // MinReductionV
    true ,  // MaxReductionV
    true ,  // LoadVector
    true ,  // LoadVectorGather
    true ,  // LoadVectorGatherMasked
    true ,  // StoreVector
    true ,  // StoreVectorScatter
    true ,  // StoreVectorScatterMasked
    true ,  // LoadVectorMasked
    true ,  // StoreVectorMasked
    false,  // VectorCmpMasked
    true ,  // VectorMaskGen
    false,  // VectorMaskOp
    true ,  // VectorMaskTrueCount
    true ,  // VectorMaskFirstTrue
    true ,  // VectorMaskLastTrue
    true ,  // VectorMaskToLong
    false,  // Pack
    false,  // PackB
    false,  // PackS
    false,  // PackI
    false,  // PackL
    false,  // PackF
    false,  // PackD
    false,  // Pack2L
    false,  // Pack2D
    true ,  // ReplicateB
    true ,  // ReplicateS
    true ,  // ReplicateI
    true ,  // ReplicateL
    true ,  // ReplicateF
    true ,  // ReplicateD
    false,  // Extract
    true ,  // ExtractB
    false,  // ExtractUB
    false,  // ExtractC
    true ,  // ExtractS
    true ,  // ExtractI
    true ,  // ExtractL
    true ,  // ExtractF
    true ,  // ExtractD
    false,  // Digit
    false,  // LowerCase
    false,  // UpperCase
    false,  // Whitespace
    false,  // VectorBox
    false,  // VectorBoxAllocate
    false,  // VectorUnbox
    false,  // VectorMaskWrapper
    true ,  // VectorMaskCmp
    true ,  // VectorMaskCast
    true ,  // VectorTest
    true ,  // VectorBlend
    true ,  // VectorRearrange
    true ,  // VectorLoadMask
    true ,  // VectorLoadShuffle
    true ,  // VectorLoadConst
    true ,  // VectorStoreMask
    true ,  // VectorReinterpret
    false,  // VectorCast
    true ,  // VectorCastB2X
    true ,  // VectorCastS2X
    true ,  // VectorCastI2X
    true ,  // VectorCastL2X
    true ,  // VectorCastF2X
    true ,  // VectorCastD2X
    true ,  // VectorInsert
    true ,  // MaskAll
    true ,  // AndVMask
    true ,  // OrVMask
    true    // XorVMask
};


int Compile::sync_stack_slots() const { return 2; }

uint Matcher::stack_alignment_in_bytes() { return StackAlignmentInBytes; }

OptoReg::Name Matcher::return_addr() const { return OptoReg::stack2reg(- 2 +
              align_up((Compile::current()->in_preserve_stack_slots() +
                        Compile::current()->fixed_slots()),
                       stack_alignment_in_slots())); }

uint Compile::varargs_C_out_slots_killed() const { return frame::arg_reg_save_area_bytes/BytesPerInt; }

OptoRegPair Matcher::return_value(uint ideal_reg) {

#line 4140 "src/hotspot/cpu/aarch64/aarch64.ad"

    // TODO do we allow ideal_reg == Op_RegN???
    assert(ideal_reg >= Op_RegI && ideal_reg <= Op_RegL,
           "only return normal values");

    static const int lo[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      R0_num,                            // Op_RegN
      R0_num,                            // Op_RegI
      R0_num,                            // Op_RegP
      V0_num,                            // Op_RegF
      V0_num,                            // Op_RegD
      R0_num                             // Op_RegL
    };

    static const int hi[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      OptoReg::Bad,                      // Op_RegN
      OptoReg::Bad,                      // Op_RegI
      R0_H_num,                          // Op_RegP
      OptoReg::Bad,                      // Op_RegF
      V0_H_num,                          // Op_RegD
      R0_H_num                           // Op_RegL
    };

    return OptoRegPair(hi[ideal_reg], lo[ideal_reg]);
  
#line 48774 "ad_aarch64.cpp"

}

OptoRegPair Matcher::c_return_value(uint ideal_reg) {

#line 4140 "src/hotspot/cpu/aarch64/aarch64.ad"

    // TODO do we allow ideal_reg == Op_RegN???
    assert(ideal_reg >= Op_RegI && ideal_reg <= Op_RegL,
           "only return normal values");

    static const int lo[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      R0_num,                            // Op_RegN
      R0_num,                            // Op_RegI
      R0_num,                            // Op_RegP
      V0_num,                            // Op_RegF
      V0_num,                            // Op_RegD
      R0_num                             // Op_RegL
    };

    static const int hi[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      OptoReg::Bad,                      // Op_RegN
      OptoReg::Bad,                      // Op_RegI
      R0_H_num,                          // Op_RegP
      OptoReg::Bad,                      // Op_RegF
      V0_H_num,                          // Op_RegD
      R0_H_num                           // Op_RegL
    };

    return OptoRegPair(hi[ideal_reg], lo[ideal_reg]);
  
#line 48810 "ad_aarch64.cpp"

}

OptoReg::Name Matcher::inline_cache_reg() { return OptoReg::Name(R12_num); }

int Matcher::inline_cache_reg_encode() { return _regEncode[inline_cache_reg()]; }

OptoReg::Name Matcher::interpreter_frame_pointer_reg() { return OptoReg::Name(R29_num); }

OptoReg::Name Matcher::c_frame_pointer() const { return OptoReg::Name(R31_num); }

// Number of callee-save + always-save registers
int  Matcher::number_of_saved_registers() {
  return 0;
};

bool Compile::needs_deep_clone_jvms() { return false; }

// Check consistency of C++ compilation with ADLC options:
// Check adlc -DLINUX=1
#ifndef LINUX
#  error "LINUX must be defined"
#endif // LINUX
// Check adlc -D_GNU_SOURCE=1
#ifndef _GNU_SOURCE
#  error "_GNU_SOURCE must be defined"
#endif // _GNU_SOURCE
// Check adlc -DAARCH64=1
#ifndef AARCH64
#  error "AARCH64 must be defined"
#endif // AARCH64
// Check adlc -D_LP64=1
#ifndef _LP64
#  error "_LP64 must be defined"
#endif // _LP64
